#include <metal_stdlib>
#include <simd/simd.h>

using namespace metal;

struct buffer_t
{
    float4x4 u_Model;
    float4x4 u_TransposeInvModel;
    float4x4 u_MVP;
    float4x4 u_Projection;
    float4x4 u_View;
};

struct main0_out
{
    float3 v_posWS [[user(locn0)]];
    float3 v_nDirWS [[user(locn1)]];
    float3 v_tDirWS [[user(locn2)]];
    float3 v_bDirWS [[user(locn3)]];
    float2 v_uv0 [[user(locn4)]];
    float2 v_uv1 [[user(locn5)]];
    float4 v_color [[user(locn6)]];
    float4 gl_Position [[position]];
};

struct main0_in
{
    float3 attPosition [[attribute(0)]];
    float3 attNormal [[attribute(1)]];
    float3 attTangent [[attribute(2)]];
    float2 attTexcoord0 [[attribute(3)]];
    float2 attTexcoord1 [[attribute(4)]];
    float4 attColor [[attribute(5)]];
};

vertex main0_out main0(main0_in in [[stage_in]], constant buffer_t& buffer)
{
    main0_out out = {};
    out.v_uv0 = in.attTexcoord0;
    out.v_uv1 = in.attTexcoord1;
    out.v_posWS = (buffer.u_Model * float4(in.attPosition, 1.0)).xyz;
    out.v_nDirWS = float4(fast::normalize((buffer.u_TransposeInvModel * float4(in.attNormal, 0.0)).xyz), 0.0).xyz;
    out.v_tDirWS = (buffer.u_Model * float4(in.attTangent, 0.0)).xyz;
    out.v_bDirWS = cross(out.v_nDirWS, out.v_tDirWS);
    out.v_color = in.attColor;
    out.v_bDirWS = cross(out.v_nDirWS, out.v_tDirWS);
    out.gl_Position = ((buffer.u_Projection * buffer.u_View) * float4(out.v_posWS, 1.0)) + (buffer.u_MVP * float4(0.0));
    out.gl_Position.z = (out.gl_Position.z + out.gl_Position.w) * 0.5;       // Adjust clip-space for Metal
    return out;
}

