import Amaz = effect.Amaz;
import Mat4 from '../../math/mat4';
import { FaceType } from '../../base/const';
declare enum FaceProviderType {
    Human = 0,
    Pet = 1
}
declare const FaceTypeToProviderType: Map<FaceType, FaceProviderType>;
/**
 * @class
 * @category Algorithm
 * @name FaceMeshInfo
 * @classdesc A FaceMeshInfo class stores 3d head algorithm result including 3d vertexes, 3d landmarks, 3d normals, 3d tangents, 3d mvp, 3d modelMatrix and face 3d scale.
 * @description Constructor to create a new FaceMeshInfo instance.
 */
declare class FaceMeshInfo {
    vertexes: Amaz.Vec3Vector;
    landmarks: Amaz.Vec3Vector;
    normals: Amaz.Vec3Vector;
    tangents: Amaz.Vec3Vector;
    mvp: Mat4;
    modelMatrix: Mat4;
    scale: number;
    /**
     * @name FaceMeshInfo#vertexes
     * @description The 3d vertexs of the tracked face.
     * @type {Vec3Vector}
     * @readonly
     */
    /**
     * @name FaceMeshInfo#normals
     * @description The 3d normals of the tracked face.
     * @type {Vec3Vector}
     * @readonly
     */
    /**
     * @name FaceMeshInfo#tangents
     * @description The 3d tangents of the tracked face.
     * @type {Vec3Vector}
     * @readonly
     */
    /**
     * @name FaceMeshInfo#mvp
     * @description The 3d mvp of the tracked face.
     * @type {Mat4}
     * @readonly
     */
    /**
     * @name FaceMeshInfo#modelMatrix
     * @description The 3d modelMatrix of the tracked face.
     * @type {Mat4}
     * @readonly
     */
    /**
     * @name FaceMeshInfo#scale
     * @description The scale of the 3d tracked face.
     * @type {number}
     * @readonly
     */
    constructor();
}
export { FaceProviderType, FaceTypeToProviderType, FaceMeshInfo };
