import Amaz = effect.Amaz;
import { SegmentationType } from '../base/const';
import { CmdBufferHelper } from '../base/utils';
/**
 * @class
 * @category Algorithm
 * @name Segmentation
 * @classdesc Segmentation textures are images which can be used as masks to show or hide certain areas of an input image.
 * @description Create a Segmentation.
 * @augments EventHandler
 * @example
 * //head segmentation creates a masked image of the head of user.
 * let headMask = amg.Segmentation.getMask(amg.SegmentationType.Head)
 * @sdk 9.8.0
 */
export default class Segmentation {
    private static _instance;
    private _segProviderMap;
    private _cmdBufferHelper;
    static getInstance(): Segmentation;
    /**
     * @function
     * @name Segmentation#getMask
     * @description Get the full-screen grey-scale mask texture.
     * @param {SegmentationType} type - The type of segmentation algorithm.
     * @param {number} id - Context-based id.
     * @returns {Amaz.Texture | Amaz.RenderTexture} Texture that contains mask information.
     * @readonly
     * @static
     */
    static getMask(type: SegmentationType, id?: number): any;
    private constructor();
    init(): void;
    get cmdBufferHelper(): CmdBufferHelper;
    onUpdate(dt: number): void;
    createRenderTextureHelper(shaders: any): RenderTextureHelper;
    createNomralScreenShader(): any;
    private getMask;
}
declare class RenderTextureHelper {
    texture: Amaz.Texture2D;
    renderTexture: Amaz.RenderTexture;
    screenMaterial: Amaz.Material;
    constructor(texture: Amaz.Texture2D, renderTexture: Amaz.RenderTexture, screenMateria: Amaz.Material);
}
export {};
