import Amaz = effect.Amaz;
import SubMesh from './submesh';
import VertexAttributeMask from '../base/vertex-attribute-mask';
import { Primitive } from './const';
/**
 * @class
 * @category Rendering
 * @name AbstractMesh
 * @classdesc Abstract class of a mesh that contains all the required information of a mesh.
 * @description This class acts as an abstract class to Mesh and LineMesh class.
 * @sdk 9.8.0
 */
export default abstract class AbstractMesh {
    /**
     * @function
     * @name AbstractMesh#addSubMesh
     * @description Adds a new submesh to a mesh class.
     * @param {SubMesh} submesh Submesh to be added to the mesh.
     * @returns {SubMesh} Returns the newly create submesh.
     * @sdk 9.8.0
     */
    addSubMesh(submesh: SubMesh): SubMesh;
    /**
     * @name AbstractMesh#setSubMeshPrimitive
     * @description This function sets the primitive of a submesh owned by the mesh.
     * @param {number} index The index of submesh that primitive will be changed.
     * @param {Primitive} primitive Type of primitive submesh will be changed to.
     * @returns {void}
     * @sdk 9.8.0
     */
    setSubMeshPrimitive(index: number, primitive: Primitive): void;
    /**
     * @name AbstractMesh#getSubMesh
     * @description This function returns the submesh at the given index.
     * @param {number} index The index of submesh that will be rturned.
     * @returns {SubMesh | undefined} Returns the submesh at index. Returns undefined if submesh does not exist.
     * @sdk 9.8.0
     */
    getSubMesh(index: number): SubMesh | undefined;
    /**
     * @name AbstractMesh#getSubMeshCount
     * @description This function returns the number of sub-mesh in the mesh.
     * @returns {number} Number of submesh owned by a mesh.
     * @sdk 9.8.0
     */
    getSubMeshCount(): number;
    /**
     * @function
     * @name AbstractMesh#clearVertexData
     * @description Set bitmask for vertex data mask to zero and clear all vertes data properties (positions, uvs, ect.).
     * @returns {void}
     * @sdk 9.8.0
     */
    clearVertexData(): void;
    /**
     * @name AbstractMesh#mask
     * @type {VertexAttributeMask}
     * @description Bitmask used to signify if a mesh has a vertex attribute type (position, normal, tangents, etc.).
     * @sdk 9.8.0
     * @readonly
     */
    protected mask: VertexAttributeMask;
    /**
     * @name AbstractMesh#native
     * @type {Amaz.Mesh}
     * @description The Amaz.Mesh (JS RTTI) type of the Mesh class.
     * @sdk 9.8.0
     */
    native: Amaz.Mesh;
    /**
     * @name AbstractMesh#name
     * @type {string}
     * @description Identifier of mesh class.
     * @sdk 9.8.0
     */
    name: string;
    /**
     * @name AbstractMesh#submeshes
     * @type {Array<SubMesh>}
     * @description Array that holds all the submesh of the Mesh.
     * @sdk 9.8.0
     */
    private _submeshses;
    protected get submeshes(): Array<SubMesh>;
    protected set submeshes(submeshes: Array<SubMesh>);
}
