/**
 * @class
 * @category Core
 * @name EventHandler
 * @classdesc Base class that implements functionality for event handling
 * Inherit EventHandler to use its functionalities.
 * @sdk 9.8.0
 */
export default class EventHandler {
    _callbacks: any;
    private _callbackActive;
    constructor();
    private _addCallback;
    /**
     * @function
     * @name EventHandler#on
     * @description Attach an event handler to an event with the specified name.
     * @param {string} name
     * @param {any} callback
     * @param {any} scope
     * @returns {EventHandler} This instance for chaining.
     * @sdk 9.8.0
     */
    on(name: string, callback: any, scope?: any): EventHandler;
    /**
     * @function
     * @name EventHandler#off
     * @description Detach an event with a specific name, if there is no name provided, all the events are detached.
     * @param {string} name
     * @param {any} callback
     * @param {any} scope
     * @returns {EventHandler} This instance for chaining.
     * @sdk 9.8.0
     */
    off(name: string, callback: any, scope?: any): EventHandler;
    /**
     * @function
     * @name EventHandler#fire
     * @description Fire an event with a specified name,  the argument is passed to the event listener
     * @param {string} name
     * @param {any} arg1
     * @param {any} arg2
     * @param {any} arg3
     * @param {any} arg4
     * @param {any} arg5
     * @param {any} arg6
     * @param {any} arg7
     * @param {any} arg8
     * @returns {EventHandler} This instance for chaining.
     * @sdk 9.8.0
     */
    fire(name: string, arg1?: any, arg2?: any, arg3?: any, arg4?: any, arg5?: any, arg6?: any, arg7?: any, arg8?: any): EventHandler;
    /**
     * @function
     * @name EventHandler#once
     * @description Attach an event handler to an event. This handler will be removed after being fired once.
     * @param {string} name
     * @param {any} callback
     * @param {any} scope
     * @returns {EventHandler} This instance for chaining.
     * @sdk 9.8.0
     */
    once(name: string, callback: any, scope?: any): EventHandler;
    /**
     * @function
     * @name EventHandler#hasEvent
     * @description Test if there are any handlers bound to an event name.
     * @param {string} name
     * @returns {boolean} True if the object has handlers bound to the specified event name.
     * @sdk 9.8.0
     */
    hasEvent(name: string): boolean;
}
