import Amaz = effect.Amaz;
import { Primitive } from './const';
import AbstractMesh from './abstract-mesh';
import Vec3 from '../math/vec3';
import Color from '../math/color';
/**
 * @interface
 * @name LineMeshData
 * @description Line mesh data used to create line meshes.
 * @sdk 9.8.0
 */
export interface LineMeshData {
    positions: Array<Vec3>;
    colors: Array<Color>;
    submeshes: Array<number> | Array<Array<number>>;
}
interface LineMeshOptions {
    primitive: Primitive;
    customIndices: boolean;
    offset: number;
    vertCount: number;
}
/**
 * @class
 * @category Rendering
 * @name LineMesh
 * @augments AbstractMesh
 * @classdesc LineMesh Class contains all vertex data a mesh has.
 * @description This class is used to represent line mesh in Amazing JS and gives the ability of updating vertex data and create new custom line meshes.
 * @param {Amaz.Mesh | undefined} native The Amaz.Mesh class used to initialize Mesh class.
 *                                       If undefined, create a new Amaz.Mesh
 * @sdk 9.8.0
 */
export default class LineMesh extends AbstractMesh {
    /**
     * @name LineMesh#populateVertexDesc
     * @type {LineMesh}
     * @description This builds and add the required vertex data descriptions for the mesh.
     * @param {LineMeshData} data The line mesh vertex data (positions and colors) of the line mesh.
     * @returns {void}
     * @sdk 9.8.0
     */
    protected populateVertexDesc(data: LineMeshData): void;
    constructor();
    constructor(native: Amaz.Mesh);
    constructor(lineMeshData: LineMeshData);
    constructor(lineMeshData: LineMeshData, lineMeshOptions: LineMeshOptions);
}
export {};
