import Amaz = effect.Amaz;
import AABB from '../math/aabb';
import Vec2 from '../math/vec2';
import Vec3 from '../math/vec3';
import Vec4 from '../math/vec4';
import Color from '../math/color';
import { Primitive } from './const';
import AbstractMesh from './abstract-mesh';
/**
 * @interface
 * @name MeshData
 * @description Mesh data used to create mesh.
 * @sdk 9.8.0
 */
export interface MeshData {
    positions: Array<Vec3>;
    colors: Array<Color>;
    uvs: Array<Vec2>;
    uv3ds: Array<Vec3>;
    normals: Array<Vec3>;
    tangents: Array<Vec4>;
    calculateTangents: boolean;
    submeshes: Array<number> | Array<Array<number>>;
}
export interface MeshOptions {
    primitive: Primitive;
    customIndices: boolean;
    offset: number;
    vertCount: number;
}
/**
 * @class
 * @category Rendering
 * @name Mesh
 * @augments AbstractMesh
 * @classdesc Mesh Class contains all vertex data a mesh has and its AABB.
 * @description This class is used to represent mesh in Amazing JS and gives the ability of updating vertex data and create new custom meshes.
 * @param {Amaz.Mesh | undefined} native Used to intiazlize mesh class with existing Amaz.Mesh class.
 * @sdk 9.8.0
 */
export default class Mesh extends AbstractMesh {
    /**
     * @name Mesh#populateVertexDesc
     * @description This builds and add the required vertex data descriptions for the mesh.
     * @param {MeshData} data The mesh vertex data (positions, uvs, normals, etc.) of the mesh.
     * @returns {void}
     * @sdk 9.8.0
     */
    protected populateVertexDesc(data: MeshData): void;
    constructor();
    constructor(native: Amaz.Mesh);
    constructor(meshData?: MeshData);
    constructor(meshData: MeshData, meshOptions: MeshOptions);
    /**
     * @name Mesh#calculateAABB
     * @type {AABB}
     * @description This function calculates the AABB of a mesh based on a submesh vertex position.
     * @returns {void}
     * @sdk 9.8.0
     */
    calculateAABB(): void;
    /**
     * @name Mesh#calculateTangents
     * @type {Array<Vec4>}
     * @description This function calculates the tangents of every vertex in the mesh.
     * @returns {Array<Vec4>} Returns the newly calcualted tangents
     * @sdk 9.8.0
     */
    calculateTangents(): Array<Vec4>;
    /**
     * @name Mesh#aabb
     * @type {AABB}
     * @description AABB that encapsulates mesh.
     * @sdk 9.8.0
     */
    private _aabb;
    get aabb(): AABB;
    set aabb(aabb: AABB);
}
