import Amaz = effect.Amaz;
import Texture, { WrapMode, FilterMode } from '../base/texture';
import DrawTexture from '../base/draw-texture';
import { ImagePixelFormat, MSAAMode, RenderTextureAttachment } from './const';
/**
 * @class
 * @category Rendering
 * @name RenderTexture
 * @augments Texture
 * @classdesc RenderTexutre class.
 * @description RenderTexture class that represents Amaz.RenderTexture class in Amazing JS.
 * @param {Amaz.RenderTexture | Amaz.Texture | undefined } native TThe Amaz.Texture or Amaz.RenderTexture that can be used to intialize Texture class.
 * @param { number } width Width of redner texture.
 * @param { number } height Height of redner texture.
 * @param { number } depth Depth of redner texture.
 * @param { WrapMode } wrapMode Wrap mode of redner texture.
 * @param { FilterMode } filterMode Filter mode of redner texture.
 * @sdk 9.8.0
 */
export default class RenderTexture extends Texture {
    constructor(native?: Amaz.RenderTexture | undefined, height?: number, width?: number, depth?: number, wrapMode?: WrapMode | undefined, filterMode?: FilterMode | undefined);
    /**
     * @name RenderTexture#native
     * @type {Amaz.RenderTexture}
     * @description The Amaz.RenderTexture (JS RTTI) type of the RenderTexture class.
     * @sdk 9.8.0
     */
    native: Amaz.RenderTexture;
    /**
     * @name RenderTexture#attachmenet
     * @type {RenderTextureAttachment}
     * @description The render texture attachment.
     * @sdk 9.8.0
     */
    private _attachment;
    get attachment(): RenderTextureAttachment;
    set attachment(attachment: RenderTextureAttachment);
    /**
     * @name RenderTexture#inputTexture
     * @type {Texture}
     * @description Input texture for the render texture.
     * @sdk 9.8.0
     */
    private _inputTexture;
    get inputTexture(): Texture;
    set inputTexture(texture: Texture);
    /**
     * @name RenderTexture#massMode
     * @type {MSAAMode}
     * @description Multi sample anti-aliasing mode used for render texture.
     * @sdk 9.8.0
     */
    private _massMode;
    get massMode(): MSAAMode;
    set massMode(massMode: MSAAMode);
    /**
     * @name RenderTexture#colorFormat
     * @type {ImagePixelFormat}
     * @description Color format used for render texture.
     * @sdk 9.8.0
     */
    private _colorFormat;
    get colorFormat(): ImagePixelFormat;
    set colorFormat(colorFormat: ImagePixelFormat);
    /**
     * @name RenderTexture#realColorFormat
     * @type {ImagePixelFormat}
     * @description Real color format used for render texture.
     * @sdk 9.8.0
     */
    private _realColorFormat;
    get realColorFormat(): ImagePixelFormat;
    set realColorFormat(realColorFormat: ImagePixelFormat);
    /**
     * @name RenderTexture#depthTexture
     * @type {DrawTexture}
     * @description Depth texture in render texture.
     * @sdk 9.8.0
     */
    private _depthTexture;
    get depthTexture(): DrawTexture;
    set depthTexture(texture: DrawTexture);
    /**
     * @name RenderTexture#stencilTexture
     * @type {DrawTexture}
     * @description Stencil texture in render texture.
     * @sdk 9.8.0
     */
    private _stencilTexture;
    get stencilTexture(): DrawTexture;
    set stencilTexture(texture: DrawTexture);
}
