import Amaz = effect.Amaz;
import { Primitive } from './const';
import AbstractMesh from './abstract-mesh';
/**
 * @class
 * @category Rendering
 * @name SubMesh
 * @classdesc A SubMesh class wraps the Amaz.SubMesh class of JS RTTI.
 * @description Constructor to create an SubMesh instance.
 * @param {AbstractMesh} owner The owner of SubMesh (either a LineMesh or a Mesh).
 * @param {Amaz.SubMesh | undefined} native Initializes SubMesh Amaz.SubMesh owned by the SubMesh class using the given native class.
 * @sdk 9.8.0
 */
export default class SubMesh {
    constructor(native?: Amaz.SubMesh | undefined);
    /**
     * @name SubMesh#native
     * @type {Amaz.SubMesh}
     * @description Native is the native version of SubMesh class (Amaz.SubMesh)
     * @sdk 9.8.0
     */
    native: Amaz.SubMesh;
    /**
     * @name SubMesh#name
     * @type {string}
     * @description Identifier of sub-mesh class.
     * @sdk 9.8.0
     */
    name: string;
    /**
     * @name SubMesh#setIndices
     * @description Sets the indices array to the sub-mesh.
     * @param {Array<number>} indices Array of indices used by the sub-mesh.
     * @sdk 9.8.0
     */
    setIndices(indices: Array<number>): void;
    /**
     * @name SubMesh#primitive
     * @type {Primitive}
     * @description Mesh topology of the sub-mesh.
     * @sdk 9.8.0
     */
    private _primitive;
    get primitive(): Primitive;
    set primitive(primitive: Primitive);
    /**
     * @name SubMesh#mesh
     * @type {AbstractMesh}
     * @description Mesh that owns the SubMesh class.
     * @sdk 9.8.0
     */
    private _mesh;
    get mesh(): AbstractMesh | undefined;
    set mesh(mesh: AbstractMesh | undefined);
}
