import VertexAttribType = effect.Amaz.VertexAttribType;
/**
 * @class
 * @category Rendering
 * @name VertexAttributeMask
 * @classdesc Class that represents mask that shows what vertex attributes is avaliable in a mesh.
 * @description Initializes mask to 0: no attributes is mapped.
 * @sdk 9.8.0
 */
export default class VertexAttributeMask {
    constructor();
    /**
     * @function
     * @name VertexAttributeMask#setAttribute
     * @param {VertexAttribType} pos bit position of vertex attribute.
     * @param {boolean} value sets bit to true if vertex attribute exists and false if it does not.
     * @description set bit to true if attribute exist and false if it does not.
     * @returns {void}.
     * @sdk 9.8.0
     */
    setAttribute(pos: VertexAttribType, value: boolean): void;
    /**
     * @function
     * @name VertexAttributeMask#hasAttribute
     * @param {VertexAttribType} pos bit position of vertex attribute.
     * @description get bit of vertex attribute mask to deterimine if vertex attribute has a vertex data type.
     * @returns {boolean} returns true if vertex attribute exists in mesh.
     * @sdk 9.8.0
     */
    hasAttribute(pos: VertexAttribType): boolean;
    /**
     * @function
     * @name VertexAttributeMask#reset
     * @description reset the vertex bitmask
     * @returns {void}}.
     * @sdk 9.8.0
     */
    reset(): void;
    /**
     * @name VertexAttributeMask#vertexAttributeMapped
     * @type {number}
     * @description Mask that indicates vertex attribute mapped.
     * @sdk 9.8.0
     */
    private vertexAttributeMapped;
    /**
     * @name VertexAttributeMask#attributeCount
     * @type {number}
     * @description Number of vertex attribute mask set to true.
     * @sdk 9.8.0
     */
    private _attributeCount;
    get attributeCount(): number;
    set attributeCount(count: number);
}
