import SceneObject from '../scene/scene-object';
import Component from '../component/component';
interface AlignmentOptions {
    target?: SceneObject;
    leftTarget?: SceneObject;
    rightTarget?: SceneObject;
    topTarget?: SceneObject;
    bottomTarget?: SceneObject;
    leftAnchor: number;
    rightAnchor: number;
    topAnchor: number;
    bottomAnchor: number;
    leftOffset: number;
    rightOffset: number;
    topOffset: number;
    bottomOffset: number;
}
/**
 * @class
 * @category Component
 * @name AlignmentComponent
 * @augments Component
 * @classdesc AlignmentComponent class for aligning UI sceneObjects.
 * @description Constructor to create an AlignmentComponent instance.
 * To add an AlignmentComponent to an {@link SceneObject},
 * use {@link SceneObject#addComponent}.
 * @param {SceneObject} sceneObject - The sceneObject.
 * @param {object} options - Options to create AlignmentComponent.
 * @example
 * // add AlignmentComponent to sceneObject
 * sceneObject.addComponent('Alignment', options);
 * @hideconstructor
 * @sdk 9.8.0
 */
export default class AlignmentComponent extends Component {
    static register(): void;
    static nativeClasses: Array<string>;
    constructor(sceneObject?: SceneObject, options?: AlignmentOptions);
    static fromNative(sceneObject: SceneObject, native: any): AlignmentComponent;
    protected getProps(): Array<string>;
    /**
     * @name AlignmentComponent#target
     * @type {SceneObject}
     * @description Target sceneObject to align with.
     * It is used for left/right/top/bottom targets if they are not set.
     * @sdk 9.8.0
     */
    set target(value: SceneObject);
    /**
     * @name AlignmentComponent#leftTarget
     * @type {SceneObject}
     * @description Left target sceneObject to align with.
     * @sdk 9.8.0
     */
    set leftTarget(value: SceneObject);
    /**
     * @name AlignmentComponent#rightTarget
     * @type {SceneObject}
     * @description Right target sceneObject to align with.
     * @sdk 9.8.0
     */
    set rightTarget(value: SceneObject);
    /**
     * @name AlignmentComponent#bottomTarget
     * @type {SceneObject}
     * @description Bottom target sceneObject to align with.
     * @sdk 9.8.0
     */
    set bottomTarget(value: SceneObject);
    /**
     * @name AlignmentComponent#topTarget
     * @type {SceneObject}
     * @description Top target sceneObject to align with.
     * @sdk 9.8.0
     */
    set topTarget(value: SceneObject);
    /**
     * @name AlignmentComponent#leftAnchor
     * @type {number}
     * @description Left anchor(0.0-1.0). Percentage of the size of the target.
     * @sdk 9.8.0
     */
    get leftAnchor(): number;
    set leftAnchor(value: number);
    /**
     * @name AlignmentComponent#rightAnchor
     * @type {number}
     * @description Right anchor(0.0-1.0). Percentage of the size of the target.
     * @sdk 9.8.0
     */
    get rightAnchor(): number;
    set rightAnchor(value: number);
    /**
     * @name AlignmentComponent#topAnchor
     * @type {number}
     * @description Top anchor(0.0-1.0). Percentage of the size of the target.
     * @sdk 9.8.0
     */
    get topAnchor(): number;
    set topAnchor(value: number);
    /**
     * @name AlignmentComponent#bottomAnchor
     * @type {number}
     * @description Bottom anchor(0.0-1.0). Percentage of the size of the target.
     * @sdk 9.8.0
     */
    get bottomAnchor(): number;
    set bottomAnchor(value: number);
    /**
     * @name AlignmentComponent#leftOffset
     * @type {number}
     * @description Left offset(in pixels). Offset from target's anchor.
     * @sdk 9.8.0
     */
    get leftOffset(): number;
    set leftOffset(value: number);
    /**
     * @name AlignmentComponent#rightOffset
     * @type {number}
     * @description Right offset(in pixels). Offset from target's anchor.
     * @sdk 9.8.0
     */
    get rightOffset(): number;
    set rightOffset(value: number);
    /**
     * @name AlignmentComponent#topOffset
     * @type {number}
     * @description Top offset(in pixels). Offset from target's anchor.
     * @sdk 9.8.0
     */
    get topOffset(): number;
    set topOffset(value: number);
    /**
     * @name AlignmentComponent#bottomOffset
     * @type {number}
     * @description Bottom offset(in pixels). Offset from target's anchor.
     * @sdk 9.8.0
     */
    get bottomOffset(): number;
    set bottomOffset(value: number);
}
export {};
