import Component from './component';
import SceneObject from '../scene/scene-object';
import Audio from '../base/audio';
interface AudioOptions {
    audio: Audio;
    autoPlay: boolean;
    loop: boolean;
}
/**
 * @class
 * @category Component
 * @name AudioComponent
 * @augments Component
 * @classdesc AudioComponent class for playing audio.
 * @description Constructor to create an AudioComponent instance.
 * To add an AudioComponent to an {@link SceneObject},
 * use {@link SceneObject#addComponent}.
 * @param {SceneObject} sceneObject - The sceneObject.
 * @param {object} options - Options to create AudioComponent.
 * @example
 * // add AudioComponent to sceneObject
 * sceneObject.addComponent('audio', options);
 * @hideconstructor
 * @sdk 9.8.0
 */
export default class AudioComponent extends Component {
    static register(): void;
    static nativeClasses: Array<string>;
    constructor(sceneObject?: SceneObject, options?: AudioOptions);
    static fromNative(sceneObject: SceneObject, native: any): AudioComponent;
    protected getProps(): Array<string>;
    /**
     * @name AudioComponent#audio
     * @type {Audio}
     * @description The audio clip.
     * @sdk 9.8.0
     */
    get audio(): Audio;
    set audio(value: Audio);
    /**
     * @name AudioComponent#autoPlay
     * @type {boolean}
     * @description Flag to auto play on awake.
     * @sdk 9.8.0
     */
    get autoPlay(): boolean;
    set autoPlay(value: boolean);
    /**
     * @name AudioComponent#loop
     * @type {boolean}
     * @description Flag for looping.
     * @sdk 9.8.0
     */
    get loop(): boolean;
    set loop(value: boolean);
    /**
     * @function
     * @name AudioComponent#play
     * @description Play audio.
     * @sdk 9.8.0
     */
    play(): void;
    /**
     * @function
     * @name AudioComponent#stop
     * @description Stop audio.
     * @sdk 9.8.0
     */
    stop(): void;
    /**
     * @function
     * @name AudioComponent#pause
     * @description Pause audio.
     * @sdk 9.8.0
     */
    pause(): void;
    /**
     * @function
     * @name AudioComponent#resume
     * @description Resume audio.
     * @sdk 9.8.0
     */
    resume(): void;
    /**
     * @function
     * @name AudioComponent#reset
     * @description Reset audio.
     * @sdk 9.8.0
     */
    reset(): void;
}
export {};
