import SceneObject from '../scene/scene-object';
import { UIControlOptions, UIControlComponent } from './ui-control-component';
declare type ButtonOptions = UIControlOptions;
/**
 * @class
 * @category Component
 * @name ButtonComponent
 * @augments UIControlComponent
 * @classdesc ButtonComponent class for UI Button.
 * @description Constructor to create an ButtonComponent instance.
 * To add an ButtonComponent to an {@link SceneObject},
 * use {@link SceneObject#addComponent}.
 * @param {SceneObject} sceneObject - The sceneObject.
 * @param {object} options - Options to create ButtonComponent.
 * @example
 * // add ButtonComponent to sceneObject
 * sceneObject.addComponent('Button', options);
 * @hideconstructor
 * @sdk 9.8.0
 */
export default class ButtonComponent extends UIControlComponent {
    static register(): void;
    static nativeClasses: Array<string>;
    constructor(sceneObject?: SceneObject, options?: ButtonOptions);
    /**
     * @function
     * @name ButtonComponent#destroy
     * @description Destroy and clean up the component.
     * @sdk 9.8.0
     */
    destroy(): void;
    static fromNative(sceneObject: SceneObject, native: any): ButtonComponent;
    protected getProps(): Array<string>;
    private registerCallbacks;
    private removeCallbacks;
    /**
     * @event
     * @name ButtonComponent#click
     * @description Fired when button is clicked.
     * @param {SceneObject} button - The clicked button sceneObject.
     * @example
     * sceneObject.button.on('click', function () {
     *     console.log('Button clicked');
     * });
     * @sdk 9.8.0
     */
    private onClicked;
}
export {};
