import Component from './component';
import SceneObject from '../scene/scene-object';
import { CanvasBlendMode, CanvasMaskType, CanvasRenderOrder } from '../base/const';
interface CanvasOptions {
    blendMode?: CanvasBlendMode;
    alpha?: number;
    alphaBlending?: boolean;
    maskType?: CanvasMaskType;
    clipping?: boolean;
    renderOrder?: CanvasRenderOrder;
}
/**
 * @class
 * @category Component
 * @name CanvasComponent
 * @augments Component
 * @classdesc CanvasComponent class for 2d rendering.
 * @description Constructor to create an CanvasComponent instance.
 * To add an CanvasComponent to an {@link SceneObject},
 * use {@link SceneObject#addComponent}.
 * @param {SceneObject} sceneObject - The sceneObject.
 * @param {object} options - Options to create CanvasComponent.
 * @example
 * // add CanvasComponent to sceneObject
 * sceneObject.addComponent('Canvas', options);
 * @hideconstructor
 * @sdk 9.8.0
 */
export default class CanvasComponent extends Component {
    static register(): void;
    static nativeClasses: Array<string>;
    constructor(sceneObject?: SceneObject, options?: CanvasOptions);
    static fromNative(sceneObject: SceneObject, native: any): CanvasComponent;
    protected getProps(): Array<string>;
    /**
     * @name CanvasComponent#blendMode
     * @type {amg.CanvasBlendMode}
     * @description The canvas's blending mode.
     * @sdk 9.8.0
     */
    get blendMode(): CanvasBlendMode;
    set blendMode(value: CanvasBlendMode);
    /**
     * @name CanvasComponent#maskType
     * @type {amg.CanvasMaskType}
     * @description The canvas's mask type.
     * @sdk 9.8.0
     */
    get maskType(): CanvasMaskType;
    set maskType(value: CanvasMaskType);
    /**
     * @name CanvasComponent#renderOrder
     * @type {amg.CanvasRenderOrder}
     * @description The canvas's render order.
     * @sdk 9.8.0
     */
    get renderOrder(): CanvasRenderOrder;
    set renderOrder(value: CanvasRenderOrder);
    /**
     * @name CanvasComponent#alpha
     * @type {number}
     * @description The canvas's alpha.
     * @sdk 9.8.0
     */
    get alpha(): number;
    set alpha(value: number);
    /**
     * @name CanvasComponent#clipping
     * @type {boolean}
     * @description The canvas's clipping flag.
     * @sdk 9.8.0
     */
    get clipping(): boolean;
    set clipping(value: boolean);
    /**
     * @name CanvasComponent#alphaBlending
     * @type {boolean}
     * @description The canvas's alpha blending flag.
     * @sdk 9.8.0
     */
    get alphaBlending(): boolean;
    set alphaBlending(value: boolean);
    /**
     * @function
     * @name CanvasComponent#getDrawCallCount
     * @description Find child sceneObject by name.
     * @returns {number} Number of draw calls.
     * @sdk 9.8.0
     */
    getDrawCallCount(): number;
}
export {};
