import Component from './component';
import SceneObject from '../scene/scene-object';
import { CanvasScalerType } from '../base/const';
import Vec2 from '../math/vec2';
interface CanvasScalerOptions {
    type?: CanvasScalerType;
    size?: Vec2;
}
/**
 * @class
 * @category Component
 * @name CanvasScalerComponent
 * @augments Component
 * @classdesc CanvasScalerComponent class for configure the design resolution.
 * @description Constructor to create an CanvasScalerComponent instance.
 * To add an CanvasScalerComponent to an {@link SceneObject},
 * use {@link SceneObject#addComponent}.
 * @param {SceneObject} sceneObject - The sceneObject.
 * @param {object} options - Options to create CanvasScalerComponent.
 * @example
 * // add CanvasScalerComponent to sceneObject
 * sceneObject.addComponent('CanvasScaler', options);
 * @hideconstructor
 * @sdk 9.8.0
 */
export default class CanvasScalerComponent extends Component {
    static register(): void;
    static nativeClasses: Array<string>;
    constructor(sceneObject?: SceneObject, options?: CanvasScalerOptions);
    static fromNative(sceneObject: SceneObject, native: any): CanvasScalerComponent;
    protected getProps(): Array<string>;
    /**
     * @name CanvasScalerComponent#type
     * @type {amg.CanvasScalerType}
     * @description Canvas's type.
     * @sdk 9.8.0
     */
    get type(): CanvasScalerType;
    set type(value: CanvasScalerType);
    /**
     * @name CanvasScalerComponent#size
     * @type {Vec2}
     * @description Canvas's size (in pixels).
     * @sdk 9.8.0
     */
    get size(): Vec2;
    set size(value: Vec2);
}
export {};
