import SceneObject from '../scene/scene-object';
import Component from './component';
import Vec3 from '../math/vec3';
import { Collider3DType } from '../base/const';
interface Collider3DOptions {
    type: Collider3DType;
    offset?: Vec3;
    halfExtents?: Vec3;
    radius?: number;
    height?: number;
}
/**
 * @class
 * @category Component
 * @name Collider3DComponent
 * @augments Component
 * @classdesc Collider3DComponent class for 3d collision shapes.
 * @description Constructor to create an Collider3DComponent instance.
 * To add an Collider3DComponent to an {@link SceneObject},
 * use {@link SceneObject#addComponent}.
 * @param {SceneObject} sceneObject - The sceneObject.
 * @param {object} options - Options to create Collider3DComponent.
 * @param {amg.Collider3DType} options.type - Collider's type.
 * @example
 * // add Collider3DComponent to sceneObject
 * sceneObject.addComponent('Collider', options);
 * @hideconstructor
 * @sdk 9.8.0
 */
export default class Collider3DComponent extends Component {
    static register(): void;
    static nativeClasses: Array<string>;
    type: Collider3DType;
    constructor(sceneObject?: SceneObject, options?: Collider3DOptions);
    static fromNative(sceneObject: SceneObject, native: any): Collider3DComponent;
    /**
     * @name Collider3DComponent#offset
     * @type {Vec3}
     * @description Offset from sceneObject's position.
     * @sdk 9.8.0
     */
    get offset(): Vec3;
    set offset(value: Vec3);
    /**
     * @name Collider3DComponent#radius
     * @type {number}
     * @description Collider's radius.
     * @sdk 9.8.0
     */
    get radius(): number;
    set radius(value: number);
    /**
     * @name Collider3DComponent#height
     * @type {number}
     * @description Collider's height.
     * @sdk 9.8.0
     */
    get height(): number;
    set height(value: number);
    /**
     * @name Collider3DComponent#halfExtents
     * @type {Vec3}
     * @description Collider's halfExtents.
     * @sdk 9.8.0
     */
    get halfExtents(): Vec3;
    set halfExtents(value: Vec3);
}
export {};
