import EventHandler from '../base/event-handler';
import Amaz = effect.Amaz;
import SceneObject from '../scene/scene-object';
/**
 * @class
 * @category Core
 * @name Component
 * @augments EventHandler
 * @classdesc Abstract Component class for adding capabilities to an {@link SceneObject}.
 * @description Constructor to create an Component instance.
 * To add an Component to a {@link SceneObject},
 * use {@link SceneObject#addComponent}:
 * @hideconstructor
 * @sdk 9.8.0
 */
export default abstract class Component extends EventHandler {
    private static _typeToComponent;
    private static _nativeToComponent;
    static registerComponentType(type: string, natives: string[], component: any): void;
    static getComponentFromType(type: string): Component | undefined;
    static getComponentFronNative(native: Amaz.Component): Component | undefined;
    native: any;
    nativeClass: string | undefined;
    [key: string]: any;
    sceneObject: SceneObject | undefined;
    constructor(sceneObject?: SceneObject, nativeClass?: string);
    protected initialize(options: any, props: any): void;
    protected initWithNative(sceneObject: SceneObject, native: any, nativeClass: string): void;
    /**
     * @function
     * @name Component#destroy
     * @description Destroy and clean up the component.
     * @sdk 9.8.0
     */
    destroy(): void;
    protected addListener(eventType: number, callback: (body: any, collision: any) => void, callbackThis: any): void;
    protected removeListener(eventType: number, callback: (body: any, collision: any) => void): void;
    /**
     * @name Component#enabled
     * @type {boolean}
     * @description The flag to enable/disable component.
     * @sdk 9.8.0
     */
    get enabled(): boolean;
    set enabled(value: boolean);
}
