import Vec3 from '../math/vec3';
import SceneObject from '../scene/scene-object';
import Component from './component';
interface GenericJoint3DOptions {
    otherSceneObject?: SceneObject;
    linearLowerLimit?: Vec3;
    linearUpperLimit?: Vec3;
    angularLowerLimit?: Vec3;
    angularUpperLimit?: Vec3;
    positionOffset?: Vec3;
    otherPositionOffset?: Vec3;
    rotationOffset?: Vec3;
    otherRotationOffset?: Vec3;
    linearCorrection?: number;
    linearSoftness?: number;
    angularCorrection?: number;
    angularSoftness?: number;
}
/**
 * @class
 * @category Component
 * @name GenericJoint3DComponent
 * @augments Component
 * @classdesc GenericJoint3DComponent class for simulating physics 3d generic joint.
 * @description Constructor to create an GenericJoint3DComponent instance.
 * To add an GenericJoint3DComponent to an {@link SceneObject},
 * use {@link SceneObject#addComponent}.
 * @param {SceneObject} sceneObject - The sceneObject.
 * @param {object} options - Options to create GenericJoint3DComponent.
 * @example
 * // add GenericJoint3DComponent to sceneObject
 * sceneObject.addComponent('GenericJoint', options);
 * @hideconstructor
 * @sdk 9.8.0
 */
export default class GenericJoint3DComponent extends Component {
    static register(): void;
    static nativeClasses: Array<string>;
    constructor(sceneObject?: SceneObject, options?: GenericJoint3DOptions);
    static fromNative(sceneObject: SceneObject, native: any): GenericJoint3DComponent;
    protected getProps(): Array<string>;
    /**
     * @name GenericJoint3DComponent#otherSceneObject
     * @type {SceneObject}
     * @description Other connected sceneObject.
     * @readonly
     * @sdk 9.8.0
     */
    set otherSceneObject(value: SceneObject);
    set linearLowerLimit(value: Vec3);
    /**
     * @name GenericJoint3DComponent#linearLowerLimit
     * @type {Vec3}
     * @description Joint's linear lower limit.
     * @readonly
     * @sdk 9.8.0
     */
    get linearLowerLimit(): Vec3;
    set linearUpperLimit(value: Vec3);
    /**
     * @name GenericJoint3DComponent#linearUpperLimit
     * @type {Vec3}
     * @description Joint's linear upper limit.
     * @readonly
     * @sdk 9.8.0
     */
    get linearUpperLimit(): Vec3;
    set angularLowerLimit(value: Vec3);
    /**
     * @name GenericJoint3DComponent#angularLowerLimit
     * @type {Vec3}
     * @description Joint's angular lower limit.
     * @readonly
     * @sdk 9.8.0
     */
    get angularLowerLimit(): Vec3;
    set angularUpperLimit(value: Vec3);
    /**
     * @name GenericJoint3DComponent#angularUpperLimit
     * @type {Vec3}
     * @description Joint's angular upper limit.
     * @readonly
     * @sdk 9.8.0
     */
    get angularUpperLimit(): Vec3;
    set positionOffset(value: Vec3);
    /**
     * @name GenericJoint3DComponent#positionOffset
     * @type {Vec3}
     * @description Joint's position offset.
     * @readonly
     * @sdk 9.8.0
     */
    get positionOffset(): Vec3;
    set otherPositionOffset(value: Vec3);
    /**
     * @name GenericJoint3DComponent#otherPositionOffset
     * @type {Vec3}
     * @description Other sceneObject's position offset.
     * @readonly
     * @sdk 9.8.0
     */
    get otherPositionOffset(): Vec3;
    set rotationOffset(value: Vec3);
    /**
     * @name GenericJoint3DComponent#rotationOffset
     * @type {Vec3}
     * @description Joint's rotation offset.
     * @readonly
     * @sdk 9.8.0
     */
    get rotationOffset(): Vec3;
    set otherRotationOffset(value: Vec3);
    /**
     * @name GenericJoint3DComponent#otherRotationOffset
     * @type {Vec3}
     * @description Other sceneObject's rotation offset.
     * @readonly
     * @sdk 9.8.0
     */
    get otherRotationOffset(): Vec3;
    set linearCorrection(value: number);
    /**
     * @name GenericJoint3DComponent#linearCorrection
     * @type {number}
     * @description Joint's linear correction.
     * @readonly
     * @sdk 9.8.0
     */
    get linearCorrection(): number;
    set linearSoftness(value: number);
    /**
     * @name GenericJoint3DComponent#linearSoftness
     * @type {number}
     * @description Joint's linear softness.
     * @readonly
     * @sdk 9.8.0
     */
    get linearSoftness(): number;
    set angularCorrection(value: number);
    /**
     * @name GenericJoint3DComponent#angularCorrection
     * @type {number}
     * @description Joint's angular correction.
     * @readonly
     * @sdk 9.8.0
     */
    get angularCorrection(): number;
    set angularSoftness(value: number);
    /**
     * @name GenericJoint3DComponent#angularSoftness
     * @type {number}
     * @description Joint's angular softness.
     * @readonly
     * @sdk 9.8.0
     */
    get angularSoftness(): number;
}
export {};
