import Amaz = effect.Amaz;
import SceneObject from '../scene/scene-object';
import Vec2 from '../math/vec2';
import { ImageRenderMode, ImageFillType } from '../base/const';
import { WidgetOptions, WidgetComponent } from './widget-component';
import Color from '../math/color';
import Texture from '../base/texture';
import ImageAtlas from '../base/image-atlas';
interface ImageOptions extends WidgetOptions {
    renderMode: ImageRenderMode;
    color?: Color;
    texture?: Amaz.Texture;
    atlas?: Amaz.ImageAtlas;
    atlasIndex?: number;
    filledType?: ImageFillType;
    filledStart?: number;
    filledRange?: number;
    slicedLeft?: number;
    slicedRight?: number;
    slicedTop?: number;
    slicedBottom?: number;
    slicedFillCenter?: boolean;
    ellipseWidth?: number;
    ellipseHeight?: number;
    freeTopLeft?: Vec2;
    freeTopRight?: Vec2;
    freeBottomLeft?: Vec2;
    freeBottomRight?: Vec2;
    cornerTopLeft?: number;
    cornerTopRight?: number;
    cornerBottomLeft?: number;
    cornerBottomRight?: number;
}
/**
 * @class
 * @category Component
 * @name ImageComponent
 * @augments WidgetComponent
 * @classdesc ImageComponent class for 2d sprite rendering.
 * @description Constructor to create an ImageComponent instance.
 * To add an ImageComponent to an {@link SceneObject},
 * use {@link SceneObject#addComponent}.
 * @param {SceneObject} sceneObject - The sceneObject.
 * @param {object} options - Options to create ImageComponent.
 * @example
 * // add ImageComponent to sceneObject
 * sceneObject.addComponent('Image', options);
 * @hideconstructor
 * @sdk 9.8.0
 */
export default class ImageComponent extends WidgetComponent {
    static register(): void;
    static nativeClasses: Array<string>;
    constructor(sceneObject?: SceneObject, options?: ImageOptions);
    static fromNative(sceneObject: SceneObject, native: any): ImageComponent;
    protected getProps(): Array<string>;
    /**
     * @name ImageComponent#renderMode
     * @type {amg.ImageRenderMode}
     * @description The sprite's render mode.
     * @sdk 9.8.0
     */
    get renderMode(): ImageRenderMode;
    set renderMode(value: ImageRenderMode);
    /**
     * @name ImageComponent#color
     * @type {Color}
     * @description The sprite's color tint.
     * @sdk 9.8.0
     */
    get color(): Color;
    set color(value: Color);
    /**
     * @name ImageComponent#texture
     * @type {Texture}
     * @description The sprite's texture.
     * @sdk 9.8.0
     */
    get texture(): Texture;
    set texture(value: Texture);
    /**
     * @name ImageComponent#atlas
     * @type {ImageAtlas}
     * @description The sprite's image atlas.
     * @sdk 9.8.0
     */
    get atlas(): ImageAtlas;
    set atlas(value: ImageAtlas);
    /**
     * @name ImageComponent#atlasIndex
     * @type {number}
     * @description The sprite's atlas index.
     * @sdk 9.8.0
     */
    get atlasIndex(): number;
    set atlasIndex(value: number);
    /**
     * @name ImageComponent#filledType
     * @type {amg.ImageFillType}
     * @description The sprite's filled type  (in filled mode).
     * @sdk 9.8.0
     */
    get filledType(): ImageFillType;
    set filledType(value: ImageFillType);
    /**
     * @name ImageComponent#filledStart
     * @type {number}
     * @description The sprite's filled start (in filled mode).
     * @sdk 9.8.0
     */
    get filledStart(): number;
    set filledStart(value: number);
    /**
     * @name ImageComponent#filledRange
     * @type {number}
     * @description The sprite's filled range (in filled mode).
     * @sdk 9.8.0
     */
    get filledRange(): number;
    set filledRange(value: number);
    /**
     * @name ImageComponent#slicedLeft
     * @type {number}
     * @description The sprite's left slice's size (in sliced mode).
     * @sdk 9.8.0
     */
    get slicedLeft(): number;
    set slicedLeft(value: number);
    /**
     * @name ImageComponent#slicedRight
     * @type {number}
     * @description The sprite's right slice's size (in sliced mode).
     * @sdk 9.8.0
     */
    get slicedRight(): number;
    set slicedRight(value: number);
    /**
     * @name ImageComponent#slicedTop
     * @type {number}
     * @description The sprite's top slice's size (in sliced mode).
     * @sdk 9.8.0
     */
    get slicedTop(): number;
    set slicedTop(value: number);
    /**
     * @name ImageComponent#slicedBottom
     * @type {number}
     * @description The sprite's bottom slice's size (in sliced mode).
     * @sdk 9.8.0
     */
    get slicedBottom(): number;
    set slicedBottom(value: number);
    /**
     * @name ImageComponent#slicedFillCenter
     * @type {boolean}
     * @description The sprite's fill center flag (in sliced mode).
     * @sdk 9.8.0
     */
    get slicedFillCenter(): boolean;
    set slicedFillCenter(value: boolean);
    /**
     * @name ImageComponent#ellipseWidth
     * @type {number}
     * @description The sprite's ellipse's width (in ellipse mode).
     * @sdk 9.8.0
     */
    get ellipseWidth(): number;
    set ellipseWidth(value: number);
    /**
     * @name ImageComponent#ellipseHeight
     * @type {number}
     * @description The sprite's ellipse's height (in ellipse mode).
     * @sdk 9.8.0
     */
    get ellipseHeight(): number;
    set ellipseHeight(value: number);
    /**
     * @name ImageComponent#freeTopLeft
     * @type {Vec2}
     * @description The sprite's top left corner (in free mode).
     * @sdk 9.8.0
     */
    get freeTopLeft(): Vec2;
    set freeTopLeft(value: Vec2);
    /**
     * @name ImageComponent#freeTopRight
     * @type {Vec2}
     * @description The sprite's top right corner (in free mode).
     * @sdk 9.8.0
     */
    get freeTopRight(): Vec2;
    set freeTopRight(value: Vec2);
    /**
     * @name ImageComponent#freeTopRight
     * @type {Vec2}
     * @description The sprite's bottom left corner (in free mode).
     * @sdk 9.8.0
     */
    get freeBottomLeft(): Vec2;
    set freeBottomLeft(value: Vec2);
    /**
     * @name ImageComponent#freeTopRight
     * @type {Vec2}
     * @description The sprite's bottom right corner (in free mode).
     * @sdk 9.8.0
     */
    get freeBottomRight(): Vec2;
    set freeBottomRight(value: Vec2);
    /**
     * @name ImageComponent#cornerTopLeft
     * @type {number}
     * @description The sprite's top left corner (in corner mode).
     * @sdk 9.8.0
     */
    get cornerTopLeft(): number;
    set cornerTopLeft(value: number);
    /**
     * @name ImageComponent#cornerTopRight
     * @type {number}
     * @description The sprite's top right corner (in corner mode).
     * @sdk 9.8.0
     */
    get cornerTopRight(): number;
    set cornerTopRight(value: number);
    /**
     * @name ImageComponent#cornerBottomLeft
     * @type {number}
     * @description The sprite's bottom left corner (in corner mode).
     * @sdk 9.8.0
     */
    get cornerBottomLeft(): number;
    set cornerBottomLeft(value: number);
    /**
     * @name ImageComponent#cornerBottomRight
     * @type {number}
     * @description The sprite's bottom right corner (in corner mode).
     * @sdk 9.8.0
     */
    get cornerBottomRight(): number;
    set cornerBottomRight(value: number);
}
export {};
