import SceneObject from '../scene/scene-object';
import { WidgetOptions, WidgetComponent } from './widget-component';
import { LabelFontType, LabelAlignment, LabelFitType } from '../base/const';
import Vec2 from '../math/vec2';
import Color from '../math/color';
interface LabelOptions extends WidgetOptions {
    text?: string;
    textColor?: Color;
    fontPath?: string;
    fontSize?: number;
    fontType?: LabelFontType;
    alignment?: LabelAlignment;
    fitType?: LabelFitType;
    spacing?: Vec2;
}
/**
 * @class
 * @category Component
 * @name LabelComponent
 * @augments Component
 * @classdesc LabelComponent class for UI Label.
 * @description Constructor to create an LabelComponent instance.
 * To add an LabelComponent to an {@link SceneObject},
 * use {@link SceneObject#addComponent}.
 * @param {SceneObject} sceneObject - The sceneObject.
 * @param {object} options - Options to create LabelComponent.
 * @example
 * // add LabelComponent to sceneObject
 * sceneObject.addComponent('Label', options);
 * @hideconstructor
 * @sdk 9.8.0
 */
export default class LabelComponent extends WidgetComponent {
    static register(): void;
    static nativeClasses: Array<string>;
    constructor(sceneObject?: SceneObject, options?: LabelOptions);
    static fromNative(sceneObject: SceneObject, native: any): LabelComponent;
    protected getProps(): Array<string>;
    /**
     * @name LabelComponent#text
     * @type {string}
     * @description Label's text.
     * @sdk 9.8.0
     */
    get text(): string;
    set text(value: string);
    /**
     * @name LabelComponent#textColor
     * @type {Color}
     * @description Label's textColor.
     * @sdk 9.8.0
     */
    get textColor(): Color;
    set textColor(value: Color);
    /**
     * @name LabelComponent#fontPath
     * @type {string}
     * @description Label's fontPath.
     * @sdk 9.8.0
     */
    get fontPath(): string;
    set fontPath(value: string);
    /**
     * @name LabelComponent#fontSize
     * @type {number}
     * @description Label's fontSize.
     * @sdk 9.8.0
     */
    get fontSize(): number;
    set fontSize(value: number);
    /**
     * @name LabelComponent#fontType
     * @type {amg.LabelFontType}
     * @description Label's fontType.
     * @sdk 9.8.0
     */
    get fontType(): LabelFontType;
    set fontType(value: LabelFontType);
    /**
     * @name LabelComponent#alignment
     * @type {amg.LabelAlignment}
     * @description Label's alignment.
     * @sdk 9.8.0
     */
    get alignment(): LabelAlignment;
    set alignment(value: LabelAlignment);
    /**
     * @name LabelComponent#fitType
     * @type {amg.LabelFitType}
     * @description Label's fitType.
     * @sdk 9.8.0
     */
    get fitType(): LabelFitType;
    set fitType(value: LabelFitType);
    /**
     * @name LabelComponent#spacing
     * @type {Vec2}
     * @description Label's spacing.
     * @sdk 9.8.0
     */
    get spacing(): Vec2;
    set spacing(value: Vec2);
}
export {};
