import SceneObject from '../scene/scene-object';
import Component from './component';
import { LayoutType, LayoutSizeMode, LayoutGridMode, LayoutVerticalDirection, LayoutHorizontalDirection, LayoutSortMode } from '../base/const';
import Vec2 from '../math/vec2';
interface LayoutOptions {
    type?: LayoutType;
    sizeMode?: LayoutSizeMode;
    gridMode?: LayoutGridMode;
    verticalDirection?: LayoutVerticalDirection;
    horizontalDirection?: LayoutHorizontalDirection;
    sortMode?: LayoutSortMode;
    cellSize?: Vec2;
    paddingLeft?: number;
    paddingRight?: number;
    paddingTop?: number;
    paddingBottom?: number;
    horizontalSpace?: number;
    verticalSpace?: number;
    useScaledSize?: boolean;
    excludeInvisible?: boolean;
}
/**
 * @class
 * @category Component
 * @name LayoutComponent
 * @augments Component
 * @classdesc LayoutComponent class for laying out 2d components.
 * @description Constructor to create an LayoutComponent instance.
 * To add an LayoutComponent to an {@link SceneObject},
 * use {@link SceneObject#addComponent}.
 * @param {SceneObject} sceneObject - The sceneObject.
 * @param {object} options - Options to create LayoutComponent.
 * @example
 * // add LayoutComponent to sceneObject
 * sceneObject.addComponent('Layout', options);
 * @hideconstructor
 * @sdk 9.8.0
 */
export default class LayoutComponent extends Component {
    static register(): void;
    static nativeClasses: Array<string>;
    constructor(sceneObject?: SceneObject, options?: LayoutOptions);
    static fromNative(sceneObject: SceneObject, native: any): LayoutComponent;
    protected getProps(): Array<string>;
    /**
     * @name LayoutComponent#type
     * @type {amg.LayoutType}
     * @description Layout's type.
     * @sdk 9.8.0
     */
    get type(): LayoutType;
    set type(value: LayoutType);
    /**
     * @name LayoutComponent#sizeMode
     * @type {amg.LayoutSizeMode}
     * @description Layout's size mode.
     * @sdk 9.8.0
     */
    get sizeMode(): LayoutSizeMode;
    set sizeMode(value: LayoutSizeMode);
    /**
     * @name LayoutComponent#gridMode
     * @type {amg.LayoutGridMode}
     * @description Layout's grid mode.
     * @sdk 9.8.0
     */
    get gridMode(): LayoutGridMode;
    set gridMode(value: LayoutGridMode);
    /**
     * @name LayoutComponent#verticalDirection
     * @type {amg.LayoutVerticalDirection}
     * @description Layout's vertical direction.
     * @sdk 9.8.0
     */
    get verticalDirection(): LayoutVerticalDirection;
    set verticalDirection(value: LayoutVerticalDirection);
    /**
     * @name LayoutComponent#horizontalDirection
     * @type {amg.LayoutHorizontalDirection}
     * @description Layout's horizontal direction.
     * @sdk 9.8.0
     */
    get horizontalDirection(): LayoutHorizontalDirection;
    set horizontalDirection(value: LayoutHorizontalDirection);
    /**
     * @name LayoutComponent#sortMode
     * @type {amg.LayoutSortMode}
     * @description Layout's sort mode.
     * @sdk 9.8.0
     */
    get sortMode(): LayoutSortMode;
    set sortMode(value: LayoutSortMode);
    /**
     * @name LayoutComponent#cellSize
     * @type {Vec2}
     * @description Layout's cell size.
     * @sdk 9.8.0
     */
    get cellSize(): Vec2;
    set cellSize(value: Vec2);
    /**
     * @name LayoutComponent#paddingLeft
     * @type {number}
     * @description Layout's left padding.
     * @sdk 9.8.0
     */
    get paddingLeft(): number;
    set paddingLeft(value: number);
    /**
     * @name LayoutComponent#paddingRight
     * @type {number}
     * @description Layout's right padding.
     * @sdk 9.8.0
     */
    get paddingRight(): number;
    set paddingRight(value: number);
    /**
     * @name LayoutComponent#paddingTop
     * @type {number}
     * @description Layout's top padding.
     * @sdk 9.8.0
     */
    get paddingTop(): number;
    set paddingTop(value: number);
    /**
     * @name LayoutComponent#paddingBottom
     * @type {number}
     * @description Layout's bottom padding.
     * @sdk 9.8.0
     */
    get paddingBottom(): number;
    set paddingBottom(value: number);
    /**
     * @name LayoutComponent#horizontalSpace
     * @type {number}
     * @description Layout's horizontal space.
     * @sdk 9.8.0
     */
    get horizontalSpace(): number;
    set horizontalSpace(value: number);
    /**
     * @name LayoutComponent#verticalSpace
     * @type {number}
     * @description Layout's vertical space.
     * @sdk 9.8.0
     */
    get verticalSpace(): number;
    set verticalSpace(value: number);
    /**
     * @name LayoutComponent#useScaledSize
     * @type {boolean}
     * @description Layout's use scaled size flag.
     * @sdk 9.8.0
     */
    get useScaledSize(): boolean;
    set useScaledSize(value: boolean);
    /**
     * @name LayoutComponent#excludeInvisible
     * @type {boolean}
     * @description Layout's exclude invisible cell flag.
     * @sdk 9.8.0
     */
    get excludeInvisible(): boolean;
    set excludeInvisible(value: boolean);
}
export {};
