import SceneObject from '../scene/scene-object';
import Component from './component';
import Material from '../base/material';
import Mesh from '../base/mesh';
interface ModelOptions {
    castShadow?: boolean;
    mesh?: Mesh;
    material?: Material;
    materials?: Array<Material>;
}
/**
 * @class
 * @category Component
 * @name ModelComponent
 * @augments Component
 * @classdesc ModelComponent class for 3d model.
 * @description Constructor to create an ModelComponent instance.
 * To add an ModelComponent to an {@link SceneObject},
 * use {@link SceneObject#addComponent}.
 * @param {SceneObject} sceneObject - The sceneObject.
 * @param {object} options - Options to create ModelComponent.
 * @example
 * // add ModelComponent to sceneObject
 * sceneObject.addComponent('Model', options);
 * @hideconstructor
 * @sdk 9.8.0
 */
export default class ModelComponent extends Component {
    static register(): void;
    static nativeClasses: Array<string>;
    /**
     * @name ModelComponent#material
     * @type {Material}
     * @description Model's material.
     * @sdk 9.8.0
     */
    private _materials;
    constructor(sceneObject?: SceneObject, options?: ModelOptions);
    static fromNative(sceneObject: SceneObject, native: any): ModelComponent;
    /**
     * @name ModelComponent#castShadow
     * @type {boolean}
     * @description Model's cast shadow flag.
     * @sdk 9.8.0
     */
    get castShadow(): boolean;
    set castShadow(value: boolean);
    /**
     * @name ModelComponent#mesh
     * @type {Mesh}
     * @description Model's mesh.
     * @sdk 9.8.0
     */
    get mesh(): Mesh;
    set mesh(value: Mesh);
    get material(): Material | undefined;
    set material(material: Material | undefined);
    /**
     * @function
     * @name ModelComponent#setMaterial
     * @description Set Material of submesh to a newly defined material.
     * @param {number} index Index of material needs to be changed.
     * @param {Material} material New material that will change the material at index.
     * @returns {void}
     * @sdk 9.8.0
     */
    setMaterial(index: number, material: Material): void;
    get materials(): Array<Material> | undefined;
    set materials(materials: Array<Material> | undefined);
}
export {};
