import Component from './component';
import SceneObject from '../scene/scene-object';
import Quat from '../math/quat';
import Vec3 from '../math/vec3';
import { Physics3DType } from '../base/const';
import ContactPoint3D from '../base/physics3d';
interface Physics3DOptions {
    type: Physics3DType;
    mass?: number;
    category?: number;
    mask?: number[];
}
/**
 * @class
 * @category Component
 * @name Physics3DComponent
 * @augments Component
 * @classdesc Abstract Physics3DComponent class for 3d physics body simulation.
 * @hideconstructor
 * @sdk 9.8.0
 */
declare abstract class Physics3DComponent extends Component {
    static register(): void;
    static nativeClasses: Array<string>;
    constructor(sceneObject?: SceneObject, options?: Physics3DOptions);
    protected initialize(options?: Physics3DOptions, props?: Array<string>): void;
    protected moveToLocation(position: Vec3, rotation: Quat): void;
    protected getProps(): Array<string>;
    protected getContactPoints(collision: any): Array<ContactPoint3D>;
    /**
     * @name Physics3DComponent#mass
     * @type {number}
     * @description The physics body's mass.
     * @sdk 9.8.0
     */
    get mass(): number;
    set mass(value: number);
    protected setSensorEnabled(isEnabled: boolean): void;
    /**
     * @name Physics3DComponent#type
     * @type {amg.Physics3DType}
     * @description The physics body's type.
     * @sdk 9.8.0
     */
    get type(): Physics3DType;
    set type(value: Physics3DType);
    /**
     * @name Physics3DComponent#category
     * @type {number}
     * @description The physics body's category for interaction masking.
     * @sdk 9.8.0
     */
    get category(): number;
    set category(value: number);
    /**
     * @name Physics3DComponent#mask
     * @type {number}
     * @description The physics body's interaction masking.
     * @sdk 9.8.0
     */
    get mask(): number[];
    set mask(value: number[]);
}
export { Physics3DOptions, Physics3DComponent };
