import Amaz = effect.Amaz;
import SceneObject from '../scene/scene-object';
import Component from './component';
import { ScreenRaycasterType } from '../base/const';
import { Vec2, Vec3, Vec4 } from '..';
interface ScreenRaycasterOptions {
    type: Amaz.RaycasterType;
    layer?: Amaz.DynamicBitset;
}
/**
 * @class
 * @category Component
 * @name ScreenRaycasterComponent
 * @augments Component
 * @classdesc ScreenRaycasterComponent class for raycast Oriented Bounding Box of Collider3D, UI-Collider and
 * Geometric Plane. The component is also involed with Respond System. Make sure the sceneObject has camera component!!!
 * @description Constructor to create an ScreenRaycasterComponent instance.
 * To add an ButtonComponent to an {@link SceneObject},
 * use {@link SceneObject#addComponent}. Make sure the sceneObject has camera component!!!
 * @param {SceneObject} sceneObject - The sceneObject.
 * @param {object} options - Options to create ScreenRaycasterComponent.
 * @hideconstructor
 * @sdk 11.0.0
 */
export default class ScreenRaycasterComponent extends Component {
    static register(): void;
    static nativeClasses: Array<string>;
    constructor(sceneObject?: SceneObject, options?: ScreenRaycasterOptions);
    static fromNative(sceneObject: SceneObject, native: any): ScreenRaycasterComponent;
    protected getProps(): Array<string>;
    /**
     * @name ScreenRaycasterComponent#type
     * @type {ScreenRaycasterType}
     * @description The type of the raycaster.
     * It is used for Respond System to recognize the type of the Camera.
     * @sdk 11.0.0
     */
    get type(): ScreenRaycasterType;
    set type(type: ScreenRaycasterType);
    /**
     * @name ScreenRaycasterComponent#layers
     * @type {number[]}
     * @description The layers of the raycaster.
     * The raycaster will test the sceneObjects which are included in the layers.
     * @sdk 11.0.0
     */
    get layers(): number[];
    set layers(value: number[]);
    /**
     * @function
     * @name ScreenRaycasterComponent#raycastOBB
     * @description Raycast all collider3D-component by using their oriented bounding box.
     * @param {Vec2} viewPos - view position
     * @returns {Array<SceneObject>} - hited entites from near to far
     * @sdk 11.0.0
     */
    raycastOBB(viewPos: Vec2): Array<SceneObject>;
    /**
     * @function
     * @name ScreenRaycasterComponent#raycastUI
     * @description Raycast all ui-collider-component.
     * @param {Vec2} viewPos - view position
     * @returns {Array<SceneObject>} - hited entites from near to far
     * @sdk 11.0.0
     */
    raycastUI(viewPos: Vec2): Array<SceneObject>;
    /**
     * @function
     * @name ScreenRaycasterComponent#raycastGeometricPlane
     * @description Raycast a geometric plane.
     * @param {Vec2} viewPos view position.
     * @param {Vec4} plane geometric plane. For example: Ax + By + Cz + D = 0, new Vec4(A,B,C,D).
     * @returns {Vec3} Hited Postion.
     * @sdk 11.0.0
     */
    raycastGeometricPlane(viewPos: Vec2, plane: Vec4): {
        hit: boolean;
        hitpos: Vec3;
    };
}
export {};
