import Component from './component';
import SceneObject from '../scene/scene-object';
import Vec2 from '../math/vec2';
interface ScreenTransformOptions {
    position: Vec2;
    rotation: number;
    scale: Vec2;
    size: Vec2;
    pivot: Vec2;
    flipX: boolean;
    flipY: boolean;
}
/**
 * @class
 * @category Component
 * @name ScreenTransformComponent
 * @augments Component
 * @classdesc ScreenTransformComponent class for placing screen based sceneObjects
 * @description Constructor to create an ScreenTransformComponent instance.
 * To add an ScreenTransformComponent to an {@link SceneObject},
 * use {@link SceneObject#addComponent}.
 * @param {SceneObject} sceneObject - The sceneObject.
 * @param {object} options - Options to create ScreenTransformComponent.
 * @example
 * // add ScreenTransformComponent to sceneObject
 * sceneObject.addComponent('ScreenTransform', options);
 * @hideconstructor
 * @sdk 9.8.0
 */
export default class ScreenTransformComponent extends Component {
    static register(): void;
    static nativeClasses: Array<string>;
    constructor(sceneObject?: SceneObject, options?: ScreenTransformOptions);
    static fromNative(sceneObject: SceneObject, native: any): ScreenTransformComponent;
    protected getProps(): Array<string>;
    /**
     * @name ScreenTransformComponent#position
     * @type {Vec2}
     * @description Local position of 2d sceneObject.
     * @sdk 9.8.0
     */
    get position(): Vec2;
    set position(value: Vec2);
    /**
     * @name ScreenTransformComponent#scale
     * @type {Vec2}
     * @description Local scale of 2d sceneObject.
     * @sdk 9.8.0
     */
    get scale(): Vec2;
    set scale(value: Vec2);
    /**
     * @name ScreenTransformComponent#rotation
     * @type {number}
     * @description Local rotation of 2d sceneObject.
     * @sdk 9.8.0
     */
    get rotation(): number;
    set rotation(value: number);
    /**
     * @name ScreenTransformComponent#size
     * @type {Vec2}
     * @description Size of 2d sceneObject.
     * @sdk 9.8.0
     */
    get size(): Vec2;
    set size(value: Vec2);
    /**
     * @name ScreenTransformComponent#pivot
     * @type {Vec2}
     * @description Pivot of 2d sceneObject.
     * @sdk 9.8.0
     */
    get pivot(): Vec2;
    set pivot(value: Vec2);
    /**
     * @name ScreenTransformComponent#flipX
     * @type {boolean}
     * @description Flip the 2d sceneObject horizontally.
     * @sdk 9.8.0
     */
    get flipX(): boolean;
    set flipX(value: boolean);
    /**
     * @name ScreenTransformComponent#flipY
     * @type {boolean}
     * @description Flip the 2d sceneObject vertically.
     * @sdk 9.8.0
     */
    get flipY(): boolean;
    set flipY(value: boolean);
}
export {};
