import SceneObject from '../scene/scene-object';
import Component from './component';
interface ScriptOptions {
    scriptPath?: string;
}
/**
 * @class
 * @category Component
 * @name ScriptComponent
 * @augments Component
 * @classdesc ScriptComponent class for JS scripting.
 * @description Constructor to create a ScriptComponent instance.
 * To add an ScriptComponent to an {@link SceneObject},
 * use {@link SceneObject#addComponent}.
 * @param {SceneObject} sceneObject - The sceneObject.
 * @param {object} options - Options to create ScriptComponent.
 * @param {string} options.path - Path to script file.
 * @example
 * // add ScriptComponent to sceneObject
 * sceneObject.addComponent('Script', options);
 * @hideconstructor
 * @sdk 9.9.0
 */
export default abstract class ScriptComponent extends Component {
    static register(): void;
    static nativeClasses: Array<string>;
    private serialzedProperties;
    private _hasInitialized;
    private constructor();
    static create(sceneObject: SceneObject, options?: ScriptOptions): ScriptComponent;
    onInit(): void;
    private _getComponent;
    onPropertyChanged(propName: string): void;
    private convertAmazToAmg;
    /**
     * @name ScriptComponent#hasIntialized
     * @type {boolean}
     * @description Flag to check if the component has been initialized.
     * @sdk 9.8.0
     */
    hasIntialized(): boolean;
}
export {};
