import Component from './component';
import SceneObject from '../scene/scene-object';
import { SeqAnimationPlayMode } from '../base/const';
import SeqAnimation from '../base/seq-animation';
interface SeqAnimationOptions {
    sequence: SeqAnimation;
    textureName: string;
    autoPlay?: boolean;
    playMode?: SeqAnimationPlayMode;
}
/**
 * @class
 * @category Component
 * @name SeqAnimationComponent
 * @augments Component
 * @classdesc SeqAnimationComponent class for playing sequential image based animation.
 * @description Constructor to create an SeqAnimationComponent instance.
 * To add an SeqAnimationComponent to an {@link SceneObject},
 * use {@link SceneObject#addComponent}.
 * @param {SceneObject} sceneObject - The sceneObject.
 * @param {object} options - Options to create SeqAnimationComponent.
 * @example
 * // add SeqAnimationComponent to sceneObject
 * sceneObject.addComponent('SeqAnimation', options);
 * @hideconstructor
 * @sdk 9.8.0
 */
export default class SeqAnimationComponent extends Component {
    static register(): void;
    static nativeClasses: Array<string>;
    constructor(sceneObject?: SceneObject, options?: SeqAnimationOptions);
    static fromNative(sceneObject: SceneObject, native: any): SeqAnimationComponent;
    protected getProps(): Array<string>;
    /**
     * @function
     * @name SeqAnimationComponent#play
     * @description Play animation.
     * @sdk 9.8.0
     */
    play(): void;
    /**
     * @function
     * @name SeqAnimationComponent#stop
     * @description Stop animation.
     * @sdk 9.8.0
     */
    stop(): void;
    /**
     * @function
     * @name SeqAnimationComponent#pause
     * @description Pause animation.
     * @sdk 9.8.0
     */
    pause(): void;
    /**
     * @function
     * @name SeqAnimationComponent#resume
     * @description Resume animation.
     * @sdk 9.8.0
     */
    resume(): void;
    /**
     * @function
     * @name SeqAnimationComponent#seek
     * @description Seek animation.
     * @param {number} frameIndex - Seek to a frame index.
     * @sdk 9.8.0
     */
    seek(frameIndex: number): void;
    /**
     * @name SeqAnimationComponent#sequence
     * @type {SeqAnimation}
     * @description The sequential animation.
     * @sdk 9.8.0
     */
    get sequence(): SeqAnimation;
    set sequence(value: SeqAnimation);
    /**
     * @name SeqAnimationComponent#textureName
     * @type {string}
     * @description The animation's texture name.
     * @sdk 9.8.0
     */
    get textureName(): string;
    set textureName(value: string);
    /**
     * @name SeqAnimationComponent#autoPlay
     * @type {boolean}
     * @description The animation's auto play flag.
     * @sdk 9.8.0
     */
    get autoPlay(): boolean;
    set autoPlay(value: boolean);
    /**
     * @name SeqAnimationComponent#playMode
     * @type {amg.SeqAnimationPlayMode}
     * @description The animation's play mode.
     * @sdk 9.8.0
     */
    get playMode(): SeqAnimationPlayMode;
    set playMode(value: SeqAnimationPlayMode);
}
export {};
