import SceneObject from '../scene/scene-object';
import { UIControlOptions, UIControlComponent } from './ui-control-component';
import { SliderMode, UIMoveDirection } from '../base/const';
interface SliderOptions extends UIControlOptions {
    mode?: SliderMode;
    direction?: UIMoveDirection;
    minValue?: number;
    maxValue?: number;
    step?: number;
    value?: number;
    fillSceneObject?: SceneObject;
    thumbSceneObject?: SceneObject;
}
/**
 * @class
 * @category Component
 * @name SliderComponent
 * @augments UIControlComponent
 * @classdesc SliderComponent class for UI slider.
 * @description Constructor to create an SliderComponent instance.
 * To add an SliderComponent to an {@link SceneObject},
 * use {@link SceneObject#addComponent}.
 * @param {SceneObject} sceneObject - The sceneObject.
 * @param {object} options - Options to create SliderComponent.
 * @example
 * // add SliderComponent to sceneObject
 * sceneObject.addComponent('Slider', options);
 * @hideconstructor
 * @sdk 9.8.0
 */
export default class SliderComponent extends UIControlComponent {
    static register(): void;
    static nativeClasses: Array<string>;
    constructor(sceneObject?: SceneObject, options?: SliderOptions);
    destroy(): void;
    static fromNative(sceneObject: SceneObject, native: any): SliderComponent;
    protected getProps(): Array<string>;
    private registerCallbacks;
    private removeCallbacks;
    /**
     * @param thisSlider
     * @event
     * @name SliderComponent#change
     * @description Fired after slider's value has been changed.
     * @example
     * sceneObject.slider.on('change', function () {
     *     console.log('slider's value was changed');
     * });
     * @sdk 9.8.0
     */
    private onValueChanged;
    /**
     * @name SliderComponent#mode
     * @type {amg.SliderMode}
     * @description The slider's mode.
     * @sdk 9.8.0
     */
    get mode(): SliderMode;
    set mode(value: SliderMode);
    /**
     * @name SliderComponent#direction
     * @type {amg.UIMoveDirection}
     * @description The slider's direction.
     * @sdk 9.8.0
     */
    get direction(): UIMoveDirection;
    set direction(value: UIMoveDirection);
    /**
     * @name SliderComponent#minValue
     * @type {number}
     * @description The slider's min value.
     * @sdk 9.8.0
     */
    get minValue(): number;
    set minValue(value: number);
    /**
     * @name SliderComponent#maxValue
     * @type {number}
     * @description The slider's max value.
     * @sdk 9.8.0
     */
    get maxValue(): number;
    set maxValue(value: number);
    /**
     * @name SliderComponent#step
     * @type {number}
     * @description The slider's step.
     * @sdk 9.8.0
     */
    get step(): number;
    set step(value: number);
    /**
     * @name SliderComponent#value
     * @type {number}
     * @description The slider's value.
     * @sdk 9.8.0
     */
    get value(): number;
    set value(value: number);
    /**
     * @name SliderComponent#fillSceneObject
     * @type {SceneObject}
     * @description The slider's visual sceneObject for filling.
     * @sdk 9.8.0
     */
    set fillSceneObject(value: SceneObject);
    /**
     * @name SliderComponent#thumbSceneObject
     * @type {SceneObject}
     * @description The slider's thumb sceneObject.
     * @sdk 9.8.0
     */
    set thumbSceneObject(value: SceneObject);
}
export {};
