import SceneObject from '../scene/scene-object';
import { UIControlOptions, UIControlComponent } from './ui-control-component';
declare type SliderThumbOptions = UIControlOptions;
/**
 * @class
 * @category Component
 * @name SliderThumbComponent
 * @augments UIControlComponent
 * @classdesc SliderThumbComponent class for UI slider's thumb.
 * @description Constructor to create an SliderThumbComponent instance.
 * To add an SliderThumbComponent to an {@link SceneObject},
 * use {@link SceneObject#addComponent}.
 * @param {SceneObject} sceneObject - The sceneObject.
 * @param {object} options - Options to create SliderThumbComponent.
 * @example
 * // add SliderThumbComponent to sceneObject
 * sceneObject.addComponent('SliderThumb', options);
 * @hideconstructor
 * @sdk 9.8.0
 */
export default class SliderThumbComponent extends UIControlComponent {
    static register(): void;
    static nativeClasses: Array<string>;
    constructor(sceneObject?: SceneObject, options?: SliderThumbOptions);
    destroy(): void;
    static fromNative(sceneObject: SceneObject, native: any): SliderThumbComponent;
    protected getProps(): Array<string>;
    private registerCallbacks;
    private removeCallbacks;
    /**
     * @param thisThumb
     * @event
     * @name SliderThumbComponent#click
     * @description Fired after slider's thumb has been clicked.
     * @example
     * sceneObject.slider.on('click', function () {
     *     console.log('slider's thumb was clicked');
     * });
     * @sdk 9.8.0
     */
    private onClicked;
}
export {};
