import Amaz = effect.Amaz;
import Component from './component';
import SceneObject from '../scene/scene-object';
import Material from '../base/material';
import Vec2 from '../math/vec2';
import Vec4 from '../math/vec4';
import { SpriteRenderMode } from '../base/const';
import Color from '../math/color';
import Texture from '../base/texture';
interface SpriteOptions {
    renderMode?: SpriteRenderMode;
    pivot?: Vec2;
    flipX?: boolean;
    flipY?: boolean;
    material?: Material;
    color?: Color;
}
/**
 * @class
 * @category Component
 * @name SpriteComponent
 * @augments Component
 * @classdesc SpriteComponent class for rendering sprite in 3d space.
 * @description Constructor to create an SpriteComponent instance.
 * To add an SpriteComponent to an {@link SceneObject},
 * use {@link SceneObject#addComponent}.
 * @param {SceneObject} sceneObject - The sceneObject.
 * @param {object} options - Options to create SpriteComponent.
 * @example
 * // add SpriteComponent to sceneObject
 * sceneObject.addComponent('Sprite', options);
 * @hideconstructor
 * @sdk 9.8.0
 */
export default class SpriteComponent extends Component {
    static register(): void;
    static nativeClasses: Array<string>;
    private _material;
    constructor(sceneObject?: SceneObject, options?: SpriteOptions);
    static fromNative(sceneObject: SceneObject, native: any): SpriteComponent;
    protected getProps(): Array<string>;
    /**
     * @name SpriteComponent#material
     * @type {Material}
     * @description Sprite's material.
     * @sdk 9.8.0
     */
    get material(): Material | undefined;
    set material(value: Material | undefined);
    /**
     * @name SpriteComponent#flipX
     * @type {boolean}
     * @description Sprite's flip x flag.
     * @sdk 9.8.0
     */
    get flipX(): boolean;
    set flipX(value: boolean);
    /**
     * @name SpriteComponent#flipY
     * @type {boolean}
     * @description Sprite's flip y flag.
     * @sdk 9.8.0
     */
    get flipY(): boolean;
    set flipY(value: boolean);
    /**
     * @name SpriteComponent#color
     * @type {Color}
     * @description Sprite's color tint.
     * @sdk 9.8.0
     */
    get color(): Color;
    set color(value: Color);
    /**
     * @name SpriteComponent#pivot
     * @type {Vec2}
     * @description Sprite's pivot.
     * @sdk 9.8.0
     */
    get pivot(): Vec2;
    set pivot(value: Vec2);
    /**
     * @name SpriteComponent#renderMode
     * @type {amg.SpriteRenderMode}
     * @description Sprite's render mode.
     * @sdk 9.8.0
     */
    get renderMode(): SpriteRenderMode;
    set renderMode(value: SpriteRenderMode);
    /**
     * @function
     * @name SpriteComponent#setBaseTexture
     * @description Set the base texture of a sprite2D renderer.
     * @param {Texture} texture - the target texture.
     * @param {Vec4} outerRect - optional
     * outerRect.x and outerRect.y define the aspect ratio
     * of rectangle that holds the texture.
     * Default value is (1,1,0,0).
     * @param {Amaz.RotateType} rotate - optional
     * Default value is Amaz.RotateType.ROTATE_0.
     * @sdk 9.8.0
     */
    setBaseTexture(texture: Texture, outerRect: Vec4 | undefined, rotate: Amaz.RotateType | undefined): void;
}
export {};
