import SceneObject from '../scene/scene-object';
import { Physics3DComponent } from './physics3d-component';
interface Trigger3DOptions {
    category?: number;
    mask?: number[];
}
/**
 * @class
 * @category Component
 * @name Trigger3DComponent
 * @augments Physics3DComponent
 * @classdesc Trigger3DComponent class for 3d physics trigger.
 * @description Constructor to create an Trigger3DComponent instance.
 * To add an Trigger3DComponent to an {@link SceneObject},
 * use {@link SceneObject#addComponent}.
 * @param {SceneObject} sceneObject - The sceneObject.
 * @param {object} options - Options to create Trigger3DComponent.
 * @example
 * // add Trigger3DComponent to sceneObject
 * sceneObject.addComponent('Trigger', options);
 * @hideconstructor
 * @sdk 9.8.0
 */
/**
 * @event
 * @name Trigger3DComponent#triggerstay
 * @description Fired while rigid body is staying in trigger.
 * @param {SceneObject} thisSceneObject - The sceneObject triggers this event.
 * @param {SceneObject} otherSceneObject - The other sceneObject hit by this sceneObject.
 * @param {Array<ContactPoint3D>} contacts - A list of 3d contact points.
 * @example
 * sceneObject.trigger.on('triggerstay', function () {
 *     console.log('SceneObject stays');
 * });
 * @sdk 9.8.0
 */
/**
 * @event
 * @name Trigger3DComponent#triggerexit
 * @description Fired after rigid body exited trigger.
 * @param {SceneObject} thisSceneObject - The sceneObject triggers this event.
 * @param {SceneObject} otherSceneObject - The other sceneObject hit by this sceneObject.
 * @param {Array<ContactPoint3D>} contacts - A list of 3d contact points.
 * @example
 * sceneObject.trigger.on('triggerexit', function () {
 *     console.log('SceneObject exited');
 * });
 * @sdk 9.8.0
 */
/**
 * @event
 * @name Trigger3DComponent#triggerenter
 * @description Fired after rigid body entered trigger.
 * @param {SceneObject} thisSceneObject - The sceneObject triggers this event.
 * @param {SceneObject} otherSceneObject - The other sceneObject hit by this sceneObject.
 * @param {Array<ContactPoint3D>} contacts - A list of 3d contact points.
 * @example
 * sceneObject.trigger.on('triggerenter', function () {
 *     console.log('SceneObject entered');
 * });
 * @sdk 9.8.0
 */
export default class Trigger3DComponent extends Physics3DComponent {
    constructor(sceneObject?: SceneObject, triggerOptions?: Trigger3DOptions);
    static fromNative(sceneObject: SceneObject, native: any): Trigger3DComponent;
    destroy(): void;
    private registerCallbacks;
    private removeCallbacks;
    private onTriggerEnter;
    private onTriggerStay;
    private onTriggerExit;
}
export {};
