import Component from './component';
import SceneObject from '../scene/scene-object';
import Vec3 from '../math/vec3';
import { UIColliderType } from '../base/const';
interface UIColliderOptions {
    type: UIColliderType;
    autoSize?: boolean;
    center?: Vec3;
    size?: Vec3;
}
/**
 * @class
 * @category Component
 * @name UIColliderComponent
 * @augments Component
 * @classdesc UIColliderComponent class for UI collision detection.
 * @description Constructor to create an UIColliderComponent instance.
 * To add an UIColliderComponent to an {@link SceneObject},
 * use {@link SceneObject#addComponent}.
 * @param {SceneObject} sceneObject - The sceneObject.
 * @param {object} options - Options to create UIColliderComponent.
 * @example
 * // add UIColliderComponent to sceneObject
 * sceneObject.addComponent('UICollider', options);
 * @hideconstructor
 * @sdk 9.8.0
 */
export default class UIColliderComponent extends Component {
    static register(): void;
    static nativeClasses: Array<string>;
    type: UIColliderType;
    constructor(sceneObject?: SceneObject, options?: UIColliderOptions);
    static fromNative(sceneObject: SceneObject, native: any): UIColliderComponent;
    protected getProps(): Array<string>;
    /**
     * @name UIColliderComponent#autoSize
     * @type {boolean}
     * @description Collider's auto resize flag.
     * @sdk 9.8.0
     */
    get autoSize(): boolean;
    set autoSize(value: boolean);
    /**
     * @name UIColliderComponent#center
     * @type {Vec3}
     * @description Collider's center.
     * @sdk 9.8.0
     */
    get center(): Vec3;
    set center(value: Vec3);
    /**
     * @name UIColliderComponent#size
     * @type {Vec3}
     * @description Collider's size.
     * @sdk 9.8.0
     */
    get size(): Vec3;
    set size(value: Vec3);
}
export {};
