import Color from '../math/color';
import SceneObject from '../scene/scene-object';
import { UIInteractOptions, UIInteractComponent } from './ui-interact-component';
interface UIControlOptions extends UIInteractOptions {
    enabled?: boolean;
    normalFrame?: number;
    pressedFrame: number;
    disabledFrame: number;
    normalColor: Color;
    pressedColor: Color;
    disabledColor: Color;
}
/**
 * @class
 * @category Component
 * @name UIControlComponent
 * @augments Component
 * @classdesc Abstract UIControlComponent class for UI Controls.
 * @hideconstructor
 * @sdk 9.8.0
 */
declare abstract class UIControlComponent extends UIInteractComponent {
    constructor(sceneObject?: SceneObject, nativeClass?: string, options?: UIControlOptions);
    protected getProps(): Array<string>;
    /**
     * @name UIControlComponent#enabled
     * @type {boolean}
     * @description Flag to enable/disable the UI control.
     * @sdk 9.8.0
     */
    get enabled(): boolean;
    set enabled(value: boolean);
    /**
     * @name UIControlComponent#normalFrame
     * @type {number}
     * @description Frame number of normal state.
     * @sdk 9.8.0
     */
    get normalFrame(): number;
    set normalFrame(value: number);
    /**
     * @name UIControlComponent#pressedFrame
     * @type {number}
     * @description Frame number of pressed state.
     * @sdk 9.8.0
     */
    get pressedFrame(): number;
    set pressedFrame(value: number);
    /**
     * @name UIControlComponent#disabledFrame
     * @type {number}
     * @description Frame number of disabled state.
     * @sdk 9.8.0
     */
    get disabledFrame(): number;
    set disabledFrame(value: number);
    /**
     * @name UIControlComponent#normalColor
     * @type {Color}
     * @description Color of normal state.
     * @sdk 9.8.0
     */
    get normalColor(): Color;
    set normalColor(value: Color);
    /**
     * @name UIControlComponent#pressedColor
     * @type {Color}
     * @description Color of pressed state.
     * @sdk 9.8.0
     */
    get pressedColor(): Color;
    set pressedColor(value: Color);
    /**
     * @name UIControlComponent#disabledColor
     * @type {Color}
     * @description Color of disabled state.
     * @sdk 9.8.0
     */
    get disabledColor(): Color;
    set disabledColor(value: Color);
}
export { UIControlOptions, UIControlComponent };
