import Component from './component';
import SceneObject from '../scene/scene-object';
interface UIEventSystemOptions {
    mask?: number;
}
/**
 * @class
 * @category Component
 * @name UIEventSystemComponent
 * @augments Component
 * @classdesc UIEventSystemComponent class for ui events.
 * @description Constructor to create an UIEventSystemComponent instance.
 * To add an UIEventSystemComponent to an {@link SceneObject} with a {@link CameraComponent},
 * use {@link SceneObject#addComponent}.
 * @param {SceneObject} sceneObject - The sceneObject.
 * @param {object} options - Options to create UIEventSystemComponent.
 * @example
 * // add UIEventSystemComponent to camera sceneObject for ui events
 * cameraSceneObject.addComponent('UIEventSystem', options);
 * @hideconstructor
 * @sdk 9.8.0
 */
export default class UIEventSystemComponent extends Component {
    static register(): void;
    static nativeClasses: Array<string>;
    constructor(sceneObject?: SceneObject, options?: UIEventSystemOptions);
    static fromNative(sceneObject: SceneObject, native: any): UIEventSystemComponent;
    protected getProps(): Array<string>;
    /**
     * @name UIEventSystemComponent#mask
     * @type {number}
     * @description The UI event system's mask.
     * @sdk 9.8.0
     */
    get mask(): number;
    set mask(value: number);
}
export {};
