import { CmdBufferHelper } from '../base/utils';
export default class CustomAssetRegistry {
    private _resEntryMap;
    private _assetsConfig;
    private _nativeObjMap;
    private _assets;
    private _cmdBufferHelper;
    constructor();
    /**
     * @function
     * @name CustomAssetRegistry#getNativeObject
     * @returns {any} the native object corresponding to the custom asset
     * @description As engine cannot excute any JS code when loading a scene.
     * We need to create all the native objects beforehand. Use this method to
     * get the native object of a custom asset rather than create by itself
     * @param {string} uuid uuid of a custom asset
     * @sdk 10.1.0
     */
    getNativeObject(uuid: string): any;
    init(): void;
    get cmdBufferHelper(): CmdBufferHelper;
    update(dt: number): void;
    start(): void;
    destroy(): void;
    lateUpdate(dt: number): void;
    private createCustomAsset;
    /**
     * @function
     * @name CustomAssetRegistry#analyzeAssetsDependency
     * @returns {Array<string>} assets update order
     * @description assets might depend on each other. For example, a segmentation asset might
     * depend on a camera input asset. This method analyzes dependency relationship across assets
     * using topological sort. And outputs a update order.
     */
    private analyzeAssetsDependency;
}
