/**
 * @name amg
 * @namespace
 * @description Root namespace for the Amazing JS Engine.
 * @sdk 9.8.0
 */
import EventHandler from './base/event-handler';
import Engine from './platform/engine';
import { Feature, FeatureMinSDKVersion } from './base/versions';
import Scene from './scene/scene';
import SceneObject from './scene/scene-object';
import Entity from './scene/scene-object';
import TouchDevice from './platform/input/touch-device';
import Gyroscope from './platform/input/gyro-scope';
import Material from './base/material';
import Mesh from './base/mesh';
import LineMesh from './base/line-mesh';
import SubMesh from './base/submesh';
import AbstractMesh from './base/abstract-mesh';
import Texture, { WrapMode, FilterMode } from './base/texture';
import RenderTexture from './base/render-texture';
import XShader from './base/xshader';
import Prefab from './base/prefab';
import Color from './math/color';
import Vec2 from './math/vec2';
import Vec3 from './math/vec3';
import Vec4 from './math/vec4';
import Mat3 from './math/mat3';
import Mat4 from './math/mat4';
import Quat from './math/quat';
import Rect from './math/rect';
import AABB from './math/aabb';
import AlignmentComponent from './component/alignment-component';
import AnimationComponent from './component/animation-component';
import AudioComponent from './component/audio-component';
import ButtonComponent from './component/button-component';
import CameraComponent from './component/camera-component';
import CanvasComponent from './component/canvas-component';
import CanvasScalerComponent from './component/canvas-scaler-component';
import Collider3DComponent from './component/collider3d-component';
import GenericJoint3DComponent from './component/generic-joint3d-component';
import ImageComponent from './component/image-component';
import LabelComponent from './component/label-component';
import LayoutComponent from './component/layout-component';
import LightComponent from './component/light-component';
import ModelComponent from './component/model-component';
import ParticleSystemComponent from './component/particle-system-component';
import RigidBody3DComponent from './component/rigidbody3d-component';
import Trigger3DComponent from './component/trigger3d-component';
import ScreenTransformComponent from './component/screen-transform-component';
import SeqAnimationComponent from './component/seq-animation-component';
import SliderComponent from './component/slider-component';
import SliderThumbComponent from './component/slider-thumb-component';
import SpriteComponent from './component/sprite-component';
import UIColliderComponent from './component/ui-collider-component';
import UIEventSystemComponent from './component/ui-event-system-component';
import ScriptComponent from './component/script-component';
import Segmentation from './algorithm/segmentation';
import Head from './algorithm/head/head';
import Hand from './algorithm/hand';
import Body2D from './algorithm/body2d';
import Body3D from './algorithm/body3d';
import AvatarDrive from './algorithm/avatar-drive';
import GeometryUtil from './base/geometry-util';
import { State, MultiToggleStateMachine, FiniteStateMachine } from './util/state-machine';
import FilterGraphRegistry from './filter/filter-graph-registry';
import OperatorFilter from './filter/operator-filter';
import { PingpongFilter, ConvFilter } from './filter/pingpong-filter';
import FilterGraph from './filter/filter-graph';
import FilterNode from './filter/filter-node';
import TouchGesture from './platform/input/touch-gesture';
import TouchRespond from './base/touch-respond';
import TapGestureRecognizer from './platform/input/recognizer/tap-recognizer';
import PanGestureRecognizer from './platform/input/recognizer/pan-recognizer';
import RotationGestureRecognizer from './platform/input/recognizer/rotation-recognizer';
import PinchGestureRecognizer from './platform/input/recognizer/pinch-recognizer';
import LongPressGestureRecognizer from './platform/input/recognizer/longpress-recognizer';
import DoubleTapGestureRecognizer from './platform/input/recognizer/doubletap-recognizer';
import ScreenRaycasterComponent from './component/screen-raycaster-component';
import ScreenHitInfo from './base/screen-hitinfo';
import AudioFactory from './audio-controller/audio-factory';
import Analytics from './analytics/analytics';
export * from './base/const';
export { EventHandler, Engine, Feature, FeatureMinSDKVersion, Scene, SceneObject, Entity, TouchDevice, Gyroscope, Material, AbstractMesh, Mesh, LineMesh, SubMesh, Texture, WrapMode, FilterMode, RenderTexture, XShader, Prefab, Color, Vec2, Vec3, Vec4, Mat3, Mat4, Quat, Rect, AABB, AlignmentComponent, AnimationComponent, AudioComponent, ButtonComponent, CameraComponent, CanvasComponent, CanvasScalerComponent, Collider3DComponent, GenericJoint3DComponent, ImageComponent, LabelComponent, LayoutComponent, LightComponent, ModelComponent, ParticleSystemComponent, RigidBody3DComponent, Trigger3DComponent, ScreenTransformComponent, SeqAnimationComponent, SliderComponent, SliderThumbComponent, SpriteComponent, UIColliderComponent, UIEventSystemComponent, Segmentation, Head, Hand, Body2D, Body3D, GeometryUtil, AvatarDrive, ScriptComponent, State, MultiToggleStateMachine, FiniteStateMachine, FilterGraphRegistry, FilterGraph, FilterNode, OperatorFilter, PingpongFilter, ConvFilter, TouchGesture, TouchRespond, TapGestureRecognizer, PanGestureRecognizer, RotationGestureRecognizer, PinchGestureRecognizer, LongPressGestureRecognizer, DoubleTapGestureRecognizer, ScreenRaycasterComponent, ScreenHitInfo, AudioFactory, Analytics, };
