import Amaz = effect.Amaz;
import Vec3 from './vec3';
/**
 * @class
 * @category Math
 * @name AABB
 * @classdesc Class for Axis-aligned bounding box.
 * @description Constructor to create an instance.
 * @param {Vec3} min - minimum point defaults to positive infinity.
 * @param {Vec3} max - maximum point defaults to negative infinity.
 * @sdk 11.7.0
 */
declare class AABB {
    private static readonly X;
    private static readonly Y;
    private static readonly Z;
    private _native;
    private _minVectorValues;
    private _maxVectorValues;
    private _supportMemoryMapping;
    constructor();
    constructor(aabb: Amaz.AABB);
    constructor(min: Vec3, max: Vec3);
    static fromNative(nativeAABB: Amaz.AABB): AABB;
    /**
     * @function
     * @name AABB#eq
     * @description Judge whether the value of one AABB is equal to other AABB.
     * @param {AABB} v0 - One AABB.
     * @param {AABB} v1 - Other AABB.
     * @returns {boolean} - Returns true if the AABB are equal and false otherwise.
     * @static
     * @sdk 11.7.0
     */
    static eq(v0: AABB, v1: AABB): boolean;
    /**
     * @name AABB#native
     * @type {Amaz.AABB}
     * @description Returns the native data structure of AABB.
     * @sdk 11.7.0
     */
    get native(): Amaz.AABB;
    /**
     * @name AABB#minX
     * @type {number}
     * @description Minimum value of x dimension.
     * @sdk 11.7.0
     */
    get minX(): number;
    set minX(value: number);
    /**
     * @name AABB#minY
     * @type {number}
     * @description Minimum value of y dimension.
     * @sdk 11.7.0
     */
    get minY(): number;
    set minY(value: number);
    /**
     * @name AABB#minZ
     * @type {number}
     * @description Minimum value of z dimension.
     * @sdk 11.7.0
     */
    get minZ(): number;
    set minZ(value: number);
    /**
     * @name AABB#maxX
     * @type {number}
     * @description Maximum value of x dimension.
     * @sdk 11.7.0
     */
    get maxX(): number;
    set maxX(value: number);
    /**
     * @name AABB#maxY
     * @type {number}
     * @description Maximum value of y dimension.
     * @sdk 11.7.0
     */
    get maxY(): number;
    set maxY(value: number);
    /**
     * @name AABB#maxZ
     * @type {number}
     * @description Maximum value of z dimension.
     * @sdk 11.7.0
     */
    get maxZ(): number;
    set maxZ(value: number);
    /**
     * @function
     * @name AABB#eq
     * @description Judge whether the value of current AABB is equal to other AABB.
     * @param {AABB} other - Other AABB.
     * @returns {boolean} - Returns true if the AABB are equal and false otherwise.
     * @sdk 11.7.0
     */
    eq(other: AABB): boolean;
    /**
     * @function
     * @name AABB#toString
     * @description Return current AABB value in string.
     * @returns {string} - Current AABB value in string.
     * @sdk 11.7.0
     */
    toString(): string;
    /**
     * @function
     * @name AABB#copy
     * @description Copy the elements from target to this object.
     * @param {AABB} target - Target.
     * @returns {AABB} - Self for chaining.
     * @sdk 11.7.0
     */
    copy(target: AABB): AABB;
    /**
     * @function
     * @name AABB#clone
     * @description Returns an identical copy of this object.
     * @returns {AABB} The cloned instance.
     * @sdk 11.7.0
     */
    clone(): AABB;
}
export default AABB;
