import Amaz = effect.Amaz;
/**
 * @class
 * @category Math
 * @name Color
 * @classdesc Class for Color.
 * @description Constructor to create an Color instance.
 * @param {number} r - Red element (0.0 - 1.0) defaults to 1.
 * @param {number} g - Green element (0.0 - 1.0) defaults to 1.
 * @param {number} b - Blue element (0.0 - 1.0) defaults to 1.
 * @param {number} a - Alpha element (0.0 - 1.0) defaults to 1.
 * @sdk 11.7.0
 */
declare class Color {
    private static readonly R;
    private static readonly G;
    private static readonly B;
    private static readonly A;
    private _native;
    private _values;
    private _supportMemoryMapping;
    constructor();
    constructor(r: number, g: number, b: number, a: number);
    constructor(color: Amaz.Color);
    static fromNative(nativeColor: Amaz.Color): Color;
    /**
     * @function
     * @name Color#eq
     * @description Judge whether the value of one color is equal to other color.
     * @param {Color} c0 - One Color.
     * @param {Color} c1 - Other Color.
     * @returns {boolean} - Returns true if the Color are equal and false otherwise.
     * @static
     * @sdk 11.7.0
     */
    static eq(c0: Color, c1: Color): boolean;
    /**
     * @name Color#native
     * @type {Amaz.Color}
     * @description Returns the native data structure of Color.
     * @sdk 11.7.0
     */
    get native(): Amaz.Color;
    /**
     * @function
     * @name Color#set
     * @description Set new elements to this Color.
     * @param {number} r - Red element.
     * @param {number} g - Green element.
     * @param {number} b - Blue element.
     * @param {number} a - Alpha element.
     * @returns {Color} - Self for chaining.
     * @sdk 11.7.0
     */
    set(r: number, g: number, b: number, a: number): Color;
    /**
     * @name Color#r
     * @type {number}
     * @description Red element.
     * @sdk 11.7.0
     */
    get r(): number;
    set r(value: number);
    /**
     * @name Color#g
     * @type {number}
     * @description Green element.
     * @sdk 11.7.0
     */
    get g(): number;
    set g(value: number);
    /**
     * @name Color#b
     * @type {number}
     * @description Blue element.
     * @sdk 11.7.0
     */
    get b(): number;
    set b(value: number);
    /**
     * @name Color#a
     * @type {number}
     * @description Alpha element.
     * @sdk 11.7.0
     */
    get a(): number;
    set a(value: number);
    /**
     * @function
     * @name Color#eq
     * @description Judge whether the value of current color is equal to other color.
     * @param {Color} other - Other color.
     * @returns {boolean} - Returns true if the color are equal and false otherwise.
     * @sdk 11.7.0
     */
    eq(other: Color): boolean;
    /**
     * @function
     * @name Color#toString
     * @description Return current color value in string.
     * @returns {string} - Current color value in string.
     * @sdk 11.7.0
     */
    toString(): string;
    /**
     * @function
     * @name Color#copy
     * @description Copy the elements from target to this object.
     * @param {Color} target - Target.
     * @returns {Color} - Self for chaining.
     * @sdk 11.7.0
     */
    copy(target: Color): Color;
    /**
     * @function
     * @name Color#clone
     * @description Returns an identical copy of this object.
     * @returns {Color} The cloned instance.
     * @sdk 11.7.0
     */
    clone(): Color;
    /**
     * @function
     * @name Color#lerp
     * @description Calculates the linear interpolation between two colors (Factor 0.0 - 1.0).
     * @param {Color} c0 - 1st Color.
     * @param {Color} c1 - 2nd Color.
     * @param {number} t - Factor will be clamped to 0.0 - 1.0.
     * @param {Color} out - output vector.
     * @returns {Color} - Self for chaining.
     * @static
     * @sdk 11.7.0
     */
    static lerp(c0: Color, c1: Color, t: number, out?: Color): Color;
}
export default Color;
