import Amaz = effect.Amaz;
/**
 * @class
 * @category Math
 * @name Rect
 * @classdesc Class to describe a rectangle.
 * @description Constructor to create a Rect instance.
 * @param {number} x - Rectangle x coordinate defaults to 0.
 * @param {number} y - Rectangle y coordinate defaults to 0.
 * @param {number} width - Rectangle width defaults to 0.
 * @param {number} height - Rectangle height defaults to 0.
 * @sdk 11.7.0
 */
export default class Rect {
    private static readonly X;
    private static readonly Y;
    private static readonly Width;
    private static readonly Height;
    private _native;
    private _values;
    private _supportMemoryMapping;
    constructor();
    constructor(x: number, y: number, width: number, height: number);
    constructor(rect: Amaz.Rect);
    static fromNative(nativeRect: Amaz.Rect): Rect;
    /**
     * @function
     * @name Rect#eq
     * @description Judge whether the value of one rectangle is equal to other rectangle.
     * @param {Rect} r0 - One rectangle.
     * @param {Rect} r1 - Other rectangle.
     * @returns {boolean} - Returns true if the Rect are equal and false otherwise.
     * @static
     * @sdk 11.7.0
     */
    static eq(r0: Rect, r1: Rect): boolean;
    /**
     * @name Rect#native
     * @type {Amaz.Rect}
     * @description Returns the native data structure of rectangle.
     * @sdk 11.7.0
     */
    get native(): Amaz.Rect;
    /**
     * @name Rect#x
     * @type {number}
     * @description Value of x coordinate.
     * @sdk 11.7.0
     */
    get x(): number;
    set x(value: number);
    /**
     * @name Rect#y
     * @type {number}
     * @description Value of y coordinate.
     * @sdk 11.7.0
     */
    get y(): number;
    set y(value: number);
    /**
     * @name Rect#width
     * @type {number}
     * @description Rectangle width.
     * @sdk 11.7.0
     */
    get width(): number;
    set width(value: number);
    /**
     * @name Rect#height
     * @type {number}
     * @description Rectangle height.
     * @sdk 11.7.0
     */
    get height(): number;
    set height(value: number);
    /**
     * @function
     * @name Rect#eq
     * @description Judge whether the value of current rectangle is equal to other rectangle.
     * @param {Rect} other - Other rectangle.
     * @returns {boolean} - Returns true if the rectangle are equal and false otherwise.
     * @sdk 11.7.0
     */
    eq(other: Rect): boolean;
    /**
     * @function
     * @name Rect#toString
     * @description Return current rectangle value in string.
     * @returns {string} - Current rectangle value in string.
     * @sdk 11.7.0
     */
    toString(): string;
    /**
     * @function
     * @name Rect#copy
     * @description Copy the elements from target to this object.
     * @param {Rect} target - Target.
     * @returns {Rect} - Self for chaining.
     * @sdk 11.7.0
     */
    copy(target: Rect): Rect;
    /**
     * @function
     * @name Rect#clone
     * @description Returns an identical copy of this object.
     * @returns {Rect} The cloned instance.
     * @sdk 11.7.0
     */
    clone(): Rect;
}
