import Asset from '../../asset/asset';
/**
 * @class
 * @category Core
 * @name AssetRegistry
 * @classdesc Class to load and store all the assets used by the engine.
 * @example
 * // use assetRegistry to load a {@link Asset}
 * engine.assets.loadBundle('asset.zip', bundleLoad);
 * @hideconstructor
 * @sdk 9.8.0
 */
export default class AssetRegistry {
    /**
     * @function
     * @name AssetRegistry#destroy
     * @description Destroy the asset registry.
     * @sdk 9.8.0
     */
    destroy(): void;
    /**
     * @name AssetRegistry#rootDir
     * @type {string}
     * @description get the root directory of the current sticker [read only]
     * @sdk 9.8.0
     */
    get rootDir(): string;
    /**
     * @function
     * @name AssetRegistry#loadSync
     * @returns {any} loaded asset object
     * @description load an asset from the specified path (synchronized)
     * @param {string} uri the uri for the asset it could be file path or asset uri
     * @example
     * // loading a mesh {@link Asset}
     * engine.assets.loadSync('robot.mesh');
     * // loading a custom asset with uri
     * engine.assets.loadSync('custom://123456');
     * @sdk 9.8.0
     */
    loadSync(uri: string): Asset | null;
    /**
     * @function
     * @name AssetRegistry#loadResource
     * @param {string} assetPath The user-generated path for the resource
     * @description load a resource based on user-generated path mapping (synchronous)
     * @returns {Asset} the loaded asset
     */
    loadResource(assetPath: string): Asset | null;
}
