/**
 * @class
 * @category Core
 * @name ResourcePathRegistry
 * @classdesc The resource path registry maps resource paths in the user-generated hierarchy in the asset panel, to exported files in an effect. This mapping makes it easy for script developers to access resources using a familiar name.
 * @description Maintain the mapping between resource paths and exported resource filenames
 * @example
 * const resource_uri = ResourcePathRegistry.getInstance().getExportedResourceName('Assets/Textures/happy.png')
 * const my_texture = loadSync(resource_uri);
 * @sdk 9.8.0
 */
export default class ResourcePathRegistry {
    private static _instance;
    private _registry;
    /**
     * @function
     * @name ResourcePathRegistry#getInstance
     * @returns {ResourcePathRegistry} the singleton instance of ResourcePathRegistry
     */
    static getInstance(): ResourcePathRegistry;
    private bufferToStr;
    /**
     * @function
     * @name ResourcePathRegistry#init
     * @description initializes the resource path registry
     */
    init(): void;
    /**
     * @function
     * @name ResourcePathRegistry#getAssetUri
     * @param {string} assetPath the path of the asset to look up in the registry
     * @returns {string} the path of the exported asset, undefined if not found
     */
    getAssetUri(assetPath: string): string | undefined;
}
