import EventHandler from '../../base/event-handler';
/**
 * @class
 * @category Input
 * @name Gyroscope
 * @augments EventHandler
 * @classdesc Gyroscope class for motion events from device's motion sensor.
 * @description Constructor to create the Gyroscope instance.
 * To add an Gyroscope to {@link Engine},
 * @param {object} options - Options for update gyroscope data.
 * @param {number} options.interval - The update interval. Default 50ms.
 * @example
 * // Add Gyroscope to engine.
 * const gyro = new amg.Gyroscope(options);
 * const engine = new amg.Engine(canvas, { touch, gyro });
 * gyro.on('change', function (gyroData) {
 *   console.log(gyroData);
 * });
 * @sdk 9.8.0
 */
export default class Gyroscope extends EventHandler {
    private hasGyroStarted;
    constructor();
    destroy(): void;
    /**
     * @event
     * @name Gyroscope#change
     * @description Fired when gyroscope was changed.
     * @param {GyroData} gyroData - Gyroscope data.
     * @example
     * gyro.on('change', function (gyroData) {
     *     console.log(gyroData);
     * });
     * @sdk 9.8.0
     */
    start(): void;
    /**
     * @name Gyroscope#hasStarted
     * @type {boolean}
     * @description Check if gyroscope has started.
     * @readonly
     * @sdk 9.8.0
     */
    get hasStarted(): boolean;
}
