import Amaz = effect.Amaz;
import EventHandler from '../../../base/event-handler';
import { GestureType, GestureRecognizerState } from '../../../base/const';
import TouchGesture from '../touch-gesture';
/**
 * @class
 * @category Gesture
 * @name GestureRecognizer
 * @augments EventHandler
 * @classdesc The GestureRecognizer class is the base class for recognizing touch gestures.
 * @description Constructor to create an GestureRecognizer instance.
 * @param {GestureType} type - The type of the GestureRecognizer.
 * @param {string} name  - The name of GestureRecognizer.
 * @param {TouchGesture} touchGesture - The touchGesture instance.
 */
export default class GestureRecognizer extends EventHandler {
    protected _type: GestureType;
    protected _state: GestureRecognizerState;
    protected _touchGesture: TouchGesture;
    constructor(type: GestureType, touchGesture: TouchGesture);
    /**
     * @name GestureRecognizer#type
     * @type {GestureType}
     * @description The type of the GestureRecognizer.
     * @readonly
     */
    get type(): GestureType;
    /**
     * @name GestureRecognizer#state
     * @type {GestureRecognizerState}
     * @description The state of the GestureRecognizer. If the state is changed to
     * Began, Ended or Changed, the TouchGesture instance will fire the event.
     */
    get state(): GestureRecognizerState;
    set state(state: GestureRecognizerState);
    reset(): void;
    update(_deltaTime: number): void;
    handleTouch(_touch: Amaz.TouchPointer): void;
}
