import Amaz = effect.Amaz;
import EventHandler from '../../base/event-handler';
export declare enum TouchEventType {
    TouchStart = 0,
    TouchMove = 1,
    TouchStationary = 2,
    TouchEnd = 3,
    TouchCancel = 4
}
export declare class Touch {
    identifier: number;
    type: TouchEventType;
    x: number;
    y: number;
    force: number;
    size: number;
    time: number;
    count: number;
    valid: boolean;
    constructor(identifier?: number, type?: TouchEventType, screenX?: number, screenY?: number, force?: number, size?: number, time?: number, count?: number);
    static fromNative(native: Amaz.TouchPointer): Touch;
    private static convertTouchType;
}
/**
 * @class
 * @category Input
 * @name TouchDevice
 * @augments EventHandler
 * @classdesc TouchDevice class for touch input events from canvas element.
 * @description Constructor function to create the TouchDevice instance with canvas.
 * To add an TouchDevice to {@link Engine},
 * @param {HTMLCanvasElement} canvas - The sceneObject.
 * @hideconstructor
 * @sdk 9.8.0
 */
/**
 * @event
 * @name TouchDevice#touchstart
 * @description Fired when touch input has started.
 * @param {TouchEvent} event - Touch event data.
 * @example
 * touch.on('touchstart', function (eventData) {
 *     console.log('Touch input has started');
 * });
 * @sdk 9.8.0
 */
/**
 * @event
 * @name TouchDevice#touchmove
 * @description Fired when touch input is moving.
 * @param {TouchEvent} event - Touch event data.
 * @example
 * touch.on('touchmove', function (eventData) {
 *     console.log('Touch input is moving');
 * });
 * @sdk 9.8.0
 */
/**
 * @event
 * @name TouchDevice#touchend
 * @description Fired when touch input has ended.
 * @param {TouchEvent} event - Touch event data.
 * @example
 * touch.on('touchend', function (eventData) {
 *     console.log('Touch input has ended');
 * });
 * @sdk 9.8.0
 */
/**
 * @event
 * @name TouchDevice#touchcancel
 * @description Fired when touch input was cancelled.
 * @param {TouchEvent} event - Touch event data.
 * @example
 * touch.on('touchcancel', function (eventData) {
 *     console.log('Touch input was cancelled');
 * });
 * @sdk 9.8.0
 */
export default class TouchDevice extends EventHandler {
    private _width;
    private _height;
    constructor(width: number, height: number);
    start(): void;
    destroy(): void;
    onEvent(event: Amaz.Event): void;
    private convertTouchEvent;
}
