import Amaz = effect.Amaz;
import EventHandler from '../../base/event-handler';
import TapGestureRecognizer from './recognizer/tap-recognizer';
import PanGestureRecognizer from './recognizer/pan-recognizer';
import RotationGestureRecognizer from './recognizer/rotation-recognizer';
import PinchGestureRecognizer from './recognizer/pinch-recognizer';
import LongPressGestureRecognizer from './recognizer/longpress-recognizer';
import DoubleTapGestureRecognizer from './recognizer/doubletap-recognizer';
import { Vec2 } from '../..';
/**
 * @class
 * @category Gesture
 * @name TouchGesture
 * @augments EventHandler
 * @classdesc TouchGesture class for recognizing touch gesture.
 * @description Constructor to create a TouchGesture instance.
 */
export default class TouchGesture extends EventHandler {
    private _gestureRecognizers;
    private _mockPoint;
    private _currentTouchNum;
    constructor();
    start(): void;
    destroy(): void;
    /**
     * @name TouchGesture#tap
     * @type {TapGestureRecognizer}
     * @description tap gesture recognizer.
     * @readonly
     * @sdk 11.0.0
     */
    get tap(): TapGestureRecognizer;
    /**
     * @name TouchGesture#pan
     * @type {PanGestureRecognizer}
     * @description pan gesture recognizer.
     * @readonly
     * @sdk 11.0.0
     */
    get pan(): PanGestureRecognizer;
    /**
     * @name TouchGesture#rotation
     * @type {RotationGestureRecognizer}
     * @description rotation gesture recognizer.
     * @readonly
     * @sdk 11.0.0
     */
    get rotation(): RotationGestureRecognizer;
    /**
     * @name TouchGesture#pinch
     * @type {PinchGestureRecognizer}
     * @description pinch gesture recognizer.
     * @readonly
     * @sdk 11.0.0
     */
    get pinch(): PinchGestureRecognizer;
    /**
     * @name TouchGesture#longPress
     * @type {LongPressGestureRecognizer}
     * @description longPress gesture recognizer.
     * @readonly
     * @sdk 11.0.0
     */
    get longPress(): LongPressGestureRecognizer;
    /**
     * @name TouchGesture#doubleTap
     * @type {DoubleTapGestureRecognizer}
     * @description doubleTap gesture recognizer.
     * @readonly
     * @sdk 11.0.0
     */
    get doubleTap(): DoubleTapGestureRecognizer;
    /**
     * @function
     * @name TouchGesture#pushMockTouch
     * @description push a mock touch to simulate multi-touch on the desktop.
     * @param {Vec2} point - The mock touch position
     */
    pushMockTouch(point: Vec2): void;
    /**
     * @function
     * @name TouchGesture#popMockTouch
     * @description remove the last mock touch
     */
    popMockTouch(): void;
    update(_deltaTime: number): void;
    private _reset;
    private _countTouch;
    private _needReset;
    private _handleTouch;
    private _handleMockTouch;
    onEvent(event: Amaz.Event): void;
}
