import Amaz = effect.Amaz;
import Vec3 from '../math/vec3';
import SceneObject from './scene-object';
/**
 * @class
 * @category Core
 * @name Scene
 * @classdesc Scene Class to manage the scene graph hierarchy and all graphical objects.
 * @description Constructor to create an Scene instance.
 * @param {string} name - The name of the scene.
 * @sdk 9.8.0
 * @hideconstructor
 */
/**
 * @name Scene#root
 * @type {SceneObject}
 * @description Root sceneObject of the scene.
 * @sdk 9.8.0
 */
export default class Scene {
    native: any;
    root: SceneObject;
    sceneObjects: Map<number, SceneObject>;
    private _physicsSystem;
    constructor(name?: Amaz.Scene | string | undefined);
    private findRoot;
    /**
     * @name Scene#children
     * @type {SceneObject[]}
     * @description Scene's children.
     * @sdk 9.8.0
     */
    get children(): SceneObject[];
    /**
     * @name Scene#name
     * @type {string}
     * @description Scene's name.
     * @sdk 9.8.0
     */
    get name(): string;
    set name(value: string);
    /**
     * @name Scene#visible
     * @type {boolean}
     * @description Scene's visible flag.
     * @sdk 9.8.0
     */
    get visible(): boolean;
    set visible(value: boolean);
    /**
     * @function
     * @name Scene#addSystem
     * @description Add system by name.
     * @param {string} name - Name of the system to add.
     * @sdk 9.8.0
     */
    addSystem(name: string): void;
    addSceneObjectToCache(sceneObject: SceneObject): void;
    removeSceneObjectToCache(sceneObject: SceneObject): void;
    sceneObjectFromNative(native: any): SceneObject | undefined;
    /**
     * @function
     * @name Scene#destroy
     * @description Remove and clean up scene.
     * @sdk 9.8.0
     */
    destroy(): void;
    /**
     * @function
     * @name Scene#rayCast
     * @description Raycast to find hit rigidbody sceneObjects in scene.
     * @param {Vec3} from - Start point of the ray.
     * @param {Vec3} to - End point of the ray.
     * @returns {Array<SceneObject>} List of hit sceneObjects.
     * @sdk 9.8.0
     */
    rayCast(from: Vec3, to: Vec3): Array<SceneObject>;
    /**
     * @function
     * @name Scene#findByName
     * @description Find sceneObject by name.
     * @param {string} name - SceneObject's name.
     * @returns {SceneObject} - The qualified sceneObject.
     * @sdk 9.8.0
     */
    findByName(name: string): SceneObject | undefined;
    /**
     * @function
     * @name Scene#findByTag
     * @description Find sceneObject by tag.
     * @param {number} tag - SceneObject's tag.
     * @returns {SceneObject} - The qualified sceneObject.
     * @sdk 9.8.0
     */
    findByTag(tag: number): SceneObject | undefined;
    /**
     * @function
     * @param type
     * @name Scene#findByComponent
     * @description Find sceneObject by component class.
     * @param {any} string - Any component class.
     * @returns {SceneObject} - The qualified sceneObject.
     * @sdk 9.8.0
     */
    findByComponent(type: string): SceneObject | undefined;
    /**
     * @function
     * @name Scene#findAllByName
     * @description Find sceneObjects by name.
     * @param {string} name - SceneObject's name.
     * @returns {SceneObject[]} - The qualified sceneObjects.
     * @sdk 9.8.0
     */
    findAllByName(name: string): SceneObject[];
    /**
     * @function
     * @name Scene#findAllByTag
     * @description Find sceneObjects by tag.
     * @param {number} tag - SceneObject's tag.
     * @returns {SceneObject[]} - The qualified sceneObjects.
     * @sdk 9.8.0
     */
    findAllByTag(tag: number): SceneObject[];
    /**
     * @function
     * @param type
     * @name Scene#findAllByComponent
     * @description Find sceneObjects by component class.
     * @param {any} string - Any component class.
     * @returns {SceneObject[]} - The qualified sceneObjects.
     * @sdk 9.8.0
     */
    findAllByComponent(type: string): SceneObject[];
    private get physicsSystem();
}
