declare namespace effect {
  namespace Amaz {
    namespace AmazingManager {
      /**
       * @brief JsAmazingManager init
       * @param arg0 width
       * @param arg1 height
       */
      function init(arg0: number, arg1: number): void;
      /**
       * @brief resize the view
       * @param arg0 width
       * @param arg1 height
       */

      function resize(arg0: number, arg1: number): void;
      /**
       * @brief setInputTexture
       * @param arg0 GL textureId or Texture2D
       * @param arg1 width
       * @param arg2 height
       * @param arg3 textureYFlip
       * @param arg4 rtYFlip
       * @param arg5 BuiltInTextureType
       */

      function setInputTexture(arg0: {
        _value: number;
      } | Texture2D, arg1?: number, arg2?: number, arg3?: boolean, arg4?: boolean, arg5?: BuiltInTextureType): void;
      /**
       * @brief setInputTexture
       * @param arg0 GL textureId or Texture2D
       * @param arg1 width
       * @param arg2 height
       * @param arg3 BuiltInTextureType
       */

      function setInputTexture(arg0: number | {
        _value: number;
      } | Texture2D, arg1: number, arg2: number, arg3: BuiltInTextureType): void;
      /**
       * @brief setInputTexture
       * @param arg0 GL textureId or Texture2D
       * @param arg1 BuiltInTextureType
       */

      function setInputTexture(arg0: number | {
        _value: number;
      } | Texture2D, arg1: BuiltInTextureType): void;
      /**
       * @brief setOutputTexture
       * @param arg0 GL textureId or Texture2D
       * @param arg1 width
       * @param arg2 height
       * @param arg3 textureYFlip
       * @param arg4 rtYFlip
       */

      function setOutputTexture(arg0: number | {
        _value: number;
      } | Texture2D, arg1?: number, arg2?: number, arg3?: boolean, arg4?: boolean): void;
      /**
       * @brief update one frame
       * @param arg0 timestamp
       */

      function update(arg0: number): void;
      /**
       * @brief call onPause
       * @param arg0 PAUSE_TYPE eg. AMAZ_PAUSE_TYPE_BGM 0x00000001
       */

      function onPause(arg0: number): void;
      /**
       * @brief call onResume
       * @param arg0 PAUSE_TYPE eg. AMAZ_PAUSE_TYPE_BGM 0x00000001
       */

      function onResume(arg0: number): void;
      /**
       * @brief add a scene to viewer
       * @param arg0 the scene to be added
       * @param arg1 order of the scene when rendering
       */

      function addScene(arg0: Scene, arg1?: number): void;
      /**
       * @brief remove a scene from viewer
       * @param arg0 the scene to be removed
       */

      function removeScene(arg0: Scene): void;
      /**
       * @brief load a scene from resource path
       * @param arg0 path to load the scene
       * @return scene
       */

      function loadScene(arg0: string, arg1?: string[], arg2?: AssetManager): Scene | undefined;
      /**
       * @brief load the prefab from
       * @param arg0 absolute file path or dir of the resource
       * @param arg1 filename of the resource when arg0 is dir
       * @return object
       */

      function loadResource(arg0: string, arg1?: string): AObject | undefined;
      /**
       * @brief set AEAlgorithmResult to Amazer
       * @param arg0 AEAlgorithmResult
       */

      function setAlgorithmResult(arg0: AEAlgorithmResult): void;
      /**
       * @brief clear AEAlgorithmResult from Amazer
       */

      function clearAlgorithmResult(): void;
      /**
       * @brief add listener to Object
       * @param arg0 listen target
       * @param arg1 listener type
       * @param arg2 callback function
       * @param arg3 userdata
       */

      function addListener(arg0: AObject, arg1: number, arg2: (user: object, obj: AObject, type: number) => void, arg3?: object): void;
      /**
       * @brief remove listener from Object
       * @param arg0 listen target
       * @param arg1 listener type
       * @param arg2 callback function
       * @param arg3 userdata
       */

      function removeListener(arg0: AObject, arg1: number, arg2: (user: object, obj: AObject, type: number) => void, arg3?: object): void;
      /**
       * @brief send touch event into amazer
       * @param arg0 pointerId
       * @param arg1 x
       * @param arg2 y
       * @param arg3 force
       * @param arg4 majorRadius
       * @param arg5 type
       * @param arg6 pointerCount
       */

      function onTouchEvent(arg0: number, arg1: number, arg2: number, arg3: number, arg4: number, arg5: number, arg6: number): void;
      /**
       * @brief send touch event into amazer
       * @param arg0 pointerId
       * @param arg1 x
       * @param arg2 y
       * @param arg3 type
       * @param arg4 pointerCount
       */

      function onTouchEvent(arg0: number, arg1: number, arg2: number, arg3: number, arg4: number): void;
      /**
       * @brief get singleton from amazer
       * @param arg0 type name of singleton
       */

      function getSingleton(arg0: 'Profiler' | 'Calibrate' | 'Input' | 'BuiltinObject' | 'AppInfo' | 'PrefabManager' | 'AMGAudioModule' | 'DictionaryManager' | 'Algorithm' | 'BingoGPU' | 'NetworkCenter' | 'NetworkCenterWS' | 'AnalyticsManager'): any;
    }
    class AlgorithmManager {
      /**
       * @brief constructor
       * @param arg0 use bach if opened
       */
      constructor(arg0?: boolean);
      /**
       * @brief init algorithm
       * @param arg0 width
       * @param arg1 height
       * @param arg2 use syncmode
       */

      public init(arg0: number, arg1: number, arg2?: boolean): void;
      /**
       * @brief execute algorithm
       * @param arg0 texture
       * @param arg1 width
       * @param arg2 height
       * @param arg3 timestamp
       */

      public doExecute(arg0: number | {
        _value: number;
      } | Texture2D, arg1: number, arg2: number, arg3: number): void;
      /**
       * @brief setRequirement
       * @param arg0 array of requirements
       */

      public setRequirement(arg0: [string]): void;
      /**
       * @brief setGraphConfig
       * @param arg0 graphName
       * @param arg1 path
       */

      public setGraphConfig(arg0: string, arg1: string): void;
      /**
       * @brief downloadModel with no callback
       * @param arg0 array of requirements
       * @param arg1 json of models
       * @return JsDownloadStatus
       */

      public downloadModel(arg0: [string], arg1: string): JsDownloadStatus;
      /**
       * @brief downloadModel with no callback
       * @param arg0 array of requirements
       * @param arg1 json of models
       */

      public downloadModel(arg0: [string], arg1: string, arg2: (task: JsDownloadStatus) => void): void;
    }
    function LOGE(tag: string, format: string): undefined;
    function LOGW(tag: string, format: string): undefined;
    function LOGS(tag: string, format: string): undefined;
    function LOGI(tag: string, format: string): undefined;
    function LOGD(tag: string, format: string): undefined;
    function LOGV(tag: string, format: string): undefined;
    namespace AmazingUtil {
      function vec2VectorToVec4Vector(arg0: Vec2Vector): Vec4Vector;
      function vec3VectorToVec4Vector(arg0: Vec3Vector): Vec4Vector;
      function vec4VectorToVec2Vector(arg0: Vec4Vector): Vec2Vector;
      function vec4VectorToVec3Vector(arg0: Vec4Vector): Vec3Vector;
      function vec2VectorToVec3Vector(arg0: Vec2Vector): Vec3Vector;
      function vec3VectorToVec2Vector(arg0: Vec3Vector): Vec2Vector;
      function getArrayBuffer(inVector: Int8Vector | Int16Vector | Int32Vector | Int64Vector | UInt8Vector | UInt16Vector | UInt32Vector | FloatVector | DoubleVector | Vec2Vector | Vec3Vector | Vec4Vector | QuatVector | Matrix4x4f | Vector3f | Guid, outBuffer: ArrayBuffer): ArrayBuffer | undefined;
      function getArrayBuffer(inVector: Int8Vector | Int16Vector | Int32Vector | Int64Vector | UInt8Vector | UInt16Vector | UInt32Vector | FloatVector | DoubleVector | Vec2Vector | Vec3Vector | Vec4Vector | QuatVector | Matrix4x4f | Vector3f | Guid, byteOffset?: number, copySize?: number, outBuffer?: ArrayBuffer): ArrayBuffer | undefined;
      function arrayBufferToPrimitiveVector(inBuffer: ArrayBuffer, outVector: Int8Vector | Int16Vector | Int32Vector | Int64Vector | UInt8Vector | UInt16Vector | UInt32Vector | FloatVector | DoubleVector | Vec2Vector | Vec3Vector | Vec4Vector | QuatVector): void;
      function arrayBufferToPrimitiveVector(inBuffer: ArrayBuffer, byteOffset: number, copySize: number, outVector: Int8Vector | Int16Vector | Int32Vector | Int64Vector | UInt8Vector | UInt16Vector | UInt32Vector | FloatVector | DoubleVector | Vec2Vector | Vec3Vector | Vec4Vector | QuatVector): void;
      function externalTextureToAMGTexture2D(tex: number | {
        _value: number;
      } | Texture2D, width: number, height: number, textureYFlip?: boolean, rtYFlip?: boolean): Texture2D | undefined;
      function convertBufferToImage(buffer: ArrayBuffer, width: number, height: number, format?: number): Image;
      function guidToPointer(guid: Guid): AObject | null;
      function setWatchValue(key: string, value: Variant): boolean;
      function getWatchValue(key: string): Variant | null;
    }
    namespace Platform {
      function getAccelValues(): Vector3f;
      function getAccelEulerValues(): Vector2f;
      function getGyroValues(): Vector3f;
      function getFov(): number;
      function name(): string;
      function getDeviceRotation(): Quaternionf;
      function getDeviceOrientation(): number;
      function getCameraToward(): number;
    }
    namespace Hand3DUtil {
      function calRotaionOnYaxis(param1: Vector3f, param2: Vector3f): void;
    }
  }
}
declare namespace effect {
  namespace Amaz {
    type MathVec = Vector2f | Vector3f | Vector4f;
    type MathMat = Matrix3x3f | Matrix4x4f;
    type MathGeo = Rect | Plane | Color | AABB | Quaternionf;
    type MathType = MathVec | MathMat | MathGeo | DynamicBitset;
    type Collective = Amaz.Vector | Amaz.Map;
    type PrimitiveVector = Int8Vector | Int16Vector | Int32Vector | Int64Vector | UInt8Vector | UInt16Vector | UInt32Vector | FloatVector | DoubleVector | StringVector | Vec2Vector | Vec3Vector | Vec4Vector | QuatVector;
    type PrimitiveDataType = MathType | Collective | PrimitiveVector | Guid;
    type Variant = PrimitiveDataType | Object;
    class Ray {
      constructor();
      constructor(min: Vector3f, max: Vector3f);
      public origin: effect.Amaz.Vector3f;
      public direction: effect.Amaz.Vector3f;
      public eq(v: Ray): boolean;
      public equals(v: Ray): boolean;
      public toString(): string;
      public getPoint(v: number): Vector3f;
      public sqrDistToPoint(v: Vector3f): number;
      public static eq(v0: Ray, v1: Ray): boolean;
      public static equals(v0: Ray, v1: Ray): boolean;
    }
    class AABB {
      constructor();
      constructor(min: Vector3f, max: Vector3f);
      public min_x: number;
      public min_y: number;
      public min_z: number;
      public max_x: number;
      public max_y: number;
      public max_z: number;
      public eq(v: AABB): boolean;
      public equals(v: AABB): boolean;
      public toString(): string;
      public static eq(v0: AABB, v1: AABB): boolean;
      public static equals(v0: AABB, v1: AABB): boolean;
      public getMinVectorBuffer(): Float32Array;
      public getMaxVectorBuffer(): Float32Array;
    }
    class Sphere {
      constructor();
      constructor(center: Vector3f, radius: number);
    }
    class Plane {
      constructor();
      constructor(v0: Vector3f, v1: number);
      public eq(v: Plane): boolean;
      public equals(v: Plane): boolean;
      public toString(): string;
      public getNormal(): Vector3f;
      public getD(): number;
      public getDistance(v: Vector3f): number;
      public getDistance(v: Vector4f): number;
      public getSide(v: Vector3f): Plane;
      public getSide(v0: Vector3f, v1: Vector3f): Plane;
      public toVec4(): Vector4f;
      public static eq(v0: Plane, v1: Plane): boolean;
      public static equals(v0: Plane, v1: Plane): boolean;
    }
    class Color {
      constructor();
      constructor(r: number, g: number, b: number);
      constructor(r: number, g: number, b: number, a: number);
      public a: number;
      public r: number;
      public g: number;
      public b: number;
      public eq(v: Color): boolean;
      public equals(v: Color): boolean;
      public toString(): string;
      public copy(): Color;
      public static eq(v0: Color, v1: Color): boolean;
      public static equals(v0: Color, v1: Color): boolean;
      public getBuffer(): Float32Array;
    }
    class DynamicBitset {
      constructor();
      constructor(v0: number, v1: number);
      public eq(v: DynamicBitset): boolean;
      public equals(v: DynamicBitset): boolean;
      public toString(): string;
      public test(v: number): boolean;
      public any(): boolean;
      public none(): boolean;
      public reset(v: number): DynamicBitset;
      public set(): void;
      public set(v: number): void;
      public set(v0: number, v1: number): void;
      public static eq(v0: DynamicBitset, v1: DynamicBitset): boolean;
      public static equals(v0: DynamicBitset, v1: DynamicBitset): boolean;
    }
    class Rect {
      constructor();
      constructor(x: number, y: number, width: number, height: number);
      public x: number;
      public y: number;
      public width: number;
      public height: number;
      public eq(v: Rect): boolean;
      public equals(v: Rect): boolean;
      public toString(): string;
      public copy(): Rect;
      public static eq(v0: Rect, v1: Rect): boolean;
      public static equals(v0: Rect, v1: Rect): boolean;
      public getBuffer(): Float32Array;
    }
    class Vector2f {
      constructor();
      constructor(x: number, y: number);
      public x: number;
      public y: number;
      public eq(v: Vector2f): boolean;
      public equals(v: Vector2f): boolean;
      public toString(): string;
      public set(x: number, y: number): void;
      public add(v: Vector2f): Vector2f;
      public sub(v: Vector2f): Vector2f;
      public unm(): Vector2f;
      public mul(v: number): Vector2f;
      public div(v: number): Vector2f;
      /**
       * @return self
       */

      public scale(v: Vector2f): Vector2f;
      public dot(v: Vector2f): number;
      /**
       * @return square of magnitude
       */

      public sqrMagnitude(): number;
      /**
       * @return magnitude
       */

      public magnitude(): number;
      /**
       * @return angle in radians
       */

      public angle(v: Vector2f): number;
      public inverse(): Vector2f;
      public normalize(): Vector2f;
      public normalizeFast(): Vector2f;
      public normalizeSafe(): Vector2f;
      public normalizeSafe(defaultV: Vector2f): Vector2f;
      public lerp(v: Vector2f, s: number): Vector2f;
      public lerp(v0: Vector2f, v1: Vector2f, s: number): Vector2f;
      public min(v: Vector2f): Vector2f;
      public max(v: Vector2f): Vector2f;
      /**
       * @param maxDist optional, default is 0.00001
       */

      public compareApproximately(v: Vector2f): boolean;
      public compareApproximately(v: Vector2f, maxDist: number): boolean;
      /**
       * @param epsilon optional
       */

      public isNormalized(): number;
      public abs(): Vector2f;
      public isFinite(): boolean;
      public distance(v: Vector2f): number;
      public copy(): Vector2f;
      public static eq(v0: Vector2f, v1: Vector2f): boolean;
      public static equals(v0: Vector2f, v1: Vector2f): boolean;
      public static add(v0: Vector2f, v1: Vector2f): Vector2f;
      public static sub(v0: Vector2f, v1: Vector2f): Vector2f;
      public static mul(v0: Vector2f, v1: number): Vector2f;
      public static div(v0: Vector2f, v1: number): Vector2f;
      public getBuffer(): Float32Array;
    }
    class Vector3f {
      constructor();
      constructor(x: number, y: number);
      constructor(x: number, y: number, z: number);
      public x: number;
      public y: number;
      public z: number;
      public eq(v: Vector3f): boolean;
      public equals(v: Vector3f): boolean;
      public toString(): string;
      public set(x: number, y: number, z: number): void;
      public add(v: Vector3f): Vector3f;
      public sub(v: Vector3f): Vector3f;
      public unm(): Vector3f;
      public mul(v: number): Vector3f;
      public div(v: number): Vector3f;
      public scale(v: Vector3f): Vector3f;
      public dot(v: Vector3f): number;
      /**
       * @return square of magnitude
       */

      public sqrMagnitude(): number;
      /**
       * @return magnitude
       */

      public magnitude(): number;
      public inverse(): Vector3f;
      public normalize(): Vector3f;
      public normalizeFastest(): Vector3f;
      /**
       * @param invOriginalLength optional
       */

      public normalizeRobust(): Vector3f;
      public normalizeRobust(invOriginalLength: number): Vector3f;
      public normalizeSafe(): Vector3f;
      public normalizeSafe(defaultV: Vector3f): Vector3f;
      public lerp(v: Vector3f, s: number): Vector3f;
      public lerp(v0: Vector3f, v1: Vector3f, s: number): Vector3f;
      public min(v0: Vector3f, v1: Vector3f): Vector3f;
      public max(v0: Vector3f, v1: Vector3f): Vector3f;
      /**
       * @param maxDist optional, default is 0.00001
       */

      public compareApproximately(v: Vector3f): boolean;
      public compareApproximately(v: Vector3f, maxDist: number): boolean;
      /**
       * @param epsilon optional
       */

      public isNormalized(): number;
      public abs(): Vector3f;
      public isFinite(): boolean;
      public distance(v: Vector3f): number;
      public cross(v: Vector3f): Vector3f;
      public reflectVector(normalVector: Vector3f): Vector3f;
      public project(v: Vector3f): Vector3f;
      public orthoNormalizeFast(v0: Vector3f, v1: Vector3f): void;
      /**
       * @param v3 optional
       */

      public orthoNormalize(v0: Vector3f, v1: Vector3f): void;
      public orthoNormalVectorFast(): Vector3f;
      public rotateTowards(v0: Vector3f, v1: number, v2: number): Vector3f;
      public rotateTowards(v0: Vector3f, v1: Vector3f, v2: number, v3: number): Vector3f;
      public slerp(v: Vector3f, s: number): Vector3f;
      public moveTowards(v0: Vector3f, v1: number): Vector3f;
      public moveTowards(v0: Vector3f, v1: Vector3f, v2: number): Vector3f;
      public copy(): Vector3f;
      public static eq(v0: Vector3f, v1: Vector3f): boolean;
      public static equals(v0: Vector3f, v1: Vector3f): boolean;
      public static add(v0: Vector3f, v1: Vector3f): Vector3f;
      public static sub(v0: Vector3f, v1: Vector3f): Vector3f;
      public static mul(v0: Vector3f, v1: number): Vector3f;
      public static div(v0: Vector3f, v1: number): Vector3f;
      public getBuffer(): Float32Array;
    }
    class Vector4f {
      constructor();
      constructor(x: number, y: number, z: number, w: number);
      public x: number;
      public y: number;
      public z: number;
      public w: number;
      public eq(v: Vector4f): boolean;
      public equals(v: Vector4f): boolean;
      public toString(): string;
      public add(v: Vector4f): Vector4f;
      public sub(v: Vector4f): Vector4f;
      public unm(): Vector4f;
      public mul(v: Vector4f): Vector4f;
      public mul(v: number): Vector4f;
      public div(v: number): Vector4f;
      public set(x: number, y: number, z: number, w: number): void;
      public dot(v: Vector4f): number;
      public lerp(v: Vector4f, s: number): Vector4f;
      public lerp(v0: Vector4f, v1: Vector4f, s: number): Vector4f;
      public copy(): Vector4f;
      public static eq(v0: Vector4f, v1: Vector4f): boolean;
      public static equals(v0: Vector4f, v1: Vector4f): boolean;
      public static add(v0: Vector4f, v1: Vector4f): Vector4f;
      public static sub(v0: Vector4f, v1: Vector4f): Vector4f;
      public static mul(v0: Vector4f, v1: Vector4f): Vector4f;
      public static mul(v0: Vector4f, v1: number): Vector4f;
      public static div(v0: Vector4f, v1: number): Vector4f;
      public getBuffer(): Float32Array;
    }
    class Quaternionf {
      constructor();
      constructor(x: number, y: number, z: number, w: number);
      public x: number;
      public y: number;
      public z: number;
      public w: number;
      public eq(v: Quaternionf): boolean;
      public equals(v: Quaternionf): boolean;
      public toString(): string;
      public add(v: Quaternionf): Quaternionf;
      public sub(v: Quaternionf): Quaternionf; // public negate(): Quaternionf

      public mul(v: Quaternionf): Quaternionf;
      public unm(): Quaternionf;
      public set(x: number, y: number, z: number, w: number): void;
      public identity(): Quaternionf;
      public inverse(): Quaternionf;
      public eulerToQuaternion(v: Vector3f): Quaternionf;
      public quaternionToEuler(): Vector3f;
      public copy(): Quaternionf;
      public fromToQuaternionSafe(from: Vector3f, to: Vector3f): Quaternionf;
      public lookRotationToQuaternion(viewVec: Vector3f, upVec: Vector3f): Quaternionf;
      public LookRotationToQuaternion(viewVec: Vector3f, upVec: Vector3f): Quaternionf;
      public rotateVectorByQuat(v: Vector3f): Vector3f;
      public slerp(v: Quaternionf, s: number): Quaternionf;
      /**
       * @param angle in radians
       */

      public axisAngleToQuaternion(axis: Vector3f, angle: number): Quaternionf;
      public static eq(v0: Quaternionf, v1: Quaternionf): boolean;
      public static equals(v0: Quaternionf, v1: Quaternionf): boolean;
      public static add(v0: Quaternionf, v1: Quaternionf): Quaternionf;
      public static sub(v0: Quaternionf, v1: Quaternionf): Quaternionf;
      public static mul(q0: Quaternionf, q1: Quaternionf): Quaternionf;
      public static identity(): Quaternionf;
      public static fromToQuaternionSafe(from: Vector3f, to: Vector3f): Quaternionf;
      public static lookRotationToQuaternion(viewVec: Vector3f, upVec: Vector3f): Quaternionf;
      public static rotateVectorByQuat(v0: Quaternionf, v1: Vector3f): Vector3f;
      public static slerp(v0: Quaternionf, v1: Quaternionf, s: number): Quaternionf;
      public static axisAngleToQuaternion(axis: Vector3f, angle: number): Quaternionf;
      public getBuffer(): Float32Array;
    }
    class Matrix3x3f {
      constructor();
      constructor(v: Matrix4x4f);
      constructor(m0: number, m1: number, m2: number, m3: number, m4: number, m5: number, m6: number, m7: number, m8: number);
      public eq(v: Matrix3x3f): boolean;
      public equals(v: Matrix3x3f): boolean;
      public toString(): string;
      public mul(m: Matrix3x3f): Matrix3x3f;
      public set(row: number, col: number, val: number): void;
      public get(row: number, col: number): number;
      public getColumn(col: number): Vector3f;
      public multiplyVector3(v: Vector3f): Vector3f;
      public multiplyVector3Transpose(v: Vector3f): Vector3f;
      public multiplyPoint3Transpose(v: Vector3f): Vector3f;
      public getDeterminant(): number;
      /**
       * @return self
       */

      public transpose(): Matrix3x3f;
      public invert(): Matrix3x3f;
      public invertTranspose(): void;
      /**
       * @return self
       */

      public setIdentity(): Matrix3x3f;
      /**
       * @return self
       */

      public setZero(): Matrix3x3f;
      /**
       * @return self
       */

      public setFromToRotation(from: Vector3f, to: Vector3f): Matrix3x3f;
      /**
       * @param angle in radians
       * @return self
       */

      public setAxisAngle(axis: Vector3f, angle: number): Matrix3x3f;
      /**
       * @return self
       */

      public setOrthoNormalBasis(v1: Vector3f, v2: Vector3f, v3: Vector3f): Matrix3x3f;
      /**
       * @return self
       */

      public setOrthoNormalBasisInverse(v1: Vector3f, v2: Vector3f, v3: Vector3f): Matrix3x3f;
      /**
       * @return self
       */

      public setScale(v: Vector3f): Matrix3x3f;
      /**
       * @return self
       */

      public scale(v: Vector3f): Matrix3x3f;
      /**
       * @param epsilon optional
       */

      public isIdentity(): boolean;
      public isIdentity(v: number): boolean;
      public lookRotationToMatrix(viewVec: Vector3f, upVec: Vector3f, outMat: Matrix3x3f): boolean;
      /**
       * @param outVec output
       */

      public matrixToEuler(outVec: Vector3f): boolean;
      public eulerToMatrix(euler: Vector3f, outMat: Matrix3x3f): void;
      public orthoNormalize(): void;
      public static eq(v0: Matrix3x3f, v1: Matrix3x3f): boolean;
      public static equals(v0: Matrix3x3f, v1: Matrix3x3f): boolean;
      public static lookRotationToMatrix(viewVec: Vector3f, upVec: Vector3f, outMat: Matrix3x3f): boolean;
      public static matrixToEuler(v0: Matrix3x3f, outVec: Vector3f): boolean;
      public static eulerToMatrix(euler: Vector3f, outMat: Matrix3x3f): void;
      public static orthoNormalize(v0: Matrix3x3f): void;
      public getBuffer(): Float32Array;
    }
    class Matrix4x4f {
      constructor();
      constructor(v: Matrix3x3f);
      constructor(m0: number, m1: number, m2: number, m3: number, m4: number, m5: number, m6: number, m7: number, m8: number, m9: number, m10: number, m11: number, m12: number, m13: number, m14: number, m15: number);
      public eq(v: Matrix4x4f): boolean;
      public equals(v: Matrix4x4f): boolean;
      public toString(): string;
      public mul(m: Matrix4x4f): Matrix4x4f;
      public set(row: number, col: number, val: number): void;
      public get(row: number, col: number): number;
      public getColumn(col: number): Vector4f;
      public multiplyVector3(v: Vector3f): Vector3f;
      public multiplyVector4(v: Vector4f): Vector4f;
      public multiplyPoint3(p: Vector3f): Vector3f;
      public getDeterminant(): number;
      /**
       * @return self
       */

      public transpose(): Matrix4x4f;
      /**
       * @return self
       */

      public invert_Full(): Matrix4x4f;
      /**
       * @return self
       */

      public setIdentity(): Matrix4x4f;
      /**
       * @return self
       */

      public setFromToRotation(from: Vector3f, to: Vector3f): Matrix4x4f;
      /**
       * @return self
       */

      public setOrthoNormalBasis(v1: Vector3f, v2: Vector3f, v3: Vector3f): Matrix4x4f;
      /**
       * @return self
       */

      public setOrthoNormalBasisInverse(v1: Vector3f, v2: Vector3f, v3: Vector3f): Matrix4x4f;
      /**
       * @return self
       */

      public setScale(v: Vector3f): Matrix4x4f;
      /**
       * @return self
       */

      public scale(v: Vector3f): Matrix4x4f;
      /**
       * @param epsilon optional
       */

      public isIdentity(): boolean;
      public isIdentity(epsilon: number): boolean;
      public perspectiveMultiplyVector3(inVec: Vector3f, outVec: Vector3f): boolean;
      public perspectiveMultiplyPoint3(inP: Vector3f, outP: Vector3f): boolean;
      public inverseMultiplyVector3Affine(v: Vector3f): Vector3f;
      public inverseMultiplyPoint3Affine(p: Vector3f): Vector3f;
      /**
       * @return self
       */

      public copy(inM: Matrix4x4f): Matrix4x4f;
      /**
       * @return self
       */

      public setPerspective(fovy: number, aspect: number, zNear: number, zFar: number): Matrix4x4f;
      /**
       * @return self
       */

      public setPerspectiveCotan(cotanHalfFOV: number, zNear: number, zFar: number): Matrix4x4f;
      /**
       * @return self
       */

      public setOrtho(left: number, right: number, bottom: number, top: number, zNear: number, zFar: number): Matrix4x4f;
      /**
       * @return self
       */

      public setFrustum(left: number, right: number, bottom: number, top: number, zNear: number, zFar: number): Matrix4x4f;
      public getAxisX(): Vector3f;
      public getAxisY(): Vector3f;
      public getAxisZ(): Vector3f;
      public getPosition(): Vector3f;
      public getRow(row: number): Vector4f;
      public setAxisX(v: Vector3f): Matrix4x4f;
      public setAxisY(v: Vector3f): Matrix4x4f;
      public setAxisZ(v: Vector3f): Matrix4x4f;
      public setPosition(v: Vector3f): Matrix4x4f;
      public setRow(row: number, v: Vector4f): Matrix4x4f;
      public setColumn(col: number, v: Vector4f): Matrix4x4f;
      /**
       * @return self
       */

      public setTranslate(v: Vector3f): Matrix4x4f;
      /**
       * @return self
       */

      public setPositionAndOrthoNormalBasis(inP: Vector3f, inX: Vector3f, inY: Vector3f, inZ: Vector3f): Matrix4x4f;
      /**
       * @return self
       */

      public translate(v: Vector3f): Matrix4x4f;
      /**
       * @return self
       */

      public addTranslate(v: Vector3f): Matrix4x4f;
      public setTR(t: Vector3f, r: Quaternionf): void;
      public setTRS(t: Vector3f, r: Quaternionf, s: Vector3f): void;
      public setTRInverse(t: Vector3f, r: Quaternionf): void;
      public getDecompose(outT: Vector3f, outS: Vector3f, outR: Quaternionf): void;
      /**
       * @param epsilon optional, default is 0.00001
       */

      public compareApproximately(m: Matrix4x4f, m1: Matrix4x4f, epsilon: number): boolean;
      public compareApproximately(m: Matrix4x4f, m1: Matrix4x4f): boolean;
      public transformPoints3x3(inVec3Ptr: Vector3f, outVec3Ptr: Vector3f, count: number): void;
      public transformPoints3x3(inVec3Ptr: Vector3f, inStride: number, outVec3Ptr: Vector3f, outStride: number, count: number): void;
      public transformPoints3x4(inVec3Ptr: Vector3f, outVec3Ptr: Vector3f): void;
      public transformPoints3x4(inVec3Ptr: Vector3f, outVec3Ptr: Vector3f, count: number): void;
      public transformPoints3x4(inVec3Ptr: Vector3f, inStride: number, outVec3Ptr: Vector3f, outStride: number, count: number): void;
      /**
       * @param inM input
       * @param outM output
       */

      public multiplyMatrices3x4(inM: Matrix4x4f, outM: Matrix4x4f): void;
      /**
       * @param inM input
       * @param outM output
       */

      public copyMatrix(inM: Matrix4x4f, outM: Matrix4x4f): void;
      /**
       * @param inM input
       * @param outM output
       */

      public transposeMatrix4x4(inM: Matrix4x4f, outM: Matrix4x4f): void;
      /**
       * @param inM1 input
       * @param inM2 input
       * @param outM output
       */

      public multiplyMatrices4x4(inM1: Matrix4x4f, inM2: Matrix4x4f, outM: Matrix4x4f): void;
      /**
       * @param inM1Vec input
       * @param inM2Vec input
       * @param outMVec output
       */

      public multiplyMatrixArray4x4(inM1Vec: Matrix4x4f, inM2Vec: Matrix4x4f, outMVec: Matrix4x4f, count: number): void;
      /**
       * @param inM1Vec input
       * @param inM2Vec input
       * @param outMVec output
       */

      public multiplyMatrixArrayWithBase4x4(baseM: Matrix4x4f, inM1Vec: Matrix4x4f, inM2Vec: Matrix4x4f, outMVec: Matrix4x4f, count: number): void;
      /**
       * @param outM output
       */

      public invert_General3D(outM: Matrix4x4f): boolean;
      public isFinite(): boolean;
      public static eq(v0: Matrix3x3f, v1: Matrix3x3f): boolean;
      public static equals(v0: Matrix3x3f, v1: Matrix3x3f): boolean;
      public static compareApproximately(m: Matrix4x4f, epsilon: Matrix4x4f): boolean;
      public static compareApproximately(m: Matrix4x4f, epsilon: Matrix4x4f, dist: number): boolean;
      public static transformPoints3x3(v0: Matrix4x4f, inVec3Ptr: Vector3f, outVec3Ptr: Vector3f, count: number): void;
      public static transformPoints3x3(v0: Matrix4x4f, inVec3Ptr: Vector3f, inStride: number, outVec3Ptr: Vector3f, outStride: number, count: number): void;
      public static transformPoints3x4(v0: Matrix4x4f, inVec3Ptr: Vector3f, outVec3Ptr: Vector3f): void;
      public static transformPoints3x4(v0: Matrix4x4f, inVec3Ptr: Vector3f, outVec3Ptr: Vector3f, count: number): void;
      public static transformPoints3x4(v0: Matrix4x4f, inVec3Ptr: Vector3f, inStride: number, outVec3Ptr: Vector3f, outStride: number, count: number): void;
      /**
       * @param inM input
       * @param outM output
       */

      public static multiplyMatrices3x4(inM0: Matrix4x4f, inM1: Matrix4x4f, outM: Matrix4x4f): void;
      /**
       * @param inM input
       * @param outM output
       */

      public static copyMatrix(inM: Matrix4x4f, outM: Matrix4x4f): void;
      /**
       * @param inM input
       * @param outM output
       */

      public static transposeMatrix4x4(inM: Matrix4x4f, outM: Matrix4x4f): void;
      /**
       * @param inM1 input
       * @param inM2 input
       * @param outM output
       */

      public static multiplyMatrices4x4(inM1: Matrix4x4f, inM2: Matrix4x4f, outM: Matrix4x4f): void;
      /**
       * @param inM1Vec input
       * @param inM2Vec input
       * @param outMVec output
       */

      public static multiplyMatrixArray4x4(inM1Vec: Matrix4x4f, inM2Vec: Matrix4x4f, outMVec: Matrix4x4f, count: number): void;
      /**
       * @param inM1Vec input
       * @param inM2Vec input
       * @param outMVec output
       */

      public static multiplyMatrixArrayWithBase4x4(baseM: Matrix4x4f, inM1Vec: Matrix4x4f, inM2Vec: Matrix4x4f, outMVec: Matrix4x4f, count: number): void;
      /**
       * @param outM output
       */

      public static invert_General3D(inM: Matrix4x4f, outM: Matrix4x4f): boolean;
      public getBuffer(): Float32Array;
    }
    class Guid {
      constructor();
      constructor(v: ArrayBuffer);
      public eq(v: Guid): boolean;
      public equals(v: Guid): boolean;
      public toString(): string;
      public isEmpty(): boolean;
    }
    class Vector {
      constructor();
      public handle: number;
      public eq(v: Vector): boolean;
      public equals(v: Vector): boolean;
      public pushBack(v: Variant): void;
      public popBack(): Variant;
      public pushFront(v: Variant): void;
      public popFront(): Variant;
      public size(): number;
      public empty(): boolean;
      public clear(): void;
      public get(index: number): Variant;
      public set(index: number, v: Variant): void;
      public insert(index: number, v: Variant): void;
      public hash(): number;
      public front(): Variant;
      public back(): Variant;
      public remove(index: number): void;
      public copy(): Vector;
      public deepCopy(): Vector;
      public clone(): Vector;
      /**
       * @param index start id
       * @return if cannot find element v, return 0xFFFFFFFF
       */

      public find(v: Variant): number;
      public find(v: Variant, index: number): number;
      /**
       * @param index start id
       * @return if cannot find element v, return 0xFFFFFFFF
       */

      public rfind(v: Variant): number;
      public rfind(v: Variant, index: number): number;
      /**
       * @return if cannot find element v, return 0xFFFFFFFF
       */

      public findLast(v: Variant): number;
      public count(v: Variant): number;
      public has(v: Variant): boolean;
      public erase(index: Variant): void;
      public sort(): void;
      public shuffle(): void;
      public reverse(): void;
      public resize(v: number): void;
    }
    class Map {
      constructor();
      public handle: number;
      public eq(v: Map): boolean;
      public equals(v: Map): boolean;
      public size(): number;
      public empty(): boolean;
      public clear(): void;
      public get(key: Variant): Variant;
      public getVectorKeys(): Vector;
      public set(key: Variant, value: Variant): void;
      public hash(): number;
      public insert(key: Variant, value: Variant): void;
      public remove(key: Variant): void;
      public copy(): Map;
      public deepCopy(): Map;
      public clone(): Map;
      public find(key: Variant): Variant;
      public has(key: Variant): boolean;
      public hasAll(keys: Vector): boolean;
    }
    class Int8Vector {
      constructor();
      public handle: number;
      public eq(v: Int8Vector): boolean;
      public equals(v: Int8Vector): boolean;
      public size(): number;
      public empty(): boolean;
      public clear(): void;
      public pushBack(v: number): void;
      public popBack(): number;
      public pushFront(v: number): void;
      public popFront(): number;
      public get(index: number): number;
      public set(index: number, value: number): void;
      public hash(): number;
      public front(): number;
      public back(): number;
      public insert(index: number, value: number): void;
      public remove(index: number): void;
      public copy(): Int8Vector;
      /**
       * @param index start index
       * @return if cannot find element v, return 0xFFFFFFFF
       */

      public find(v: number, index: number): number;
      /**
       * @param index start id
       * @return if cannot find element v, return 0xFFFFFFFF
       */

      public rfind(v: number, index: number): number;
      /**
       * @return if cannot find element v, return 0xFFFFFFFF
       */

      public findLast(v: number): number;
      public count(v: number): number;
      public has(v: number): boolean;
      public erase(v: number): void;
      public sort(): void;
      public shuffle(): void;
      public reverse(): void;
      public resize(n: number): void;
    }
    class Int16Vector {
      constructor();
      public handle: number;
      public eq(v: Int16Vector): boolean;
      public equals(v: Int16Vector): boolean;
      public size(): number;
      public empty(): boolean;
      public clear(): void;
      public pushBack(v: number): void;
      public popBack(): number;
      public pushFront(v: number): void;
      public popFront(): number;
      public get(index: number): number;
      public set(index: number, value: number): void;
      public hash(): number;
      public front(): number;
      public back(): number;
      public insert(index: number, value: number): void;
      public remove(index: number): void;
      public copy(): Int16Vector;
      /**
       * @param index start index
       * @return if cannot find element v, return 0xFFFFFFFF
       */

      public find(v: number, index: number): number;
      /**
       * @param index start id
       * @return if cannot find element v, return 0xFFFFFFFF
       */

      public rfind(v: number, index: number): number;
      /**
       * @return if cannot find element v, return 0xFFFFFFFF
       */

      public findLast(v: number): number;
      public count(v: number): number;
      public has(v: number): boolean;
      public erase(v: number): void;
      public sort(): void;
      public shuffle(): void;
      public reverse(): void;
      public resize(n: number): void;
    }
    class Int32Vector {
      constructor();
      public handle: number;
      public eq(v: Int32Vector): boolean;
      public equals(v: Int32Vector): boolean;
      public size(): number;
      public empty(): boolean;
      public clear(): void;
      public pushBack(v: number): void;
      public popBack(): number;
      public pushFront(v: number): void;
      public popFront(): number;
      public get(index: number): number;
      public set(index: number, value: number): void;
      public hash(): number;
      public front(): number;
      public back(): number;
      public insert(index: number, value: number): void;
      public remove(index: number): void;
      public copy(): Int32Vector;
      /**
       * @param index start index
       * @return if cannot find element v, return 0xFFFFFFFF
       */

      public find(v: number, index: number): number;
      /**
       * @param index start id
       * @return if cannot find element v, return 0xFFFFFFFF
       */

      public rfind(v: number, index: number): number;
      /**
       * @return if cannot find element v, return 0xFFFFFFFF
       */

      public findLast(v: number): number;
      public count(v: number): number;
      public has(v: number): boolean;
      public erase(v: number): void;
      public sort(): void;
      public shuffle(): void;
      public reverse(): void;
      public resize(n: number): void;
    }
    class Int64Vector {
      constructor();
      public handle: number;
      public eq(v: Int64Vector): boolean;
      public equals(v: Int64Vector): boolean;
      public size(): number;
      public empty(): boolean;
      public clear(): void;
      public pushBack(v: number): void;
      public popBack(): number;
      public pushFront(v: number): void;
      public popFront(): number;
      public get(index: number): number;
      public set(index: number, value: number): void;
      public hash(): number;
      public front(): number;
      public back(): number;
      public insert(index: number, value: number): void;
      public remove(index: number): void;
      public copy(): Int64Vector;
      /**
       * @param index start index
       * @return if cannot find element v, return 0xFFFFFFFF
       */

      public find(v: number, index: number): number;
      /**
       * @param index start id
       * @return if cannot find element v, return 0xFFFFFFFF
       */

      public rfind(v: number, index: number): number;
      /**
       * @return if cannot find element v, return 0xFFFFFFFF
       */

      public findLast(v: number): number;
      public count(v: number): number;
      public has(v: number): boolean;
      public erase(v: number): void;
      public sort(): void;
      public shuffle(): void;
      public reverse(): void;
      public resize(n: number): void;
    }
    class UInt8Vector {
      constructor();
      public handle: number;
      public eq(v: UInt8Vector): boolean;
      public equals(v: UInt8Vector): boolean;
      public size(): number;
      public empty(): boolean;
      public clear(): void;
      public pushBack(v: number): void;
      public popBack(): number;
      public pushFront(v: number): void;
      public popFront(): number;
      public get(index: number): number;
      public set(index: number, value: number): void;
      public hash(): number;
      public front(): number;
      public back(): number;
      public insert(index: number, value: number): void;
      public remove(index: number): void;
      public copy(): UInt8Vector;
      /**
       * @param index start index
       * @return if cannot find element v, return 0xFFFFFFFF
       */

      public find(v: number, index: number): number;
      /**
       * @param index start id
       * @return if cannot find element v, return 0xFFFFFFFF
       */

      public rfind(v: number, index: number): number;
      /**
       * @return if cannot find element v, return 0xFFFFFFFF
       */

      public findLast(v: number): number;
      public count(v: number): number;
      public has(v: number): boolean;
      public erase(v: number): void;
      public sort(): void;
      public shuffle(): void;
      public reverse(): void;
      public resize(n: number): void;
    }
    class UInt16Vector {
      constructor();
      public handle: number;
      public eq(v: UInt16Vector): boolean;
      public equals(v: UInt16Vector): boolean;
      public size(): number;
      public empty(): boolean;
      public clear(): void;
      public pushBack(v: number): void;
      public popBack(): number;
      public pushFront(v: number): void;
      public popFront(): number;
      public get(index: number): number;
      public set(index: number, value: number): void;
      public hash(): number;
      public front(): number;
      public back(): number;
      public insert(index: number, value: number): void;
      public remove(index: number): void;
      public copy(): UInt16Vector;
      /**
       * @param index start index
       * @return if cannot find element v, return 0xFFFFFFFF
       */

      public find(v: number, index: number): number;
      /**
       * @param index start id
       * @return if cannot find element v, return 0xFFFFFFFF
       */

      public rfind(v: number, index: number): number;
      /**
       * @return if cannot find element v, return 0xFFFFFFFF
       */

      public findLast(v: number): number;
      public count(v: number): number;
      public has(v: number): boolean;
      public erase(v: number): void;
      public sort(): void;
      public shuffle(): void;
      public reverse(): void;
      public resize(n: number): void;
    }
    class UInt32Vector {
      constructor();
      public handle: number;
      public eq(v: UInt32Vector): boolean;
      public equals(v: UInt32Vector): boolean;
      public size(): number;
      public empty(): boolean;
      public clear(): void;
      public pushBack(v: number): void;
      public popBack(): number;
      public pushFront(v: number): void;
      public popFront(): number;
      public get(index: number): number;
      public set(index: number, value: number): void;
      public hash(): number;
      public front(): number;
      public back(): number;
      public insert(index: number, value: number): void;
      public remove(index: number): void;
      public copy(): UInt32Vector;
      /**
       * @param index start index
       * @return if cannot find element v, return 0xFFFFFFFF
       */

      public find(v: number, index: number): number;
      /**
       * @param index start id
       * @return if cannot find element v, return 0xFFFFFFFF
       */

      public rfind(v: number, index: number): number;
      /**
       * @return if cannot find element v, return 0xFFFFFFFF
       */

      public findLast(v: number): number;
      public count(v: number): number;
      public has(v: number): boolean;
      public erase(v: number): void;
      public sort(): void;
      public shuffle(): void;
      public reverse(): void;
      public resize(n: number): void;
    }
    class FloatVector {
      constructor();
      public handle: number;
      public eq(v: FloatVector): boolean;
      public equals(v: FloatVector): boolean;
      public size(): number;
      public empty(): boolean;
      public clear(): void;
      public pushBack(v: number): void;
      public popBack(): number;
      public pushFront(v: number): void;
      public popFront(): number;
      public get(index: number): number;
      public set(index: number, value: number): void;
      public hash(): number;
      public front(): number;
      public back(): number;
      public insert(index: number, value: number): void;
      public remove(index: number): void;
      public copy(): FloatVector;
      /**
       * @param index start index
       * @return if cannot find element v, return 0xFFFFFFFF
       */

      public find(v: number, index: number): number;
      /**
       * @param index start id
       * @return if cannot find element v, return 0xFFFFFFFF
       */

      public rfind(v: number, index: number): number;
      /**
       * @return if cannot find element v, return 0xFFFFFFFF
       */

      public findLast(v: number): number;
      public count(v: number): number;
      public has(v: number): boolean;
      public erase(v: number): void;
      public sort(): void;
      public shuffle(): void;
      public reverse(): void;
      public resize(n: number): void;
    }
    class DoubleVector {
      constructor();
      public handle: number;
      public eq(v: DoubleVector): boolean;
      public equals(v: DoubleVector): boolean;
      public size(): number;
      public empty(): boolean;
      public clear(): void;
      public pushBack(v: number): void;
      public popBack(): number;
      public pushFront(v: number): void;
      public popFront(): number;
      public get(index: number): number;
      public set(index: number, value: number): void;
      public hash(): number;
      public front(): number;
      public back(): number;
      public insert(index: number, value: number): void;
      public remove(index: number): void;
      public copy(): DoubleVector;
      /**
       * @param index start index
       * @return if cannot find element v, return 0xFFFFFFFF
       */

      public find(v: number, index: number): number;
      /**
       * @param index start id
       * @return if cannot find element v, return 0xFFFFFFFF
       */

      public rfind(v: number, index: number): number;
      /**
       * @return if cannot find element v, return 0xFFFFFFFF
       */

      public findLast(v: number): number;
      public count(v: number): number;
      public has(v: number): boolean;
      public erase(v: number): void;
      public sort(): void;
      public shuffle(): void;
      public reverse(): void;
      public resize(n: number): void;
    }
    class StringVector {
      constructor();
      public handle: number;
      public eq(v: StringVector): boolean;
      public equals(v: StringVector): boolean;
      public size(): number;
      public empty(): boolean;
      public clear(): void;
      public pushBack(v: string): void;
      public popBack(): string;
      public pushFront(v: string): void;
      public popFront(): string;
      public get(index: number): string;
      public set(index: number, value: string): void;
      public hash(): number;
      public front(): string;
      public back(): string;
      public insert(index: number, value: string): void;
      public remove(index: number): void;
      public copy(): StringVector;
      /**
       * @param index start index
       * @return if cannot find element v, return 0xFFFFFFFF
       */

      public find(v: string, index: number): number;
      /**
       * @param index start id
       * @return if cannot find element v, return 0xFFFFFFFF
       */

      public rfind(v: string, index: number): number;
      /**
       * @return if cannot find element v, return 0xFFFFFFFF
       */

      public findLast(v: string): number;
      public count(v: string): number;
      public has(v: string): boolean;
      public erase(v: string): void;
      public sort(): void;
      public shuffle(): void;
      public reverse(): void;
      public resize(n: number): void;
    }
    class Vec2Vector {
      constructor();
      public handle: number;
      public eq(v: Vec2Vector): boolean;
      public equals(v: Vec2Vector): boolean;
      public size(): number;
      public empty(): boolean;
      public clear(): void;
      public pushBack(v: Vector2f): void;
      public popBack(): Vector2f;
      public pushFront(v: Vector2f): void;
      public popFront(): Vector2f;
      public get(index: number): Vector2f;
      public set(index: number, value: Vector2f): void;
      public hash(): number;
      public front(): Vector2f;
      public back(): Vector2f;
      public insert(index: number, value: Vector2f): void;
      public remove(index: number): void;
      public copy(): Vec2Vector;
      /**
       * @param index start index
       * @return if cannot find element v, return 0xFFFFFFFF
       */

      public find(v: Vector2f, index: number): number;
      /**
       * @param index start id
       * @return if cannot find element v, return 0xFFFFFFFF
       */

      public rfind(v: Vector2f, index: number): number;
      /**
       * @return if cannot find element v, return 0xFFFFFFFF
       */

      public findLast(v: Vector2f): number;
      public count(v: Vector2f): number;
      public has(v: Vector2f): boolean;
      public erase(v: Vector2f): void;
      public sort(): void;
      public shuffle(): void;
      public reverse(): void;
      public resize(n: number): void;
    }
    class Vec3Vector {
      constructor();
      public handle: number;
      public eq(v: Vec3Vector): boolean;
      public equals(v: Vec3Vector): boolean;
      public size(): number;
      public empty(): boolean;
      public clear(): void;
      public pushBack(v: Vector3f): void;
      public popBack(): Vector3f;
      public pushFront(v: Vector3f): void;
      public popFront(): Vector3f;
      public get(index: number): Vector3f;
      public set(index: number, value: Vector3f): void;
      public hash(): number;
      public front(): Vector3f;
      public back(): Vector3f;
      public insert(index: number, value: Vector3f): void;
      public remove(index: number): void;
      public copy(): Vec3Vector;
      /**
       * @param index start index
       * @return if cannot find element v, return 0xFFFFFFFF
       */

      public find(v: Vector3f, index: number): number;
      /**
       * @param index start id
       * @return if cannot find element v, return 0xFFFFFFFF
       */

      public rfind(v: Vector3f, index: number): number;
      /**
       * @return if cannot find element v, return 0xFFFFFFFF
       */

      public findLast(v: Vector3f): number;
      public count(v: Vector3f): number;
      public has(v: Vector3f): boolean;
      public erase(v: Vector3f): void;
      public sort(): void;
      public shuffle(): void;
      public reverse(): void;
      public resize(n: number): void;
    }
    class Vec4Vector {
      constructor();
      public handle: number;
      public eq(v: Vec4Vector): boolean;
      public equals(v: Vec4Vector): boolean;
      public size(): number;
      public empty(): boolean;
      public clear(): void;
      public pushBack(v: Vector4f): void;
      public popBack(): Vector4f;
      public pushFront(v: Vector4f): void;
      public popFront(): Vector4f;
      public get(index: number): Vector4f;
      public set(index: number, value: Vector4f): void;
      public hash(): number;
      public front(): Vector4f;
      public back(): Vector4f;
      public insert(index: number, value: Vector4f): void;
      public remove(index: number): void;
      public copy(): Vec4Vector;
      /**
       * @param index start index
       * @return if cannot find element v, return 0xFFFFFFFF
       */

      public find(v: Vector4f, index: number): number;
      /**
       * @param index start id
       * @return if cannot find element v, return 0xFFFFFFFF
       */

      public rfind(v: Vector4f, index: number): number;
      /**
       * @return if cannot find element v, return 0xFFFFFFFF
       */

      public findLast(v: Vector4f): number;
      public count(v: Vector4f): number;
      public has(v: Vector4f): boolean;
      public erase(v: Vector4f): void;
      public sort(): void;
      public shuffle(): void;
      public reverse(): void;
      public resize(n: number): void;
    }
    class QuatVector {
      constructor();
      public handle: number;
      public eq(v: QuatVector): boolean;
      public equals(v: QuatVector): boolean;
      public size(): number;
      public empty(): boolean;
      public clear(): void;
      public pushBack(v: Quaternionf): void;
      public popBack(): Quaternionf;
      public pushFront(v: Quaternionf): void;
      public popFront(): Quaternionf;
      public get(index: number): Quaternionf;
      public set(index: number, value: Quaternionf): void;
      public hash(): number;
      public front(): Quaternionf;
      public back(): Quaternionf;
      public insert(index: number, value: Quaternionf): void;
      public remove(index: number): void;
      public copy(): QuatVector;
      /**
       * @param index start index
       * @return if cannot find element v, return 0xFFFFFFFF
       */

      public find(v: Quaternionf, index: number): number;
      /**
       * @param index start id
       * @return if cannot find element v, return 0xFFFFFFFF
       */

      public rfind(v: Quaternionf, index: number): number;
      /**
       * @return if cannot find element v, return 0xFFFFFFFF
       */

      public findLast(v: Quaternionf): number;
      public count(v: Quaternionf): number;
      public has(v: Quaternionf): boolean;
      public erase(v: Quaternionf): void;
      public sort(): void;
      public shuffle(): void;
      public reverse(): void;
      public resize(n: number): void;
    }
    class Mat3Vector {
      constructor();
      public handle: number;
      public eq(v: Mat3Vector): boolean;
      public equals(v: Mat3Vector): boolean;
      public size(): number;
      public empty(): boolean;
      public clear(): void;
      public pushBack(v: Matrix3x3f): void;
      public popBack(): Matrix3x3f;
      public pushFront(v: Matrix3x3f): void;
      public popFront(): Matrix3x3f;
      public get(index: number): Matrix3x3f;
      public set(index: number, value: Matrix3x3f): void;
      public hash(): number;
      public front(): Matrix3x3f;
      public back(): Matrix3x3f;
      public insert(index: number, value: Matrix3x3f): void;
      public remove(index: number): void;
      public copy(): Mat3Vector;
      /**
       * @param index start index
       * @return if cannot find element v, return 0xFFFFFFFF
       */

      public find(v: Matrix3x3f, index: number): number;
      /**
       * @param index start id
       * @return if cannot find element v, return 0xFFFFFFFF
       */

      public rfind(v: Matrix3x3f, index: number): number;
      /**
       * @return if cannot find element v, return 0xFFFFFFFF
       */

      public findLast(v: Matrix3x3f): number;
      public count(v: Matrix3x3f): number;
      public has(v: Matrix3x3f): boolean;
      public erase(v: Matrix3x3f): void;
      public sort(): void;
      public shuffle(): void;
      public reverse(): void;
      public resize(n: number): void;
    }
    class Mat4Vector {
      constructor();
      public handle: number;
      public eq(v: Mat4Vector): boolean;
      public equals(v: Mat4Vector): boolean;
      public size(): number;
      public empty(): boolean;
      public clear(): void;
      public pushBack(v: Matrix4x4f): void;
      public popBack(): Matrix4x4f;
      public pushFront(v: Matrix4x4f): void;
      public popFront(): Matrix4x4f;
      public get(index: number): Matrix4x4f;
      public set(index: number, value: Matrix4x4f): void;
      public hash(): number;
      public front(): Matrix4x4f;
      public back(): Matrix4x4f;
      public insert(index: number, value: Matrix4x4f): void;
      public remove(index: number): void;
      public copy(): Mat4Vector;
      /**
       * @param index start index
       * @return if cannot find element v, return 0xFFFFFFFF
       */

      public find(v: Matrix4x4f, index: number): number;
      /**
       * @param index start id
       * @return if cannot find element v, return 0xFFFFFFFF
       */

      public rfind(v: Matrix4x4f, index: number): number;
      /**
       * @return if cannot find element v, return 0xFFFFFFFF
       */

      public findLast(v: Matrix4x4f): number;
      public count(v: Matrix4x4f): number;
      public has(v: Matrix4x4f): boolean;
      public erase(v: Matrix4x4f): void;
      public sort(): void;
      public shuffle(): void;
      public reverse(): void;
      public resize(n: number): void;
    }
  }
}
declare namespace effect {
  namespace Amaz {
    type prototype = any;
    /**
     * RTTI Descriptor
     */

    interface RTTIDescriptor {
      Children: Array<prototype>;
      EnumNameMap: {
        [key: string]: number;
      };
      EnumValueMap: {
        [key: number]: string;
      };
      FullName: string;
      Methods: Array<RTTIMethodDescriptor>;
      Name: string;
      Parent: prototype;
      Properties: Array<RTTIPropertyDescriptor>;
      This: prototype;
      isClass: boolean;
      isDerivedFromObject: boolean;
      isEnum: boolean;
      isExternal: boolean;
      isLocal: boolean;
      isPrimitive: boolean;
      attributes: RTTIDescriptorAttributes;
    }
    interface RTTIDescriptorAttributes {
      classAttr?: {
        path: string;
      };
    }
    /**
     * RTTI Method Descriptor
     */

    interface RTTIMethodDescriptor {
      Argc: number;
      Args: Array<RTTIArgumentDescriptor>;
      DefaultValues: Array<any>;
      Name: string;
      ReturnClass: prototype;
      isConst: boolean;
      isReturnConst: boolean;
      isReturnRef: boolean;
      isReturnVoid: boolean;
      _proto: prototype;
    }
    /**
     * RTTI Argument Descriptor
     */

    interface RTTIArgumentDescriptor {
      Name: string;
      isConstRef: boolean;
      _proto: prototype;
    }
    /**
     * RTTI Property Descriptor
     */

    interface RTTIPropertyDescriptor {
      Name: string;
      PropertyRTTI: prototype;
      Getter: RTTIMethodDescriptor;
      Setter: RTTIMethodDescriptor;
      isClone: boolean;
      isScriptBind: boolean;
      isSerialize: boolean;
      isWeak: boolean;
      isWeakBind: boolean;
      attributes: RTTIPropertyDescriptorAttributes;
    }
    /**
     * RTTI Property Attributes
     */

    interface RTTIPropertyDescriptorAttributes {
      displayAttr?: DisplayAttribute;
      hiddenAttr?: HiddenAttribute;
      orderAttr?: OrderAttribute;
      expandAttr?: ExpandAttribute;
      tileAttr?: TileAttribute;
      readonlyAttr?: ReadonlyAttribute;
      rangeAttr?: RangeAttribute;
      dragAttr?: DragAttribute;
      optionAttr?: OptionAttribute;
      enumArrowAttr?: EnumArrowAttribute;
      sliderAttr?: SliderAttribute;
      inputAttr?: InputAttribute;
      dirtyAttr?: DirtyAttribute;
      typeAttr?: TypeAttribute;
      noAlphaAttr?: NoAlphaAttribute;
      sizeAttr?: SizeAttribute;
      sizeOnlyAttr?: SizeOnlyAttribute;
      colorAttr?: ColorAttribute;
      radian2AngleAttr?: Radian2AngleAttribute;
      vectorReadonlyAttr?: VectorReadonlyAttribute;
      weakShowAttr?: WeakShowAttribute;
      colorMapAttr?: ColorMapAttribute;
      buttonAttr?: ButtonAttribute;
    }
    /**
     * Property Attribute (Base class)
     */

    interface Attribute {}
    interface DisplayAttribute extends Attribute {
      label: string;
    }
    interface HiddenAttribute extends Attribute {}
    interface OrderAttribute extends Attribute {
      order: number;
    }
    interface ExpandAttribute extends Attribute {
      hasTitle: boolean;
      title: string;
    }
    interface TileAttribute extends Attribute {}
    interface ReadonlyAttribute extends Attribute {}
    interface RangeAttribute extends Attribute {
      min: Variant;
      max: Variant;
    }
    interface DragAttribute extends Attribute {
      step: Variant;
    }
    interface OptionAttribute extends Attribute {
      labels: string[];
      values: Variant[];
    }
    interface EnumArrowAttribute extends Attribute {}
    interface SliderAttribute extends Attribute {}
    interface InputAttribute extends Attribute {}
    interface DirtyAttribute extends Attribute {
      keys: string[];
    }
    interface TypeAttribute extends Attribute {
      type: string;
    }
    interface NoAlphaAttribute extends Attribute {}
    interface SizeAttribute extends Attribute {
      min: number;
      max: number;
    }
    interface SizeOnlyAttribute extends Attribute {}
    interface ColorAttribute extends Attribute {}
    interface Radian2AngleAttribute extends Attribute {}
    interface VectorReadonlyAttribute extends Attribute {}
    interface WeakShowAttribute extends Attribute {}
    interface ColorMapAttribute extends Attribute {}
    interface ButtonAttribute extends Attribute {
      label: string;
    }
    /**
     * Generic Interface
     */

    interface IGenericRTTI {
      RTTI: RTTIDescriptor;
      prototype: {
        RTTI: RTTIDescriptor;
      };
    }
    /**
     * Base Class interface
     */

    interface AObject {
      RTTI: RTTIDescriptor;
    }
  }
}
declare namespace effect {
  namespace Amaz {
    class ParticleIterator extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public getFirst(): Particle;
      public getNext(): Particle;
      public isEnd(): boolean;
      public getParticle(): Particle;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum EventPriority {
      LOW,
      NORMAL,
      HIGH,
    }
    namespace EventPriority {
      let RTTI: RTTIDescriptor;
    }
    class LineEmitter extends Emitter {
      constructor();
      public assetMgr: AssetManager;
      public position: Vector3f;
      public rotation: Quaternionf;
      public enable: boolean;
      public keepLocalParticles: boolean;
      public forceEmission: boolean;
      public useDurationTime: boolean;
      public angle: Value;
      public emissionRate: Value;
      public totalTimeToLive: Value;
      public duration: Value;
      public repeatDelay: Value;
      public particleMass: Value;
      public particleVelocity: Value;
      public particleColorList: Vec4Vector;
      public particleColor: Vector4f;
      public particleBurstsList: Vec2Vector;
      public orientationStart: Quaternionf;
      public orientationEnd: Quaternionf;
      public particleWidth: Value;
      public particleHeight: Value;
      public particleDepth: Value;
      public particleScale: Value;
      public particleSize: Value;
      public particleXRotation: Value;
      public particleYRotation: Value;
      public particleZRotation: Value;
      public particleXRotationSpeed: Value;
      public particleYRotationSpeed: Value;
      public particleZRotationSpeed: Value;
      public alignToDirection: boolean;
      public RandomDirection: Value;
      public SphereDirection: Value;
      public RandomPosition: Value;
      public distanceEmissionRate: Value;
      public start: Vector3f;
      public end: Vector3f;
      public lineSegments: number;
      public isUseRandomRange: boolean;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class StorageBuffer extends Buffer {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public load(data: StructData): boolean;
      public resize(size: number): void;
      public setData(updateFractionalFlag: boolean, offset: number, data: StructData, vec3vec: Vec3Vector, default_w: number): boolean;
      public getData(dataType: string, indices: Int32Vector): FloatVector;
      public readFromFile(filePath: string, dataType: string, name: string): boolean;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class UniformBuffer extends Buffer {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public load(data: StructData): boolean;
      public resize(size: number): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class VertexBuffer extends Buffer {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class IndexBuffer extends Buffer {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Buffer extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class SwapLiveInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public image: Image;
      public width: number;
      public height: number;
      public image_width: number;
      public image_height: number;
      public affine: Matrix4x4f;
      public valid: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class CloneFeatureNode extends FeatureNode {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public defaultInput: RenderTexture;
      public inputTextures: Vector;
      public outputTextures: Vector;
      public renderOrder: number;
      public minorOrder: number;
      public rendererType: RendererType;
      public featureTag: string;
      public effectName: string;
      public cloneFeatureTypes: StringVector;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class UniformAutoBinding extends Uniform {
      constructor();
      public assetMgr: AssetManager;
      public bindingType: UniformBinding;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class JSWrapNetworkCenter extends NetworkCenter {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class NetworkCenter extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public initClient(): void;
      public get(listener: NetworkListener, url: string, headers: Map): number;
      public post(listener: NetworkListener, url: string, headers: Map, postContent: string): number;
      public postBinary(listener: NetworkListener, url: string, headers: Map, postContent: UInt8Vector): number;
      public addNetworkListener(listener: NetworkListener): void;
      public removeNetworkListener(listener: NetworkListener): void;
      public update(): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class MeshDecimationOption extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public maxTris: number;
      public maxError: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class LightProbeSystem extends System {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public isBakeLightProbesTriggered: boolean;
      public isCubeMapGenerated: boolean;
      public combinedLightProbeGroup: LightProbeGroup;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class BehaviorSystem extends System {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum LookAtMode {
      LOOK_AT_DIRECTION,
      LOOK_AT_POINT,
    }
    namespace LookAtMode {
      let RTTI: RTTIDescriptor;
    }
    enum Texture2DAssetFormat {
      unknown,
      tga,
      png,
      hdr,
      etc2,
      jpeg,
    }
    namespace Texture2DAssetFormat {
      let RTTI: RTTIDescriptor;
    }
    enum CollisionDetectionType {
      DISCRETE,
      CONTINUOUS,
      CONTINUOUS_SPECULATIVE,
      CONTINUOUS_DYNAMIC,
    }
    namespace CollisionDetectionType {
      let RTTI: RTTIDescriptor;
    }
    enum BEFTimerType {
      EVENT_ONCE,
      EVENT_CIRCLE,
    }
    namespace BEFTimerType {
      let RTTI: RTTIDescriptor;
    }
    class LinearForceAffector extends BaseForceAffector {
      constructor();
      public assetMgr: AssetManager;
      public postion: Vector3f;
      public rotation: Quaternionf;
      public enabled: boolean;
      public updateMode: ParticleUpdateMode;
      public forceScalar: number;
      public forceApplication: AffectorForceApplication;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum UniformBinding {
      RENDER_WIDTH,
      RENDER_HEIGHT,
      SIM_SIN_TIME,
      SIM_TIME,
      CAMERA_NEAR_FAR,
      BONE_MATRIXES,
      MODEL_MATRIX,
      MODEL_VIEW_PROJECTION_MATRIX,
      NONE,
      MODEL_VIEW_MATRIX,
      CAMERA_WORLD_POS,
      VIEW_MATRIX,
      INV_VIEW_MATRIX,
      PROJECTION_MATRIX,
      NORMAL_MATRIX,
      NORMAL_WORLD_MATRIX,
    }
    namespace UniformBinding {
      let RTTI: RTTIDescriptor;
    }
    enum JsDownloadStatus {
      IDLE,
      BUSY,
      RUNNING,
    }
    namespace JsDownloadStatus {
      let RTTI: RTTIDescriptor;
    }
    class ExternalClip extends BaseClip {
      constructor();
      public assetMgr: AssetManager;
      public blendWeight: number;
      public isRestoreOrigVal: boolean;
      public overrideOther: boolean;
      public initialBlendWeight: number;
      public handle: number;
      public getPropertyItem(targetName: string, propertyName: string): ExternalPropertyItem;
      public registerOrGetPropertyItem(targetName: string, propertyName: string, dataType: TrackDataType): ExternalPropertyItem;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Texture2DImporter extends AssetImporter {
      constructor();
      public assetMgr: AssetManager;
      public platformSettings: Map;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class AssetImporter extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public platformSettings: Map;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum AnimazEventType {
      ANIM_START,
      ANIM_TIME,
      STATE_START,
      ANIM_END,
      STATE_END,
      ANIM_RESUME,
      ANIM_PAUSE,
    }
    namespace AnimazEventType {
      let RTTI: RTTIDescriptor;
    }
    class ContourSet extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public contours: Vector;
      public normals: Vector;
      public handle: number;
      public clone(): ContourSet;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Envmap extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public diffuseEnvmap: TextureCube;
      public coefficients: FloatVector;
      public envmapLayers: DynamicBitset;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class UniformVec3 extends Uniform {
      constructor();
      public assetMgr: AssetManager;
      public value: Vector3f;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Scene extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public editSceneGuid: Guid;
      public calibrateVer: string;
      public entities: Vector;
      public visible: boolean;
      public config: Map;
      public msaa: MSAAMode;
      public scriptSystems: StringVector;
      public jsScriptSystems: StringVector;
      public disabledSystems: StringVector;
      public enableMultiTouch: boolean;
      public enableLightMultiPass: boolean;
      public pixelLightCount: number;
      public prefabInstanceConfig: PrefabInstanceConfig;
      public handle: number;
      public createEntity(name: string): Entity;
      public removeEntity(entity: Entity): boolean;
      public removeAllEntity(): void;
      public cloneEntityFrom(srcEntity: Entity): Entity;
      public findEntityBy(name: string, root: Entity): Entity;
      public findEntitiesByName(name: string, root: Entity): Vector;
      public getSystem(type: string): System;
      public getOutputRenderTexture(): RenderTexture;
      public getInputTexture(inputType: BuiltInTextureType): Texture;
      public postEvent(event: Event): void;
      public sendEvent(event: Event): void;
      public sendMessage(unMsgID: number, arg1: number, arg2: number, arg3: string): void;
      public postMessage(unMsgID: number, arg1: number, arg2: number, arg3: string): void;
      public commitCommandBuffer(buffer: CommandBuffer): void;
      public addInstantiatedPrefab(prefab: Prefab): Entity;
      public addInstantiatedPrefabToEntity(prefab: Prefab, entity: Entity): Entity;
      public removeAllSystems(): void;
      public addSystem(sysName: string): void;
      public setAssetManager(assetManager: AssetManager): void;
      public getSceneOETF(): void;
      public setEnableMultiTouch(value: boolean): void;
      public addEntity(entity: Entity, index: number): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class RotationLimitHinge extends RotationLimit {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public axis: Vector3f;
      public maxAngle: number;
      public minAngle: number;
      public useConstraint: boolean;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ARSessionConfig extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public sessionType: ARSessionType;
      public planeDetectionMode: ARPlaneDetectionMode;
      public environmentCaptureProbe: AREnvironmentCaptureProbeType;
      public trackingFeature: ARSessionTrackingFeature;
      public sceneReconstructionMode: ARSceneReconstructionMode;
      public alwaysUpdateMesh: boolean;
      public needMeshNormal: boolean;
      public useBachAlgorithm: boolean;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class EffectFaceSclera extends EffectFaceMakeup {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public type: EffectFaceMakeupType;
      public templateMesh: Mesh;
      public dynamicRenderChain: boolean;
      public makeupEntity: Entity;
      public faceIds: UInt8Vector;
      public renderer: Renderer;
      public facemakeupEntityName: string;
      public zPosition: number;
      public triggerLua: boolean;
      public version: number;
      public sdkType: number;
      public useVideoTexture: boolean;
      public useSegment: boolean;
      public maleOpacity: number;
      public femaleOpacity: number;
      public ScleraMesh: Mesh;
      public ScleraEntityName: string;
      public scleraCutoffEntity: Entity;
      public cutoffRenderer: Renderer;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Layer2DRenderer extends Brush2DRenderer {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public dirtyFlag: Brush2DDirtyFlag;
      public dirtyRect: AABB;
      public boundingBox: AABB;
      public resolution: Vector2f;
      public finished: boolean;
      public outputTex: RenderTexture;
      public root: boolean;
      public outputShared: boolean;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class BoxColliderAffector extends BaseColliderAffector {
      constructor();
      public assetMgr: AssetManager;
      public postion: Vector3f;
      public rotation: Quaternionf;
      public enabled: boolean;
      public updateMode: ParticleUpdateMode;
      public intersectionType: AffectorIntersectionType;
      public collisionType: AffectorCollisionType;
      public width: number;
      public height: number;
      public depth: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ParticleSubEmitter extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public parentParticleComponent: ParticleComponent;
      public particleComponent: ParticleComponent;
      public subEmitter: Transform;
      public type: SubEmitterType;
      public probability: number;
      public inheritType: DynamicBitset;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ScriptMethodInfo extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class SwapperMeBaseInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public checkMode: boolean;
      public faceCount: number;
      public checkResult: Int32Vector;
      public image: Image;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class PngMeta extends Meta {
      constructor();
      public assetMgr: AssetManager;
      public assetImporter: AssetImporter;
      public innerAlphaPremul: boolean;
      public outerAlphaPremul: boolean;
      public enableMipmap: boolean;
      public filterMin: FilterMode;
      public filterMag: FilterMode;
      public filterMipmap: FilterMipmapMode;
      public wrapModeS: WrapMode;
      public wrapModeT: WrapMode;
      public wrapModeR: WrapMode;
      public maxAnisotropy: number;
      public isColorTexture: boolean;
      public maxTextureSize: TextureResizeLevel;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Joint extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public invBindPosMatrix: Matrix4x4f;
      public boundingBox: AABB;
      public jointTransform: Transform;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class JSWrapByteNNTensor extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class IFScriptComponent extends ScriptComponent {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public path: string;
      public properties: Map;
      public className: string;
      public target: Transform;
      public LuaObjRef: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class BachVectorInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public size(): number;
      public get(index: number): Variant;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class SpriteRendererSystem extends RendererSystem {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class PathFollowerAffector extends Affector {
      constructor();
      public assetMgr: AssetManager;
      public postion: Vector3f;
      public rotation: Quaternionf;
      public enabled: boolean;
      public updateMode: ParticleUpdateMode;
      public spline: Vector;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class AMGAudioProxy extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public createAudioGraph(): AMGAudioGraph;
      public useAudioGraph(graph: AMGAudioGraph): void;
      public start(): void;
      public stop(): void;
      public getTime(): number;
      public getUnderRunCount(): number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class FaceAttributeInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public age: number;
      public attractive: number;
      public happyScore: number;
      public exp_probs: FloatVector;
      public boyProb: number;
      public gender: FaceAttrGender;
      public exp_type: FaceAttrExpression;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class HairResultInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public rect: Rect;
      public reflection: number;
      public rotateType: number;
      public width: number;
      public height: number;
      public mask_data: UInt8Vector;
      public mAlphal: number;
      public mAlphac: number;
      public mAlphas: number;
      public new_rect: Rect;
      public mask: Image;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum TrackDataType {
      FLOAT,
      VEC4,
      VEC2,
      VEC3,
      QUAT,
      SRT_VEC,
    }
    namespace TrackDataType {
      let RTTI: RTTIDescriptor;
    }
    class PrefabInstanceConfig extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public configVersion: string;
      public prefabInstanceIdMap: Map;
      public prefabInstanceList: Vector;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ScaleGesture extends Gesture {
      constructor();
      public assetMgr: AssetManager;
      public type: GestureType;
      public time: number;
      public scale: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum FaceAttrGender {
      UNKNOWN,
      MALE,
      FEMALE,
    }
    namespace FaceAttrGender {
      let RTTI: RTTIDescriptor;
    }
    class ARActionResult extends AlgorithmResultEvent {
      constructor();
      public assetMgr: AssetManager;
      public eventType: BEFEventType;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Entity extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public selfvisible: boolean;
      public visible: boolean;
      public tag: number;
      public components: Vector;
      public layer: number;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public handle: number;
      public addTag(tag: number): void;
      public hasTag(tag: number): boolean;
      public addComponent(rttiType: string): Component;
      public addJsScriptComponent(codePath: string): Component;
      public removeComponent(rttiType: string): boolean;
      public getComponent(rttiType: string): Component;
      public getComponents(rttiType: string): Vector;
      public getComponentsRecursive(rttiType: string): Vector;
      public searchEntity(name: string): Entity;
      public cloneComponentOf(comp: Component): Component;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class CompatScene extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public wrapper(scene: Scene): void;
      public play(anim_type: string, entity_name: string, clip_name: string, loop: boolean): boolean;
      public getEntityGUIDWithName(entity_name: string): number;
      public setVisible(entity_name: string, is_vis: boolean): void;
      public isVisible(entity_name: string): boolean;
      public setPositionGUID(entityGUID: number, posX: number, posY: number, posZ: number): void;
      public setDeviceOrientation(orient_0: number, orient_1: number, orient_2: number, orient_3: number, entityName: string): boolean;
      public setCameraOrientation(orient_0: number, orient_1: number, orient_2: number, orient_3: number): boolean;
      public bindEntityToFaceId(guid: number, faceID: number): void;
      public axisAngleToQuaternion(axis: Vector3f, angle: number): Quaternionf;
      public rotateQuat(rotate: Quaternionf, orient: Quaternionf): Quaternionf;
      public quatInverse(quat: Quaternionf): Quaternionf;
      public quatRoll(quat: Quaternionf, reprojectAxis: boolean): number;
      public setVisibleWithGUID(entityGUID: number, is_vis: boolean): void;
      public setEntityComponentEnableWithGUID(entityGUID: number, componentName: string, enable: boolean): boolean;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class PrefabInstance extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public overrides: Vector;
      public prefab: Prefab;
      public prefabInstancId: Guid;
      public parentId: Guid;
      public handle: number;
      public addOverride(ov: PrefabOverride): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum AnimTimeType {
      GAMETIME,
      SYSTEMTIME,
    }
    namespace AnimTimeType {
      let RTTI: RTTIDescriptor;
    }
    class Raycaster extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public layer: DynamicBitset;
      public raycasterType: RaycasterType;
      public handle: number;
      public isTouchInIF(viewPos: Vector2f): boolean;
      public raycastIF(viewPos: Vector2f): Vector;
      public raycast3D(viewPos: Vector2f): Vector;
      public viewPointHitPlane(viewPos: Vector2f, normal: Vector3f, d: number): Vector3f;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Physics2DSystem extends System {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public runSimulation(): void;
      public stopSimulation(): void;
      public editSimulation(): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Collision3D extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public thisRigidbody: RigidBody3D;
      public otherRigidbody: RigidBody3D;
      public thisCollider: Collider3D;
      public otherCollider: Collider3D;
      public contacts: Vector;
      public thisComponent: Component;
      public otherComponent: Component;
      public thisColliderObject: AObject;
      public otherColliderObject: AObject;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class UserEventHandleSystem extends System {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum ConeEmitterEmitFrom {
      BASE,
      VOLUME,
    }
    namespace ConeEmitterEmitFrom {
      let RTTI: RTTIDescriptor;
    }
    enum LayerType {
      LERP,
      ADDITIVE,
      OVERRIDE,
    }
    namespace LayerType {
      let RTTI: RTTIDescriptor;
    }
    class FaceStretchComponent extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public T_P: Vec2Vector;
      public T_Q: Vec2Vector;
      public FaceId: number;
      public Intensity: number;
      public Type: FaceStretchType;
      public T_fpts: Vec2Vector;
      public T_w: number;
      public T_h: number;
      public indexSetValid: UInt16Vector;
      public curFace_P: Vec2Vector;
      public curFace_Q: Vec2Vector;
      public handle: number;
      public setDirty(dirty: boolean): void;
      public isDirty(): boolean;
      public isValid(): boolean;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum ComponentOverrideType {
      Modify,
      Remove,
      Add,
    }
    namespace ComponentOverrideType {
      let RTTI: RTTIDescriptor;
    }
    class AnimazClip extends BaseClip {
      constructor();
      public assetMgr: AssetManager;
      public blendWeight: number;
      public isRestoreOrigVal: boolean;
      public overrideOther: boolean;
      public initialBlendWeight: number;
      public handle: number;
      public getStartTime(): number;
      public getEndTime(): number;
      public getElapsedTime(): number;
      public setWrapMode(wrapMode: number): void;
      public getWrapMode(): number;
      public setSpeed(speed: number): void;
      public getSpeed(): number;
      public isPlaying(): boolean;
      public play(): void;
      public stop(): void;
      public pause(): void;
      public seek(seekTime: number): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum ParticleOritationDisplay {
      ONLY_Z,
      ALL_AXIS,
      ALL_AXIS_WITH_ORITATION,
    }
    namespace ParticleOritationDisplay {
      let RTTI: RTTIDescriptor;
    }
    enum FaceLiquifyVersionType {
      V1,
      V2,
    }
    namespace FaceLiquifyVersionType {
      let RTTI: RTTIDescriptor;
    }
    class BuiltinObject extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public getInputTextureWidth(): number;
      public getInputTextureHeight(): number;
      public getOutputTextureWidth(): number;
      public getOutputTextureHeight(): number;
      public isAndroid(): boolean;
      public getBuiltinEffectConfig(): BuiltinEffectConfig;
      public getScene(name: string): Scene;
      public addScene(name: string, scene: Scene): void;
      public removeScene(name: string): boolean;
      public getUserTexture(name: string): Texture2D;
      public getUserTextureOrientation(name: string): number;
      public getUserStringValue(name: string): string;
      public addUserTexture(name: string, texture: Texture): void;
      public getBuiltinTexture(type: BuiltInTextureType, index: number): Texture;
      public releaseMidRts(): void;
      public isInEditMode(): boolean;
      public setInEditMode(mode: boolean): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class JSScript extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public className: string;
      public handle: number;
      public addEventType(type: number): void;
      public removeEventType(type: number): void;
      public addAllEventType(): void;
      public clearAllEventType(): void;
      public addScriptListener(object: AObject, listenerType: number, funcName: string, scriptUserData: AObject): void;
      public removeScriptListener(object: AObject, listenerType: number, funcName: string, scriptUserData: AObject): void;
      public handleComponentName(compName: string): void;
      public handleNoComponent(): void;
      public handleAllComponent(): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ClothClassInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public trackID: number;
      public type: number;
      public score: number;
      public x0: number;
      public y0: number;
      public x1: number;
      public y1: number;
      public vertices: Vec2Vector;
      public probs: FloatVector;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class LightingData extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public lightProbePoss: Vec3Vector;
      public coefficients: Vector;
      public hullRays: Vec3Vector;
      public tetrahedra: Vector;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class MeshBandOption extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public offset: number;
      public width: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class AvacapInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public alpha: FloatVector;
      public beta: FloatVector;
      public mv: Matrix4x4f;
      public mvp: Matrix4x4f;
      public rot: Matrix3x3f;
      public trans: Vector3f;
      public meshv: Vec3Vector;
      public meshTriFace: Vector3f;
      public proj: Matrix4x4f;
      public idLen: number;
      public expLen: number;
      public vertexLen: number;
      public faceLen: number;
      public faceCount: number;
      public faceID: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class JSScriptComponent extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public path: string;
      public properties: Map;
      public handle: number;
      public getScript(): JSScript;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class DirectionalLight extends Light {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public color: Vector3f;
      public intensiy: number;
      public shadowEnable: boolean;
      public shadowEnableNew: boolean;
      public shadowResolution: Vector2f;
      public shadowBias: number;
      public shadowStrength: number;
      public useSoftShadow: boolean;
      public shadowSoftness: number;
      public blurRadius: number;
      public blurNum: number;
      public selfShadowGradient: number;
      public shadowColor: Vector3f;
      public InitStrength: number;
      public EsmC: number;
      public cookieTexture: Texture;
      public lightingLayers: DynamicBitset;
      public renderMode: LightRenderMode;
      public mainCamera: Transform;
      public shadowArea: number;
      public autoShadowFrustum: boolean;
      public shadowFrustumZNear: number;
      public shadowFrustumZFar: number;
      public shadowTexture: Texture;
      public cookieSize: number;
      public softShadowType: SoftShadowType;
      public EVSMExponents: Vector2f;
      public contactShadowEnable: boolean;
      public lightUnit: LightUnit;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class PointLight extends Light {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public color: Vector3f;
      public intensiy: number;
      public shadowEnable: boolean;
      public shadowEnableNew: boolean;
      public shadowResolution: Vector2f;
      public shadowBias: number;
      public shadowStrength: number;
      public useSoftShadow: boolean;
      public shadowSoftness: number;
      public blurRadius: number;
      public blurNum: number;
      public selfShadowGradient: number;
      public shadowColor: Vector3f;
      public InitStrength: number;
      public EsmC: number;
      public cookieTexture: Texture;
      public lightingLayers: DynamicBitset;
      public renderMode: LightRenderMode;
      public mainCamera: Transform;
      public shadowArea: number;
      public autoShadowFrustum: boolean;
      public shadowFrustumZNear: number;
      public shadowFrustumZFar: number;
      public shadowTexture: Texture;
      public range: number;
      public attenuationRange: number;
      public lightUnit: LightUnit;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class SpotLight extends Light {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public color: Vector3f;
      public intensiy: number;
      public shadowEnable: boolean;
      public shadowEnableNew: boolean;
      public shadowResolution: Vector2f;
      public shadowBias: number;
      public shadowStrength: number;
      public useSoftShadow: boolean;
      public shadowSoftness: number;
      public blurRadius: number;
      public blurNum: number;
      public selfShadowGradient: number;
      public shadowColor: Vector3f;
      public InitStrength: number;
      public EsmC: number;
      public cookieTexture: Texture;
      public lightingLayers: DynamicBitset;
      public renderMode: LightRenderMode;
      public mainCamera: Transform;
      public shadowArea: number;
      public autoShadowFrustum: boolean;
      public shadowFrustumZNear: number;
      public shadowFrustumZFar: number;
      public shadowTexture: Texture;
      public range: number;
      public attenuationRange: number;
      public innerAngle: number;
      public outerAngle: number;
      public lightUnit: LightUnit;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class AreaLight extends Light {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public color: Vector3f;
      public intensiy: number;
      public shadowEnable: boolean;
      public shadowEnableNew: boolean;
      public shadowResolution: Vector2f;
      public shadowBias: number;
      public shadowStrength: number;
      public useSoftShadow: boolean;
      public shadowSoftness: number;
      public blurRadius: number;
      public blurNum: number;
      public selfShadowGradient: number;
      public shadowColor: Vector3f;
      public InitStrength: number;
      public EsmC: number;
      public cookieTexture: Texture;
      public lightingLayers: DynamicBitset;
      public renderMode: LightRenderMode;
      public mainCamera: Transform;
      public shadowArea: number;
      public autoShadowFrustum: boolean;
      public shadowFrustumZNear: number;
      public shadowFrustumZFar: number;
      public shadowTexture: Texture;
      public attenuationRange: number;
      public lightUnit: LightUnit;
      public shape: AreaShape;
      public twoSide: boolean;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Light extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public color: Vector3f;
      public intensiy: number;
      public shadowEnable: boolean;
      public shadowEnableNew: boolean;
      public shadowResolution: Vector2f;
      public shadowBias: number;
      public shadowStrength: number;
      public useSoftShadow: boolean;
      public shadowSoftness: number;
      public blurRadius: number;
      public blurNum: number;
      public selfShadowGradient: number;
      public shadowColor: Vector3f;
      public InitStrength: number;
      public EsmC: number;
      public cookieTexture: Texture;
      public lightingLayers: DynamicBitset;
      public renderMode: LightRenderMode;
      public mainCamera: Transform;
      public shadowArea: number;
      public autoShadowFrustum: boolean;
      public shadowFrustumZNear: number;
      public shadowFrustumZFar: number;
      public shadowTexture: Texture;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class LightProbeGroup extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public lightingData: LightingData;
      public handle: number;
      public getLightProbeNum(): number;
      public getLightProbePos(index: number): Vector3f;
      public getCubeMapTexArray(index: number): RenderTextureArray;
      public setSliceData(data: Variant, i: number, j: number): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ReflectionProbe extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public cubeMapTexArray: RenderTextureArray;
      public isReflectionCubeMapGenerated: boolean;
      public isBakingReflectionProbeTriggered: boolean;
      public boxProjection: boolean;
      public zone: AABB;
      public cubeMapTexture: TextureCube;
      public handle: number;
      public setSliceData(data: Variant, index: number): void;
      public getReflectionProbePosXYZ(): Vector3f;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Skeleton extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class LookAt extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public target: Transform;
      public mode: LookAtMode;
      public worldUp: LookAtWorldUp;
      public aim: LookAtDirection;
      public up: LookAtDirection;
      public offsetRotation: Vector3f;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class MeshTriangleSorter extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public subMeshIndices: Vector;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ScriptComponent extends BehaviorComponent {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public path: string;
      public properties: Map;
      public className: string;
      public handle: number;
      public getScript(): Script;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class MeshRenderer extends Renderer {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public sharedMaterials: Vector;
      public sharedMaterial: Material;
      public props: MaterialPropertyBlock;
      public sortingOrder: number;
      public autoSortingOrder: boolean;
      public materials: Vector;
      public material: Material;
      public useFrustumCulling: boolean;
      public useCustomProjectMatrix: boolean;
      public customProjectMatrix: Matrix4x4f;
      public receiveShadow: boolean;
      public lightProbeBlendMode: LightProbeBlendMode;
      public mesh: Mesh;
      public castShadow: boolean;
      public handle: number;
      public getMorphedMesh(): Mesh;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class SkinMeshRenderer extends Renderer {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public sharedMaterials: Vector;
      public sharedMaterial: Material;
      public props: MaterialPropertyBlock;
      public sortingOrder: number;
      public autoSortingOrder: boolean;
      public materials: Vector;
      public material: Material;
      public useFrustumCulling: boolean;
      public useCustomProjectMatrix: boolean;
      public customProjectMatrix: Matrix4x4f;
      public receiveShadow: boolean;
      public lightProbeBlendMode: LightProbeBlendMode;
      public mesh: Mesh;
      public gpuTextureSkinning: boolean;
      public useCoarseMesh: boolean;
      public castShadow: boolean;
      public skin: Skin;
      public handle: number;
      public attachSkin(skin: Skin, skelRootEnt: Entity): void;
      public getMorphedMesh(): Mesh;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ParticleComponent extends Renderer {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public sharedMaterials: Vector;
      public sharedMaterial: Material;
      public props: MaterialPropertyBlock;
      public sortingOrder: number;
      public autoSortingOrder: boolean;
      public materials: Vector;
      public material: Material;
      public useFrustumCulling: boolean;
      public useCustomProjectMatrix: boolean;
      public customProjectMatrix: Matrix4x4f;
      public receiveShadow: boolean;
      public lightProbeBlendMode: LightProbeBlendMode;
      public emitters: Vector;
      public affectors: Vector;
      public renderer: ParticleRenderer;
      public particleQuota: number;
      public textureBlockWidth: number;
      public textureBlockHeight: number;
      public flipY: boolean;
      public autoStart: boolean;
      public prewarm: boolean;
      public simulationSpace: ParticleSimulationSpace;
      public oritationDisplayMode: ParticleOritationDisplay;
      public oritationMode: ParticleOritationMode;
      public simulationSpeed: number;
      public ringBufferMode: ParticleRingBufferMode;
      public loopRange: Value;
      public subEmitters: Vector;
      public use_physics: number;
      public gravityScale: number;
      public colliderScale: number;
      public colliderOffset: Vector3f;
      public fixedRotate: boolean;
      public friction: number;
      public bounciness: number;
      public linearDamping: number;
      public angularDamping: number;
      public linearFactor: Vector3f;
      public angularFactor: Vector3f;
      public colliderCategoryBits: number;
      public colliderMaskBits: number;
      public enableTransformAffector: boolean;
      public handle: number;
      public start(): void;
      public stop(): void;
      public resume(): void;
      public pause(): void;
      public forceStop(): void;
      public isStopped(): boolean;
      public isStarted(): boolean;
      public isPaused(): boolean;
      public getParticleIterator(): ParticleIterator;
      public triggerSubEmitter(arg0: number, arg1: Particle): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Sprite2DRenderer extends Renderer {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public sharedMaterials: Vector;
      public sharedMaterial: Material;
      public props: MaterialPropertyBlock;
      public sortingOrder: number;
      public autoSortingOrder: boolean;
      public materials: Vector;
      public material: Material;
      public useFrustumCulling: boolean;
      public useCustomProjectMatrix: boolean;
      public customProjectMatrix: Matrix4x4f;
      public receiveShadow: boolean;
      public lightProbeBlendMode: LightProbeBlendMode;
      public stretchMode: StretchMode;
      public pivot: Vector2f;
      public flip: boolean;
      public mirror: boolean;
      public color: Vector4f;
      public handle: number;
      public getBaseTexture(): Texture;
      public setBaseTexture(tex: Texture, outerRect: Vector4f, rotate: RotateType): void;
      public getTextureSize(): Vector2f;
      public setTexFromKey(key: string): void;
      public setTextureSize(arg0: Vector2f): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ReshapableGridRenderer extends Renderer {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public sharedMaterials: Vector;
      public sharedMaterial: Material;
      public props: MaterialPropertyBlock;
      public sortingOrder: number;
      public autoSortingOrder: boolean;
      public materials: Vector;
      public material: Material;
      public useFrustumCulling: boolean;
      public useCustomProjectMatrix: boolean;
      public customProjectMatrix: Matrix4x4f;
      public receiveShadow: boolean;
      public lightProbeBlendMode: LightProbeBlendMode;
      public drawGridAsWireframe: boolean;
      public cellHorizontal: number;
      public cellVertical: number;
      public canvasSize: Vector2f;
      public reshapeType: GridReshapeType;
      public intensity: number;
      public slimMaxOffset: number;
      public expandHardnessPos: number;
      public expandHardnessNeg: number;
      public stretchBottomY: number;
      public stretchUpY: number;
      public stretchWidthDiff: number;
      public stretchHeightDiff: number;
      public shrinkWidthDiff: number;
      public shrinkHeightDiff: number;
      public reshapeQuadPointA: Vector2f;
      public reshapeQuadPointB: Vector2f;
      public reshapeQuadPointC: Vector2f;
      public reshapeQuadPointD: Vector2f;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class SeqMeshRenderer extends Renderer {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public sharedMaterials: Vector;
      public sharedMaterial: Material;
      public props: MaterialPropertyBlock;
      public sortingOrder: number;
      public autoSortingOrder: boolean;
      public materials: Vector;
      public material: Material;
      public useFrustumCulling: boolean;
      public useCustomProjectMatrix: boolean;
      public customProjectMatrix: Matrix4x4f;
      public receiveShadow: boolean;
      public lightProbeBlendMode: LightProbeBlendMode;
      public castShadow: boolean;
      public mesh: Mesh;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class IFLayer2d extends Renderer {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public sharedMaterials: Vector;
      public sharedMaterial: Material;
      public props: MaterialPropertyBlock;
      public sortingOrder: number;
      public autoSortingOrder: boolean;
      public materials: Vector;
      public material: Material;
      public useFrustumCulling: boolean;
      public useCustomProjectMatrix: boolean;
      public customProjectMatrix: Matrix4x4f;
      public receiveShadow: boolean;
      public lightProbeBlendMode: LightProbeBlendMode;
      public renderOrderMode: IFLayer2dRenderOrderMode;
      public blendMode: IFBlendMode;
      public blendAlpha: number;
      public blendAlphaCkeck: boolean;
      public drawCallNum: number;
      public maskType: IFMaskType;
      public inverted: boolean;
      public scissorRectMask: boolean;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class SpriteRenderer extends Renderer {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public sharedMaterials: Vector;
      public sharedMaterial: Material;
      public props: MaterialPropertyBlock;
      public sortingOrder: number;
      public autoSortingOrder: boolean;
      public materials: Vector;
      public material: Material;
      public useFrustumCulling: boolean;
      public useCustomProjectMatrix: boolean;
      public customProjectMatrix: Matrix4x4f;
      public receiveShadow: boolean;
      public lightProbeBlendMode: LightProbeBlendMode;
      public sprite: Sprite;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ColorFilterRender extends Renderer {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public sharedMaterials: Vector;
      public sharedMaterial: Material;
      public props: MaterialPropertyBlock;
      public sortingOrder: number;
      public autoSortingOrder: boolean;
      public materials: Vector;
      public material: Material;
      public useFrustumCulling: boolean;
      public useCustomProjectMatrix: boolean;
      public customProjectMatrix: Matrix4x4f;
      public receiveShadow: boolean;
      public lightProbeBlendMode: LightProbeBlendMode;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Renderer extends BehaviorComponent {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public sharedMaterials: Vector;
      public sharedMaterial: Material;
      public props: MaterialPropertyBlock;
      public sortingOrder: number;
      public autoSortingOrder: boolean;
      public materials: Vector;
      public material: Material;
      public useFrustumCulling: boolean;
      public useCustomProjectMatrix: boolean;
      public customProjectMatrix: Matrix4x4f;
      public receiveShadow: boolean;
      public lightProbeBlendMode: LightProbeBlendMode;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class FaceReshape extends BehaviorComponent {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public params: FaceReshapeParams;
      public faceids: UInt8Vector;
      public smooth_strip: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class FaceReshapeV4 extends BehaviorComponent {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public indices: UInt16Vector;
      public representInfo: FloatVector;
      public param: FloatVector;
      public faceIds: UInt8Vector;
      public enableMultiParams: boolean;
      public paramsMap: Map;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class FaceReshapeLiquefy extends BehaviorComponent {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public params: FaceReshapeLiquefyParams;
      public petparams: FaceReshapeLiquefyPetParams;
      public indices: string;
      public faceids: UInt8Vector;
      public intensityParams: FloatVector;
      public Type: FaceReshapeLiquefyType;
      public version: FaceLiquifyVersionType;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ManualLiquefy extends BehaviorComponent {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public type: LiquefyBrushType;
      public faceID: number;
      public radius: number;
      public intensity: number;
      public hardness: number;
      public cellHorizontal: number;
      public cellVertical: number;
      public flipHorizontal: boolean;
      public flipVertical: boolean;
      public drawGridAsWireframe: boolean;
      public handle: number;
      public addTouchInfo(startPt: Vector2f, endPt: Vector2f): void;
      public resetVertexState(): boolean;
      public saveVertexState(path: string): boolean;
      public loadVertexState(path: string): boolean;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class FaceBackgroundFitting extends BehaviorComponent {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Face3DAccurateAttaching extends BehaviorComponent {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public controlPointsIndices: Int32Vector;
      public constrainPointsIndices: Int32Vector;
      public targetFacesIndices: Int32Vector;
      public targetPointsCoords: FloatVector;
      public barycentricCoords: FloatVector;
      public laplacianWeight: number;
      public constrainWeight: number;
      public selectionWeight: number;
      public iteration: number;
      public isInit: boolean;
      public target: Transform;
      public deformationType: DeformationType;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class FaceEditor extends BehaviorComponent {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public controlMode: ControlMode;
      public faceID: number;
      public curFrame: number;
      public controlPointsName: StringVector;
      public keyFramesDelta: FloatVector;
      public regionsName: StringVector;
      public regionsWeight: FloatVector;
      public mvp: Matrix4x4f;
      public rotationMatrix: Matrix4x4f;
      public isValid: boolean;
      public isInit: boolean;
      public headSwingPivot: number;
      public useControler: boolean;
      public VATfilename: string;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ShroudDeform extends BehaviorComponent {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public target: Transform;
      public isValid: boolean;
      public isInit: boolean;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class IFCanvas2d extends BehaviorComponent {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public resolutionType: IFResolutionType;
      public resolutionSize: Vector2f;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class IFEventDistributor extends BehaviorComponent {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public EventMask: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class IFUIAnchor extends BehaviorComponent {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public leftAnchorPercent: number;
      public leftAnchorAbs: number;
      public rightAnchorPercent: number;
      public rightAnchorAbs: number;
      public topAnchorPercent: number;
      public topAnchorAbs: number;
      public bottomAnchorPercent: number;
      public bottomAnchorAbs: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class IFTweenPosition extends IFTween {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public CurveType: IFTweenCurveType;
      public Duration: number;
      public Delay: number;
      public PlayStyle: IFTweenStyle;
      public ControlMode: IFTweenControlMode;
      public "2dPostion_From": Vector2f;
      public "2dPostion_To": Vector2f;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class IFTween extends BehaviorComponent {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public CurveType: IFTweenCurveType;
      public Duration: number;
      public Delay: number;
      public PlayStyle: IFTweenStyle;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class IFUIButton extends IFUIControl {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public swallowTouch: boolean;
      public touchEnabled: boolean;
      public scriptComponent: Transform;
      public hitOnTouchMoved: boolean;
      public stateTextures: Vector;
      public normalSprite: number;
      public pressedSprite: number;
      public disabledSprite: number;
      public normalColor: Color;
      public pressedColor: Color;
      public disabledColor: Color;
      public enabled: boolean;
      public touchMoveRespond: boolean;
      public onSprite: number;
      public offSprite: number;
      public onColor: Color;
      public offColor: Color;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class IFUISwitch extends IFUIControl {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public swallowTouch: boolean;
      public touchEnabled: boolean;
      public scriptComponent: Transform;
      public hitOnTouchMoved: boolean;
      public stateTextures: Vector;
      public normalSprite: number;
      public pressedSprite: number;
      public disabledSprite: number;
      public normalColor: Color;
      public pressedColor: Color;
      public disabledColor: Color;
      public enabled: boolean;
      public touchMoveRespond: boolean;
      public onSprite: number;
      public offSprite: number;
      public onColor: Color;
      public offColor: Color;
      public on: boolean;
      public thumb: IFTransform2d;
      public AnimScale: number;
      public AnimTime: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class IFUITab extends IFUIControl {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public swallowTouch: boolean;
      public touchEnabled: boolean;
      public scriptComponent: Transform;
      public hitOnTouchMoved: boolean;
      public stateTextures: Vector;
      public normalSprite: number;
      public pressedSprite: number;
      public disabledSprite: number;
      public normalColor: Color;
      public pressedColor: Color;
      public disabledColor: Color;
      public enabled: boolean;
      public touchMoveRespond: boolean;
      public onSprite: number;
      public offSprite: number;
      public onColor: Color;
      public offColor: Color;
      public groupEnabled: boolean;
      public groupCancelSelf: boolean;
      public groupID: number;
      public index: number;
      public Selected: boolean;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class IFUIJoyStick extends IFUIControl {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public swallowTouch: boolean;
      public touchEnabled: boolean;
      public scriptComponent: Transform;
      public hitOnTouchMoved: boolean;
      public stateTextures: Vector;
      public normalSprite: number;
      public pressedSprite: number;
      public disabledSprite: number;
      public normalColor: Color;
      public pressedColor: Color;
      public disabledColor: Color;
      public enabled: boolean;
      public touchMoveRespond: boolean;
      public onSprite: number;
      public offSprite: number;
      public onColor: Color;
      public offColor: Color;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class IFUIDropdown extends IFUIControl {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public swallowTouch: boolean;
      public touchEnabled: boolean;
      public scriptComponent: Transform;
      public hitOnTouchMoved: boolean;
      public stateTextures: Vector;
      public normalSprite: number;
      public pressedSprite: number;
      public disabledSprite: number;
      public normalColor: Color;
      public pressedColor: Color;
      public disabledColor: Color;
      public enabled: boolean;
      public touchMoveRespond: boolean;
      public onSprite: number;
      public offSprite: number;
      public onColor: Color;
      public offColor: Color;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class IFUISlider extends IFUIControl {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public swallowTouch: boolean;
      public touchEnabled: boolean;
      public scriptComponent: Transform;
      public hitOnTouchMoved: boolean;
      public stateTextures: Vector;
      public normalSprite: number;
      public pressedSprite: number;
      public disabledSprite: number;
      public normalColor: Color;
      public pressedColor: Color;
      public disabledColor: Color;
      public enabled: boolean;
      public touchMoveRespond: boolean;
      public onSprite: number;
      public offSprite: number;
      public onColor: Color;
      public offColor: Color;
      public direction: IFUIMoveDirection;
      public mode: IFUISliderMode;
      public minValue: number;
      public maxValue: number;
      public steps: number;
      public fillTrans: IFTransform2d;
      public thumbTrans: IFTransform2d;
      public value: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class IFUISliderThumb extends IFUIControl {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public swallowTouch: boolean;
      public touchEnabled: boolean;
      public scriptComponent: Transform;
      public hitOnTouchMoved: boolean;
      public stateTextures: Vector;
      public normalSprite: number;
      public pressedSprite: number;
      public disabledSprite: number;
      public normalColor: Color;
      public pressedColor: Color;
      public disabledColor: Color;
      public enabled: boolean;
      public touchMoveRespond: boolean;
      public onSprite: number;
      public offSprite: number;
      public onColor: Color;
      public offColor: Color;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class IFUIControl extends IFResponder {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public swallowTouch: boolean;
      public touchEnabled: boolean;
      public scriptComponent: Transform;
      public hitOnTouchMoved: boolean;
      public stateTextures: Vector;
      public normalSprite: number;
      public pressedSprite: number;
      public disabledSprite: number;
      public normalColor: Color;
      public pressedColor: Color;
      public disabledColor: Color;
      public enabled: boolean;
      public touchMoveRespond: boolean;
      public onSprite: number;
      public offSprite: number;
      public onColor: Color;
      public offColor: Color;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class IFUIScrollView extends IFResponder {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public swallowTouch: boolean;
      public touchEnabled: boolean;
      public scriptComponent: Transform;
      public hitOnTouchMoved: boolean;
      public content: Transform;
      public direction: IFUIScrollDirection;
      public horizontalScrollBar: Transform;
      public verticalScrollBar: Transform;
      public bounce: boolean;
      public bounceDuration: number;
      public inertia: number;
      public offset: Vector2f;
      public minOffset: Vector2f;
      public maxOffset: Vector2f;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class IFUIScrollBar extends IFResponder {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public swallowTouch: boolean;
      public touchEnabled: boolean;
      public scriptComponent: Transform;
      public hitOnTouchMoved: boolean;
      public direction: IFUIMoveDirection;
      public handleTrans: Transform;
      public handleSize: Vector2f;
      public displayTime: number;
      public disappearTime: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class IFResponder extends BehaviorComponent {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public swallowTouch: boolean;
      public touchEnabled: boolean;
      public scriptComponent: Transform;
      public hitOnTouchMoved: boolean;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class BehaviorComponent extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class TableComponent extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public table: Map;
      public type: string;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Camera extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public layerVisibleMask: DynamicBitset;
      public renderOrder: number;
      public type: CameraType;
      public clearColor: Color;
      public clearType: CameraClearType;
      public alwaysClear: boolean;
      public viewport: Rect;
      public fovy: number;
      public orthoScale: number;
      public zNear: number;
      public zFar: number;
      public inputTexture: Texture;
      public renderTexture: RenderTexture;
      public projectionMatrix: Matrix4x4f;
      public isRootCamera: boolean;
      public handle: number;
      public isOutOfFrustum(bbox: AABB): boolean;
      public worldToScreenPoint(v: Vector3f): Vector3f;
      public screenToWorldPoint(v: Vector3f): Vector3f;
      public viewportToWorldPoint(viewPortPoint: Vector3f): Vector3f;
      public worldToViewportPoint(worldPoint: Vector3f): Vector3f;
      public isLayerVisible(layer: number): boolean;
      public clearTarget(isolated: boolean): void;
      public getWorldToClipMatrix(): Matrix4x4f;
      public getCameraToWorldMatrix(): Matrix4x4f;
      public getWorldToCameraMatrix(): Matrix4x4f;
      public setWorldToCameraMatrix(matrix: Matrix4x4f): void;
      public resetWorldToCameraMatrix(): void;
      public getPosition(): Vector3f;
      public getLookAt(): Vector3f;
      public ScreenPointToRay(screenPos: Vector2f): Ray;
      public ViewportPointToRay(viewportPos: Vector2f): Ray;
      public invokeCameraEvent(cameraEvent: number): void;
      public tryGetCullingParameters(): ScriptableCullingParameters;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class AMGTransform2D extends Transform {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public localPosition: ProxyVector3f;
      public localScale: Vector3f;
      public localOrientation: Quaternionf;
      public localMatrix: Matrix4x4f;
      public localEulerAngle: Vector3f;
      public worldPosition: Vector3f;
      public worldOrientation: Quaternionf;
      public worldScale: Vector3f;
      public worldEulerAngle: Vector3f;
      public parent: Transform;
      public children: Vector;
      public right: Vector3f;
      public up: Vector3f;
      public forward: Vector3f;
      public mobility: Mobility;
      public handle: number;
      public setAnchor(anchorTo: Vector2f, originalPixelSize: Vector2f, pixelRatio: number): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class IFTransform2d extends Transform {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public localPosition: ProxyVector3f;
      public localScale: Vector3f;
      public localOrientation: Quaternionf;
      public localMatrix: Matrix4x4f;
      public localEulerAngle: Vector3f;
      public worldPosition: Vector3f;
      public worldOrientation: Quaternionf;
      public worldScale: Vector3f;
      public worldEulerAngle: Vector3f;
      public parent: Transform;
      public children: Vector;
      public right: Vector3f;
      public up: Vector3f;
      public forward: Vector3f;
      public mobility: Mobility;
      public position: Vector2f;
      public rotation: number;
      public scale: Vector2f;
      public size: Vector2f;
      public pivot: Vector2f;
      public flipX: boolean;
      public flipY: boolean;
      public depth: number;
      public handle: number;
      public getWorldRectPosArray(): Vec3Vector;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Transform extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public localPosition: ProxyVector3f;
      public localScale: Vector3f;
      public localOrientation: Quaternionf;
      public localMatrix: Matrix4x4f;
      public localEulerAngle: Vector3f;
      public worldPosition: Vector3f;
      public worldOrientation: Quaternionf;
      public worldScale: Vector3f;
      public worldEulerAngle: Vector3f;
      public parent: Transform;
      public children: Vector;
      public right: Vector3f;
      public up: Vector3f;
      public forward: Vector3f;
      public mobility: Mobility;
      public handle: number;
      public addTransform(childTrans: Transform): boolean;
      public removeTransform(childTrans: Transform): boolean;
      public getWorldPosition(): Vector3f;
      public setWorldPosition(worldPos: Vector3f): void;
      public getWorldScale(): Vector3f;
      public setWorldScale(worldScale: Vector3f): void;
      public getWorldOrientation(): Quaternionf;
      public setWorldOrientation(worldOrientation: Quaternionf): void;
      public setWorldMatrix(worldMat: Matrix4x4f): void;
      public getWorldMatrix(): Matrix4x4f;
      public lookAt(target: Vector3f, up: Vector3f): void;
      public getWorldToLocalMatrix(): Matrix4x4f;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class BrushComponent extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public distance: number;
      public brushBeginLength: number;
      public brushMainLength: number;
      public brushEndLength: number;
      public brushDrawingScale: number;
      public brushLocalFrameType: BrushLocalFrameType;
      public brushDrawingType: BrushDrawingType;
      public brushFixedEnd: BrushSegment;
      public animationEnabled: boolean;
      public controlledByInputSpeed: boolean;
      public resamplingEnabled: boolean;
      public smoothingEnabled: boolean;
      public smoothingStrength: number;
      public verticalForcingStrength: number;
      public animationSpeed: number;
      public inputSpeedScale: number;
      public inputSpeedCutOff: number;
      public inputSpeedControlStrength: number;
      public skipMinDistance: number;
      public skipMaxDistance: number;
      public resampleArcLengthInterval: number;
      public simplifyEnabled: boolean;
      public redistributeUVEnabled: boolean;
      public alignEndUV: boolean;
      public simplifyThreshold: number;
      public simplifyWindowSize: number;
      public simplifyMaximumLength: number;
      public faceEnabled: boolean;
      public prefabBegin: Prefab;
      public prefabMain: Prefab;
      public prefabEnd: Prefab;
      public stroke: BrushStroke;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ViewTracker extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public trackingType: TrackingType;
      public trackingMode: TrackingMode;
      public arUnit: ARUnit;
      public multiTouch: boolean;
      public algNode: string;
      public handle: number;
      public getSlamHandler(): SlamHandler;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class PoseTracker extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public pose: Vector3f;
      public scale: Vector3f;
      public degrees: Vector3f;
      public state: Matrix4x4f;
      public result: Matrix4x4f;
      public anchorIndex: number;
      public dirty: boolean;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class FeatureNode extends EffectNode {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public defaultInput: RenderTexture;
      public inputTextures: Vector;
      public outputTextures: Vector;
      public renderOrder: number;
      public minorOrder: number;
      public rendererType: RendererType;
      public featureTag: string;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class EffectNode extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public defaultInput: RenderTexture;
      public inputTextures: Vector;
      public outputTextures: Vector;
      public renderOrder: number;
      public minorOrder: number;
      public rendererType: RendererType;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class FeatureNodeExclusion extends EffectNodeExclusion {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public groupId: number;
      public sceneKey: string;
      public priority: number;
      public tagName: Vector;
      public composerKey: Vector;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class EffectNodeExclusion extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public groupId: number;
      public sceneKey: string;
      public priority: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Audio extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public clip: AudioClip;
      public playOnAwake: boolean;
      public loop: boolean;
      public handle: number;
      public play(): void;
      public pause(): void;
      public resume(): void;
      public reset(): void;
      public stop(): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class SDFText extends BaseText {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public forceDegeneratedEs2Enabled: boolean;
      public str: string;
      public fontSize: number;
      public autoAdaptDpiEnabled: boolean;
      public fontPath: string;
      public fallbackFontPath: string;
      public wordGap: number;
      public horizontalPadding: number;
      public verticalPadding: number;
      public lineGap: number;
      public typeSettingKind: TypeSettingKind;
      public textAlign: TextAlign;
      public fixedRectEnabled: boolean;
      public autoFontSize: boolean;
      public rect: Rect;
      public autoWrapWidth: number;
      public chars: Vector;
      public drivenByScript: boolean;
      public textColor: Vector4f;
      public randomGridSize: Vector2f;
      public shadowEnabled: boolean;
      public shadowColor: Vector4f;
      public shadowOffset: Vector2f;
      public shadowSmoothing: number;
      public shadowBlur: number;
      public outlineEnabled: boolean;
      public outlineWidth: number;
      public outlineMaxWidth: number;
      public outlineColor: Vector4f;
      public boldWidth: number;
      public italicDegree: number;
      public underlineEnabled: boolean;
      public underlineWidth: number;
      public underlineOffset: number;
      public backgroundEnabled: boolean;
      public backgroundColor: Vector4f;
      public backgroundRoundCornerEnabled: boolean;
      public backgroundRoundRadius: number;
      public backgroundWrappedEnabled: boolean;
      public backgroundRoundRadiusScale: number;
      public backgroundSplitThreshold: number;
      public backgroundSplitPadding: number;
      public backgroundCustomizedEnabled: boolean;
      public backgroundWHCustomized: Vector2f;
      public backgroundOffsetCustomized: Vector2f;
      public alpha: number;
      public effectTextParam: EffectTextParam;
      public ktvEnabled: boolean;
      public ktvDirection: number;
      public ktvAlpha: number;
      public renderToRT: boolean;
      public targetRTExtraSize: Vector2f;
      public ktvTransparentRatio: number;
      public maxRTSize: number;
      public handle: number;
      public forceTypeSetting(): void;
      public forceSdfTexture(): void;
      public getRenderer(): Renderer;
      public getTextTexture(): TextTexture;
      public getRectExpanded(): Rect;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Text3D extends BaseText {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public forceDegeneratedEs2Enabled: boolean;
      public str: string;
      public fontSize: number;
      public autoAdaptDpiEnabled: boolean;
      public fontPath: string;
      public fallbackFontPath: string;
      public wordGap: number;
      public horizontalPadding: number;
      public verticalPadding: number;
      public lineGap: number;
      public typeSettingKind: TypeSettingKind;
      public textAlign: TextAlign;
      public fixedRectEnabled: boolean;
      public autoFontSize: boolean;
      public rect: Rect;
      public autoWrapWidth: number;
      public chars: Vector;
      public charCenter: MeshCenter;
      public curve: MeshCurve;
      public curveSeg: number;
      public subdivisionLevel: number;
      public maxTris: number;
      public maxError: number;
      public extrudeNormal: MeshNormal;
      public extrude: number;
      public extrudeMiddle: number;
      public extrudeCap: number;
      public extrudeSeg: number;
      public genContours: boolean;
      public genTriMeshes: boolean;
      public skipRender: boolean;
      public textMat: Material;
      public clearMeshAfterUpload: boolean;
      public handle: number;
      public forceTypeSetting(): void;
      public getContours(): Vector;
      public getTriMeshes(): Vector;
      public getMeshes(): Vector;
      public getLocalMatrices(): Vector;
      public getEntities(): Vector;
      public getValidChars(): Vector;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class BaseText extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public forceDegeneratedEs2Enabled: boolean;
      public str: string;
      public fontSize: number;
      public autoAdaptDpiEnabled: boolean;
      public fontPath: string;
      public fallbackFontPath: string;
      public wordGap: number;
      public horizontalPadding: number;
      public verticalPadding: number;
      public lineGap: number;
      public typeSettingKind: TypeSettingKind;
      public textAlign: TextAlign;
      public fixedRectEnabled: boolean;
      public autoFontSize: boolean;
      public rect: Rect;
      public autoWrapWidth: number;
      public chars: Vector;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Animator extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public animations: Vector;
      public runningClips: Vector;
      public runningWrapModes: Map;
      public cullingMode: AnimatorCullingMode;
      public layers: Vector;
      public layerMasks: Vector;
      public handle: number;
      public play(clipName: string, wrapMode: number, speed: number, fadeInTime: number, startTime: number): void;
      public playState(layerIndex: number, stateIndex: number, fadeTime: number): void;
      public stopAllAnimations(): void;
      public schedule(clip: AnimazClip, wrapMode: number, speed: number): void;
      public unschedule(clip: AnimazClip): void;
      public pauseAnimator(): void;
      public resumeAnimator(): void;
      public createAnimation(name: string): Animaz;
      public getAnimation(name: string): Animaz;
      public removeAnimation(animationName: string): boolean;
      public getAnimationLayer(layerIndex: number): AnimLayer;
      public getOrCreateAnimationLayer(name: string): AnimLayer;
      public removeAnimationLayer(name: string): boolean;
      public getClipByName(name: string): BaseClip;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class FABRIK extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public targetJoint: Transform;
      public targetOffset: Vector3f;
      public rootJoint: string;
      public ikWeight: number;
      public maxIteration: number;
      public precision: number;
      public useRotationLimit: boolean;
      public ikPosition: Vector3f;
      public chainLength: number;
      public handle: number;
      public AddCollider(collider: DynamicJointCollider): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class RotationLimitAngle extends RotationLimit {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public axis: Vector3f;
      public swing: number;
      public twist: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class RotationLimit extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public axis: Vector3f;
      public handle: number;
      public setDefaultLocalRotation(q: Quaternionf): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class DynamicJoint extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public damping: Value;
      public elasticity: Value;
      public stiffness: Value;
      public inert: Value;
      public radius: Value;
      public force: Vector3f;
      public isLocalForce: boolean;
      public colliderList: Vector;
      public handle: number;
      public resetMomentum(): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class DynamicJointCollider extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public center: Vector3f;
      public radius: number;
      public height: number;
      public direction: CollideDirection;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class FaceMakeupV2EffectAnimSeq extends EffectAnimSeq {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public animSeq: AnimSeq;
      public texName: string;
      public frameName: string;
      public frameRotateName: string;
      public frameInnerName: string;
      public playmode: PlayMode;
      public loopCount: number;
      public speed: number;
      public autoplay: boolean;
      public frameIndex: number;
      public animSeqMap: Map;
      public entityName: string;
      public clipName: string;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class EffectAnimSeq extends AnimSeqComponent {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public animSeq: AnimSeq;
      public texName: string;
      public frameName: string;
      public frameRotateName: string;
      public frameInnerName: string;
      public playmode: PlayMode;
      public loopCount: number;
      public speed: number;
      public autoplay: boolean;
      public frameIndex: number;
      public animSeqMap: Map;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class AnimSeqComponent extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public animSeq: AnimSeq;
      public texName: string;
      public frameName: string;
      public frameRotateName: string;
      public frameInnerName: string;
      public playmode: PlayMode;
      public loopCount: number;
      public speed: number;
      public autoplay: boolean;
      public frameIndex: number;
      public animSeqMap: Map;
      public handle: number;
      public play(): void;
      public pause(): void;
      public stop(): void;
      public seek(index: number): void;
      public seekToTime(localTime: number): void;
      public resetAnim(): void;
      public switchAnimseq(key: string): void;
      public playFromTo(startIndex: number, endIndex: number, playMode: PlayMode, playCount: number, isVisible: boolean): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class GifAnimSeq extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public giffilename: string;
      public texName: string;
      public playmode: PlayMode;
      public loopCount: number;
      public speed: number;
      public autoplay: boolean;
      public handle: number;
      public play(): void;
      public pause(): void;
      public stop(): void;
      public seek(index: number): void;
      public seekToTime(localTime: number): void;
      public resetAnim(): void;
      public getOrCreateTexture(): Texture;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class VideoAnimSeq extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public videoFilename: string;
      public texName: string;
      public playmode: PlayMode;
      public loopCount: number;
      public speed: number;
      public autoplay: boolean;
      public enableAlphaBlend: boolean;
      public enableFixedSeekMode: boolean;
      public handle: number;
      public play(): void;
      public pause(): void;
      public stop(): void;
      public seek(index: number): void;
      public seekToTime(localTime: number): void;
      public resetAnim(): void;
      public getFrameCount(): number;
      public getDuration(): number;
      public getVideoSize(): Vector2f;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class PBF extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public viscosity: number;
      public dt: number;
      public niter: number;
      public kcorr: number;
      public ncorr: number;
      public lambda_eps: number;
      public gravity: Vector3f;
      public fluidStepType: FluidStepType;
      public fluidVelocity: Vector3f;
      public fluidSphereCenter: Vector3f;
      public fluidSphereRadius: Vector3f;
      public fluidSphereRatio: number;
      public fluidCubeLlim: Vector3f;
      public fluidCubeDimension: Vector3f;
      public modelPosition: Vector3f;
      public modelRadius: Vector3f;
      public isValid: boolean;
      public shaders: Map;
      public handle: number;
      public addFluid(): void;
      public getFluidParticlePosition(i: number): Vector3f;
      public getFluidParticleVelocity(i: number): Vector3f;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class MorpherComponent extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public originalVertices: FloatVector;
      public basemesh: Mesh;
      public useAvatarDrive: boolean;
      public useFaceBackgroundFitting: boolean;
      public usePosAttrOnly: boolean;
      public splitPosAndOffset: boolean;
      public recalcNormal: boolean;
      public updateOriginalMesh: boolean;
      public channelWeights: Map;
      public channelAmplifiers: Map;
      public handle: number;
      public hasChannel(name: string): boolean;
      public getChannelWeight(name: string): number;
      public setChannelWeight(name: string, weight: number): void;
      public reset(): void;
      public getMorpher(): Morpher;
      public getMorphedMesh(): Mesh;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class RenderPipelineSetting extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public PipelineType: RenderPipelineType;
      public LuaPath: string;
      public handle: number;
      public getPipelineLuaScript(): Script;
      public getPipelineJSScript(): JSScript;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class CircleCollider2D extends Collider2D {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public material: PhysicsMaterial;
      public density: number;
      public trigger: boolean;
      public categoryBits: number;
      public maskBits: number;
      public groupIndex: number;
      public offset: Vector2f;
      public radius: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class EdgeCollider2D extends Collider2D {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public material: PhysicsMaterial;
      public density: number;
      public trigger: boolean;
      public categoryBits: number;
      public maskBits: number;
      public groupIndex: number;
      public offset: Vector2f;
      public points: Vec2Vector;
      public edgeRadius: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class BoxCollider2D extends Collider2D {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public material: PhysicsMaterial;
      public density: number;
      public trigger: boolean;
      public categoryBits: number;
      public maskBits: number;
      public groupIndex: number;
      public offset: Vector2f;
      public size: Vector2f;
      public edgeRadius: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Collider2D extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public material: PhysicsMaterial;
      public density: number;
      public trigger: boolean;
      public categoryBits: number;
      public maskBits: number;
      public groupIndex: number;
      public offset: Vector2f;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class RigidBody2D extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public initPosition: Vector3f;
      public initRotation: Vector3f;
      public initLinearVel: Vector3f;
      public initAngularVel: Vector3f;
      public position: Vector3f;
      public rotation: Vector3f;
      public linearVel: Vector3f;
      public angularVel: Vector3f;
      public linearDamping: number;
      public angularDamping: number;
      public gravityScale: number;
      public externalForce: Vector3f;
      public forcePosition: Vector3f;
      public fixedRotate: boolean;
      public awake: boolean;
      public allowSleep: boolean;
      public rigidBodyType: RigidBodyType;
      public collisionDetectionType: CollisionDetectionType;
      public minSubSteps: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class SpringJoint2D extends Joint2D {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public connectedBody: RigidBody2D;
      public collideConnected: boolean;
      public anchor: Vector2f;
      public connectedAnchor: Vector2f;
      public distance: number;
      public frequency: number;
      public dampingRatio: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class SliderJoint2D extends Joint2D {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public connectedBody: RigidBody2D;
      public collideConnected: boolean;
      public anchor: Vector2f;
      public connectedAnchor: Vector2f;
      public motorized: boolean;
      public motorSpeed: number;
      public motorMaxForce: number;
      public limited: boolean;
      public lowerLimit: number;
      public upperLimit: number;
      public sliderAngle: number;
      public referenceAngle: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class HingeJoint2D extends Joint2D {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public connectedBody: RigidBody2D;
      public collideConnected: boolean;
      public anchor: Vector2f;
      public connectedAnchor: Vector2f;
      public motorized: boolean;
      public motorSpeed: number;
      public motorMaxForce: number;
      public limited: boolean;
      public lowerLimit: number;
      public upperLimit: number;
      public referenceAngle: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Joint2D extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public connectedBody: RigidBody2D;
      public collideConnected: boolean;
      public anchor: Vector2f;
      public connectedAnchor: Vector2f;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class RigidBody3D extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public position: Vector3f;
      public rotation: Quaternionf;
      public linearVel: Vector3f;
      public angularVel: Vector3f;
      public initPosition: Vector3f;
      public initRotation: Quaternionf;
      public initLinearVel: Vector3f;
      public initAngularVel: Vector3f;
      public mass: number;
      public material: PhysicsMaterial;
      public linearDamping: number;
      public angularDamping: number;
      public gravityAcceleration: Vector3f;
      public externalForce: Vector3f;
      public forcePosition: Vector3f;
      public localInertiaScale: number;
      public angularFactor: Vector3f;
      public linearFactor: Vector3f;
      public rigidBodyType: RigidBodyType;
      public collisionDetectionType: CollisionDetectionType;
      public minSubSteps: number;
      public sensor: boolean;
      public allowSleep: boolean;
      public categoryBits: number;
      public maskBits: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class GenericJoint3D extends Joint3D {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public connectedBody: RigidBody3D;
      public posAnchorA: Vector3f;
      public rotAnchorA: Quaternionf;
      public posAnchorB: Vector3f;
      public rotAnchorB: Quaternionf;
      public linearLowerLimit: Vector3f;
      public linearUpperLimit: Vector3f;
      public angularLowerLimit: Vector3f;
      public angularUpperLimit: Vector3f;
      public erpLinear: number;
      public cfmLinear: number;
      public erpAngular: number;
      public cfmAngular: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Joint3D extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public connectedBody: RigidBody3D;
      public posAnchorA: Vector3f;
      public rotAnchorA: Quaternionf;
      public posAnchorB: Vector3f;
      public rotAnchorB: Quaternionf;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class SphereCollider3D extends Collider3D {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public offset: Vector3f;
      public rot: Quaternionf;
      public flag: Collider3DFlag;
      public inputExclusive: boolean;
      public radius: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class StaticMeshCollider3D extends Collider3D {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public offset: Vector3f;
      public rot: Quaternionf;
      public flag: Collider3DFlag;
      public inputExclusive: boolean;
      public mesh: Mesh;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class CapsuleCollider3D extends Collider3D {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public offset: Vector3f;
      public rot: Quaternionf;
      public flag: Collider3DFlag;
      public inputExclusive: boolean;
      public radius: number;
      public height: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class BoxCollider3D extends Collider3D {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public offset: Vector3f;
      public rot: Quaternionf;
      public flag: Collider3DFlag;
      public inputExclusive: boolean;
      public halfExtent: Vector3f;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Collider3D extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public offset: Vector3f;
      public rot: Quaternionf;
      public flag: Collider3DFlag;
      public inputExclusive: boolean;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class VFXEffectBlock extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public profile: VFXProfile;
      public handle: number;
      public getCtxBlock(i: number): VFXContextBlock;
      public getCtxBlockWithID(index: number): VFXContextBlock;
      public setSystemSeed(seed: number): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class FaceCapture extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public faceid: number;
      public captureType: CaptureType;
      public captureVersion: CaptureVersion;
      public alignarray: Vec2Vector;
      public alignoffset: Vector2f;
      public alignz: number;
      public isGlobal: boolean;
      public useSceneCameraFov: boolean;
      public isPictureMode: boolean;
      public isFaceCaptureEnable: boolean;
      public calirateVersion: CalibrationType;
      public nearPlane: number;
      public farPlane: number;
      public useSceneCameraNearFar: boolean;
      public behaviorWhenTrackerDisappear: BehaviorWhenTrackerDisappear;
      public entityRotateType: EntityRotateType;
      public handle: number;
      public getProjectionMatrix(): Matrix4x4f;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class EffectListenerComp extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class EffectAudioComp extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class CompEntityGUID extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class AmazingVRBrushComp extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class FilterControlComponent extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public isFilter: boolean;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class PinToMesh extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public uv: Vector2f;
      public target: Transform;
      public offsetPosition: Vector3f;
      public offsetRotation: Vector3f;
      public modelScale: Vector3f;
      public orientation: PinOrientation;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class EffectFaceMakeupFaceUEyeDetail extends EffectFaceEyeDetail {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public type: EffectFaceMakeupType;
      public templateMesh: Mesh;
      public dynamicRenderChain: boolean;
      public makeupEntity: Entity;
      public faceIds: UInt8Vector;
      public renderer: Renderer;
      public facemakeupEntityName: string;
      public zPosition: number;
      public triggerLua: boolean;
      public version: number;
      public sdkType: number;
      public useVideoTexture: boolean;
      public useSegment: boolean;
      public maleOpacity: number;
      public femaleOpacity: number;
      public BlurVEntityName: string;
      public BlurHEntityName: string;
      public BlurVerticalEntity: Entity;
      public blurVerticalRenderer: Renderer;
      public blurHorizotalRenderer: Renderer;
      public BlurHorizontalEntity: Entity;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class EffectFaceEyeDetail extends EffectFaceMakeup {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public type: EffectFaceMakeupType;
      public templateMesh: Mesh;
      public dynamicRenderChain: boolean;
      public makeupEntity: Entity;
      public faceIds: UInt8Vector;
      public renderer: Renderer;
      public facemakeupEntityName: string;
      public zPosition: number;
      public triggerLua: boolean;
      public version: number;
      public sdkType: number;
      public useVideoTexture: boolean;
      public useSegment: boolean;
      public maleOpacity: number;
      public femaleOpacity: number;
      public BlurVEntityName: string;
      public BlurHEntityName: string;
      public BlurVerticalEntity: Entity;
      public blurVerticalRenderer: Renderer;
      public blurHorizotalRenderer: Renderer;
      public BlurHorizontalEntity: Entity;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class EffectFaceJieMaoV1 extends EffectFaceMakeup {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public type: EffectFaceMakeupType;
      public templateMesh: Mesh;
      public dynamicRenderChain: boolean;
      public makeupEntity: Entity;
      public faceIds: UInt8Vector;
      public renderer: Renderer;
      public facemakeupEntityName: string;
      public zPosition: number;
      public triggerLua: boolean;
      public version: number;
      public sdkType: number;
      public useVideoTexture: boolean;
      public useSegment: boolean;
      public maleOpacity: number;
      public femaleOpacity: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class EffectFaceMouthPart extends EffectFaceMakeup {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public type: EffectFaceMakeupType;
      public templateMesh: Mesh;
      public dynamicRenderChain: boolean;
      public makeupEntity: Entity;
      public faceIds: UInt8Vector;
      public renderer: Renderer;
      public facemakeupEntityName: string;
      public zPosition: number;
      public triggerLua: boolean;
      public version: number;
      public sdkType: number;
      public useVideoTexture: boolean;
      public useSegment: boolean;
      public maleOpacity: number;
      public femaleOpacity: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class EffectFaceLipV2 extends EffectFaceMakeup {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public type: EffectFaceMakeupType;
      public templateMesh: Mesh;
      public dynamicRenderChain: boolean;
      public makeupEntity: Entity;
      public faceIds: UInt8Vector;
      public renderer: Renderer;
      public facemakeupEntityName: string;
      public zPosition: number;
      public triggerLua: boolean;
      public version: number;
      public sdkType: number;
      public useVideoTexture: boolean;
      public useSegment: boolean;
      public maleOpacity: number;
      public femaleOpacity: number;
      public mouth_color: Vec4Vector;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class EffectFaceLipV3 extends EffectFaceMakeup {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public type: EffectFaceMakeupType;
      public templateMesh: Mesh;
      public dynamicRenderChain: boolean;
      public makeupEntity: Entity;
      public faceIds: UInt8Vector;
      public renderer: Renderer;
      public facemakeupEntityName: string;
      public zPosition: number;
      public triggerLua: boolean;
      public version: number;
      public sdkType: number;
      public useVideoTexture: boolean;
      public useSegment: boolean;
      public maleOpacity: number;
      public femaleOpacity: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class EffectFaceBrowV2 extends EffectFaceMakeup {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public type: EffectFaceMakeupType;
      public templateMesh: Mesh;
      public dynamicRenderChain: boolean;
      public makeupEntity: Entity;
      public faceIds: UInt8Vector;
      public renderer: Renderer;
      public facemakeupEntityName: string;
      public zPosition: number;
      public triggerLua: boolean;
      public version: number;
      public sdkType: number;
      public useVideoTexture: boolean;
      public useSegment: boolean;
      public maleOpacity: number;
      public femaleOpacity: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class EffectFaceMakeupFaceUPupilV2 extends EffectFacePupilV2 {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public type: EffectFaceMakeupType;
      public templateMesh: Mesh;
      public dynamicRenderChain: boolean;
      public makeupEntity: Entity;
      public faceIds: UInt8Vector;
      public renderer: Renderer;
      public facemakeupEntityName: string;
      public zPosition: number;
      public triggerLua: boolean;
      public version: number;
      public sdkType: number;
      public useVideoTexture: boolean;
      public useSegment: boolean;
      public maleOpacity: number;
      public femaleOpacity: number;
      public PupilMesh: Mesh;
      public PupilEntityName: string;
      public pupilCutoffEntity: Entity;
      public cutoffRenderer: Renderer;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class EffectFacePupilV2 extends EffectFaceMakeup {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public type: EffectFaceMakeupType;
      public templateMesh: Mesh;
      public dynamicRenderChain: boolean;
      public makeupEntity: Entity;
      public faceIds: UInt8Vector;
      public renderer: Renderer;
      public facemakeupEntityName: string;
      public zPosition: number;
      public triggerLua: boolean;
      public version: number;
      public sdkType: number;
      public useVideoTexture: boolean;
      public useSegment: boolean;
      public maleOpacity: number;
      public femaleOpacity: number;
      public PupilMesh: Mesh;
      public PupilEntityName: string;
      public pupilCutoffEntity: Entity;
      public cutoffRenderer: Renderer;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class EffectFaceLipV4 extends EffectFaceMakeup {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public type: EffectFaceMakeupType;
      public templateMesh: Mesh;
      public dynamicRenderChain: boolean;
      public makeupEntity: Entity;
      public faceIds: UInt8Vector;
      public renderer: Renderer;
      public facemakeupEntityName: string;
      public zPosition: number;
      public triggerLua: boolean;
      public version: number;
      public sdkType: number;
      public useVideoTexture: boolean;
      public useSegment: boolean;
      public maleOpacity: number;
      public femaleOpacity: number;
      public LipV4GlossMesh: Mesh;
      public LipV4GlossEntityName: string;
      public lipv4GlossEntity: Entity;
      public glossRenderer: Renderer;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class EffectFaceBrowLiquify extends EffectFaceMakeup {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public type: EffectFaceMakeupType;
      public templateMesh: Mesh;
      public dynamicRenderChain: boolean;
      public makeupEntity: Entity;
      public faceIds: UInt8Vector;
      public renderer: Renderer;
      public facemakeupEntityName: string;
      public zPosition: number;
      public triggerLua: boolean;
      public version: number;
      public sdkType: number;
      public useVideoTexture: boolean;
      public useSegment: boolean;
      public maleOpacity: number;
      public femaleOpacity: number;
      public BrowLiquifyWarpMesh: Mesh;
      public BrowLiquifyWarpEntityName: string;
      public browLiquifyWarpEntity: Entity;
      public BrowLiquifySucaiMesh: Mesh;
      public BrowLiquifySucaiEntityName: string;
      public browLiquifySucaiEntity: Entity;
      public leftPoints: Vec2Vector;
      public rightPoints: Vec2Vector;
      public warpRenderer: Renderer;
      public sucaiRenderer: Renderer;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class EffectFaceMakeupFaceULipKeypoint extends EffectFaceMakeupFaceU {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public type: EffectFaceMakeupType;
      public templateMesh: Mesh;
      public dynamicRenderChain: boolean;
      public makeupEntity: Entity;
      public faceIds: UInt8Vector;
      public renderer: Renderer;
      public facemakeupEntityName: string;
      public zPosition: number;
      public triggerLua: boolean;
      public version: number;
      public sdkType: number;
      public useVideoTexture: boolean;
      public useSegment: boolean;
      public maleOpacity: number;
      public femaleOpacity: number;
      public xoffset: number;
      public yoffset: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class EffectFaceMakeupFaceU extends EffectFaceMakeup {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public type: EffectFaceMakeupType;
      public templateMesh: Mesh;
      public dynamicRenderChain: boolean;
      public makeupEntity: Entity;
      public faceIds: UInt8Vector;
      public renderer: Renderer;
      public facemakeupEntityName: string;
      public zPosition: number;
      public triggerLua: boolean;
      public version: number;
      public sdkType: number;
      public useVideoTexture: boolean;
      public useSegment: boolean;
      public maleOpacity: number;
      public femaleOpacity: number;
      public xoffset: number;
      public yoffset: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class EffectFaceMakeup extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public type: EffectFaceMakeupType;
      public templateMesh: Mesh;
      public dynamicRenderChain: boolean;
      public makeupEntity: Entity;
      public faceIds: UInt8Vector;
      public renderer: Renderer;
      public facemakeupEntityName: string;
      public zPosition: number;
      public triggerLua: boolean;
      public version: number;
      public sdkType: number;
      public useVideoTexture: boolean;
      public useSegment: boolean;
      public maleOpacity: number;
      public femaleOpacity: number;
      public handle: number;
      public setFaceUniform(uniform: string, face: number, value: number): void;
      public setUniform(uniform: string, value: number): void;
      public onInit(): void;
      public hide(): boolean;
      public show(): boolean;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Billboard extends CameraFollower {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class SkyboxComponent extends CameraFollower {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class CameraFollower extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Sticker3DV3Component extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Sticker3DV3FaceDetectComponent extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class FaceFollowComponent extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ActionManipulator extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ModelManipulator3D extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class EntityGroups extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class PostProcessor extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public cameraName: string;
      public handle: number;
      public record(camera: Camera, commands: CommandBuffer): void;
      public process(): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ARCameraComponent extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public zNear: number;
      public zFar: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ARSessionComponent extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public sessionConfig: ARSessionConfig;
      public handle: number;
      public getARSessionWrapper(): ARSessionWrapper;
      public getAllTrackedGeometries(): Vector;
      public hitTest(screenCoord: Vector2f, camera: Camera): Vector;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ARAnchorableComponent extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ARScaleableComponent extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ARPanableComponent extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ARRotateableComponent extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ARTappableComponent extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class EffectHolder extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public featurePaths: Vector;
      public handle: number;
      public getFeature(relPath: string): FeatureType;
      public asFeature(): boolean;
      public getFeatureLuaPath(): string;
      public getFeaturePathSize(): number;
      public getAllFeaturePaths(): Vector;
      public getAllFeatureLuaPaths(): Vector;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class MemojiComponent extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public targetEntityName: string;
      public jointList: Vector;
      public weightJointMap: Map;
      public predefineJointInfo: Map;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class MemojiInitialComponent extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class AMGPinComponent extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Brush2DComponent extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public curveType: Brush2DCurveType;
      public stablizerThreshold: number;
      public smoothRadius: number;
      public subdivisionLevel: number;
      public resampleSpacing: number;
      public meshType: Brush2DMeshType;
      public baseResolution: number;
      public strokeSize: Brush2DParam;
      public strokeStep: Brush2DParam;
      public stampStrategy: Brush2DStampStrategy;
      public uvArray: Vector;
      public uvIndex: number;
      public colorBase: Color;
      public colorJitter: Color;
      public useOrient: boolean;
      public rotationAngle: Brush2DParam;
      public posJitter: Vector2f;
      public paintMode: Brush2DPaintMode;
      public brushMaterial: Material;
      public brushScript: string;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Brush2DMeshGenerator extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public handle: number;
      public setResolution(arg0: Vector2f): void;
      public setConfig(arg0: Brush2DComponent): void;
      public clear(): void;
      public getMesh(): Mesh;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Brush2DInputProcessor extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public handle: number;
      public setResolution(arg0: Vector2f): void;
      public setConfig(arg0: Brush2DComponent): void;
      public clear(): void;
      public addRawPoint(point: Vector2f, isEnd: boolean): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Stroke2DRenderer extends Brush2DRenderer {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public dirtyFlag: Brush2DDirtyFlag;
      public dirtyRect: AABB;
      public boundingBox: AABB;
      public resolution: Vector2f;
      public finished: boolean;
      public undoTexCache: TextureCache;
      public redoTexCache: TextureCache;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Brush2DRenderer extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public dirtyFlag: Brush2DDirtyFlag;
      public dirtyRect: AABB;
      public boundingBox: AABB;
      public resolution: Vector2f;
      public finished: boolean;
      public handle: number;
      public isStarted(): boolean;
      public isEmpty(): boolean;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Brush2DCanvas extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public historyMode: Brush2DHistoryMode;
      public bgColor: Color;
      public bgInput: Texture;
      public layerMaterial: Material;
      public blitMaterial: Material;
      public brushConfig: Brush2DComponent;
      public handle: number;
      public validArea(): AABB;
      public add(arg0: Stroke2DRenderer): boolean;
      public clear(): void;
      public undo(step: number): boolean;
      public redo(step: number): boolean;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class IFBoxCollider extends IFCollider {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public autoAdjustCollider: boolean;
      public autoAdjustByPixelSize: boolean;
      public center: Vector3f;
      public size: Vector3f;
      public pixelSize: Vector2f;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class IFCollider extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public autoAdjustCollider: boolean;
      public autoAdjustByPixelSize: boolean;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class IFSprite2d extends IFWidget {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public alpha: number;
      public cascadeAlphaEnabled: boolean;
      public sharedMaterial: Material;
      public type: IFSprite2dType;
      public sizeMode: IFSprite2dSizeMode;
      public colorTint: Color;
      public blendMode: IFBlendMode;
      public texture: Texture;
      public imageAtlas: ImageAtlas;
      public atlasIndex: number;
      public filledType: IFFilledType;
      public filledStartPos: number;
      public filledRange: number;
      public ellipseX: number;
      public ellipseY: number;
      public topLeftPoint: Vector2f;
      public topRightPoint: Vector2f;
      public bottomLeftPoint: Vector2f;
      public bottomRightPoint: Vector2f;
      public slicedLeft: number;
      public slicedRight: number;
      public slicedBottom: number;
      public slicedTop: number;
      public fillCenter: boolean;
      public gridVertices: Vec2Vector;
      public gridUVs: Vec2Vector;
      public gridIndexes: UInt16Vector;
      public topLeft: number;
      public topRight: number;
      public bottomLeft: number;
      public bottomRight: number;
      public lineWidth: number;
      public lineColor: Color;
      public outer: boolean;
      public sizeInited: boolean;
      public freeInited: boolean;
      public handle: number;
      public getImageFrameSize(): Vector2f;
      public getFilledRange(): number;
      public setFilledRange(range: number): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class IFUILabel extends IFWidget {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public alpha: number;
      public cascadeAlphaEnabled: boolean;
      public sharedMaterial: Material;
      public text: string;
      public textColor: Color;
      public fontPath: string;
      public fontSize: number;
      public fontType: IFUILabelFontType;
      public alignment: IFUILabelAlignment;
      public fitType: IFUILabelFitType;
      public spacing: Vector2f;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class IFWidget extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public alpha: number;
      public cascadeAlphaEnabled: boolean;
      public sharedMaterial: Material;
      public handle: number;
      public getInstantiatedMaterial(): Material;
      public setInstantiatedMaterial(material: Material): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class IFFaceAnchorAlignment extends IFAnchorAlignment {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public pseudo3DType: IFPseudo3DType;
      public targetNum: number;
      public alignType: IFAnchorAlignmentType;
      public indexs1: Int32Vector;
      public weights1: FloatVector;
      public anchor1: Vector2f;
      public indexs2: Int32Vector;
      public weights2: FloatVector;
      public anchor2: Vector2f;
      public indexs3: Int32Vector;
      public weights3: FloatVector;
      public anchor3: Vector2f;
      public indexs4: Int32Vector;
      public weights4: FloatVector;
      public anchor4: Vector2f;
      public useScaleX: boolean;
      public scaleXStartIndex: number;
      public scaleXEndIndex: number;
      public scaleXFactor: number;
      public useScaleY: boolean;
      public scaleYStartIndex: number;
      public scaleYEndIndex: number;
      public scaleYFactor: number;
      public rotationType: IFRotationType;
      public rotation: number;
      public presetScale: Vector2f;
      public sendLocation: boolean;
      public arcAlign: boolean;
      public arcProportion: number;
      public trackOptions: IFAnchorAlignmentTrackOption;
      public IdorIndexNumber: Int32Vector;
      public gender: IFGenderType;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class IFHandAnchorAlignment extends IFAnchorAlignment {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public pseudo3DType: IFPseudo3DType;
      public targetNum: number;
      public alignType: IFAnchorAlignmentType;
      public indexs1: Int32Vector;
      public weights1: FloatVector;
      public anchor1: Vector2f;
      public indexs2: Int32Vector;
      public weights2: FloatVector;
      public anchor2: Vector2f;
      public indexs3: Int32Vector;
      public weights3: FloatVector;
      public anchor3: Vector2f;
      public indexs4: Int32Vector;
      public weights4: FloatVector;
      public anchor4: Vector2f;
      public useScaleX: boolean;
      public scaleXStartIndex: number;
      public scaleXEndIndex: number;
      public scaleXFactor: number;
      public useScaleY: boolean;
      public scaleYStartIndex: number;
      public scaleYEndIndex: number;
      public scaleYFactor: number;
      public rotationType: IFRotationType;
      public rotation: number;
      public presetScale: Vector2f;
      public sendLocation: boolean;
      public arcAlign: boolean;
      public arcProportion: number;
      public trackOptions: IFAnchorAlignmentTrackOption;
      public IdorIndexNumber: Int32Vector;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class IFForegroundAnchorAlignment extends IFAnchorAlignment {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public pseudo3DType: IFPseudo3DType;
      public targetNum: number;
      public alignType: IFAnchorAlignmentType;
      public indexs1: Int32Vector;
      public weights1: FloatVector;
      public anchor1: Vector2f;
      public indexs2: Int32Vector;
      public weights2: FloatVector;
      public anchor2: Vector2f;
      public indexs3: Int32Vector;
      public weights3: FloatVector;
      public anchor3: Vector2f;
      public indexs4: Int32Vector;
      public weights4: FloatVector;
      public anchor4: Vector2f;
      public useScaleX: boolean;
      public scaleXStartIndex: number;
      public scaleXEndIndex: number;
      public scaleXFactor: number;
      public useScaleY: boolean;
      public scaleYStartIndex: number;
      public scaleYEndIndex: number;
      public scaleYFactor: number;
      public rotationType: IFRotationType;
      public rotation: number;
      public presetScale: Vector2f;
      public sendLocation: boolean;
      public arcAlign: boolean;
      public arcProportion: number;
      public trackOptions: IFAnchorAlignmentTrackOption;
      public IdorIndexNumber: Int32Vector;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class IFSkeletonAnchorAlignment extends IFAnchorAlignment {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public pseudo3DType: IFPseudo3DType;
      public targetNum: number;
      public alignType: IFAnchorAlignmentType;
      public indexs1: Int32Vector;
      public weights1: FloatVector;
      public anchor1: Vector2f;
      public indexs2: Int32Vector;
      public weights2: FloatVector;
      public anchor2: Vector2f;
      public indexs3: Int32Vector;
      public weights3: FloatVector;
      public anchor3: Vector2f;
      public indexs4: Int32Vector;
      public weights4: FloatVector;
      public anchor4: Vector2f;
      public useScaleX: boolean;
      public scaleXStartIndex: number;
      public scaleXEndIndex: number;
      public scaleXFactor: number;
      public useScaleY: boolean;
      public scaleYStartIndex: number;
      public scaleYEndIndex: number;
      public scaleYFactor: number;
      public rotationType: IFRotationType;
      public rotation: number;
      public presetScale: Vector2f;
      public sendLocation: boolean;
      public arcAlign: boolean;
      public arcProportion: number;
      public trackOptions: IFAnchorAlignmentTrackOption;
      public IdorIndexNumber: Int32Vector;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class IFPetAnchorAlignment extends IFAnchorAlignment {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public pseudo3DType: IFPseudo3DType;
      public targetNum: number;
      public alignType: IFAnchorAlignmentType;
      public indexs1: Int32Vector;
      public weights1: FloatVector;
      public anchor1: Vector2f;
      public indexs2: Int32Vector;
      public weights2: FloatVector;
      public anchor2: Vector2f;
      public indexs3: Int32Vector;
      public weights3: FloatVector;
      public anchor3: Vector2f;
      public indexs4: Int32Vector;
      public weights4: FloatVector;
      public anchor4: Vector2f;
      public useScaleX: boolean;
      public scaleXStartIndex: number;
      public scaleXEndIndex: number;
      public scaleXFactor: number;
      public useScaleY: boolean;
      public scaleYStartIndex: number;
      public scaleYEndIndex: number;
      public scaleYFactor: number;
      public rotationType: IFRotationType;
      public rotation: number;
      public presetScale: Vector2f;
      public sendLocation: boolean;
      public arcAlign: boolean;
      public arcProportion: number;
      public trackOptions: IFAnchorAlignmentTrackOption;
      public IdorIndexNumber: Int32Vector;
      public petType: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class IFObjectAnchorAlignment extends IFAnchorAlignment {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public pseudo3DType: IFPseudo3DType;
      public targetNum: number;
      public alignType: IFAnchorAlignmentType;
      public indexs1: Int32Vector;
      public weights1: FloatVector;
      public anchor1: Vector2f;
      public indexs2: Int32Vector;
      public weights2: FloatVector;
      public anchor2: Vector2f;
      public indexs3: Int32Vector;
      public weights3: FloatVector;
      public anchor3: Vector2f;
      public indexs4: Int32Vector;
      public weights4: FloatVector;
      public anchor4: Vector2f;
      public useScaleX: boolean;
      public scaleXStartIndex: number;
      public scaleXEndIndex: number;
      public scaleXFactor: number;
      public useScaleY: boolean;
      public scaleYStartIndex: number;
      public scaleYEndIndex: number;
      public scaleYFactor: number;
      public rotationType: IFRotationType;
      public rotation: number;
      public presetScale: Vector2f;
      public sendLocation: boolean;
      public arcAlign: boolean;
      public arcProportion: number;
      public trackOptions: IFAnchorAlignmentTrackOption;
      public IdorIndexNumber: Int32Vector;
      public objectType: IFObjectType;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class IFJointAnchorAlignment extends IFAnchorAlignment {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public pseudo3DType: IFPseudo3DType;
      public targetNum: number;
      public alignType: IFAnchorAlignmentType;
      public indexs1: Int32Vector;
      public weights1: FloatVector;
      public anchor1: Vector2f;
      public indexs2: Int32Vector;
      public weights2: FloatVector;
      public anchor2: Vector2f;
      public indexs3: Int32Vector;
      public weights3: FloatVector;
      public anchor3: Vector2f;
      public indexs4: Int32Vector;
      public weights4: FloatVector;
      public anchor4: Vector2f;
      public useScaleX: boolean;
      public scaleXStartIndex: number;
      public scaleXEndIndex: number;
      public scaleXFactor: number;
      public useScaleY: boolean;
      public scaleYStartIndex: number;
      public scaleYEndIndex: number;
      public scaleYFactor: number;
      public rotationType: IFRotationType;
      public rotation: number;
      public presetScale: Vector2f;
      public sendLocation: boolean;
      public arcAlign: boolean;
      public arcProportion: number;
      public trackOptions: IFAnchorAlignmentTrackOption;
      public IdorIndexNumber: Int32Vector;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class IFARScanAnchorAlignment extends IFAnchorAlignment {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public pseudo3DType: IFPseudo3DType;
      public targetNum: number;
      public alignType: IFAnchorAlignmentType;
      public indexs1: Int32Vector;
      public weights1: FloatVector;
      public anchor1: Vector2f;
      public indexs2: Int32Vector;
      public weights2: FloatVector;
      public anchor2: Vector2f;
      public indexs3: Int32Vector;
      public weights3: FloatVector;
      public anchor3: Vector2f;
      public indexs4: Int32Vector;
      public weights4: FloatVector;
      public anchor4: Vector2f;
      public useScaleX: boolean;
      public scaleXStartIndex: number;
      public scaleXEndIndex: number;
      public scaleXFactor: number;
      public useScaleY: boolean;
      public scaleYStartIndex: number;
      public scaleYEndIndex: number;
      public scaleYFactor: number;
      public rotationType: IFRotationType;
      public rotation: number;
      public presetScale: Vector2f;
      public sendLocation: boolean;
      public arcAlign: boolean;
      public arcProportion: number;
      public trackOptions: IFAnchorAlignmentTrackOption;
      public IdorIndexNumber: Int32Vector;
      public ARScanType: string;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class IFTeethAnchorAlignment extends IFAnchorAlignment {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public pseudo3DType: IFPseudo3DType;
      public targetNum: number;
      public alignType: IFAnchorAlignmentType;
      public indexs1: Int32Vector;
      public weights1: FloatVector;
      public anchor1: Vector2f;
      public indexs2: Int32Vector;
      public weights2: FloatVector;
      public anchor2: Vector2f;
      public indexs3: Int32Vector;
      public weights3: FloatVector;
      public anchor3: Vector2f;
      public indexs4: Int32Vector;
      public weights4: FloatVector;
      public anchor4: Vector2f;
      public useScaleX: boolean;
      public scaleXStartIndex: number;
      public scaleXEndIndex: number;
      public scaleXFactor: number;
      public useScaleY: boolean;
      public scaleYStartIndex: number;
      public scaleYEndIndex: number;
      public scaleYFactor: number;
      public rotationType: IFRotationType;
      public rotation: number;
      public presetScale: Vector2f;
      public sendLocation: boolean;
      public arcAlign: boolean;
      public arcProportion: number;
      public trackOptions: IFAnchorAlignmentTrackOption;
      public IdorIndexNumber: Int32Vector;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class IFNailAnchorAlignment extends IFAnchorAlignment {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public pseudo3DType: IFPseudo3DType;
      public targetNum: number;
      public alignType: IFAnchorAlignmentType;
      public indexs1: Int32Vector;
      public weights1: FloatVector;
      public anchor1: Vector2f;
      public indexs2: Int32Vector;
      public weights2: FloatVector;
      public anchor2: Vector2f;
      public indexs3: Int32Vector;
      public weights3: FloatVector;
      public anchor3: Vector2f;
      public indexs4: Int32Vector;
      public weights4: FloatVector;
      public anchor4: Vector2f;
      public useScaleX: boolean;
      public scaleXStartIndex: number;
      public scaleXEndIndex: number;
      public scaleXFactor: number;
      public useScaleY: boolean;
      public scaleYStartIndex: number;
      public scaleYEndIndex: number;
      public scaleYFactor: number;
      public rotationType: IFRotationType;
      public rotation: number;
      public presetScale: Vector2f;
      public sendLocation: boolean;
      public arcAlign: boolean;
      public arcProportion: number;
      public trackOptions: IFAnchorAlignmentTrackOption;
      public IdorIndexNumber: Int32Vector;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class IFMugAnchorAlignment extends IFAnchorAlignment {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public pseudo3DType: IFPseudo3DType;
      public targetNum: number;
      public alignType: IFAnchorAlignmentType;
      public indexs1: Int32Vector;
      public weights1: FloatVector;
      public anchor1: Vector2f;
      public indexs2: Int32Vector;
      public weights2: FloatVector;
      public anchor2: Vector2f;
      public indexs3: Int32Vector;
      public weights3: FloatVector;
      public anchor3: Vector2f;
      public indexs4: Int32Vector;
      public weights4: FloatVector;
      public anchor4: Vector2f;
      public useScaleX: boolean;
      public scaleXStartIndex: number;
      public scaleXEndIndex: number;
      public scaleXFactor: number;
      public useScaleY: boolean;
      public scaleYStartIndex: number;
      public scaleYEndIndex: number;
      public scaleYFactor: number;
      public rotationType: IFRotationType;
      public rotation: number;
      public presetScale: Vector2f;
      public sendLocation: boolean;
      public arcAlign: boolean;
      public arcProportion: number;
      public trackOptions: IFAnchorAlignmentTrackOption;
      public IdorIndexNumber: Int32Vector;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class IFAnchorAlignment extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public pseudo3DType: IFPseudo3DType;
      public targetNum: number;
      public alignType: IFAnchorAlignmentType;
      public indexs1: Int32Vector;
      public weights1: FloatVector;
      public anchor1: Vector2f;
      public indexs2: Int32Vector;
      public weights2: FloatVector;
      public anchor2: Vector2f;
      public indexs3: Int32Vector;
      public weights3: FloatVector;
      public anchor3: Vector2f;
      public indexs4: Int32Vector;
      public weights4: FloatVector;
      public anchor4: Vector2f;
      public useScaleX: boolean;
      public scaleXStartIndex: number;
      public scaleXEndIndex: number;
      public scaleXFactor: number;
      public useScaleY: boolean;
      public scaleYStartIndex: number;
      public scaleYEndIndex: number;
      public scaleYFactor: number;
      public rotationType: IFRotationType;
      public rotation: number;
      public presetScale: Vector2f;
      public sendLocation: boolean;
      public arcAlign: boolean;
      public arcProportion: number;
      public trackOptions: IFAnchorAlignmentTrackOption;
      public IdorIndexNumber: Int32Vector;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class IFBone2d extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public enable: boolean;
      public indexes: Int32Vector;
      public meshVertices: Vec2Vector;
      public meshUV: Vec2Vector;
      public meshIndexes: UInt16Vector;
      public weights: Vector;
      public alpha: number;
      public templateVertices: Vec2Vector;
      public templateSize: Vector2f;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class IFUIGrid extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public type: IFUIGridType;
      public resizeMode: IFUIGridResizeMode;
      public cellSize: Vector2f;
      public startAxis: IFUIGridStartAxis;
      public paddingLeft: number;
      public paddingRight: number;
      public paddingTop: number;
      public paddingBottom: number;
      public spacingX: number;
      public spacingY: number;
      public verticalDirection: IFUIGridVerticalDirection;
      public horizontalDirection: IFUIGridHorizontalDirection;
      public affectedByScale: boolean;
      public filterInvisibleChildren: boolean;
      public sortingType: IFUIGridSortingType;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class IFUIConstraints extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public mode: IFUIConstraintsMode;
      public execute: IFUIConstraintsExecute;
      public target: IFTransform2d;
      public leftTarget: IFTransform2d;
      public leftRange: number;
      public leftOffset: number;
      public rightTarget: IFTransform2d;
      public rightRange: number;
      public rightOffset: number;
      public bottomTarget: IFTransform2d;
      public bottomRange: number;
      public bottomOffset: number;
      public topTarget: IFTransform2d;
      public topRange: number;
      public topOffset: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class IFUISafeArea extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public type: IFUISafeAreaType;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class RectTransform extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public pivot: Vector2f;
      public anchorMax: Vector2f;
      public anchorMin: Vector2f;
      public width: number;
      public height: number;
      public rect: Vector4f;
      public position: Vector3f;
      public scale: Vector3f;
      public rotation: Vector3f;
      public parent: RectTransform;
      public children: Vector;
      public handle: number;
      public removeTransform(childTrans: RectTransform): boolean;
      public addTransform(childTrans: RectTransform): boolean;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class FaceMakeUp extends Component {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public mesh: Mesh;
      public type: FaceMakeUpType;
      public useAppConfig: boolean;
      public faceIds: UInt8Vector;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Component extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public enabled: boolean;
      public entity: Entity;
      public prefab: Prefab;
      public prefabObjectGuid: Guid;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class MorpherSystem extends System {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class AnimatorSystem extends System {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class TransformSystem extends System {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ImageAtlas extends ImageAtlasBase {
      constructor();
      public assetMgr: AssetManager;
      public frames: Vector;
      public texture: Texture;
      public uri: string;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class MaterialSystem extends System {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ImagePreprocessOption extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public doPrefilter: boolean;
      public smoothKernelHalfSize: number;
      public threshold: number;
      public offsetPercentage: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum IFUIGridType {
      NONE,
      HORIZONTAL,
      VERTICAL,
      GRID,
    }
    namespace IFUIGridType {
      let RTTI: RTTIDescriptor;
    }
    class TweenSystem extends System {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class LayoutBufferDesc extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public buffer: Buffer;
      public stride: number;
      public pointer: number;
      public attributes: Vector;
      public bufferName: string;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class UniformRealArray extends Uniform {
      constructor();
      public assetMgr: AssetManager;
      public value: FloatVector;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum AreaShape {
      Rect,
      Circle,
    }
    namespace AreaShape {
      let RTTI: RTTIDescriptor;
    }
    enum ParticleQuatRendererAlignType {
      TOP,
      CENTER,
      BOTTOM,
    }
    namespace ParticleQuatRendererAlignType {
      let RTTI: RTTIDescriptor;
    }
    class ScriptSystem extends System {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class FaceVerifyInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public features: FloatVector;
      public ID: number;
      public rect: Rect;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class MemojiMatchResourceInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class UniformVec2Array extends Uniform {
      constructor();
      public assetMgr: AssetManager;
      public value: Vec2Vector;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ARTrackedAnchorInfo extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public anchors: Vector;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class CarSegInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public bounding_box: FloatVector;
      public brand_bounding_box: FloatVector;
      public direction: number;
      public car_Id: number;
      public is_new: boolean;
      public landmarks: Vec2Vector;
      public valid_landmarks: boolean;
      public car_prob: number;
      public color: number;
      public valid_segmentation: boolean;
      public seg_data: UInt8Vector;
      public left_seg_border: number;
      public up_seg_border: number;
      public seg_width: number;
      public seg_height: number;
      public segmented_car: Image;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class MeshEmitter extends Emitter {
      constructor();
      public assetMgr: AssetManager;
      public position: Vector3f;
      public rotation: Quaternionf;
      public enable: boolean;
      public keepLocalParticles: boolean;
      public forceEmission: boolean;
      public useDurationTime: boolean;
      public angle: Value;
      public emissionRate: Value;
      public totalTimeToLive: Value;
      public duration: Value;
      public repeatDelay: Value;
      public particleMass: Value;
      public particleVelocity: Value;
      public particleColorList: Vec4Vector;
      public particleColor: Vector4f;
      public particleBurstsList: Vec2Vector;
      public orientationStart: Quaternionf;
      public orientationEnd: Quaternionf;
      public particleWidth: Value;
      public particleHeight: Value;
      public particleDepth: Value;
      public particleScale: Value;
      public particleSize: Value;
      public particleXRotation: Value;
      public particleYRotation: Value;
      public particleZRotation: Value;
      public particleXRotationSpeed: Value;
      public particleYRotationSpeed: Value;
      public particleZRotationSpeed: Value;
      public alignToDirection: boolean;
      public RandomDirection: Value;
      public SphereDirection: Value;
      public RandomPosition: Value;
      public distanceEmissionRate: Value;
      public mesh: Mesh;
      public useMeshOrientation: boolean;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Material extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public xshader: XShader;
      public properties: PropertySheet;
      public renderQueue: number;
      public passes: Vector;
      public enabledMacros: Map;
      public mshaderPath: string;
      public instanceCount: number;
      public handle: number;
      public setFloat(name: string, f: number): void;
      public getFloat(name: string): number;
      public setVec4(name: string, c: Vector4f): void;
      public getVec4(name: string): Vector4f;
      public setVec3(name: string, c: Vector3f): void;
      public getVec3(name: string): Vector3f;
      public setVec2(name: string, c: Vector2f): void;
      public getVec2(name: string): Vector2f;
      public setMat4(name: string, m: Matrix4x4f): void;
      public getMat4(name: string): Matrix4x4f;
      public setTex(name: string, tex: Texture): void;
      public getTex(name: string): Texture;
      public setMultiValue(name: string, val: FloatVector, rows: number, cols: number, count: number): void;
      public setBuffer(name: string, tex: Buffer): void;
      public getBuffer(name: string): Buffer;
      public setInt(name: string, tex: number): void;
      public getInt(name: string): number;
      public enableMacro(macro: string, value: number): void;
      public disableMacro(macro: string): void;
      public setPassEnabled(passIndex: number, enabled: boolean): void;
      public getPassEnabled(passIndex: number): boolean;
      public instantiate(): Material;
      public setTexFromKey(name: string, key: string): void;
      public setFloatVector(name: string, data: FloatVector): void;
      public setVec2Vector(name: string, data: Vec2Vector): void;
      public setVec3Vector(name: string, data: Vec3Vector): void;
      public setVec4Vector(name: string, data: Vec4Vector): void;
      public setInstanceCount(count: number): void;
      public getInstanceCount(): number;
      public markNeedToInstantiated(): void;
      public markInstantiated(): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum LightRenderMode {
      AUTO,
      IMPORTANT,
      NOT_IMPORTANT,
    }
    namespace LightRenderMode {
      let RTTI: RTTIDescriptor;
    }
    class FoodComicsInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public faceCount: number;
      public width: number;
      public height: number;
      public matrix: FloatVector;
      public mask: UInt8Vector;
      public mask_image: Image;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class MaterialArray extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public materials: Vector;
      public handle: number;
      public pushMaterial(material: Material): void;
      public getMaterials(): Vector;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class EventCenter extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public postEvent(event: Event, targetScene: Scene): void;
      public sendEvent(event: Event, targetScene: Scene): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class AMGAudioMDSPNode extends AMGAudioNode {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public setupMDSPGraphFromFile(s: string): number;
      public addSearchPath(s: string): void;
      public prepare(d: number, i: number): number;
      public setParameter(i: number, i0: number, f: number): boolean;
      public setTempo(d: number): void;
      public dynamicParameterChange(i: number, i0: number, f: number): boolean;
      public dynamicParameterChangeByName(i: number, s: string, f: number): boolean;
      public emplaceMidiEvent(i: number, i0: number, i1: number, i2: number, i3: number): boolean;
      public emplaceMidiEventQuantised(i: number, i0: number, i1: number, i2: number, i3: number, f: number, f4: number): boolean;
      public createSubNode(s: string, s0: string): AMGAudioMDSPSubNode;
      public createSubNodeFromFilePath(s: string, s0: string): AMGAudioMDSPSubNode;
      public createSubNodeFromFileURI(s: string, s0: string): AMGAudioMDSPSubNode;
      public build(): void;
      public saveToJson(s: string): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class AMGAudioMDSPSubNode extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public connect(AMGAudioMDSPSubNode: AMGAudioMDSPSubNode, i: number, i0: number, i1: number): AMGAudioMDSPSubNode;
      public exposePort(i: number, i0: number, i1: number, i2: number): void;
      public addNote(f: number, f0: number, i: number, f1: number, i2: number): void;
      public deleteNoteByNoteID(i: number): void;
      public deleteNoteByPosition(f: number, i: number, i0: number): void;
      public clearAllNotes(): void;
      public play(): void;
      public stop(): void;
      public setMaxBeats(d: number): void;
      public setIsLooping(b: boolean): void;
      public setGrooveTimingStrength(f: number): void;
      public setGrooveVelocityStrength(f: number): void;
      public getBeatPosition(): number;
      public isPlaying(): boolean;
      public whichLoop(): number;
      public addMidiEvent(i: number, i0: number, d: number, d1: number, i2: number): boolean;
      public deleteMidiEvent(i: number, i0: number, d: number, d1: number, i2: number): boolean;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class TapGesture extends Gesture {
      constructor();
      public assetMgr: AssetManager;
      public type: GestureType;
      public time: number;
      public point: Vector2f;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum SensorDataSpace {
      Z_UP,
      Y_UP,
    }
    namespace SensorDataSpace {
      let RTTI: RTTIDescriptor;
    }
    class RenderState extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public viewport: ViewportState;
      public scissor: ScissorState;
      public rasterization: RasterizationState;
      public depthstencil: DepthStencilState;
      public colorBlend: ColorBlendState;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ProxyRect extends ProxyBase {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class AmazingViewer extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class FacesTexture2D extends Texture2D {
      constructor();
      public assetMgr: AssetManager;
      public width: number;
      public height: number;
      public depth: number;
      public internalFormat: InternalFormat;
      public dataType: DataType;
      public builtinType: BuiltInTextureType;
      public enableMipmap: boolean;
      public filterMin: FilterMode;
      public filterMag: FilterMode;
      public filterMipmap: FilterMipmapMode;
      public wrapModeS: WrapMode;
      public wrapModeT: WrapMode;
      public wrapModeR: WrapMode;
      public maxAnisotropy: number;
      public image: Image;
      public readable: boolean;
      public isColorTexture: boolean;
      public maxTextureSize: TextureResizeLevel;
      public faceIndex: number;
      public matrixName: string;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Texture2D extends Texture {
      constructor();
      public assetMgr: AssetManager;
      public width: number;
      public height: number;
      public depth: number;
      public internalFormat: InternalFormat;
      public dataType: DataType;
      public builtinType: BuiltInTextureType;
      public enableMipmap: boolean;
      public filterMin: FilterMode;
      public filterMag: FilterMode;
      public filterMipmap: FilterMipmapMode;
      public wrapModeS: WrapMode;
      public wrapModeT: WrapMode;
      public wrapModeR: WrapMode;
      public maxAnisotropy: number;
      public image: Image;
      public readable: boolean;
      public isColorTexture: boolean;
      public maxTextureSize: TextureResizeLevel;
      public handle: number;
      public storage(image: Image): void;
      public syncResource(): void;
      public getPixel(x: number, y: number): Vector4f;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum AppEventType {
      SwitchFilter,
      CAPTURE,
      SetTextEditorContent,
      SetUniform,
      COMPAT_BEF,
      RECORD,
      SetFilter,
      MODULE,
      SetFilterEnabled,
      INTERACTIVE_VIEW_MESSAGE,
      Memoji,
      SetEffectIntensity,
      INTERACTIVE_VIEW_SET_JSON,
      TipsCommand,
      INTERACTIVE_VIEW_SET_TEXTURE,
    }
    namespace AppEventType {
      let RTTI: RTTIDescriptor;
    }
    class RenderTextureArray extends RenderTexture {
      constructor();
      public assetMgr: AssetManager;
      public width: number;
      public height: number;
      public depth: number;
      public internalFormat: InternalFormat;
      public dataType: DataType;
      public builtinType: BuiltInTextureType;
      public enableMipmap: boolean;
      public filterMin: FilterMode;
      public filterMag: FilterMode;
      public filterMipmap: FilterMipmapMode;
      public wrapModeS: WrapMode;
      public wrapModeT: WrapMode;
      public wrapModeR: WrapMode;
      public maxAnisotropy: number;
      public attachment: RenderTextureAttachment;
      public inputTexture: Texture;
      public massMode: MSAAMode;
      public shared: boolean;
      public colorFormat: PixelFormat;
      public realColorFormat: PixelFormat;
      public depthTexture: DrawTexture;
      public stencilTexture: DrawTexture;
      public colorTextures: Vector;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class PointCache extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public mesh: Mesh;
      public skin: Skin;
      public handle: number;
      public setSkinData(skin: Skin): void;
      public getPointsCount(): number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class AnimState extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public animazClips: Vector;
      public externalClips: Vector;
      public speed: number;
      public startTime: number;
      public wrapMode: number;
      public overrideBlend: boolean;
      public isRestoreOrigVal: boolean;
      public blendWeight: number;
      public clips: Vector;
      public animationLayer: AnimLayer;
      public handle: number;
      public playState(): void;
      public addExternalClip(clipName: string, initialBlendWeight: number): boolean;
      public addAnimazClip(clipName: string, animaz: Animaz, startTime: number, endTime: number, wrapMode: number, initialBlendWeight: number): boolean;
      public getStateTransition(dstState: AnimState): AnimStateTransition;
      public createStateTransition(dstState: AnimState, isTemporary: boolean): AnimStateTransition;
      public setClipWeight(clipIndex: number, blendWeight: number): void;
      public setClipWeights(clipWeights: FloatVector): void;
      public getElapsedTime(): number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class AppInfo extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public maleMakeupEnabled: boolean;
      public clientState: string;
      public handle: number;
      public getSkipRecording(): boolean;
      public setSkipRecording(value: boolean): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class JsWrapScriptAlgorithm extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public addInputType(key: number, resultType: AlgorithmResultType): void;
      public addOutputType(key: number, resultType: AlgorithmResultType): void;
      public loadAlgorithmModel(modelName: string): number;
      public getCacheDir(): string;
      public reportEvent(eventName: string, data: Map): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class EyeFittingInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public faceId: number;
      public leftVertexes: Vec3Vector;
      public leftLandmarks: Vec3Vector;
      public leftNormals: Vec3Vector;
      public leftTangents: Vec3Vector;
      public leftRvec: Vector3f;
      public leftTvec: Vector3f;
      public leftMVP: Matrix4x4f;
      public leftModel: Matrix4x4f;
      public rightVertexes: Vec3Vector;
      public rightLandmarks: Vec3Vector;
      public rightNormals: Vec3Vector;
      public rightTangents: Vec3Vector;
      public rightRvec: Vector3f;
      public rightTvec: Vector3f;
      public rightMVP: Matrix4x4f;
      public rightModel: Matrix4x4f;
      public uvs: Vec2Vector;
      public triangles: UInt16Vector;
      public cameraParam: FloatVector;
      public fovy: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class PropertySheet extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public floatmap: Map;
      public vec4map: Map;
      public vec3map: Map;
      public vec2map: Map;
      public mat4map: Map;
      public texmap: Map;
      public intmap: Map;
      public handle: number;
      public getTex(name: string): Texture;
      public setTex(name: string, tex: Texture): void;
      public getBuffer(name: string): Buffer;
      public setBuffer(name: string, buffer: Buffer): void;
      public getFloat(name: string): number;
      public setFloat(name: string, value: number): void;
      public getVec4(name: string): Vector4f;
      public setVec4(name: string, v: Vector4f): void;
      public getVec3(name: string): Vector3f;
      public setVec3(name: string, v: Vector3f): void;
      public getVec2(name: string): Vector2f;
      public setVec2(name: string, v: Vector2f): void;
      public getMat4(name: string): Matrix4x4f;
      public setMat4(name: string, v: Matrix4x4f): void;
      public getInt(name: string): number;
      public setInt(name: string, v: number): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class AMGComputeEntity extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public setProperty(property: PropertySheet): void;
      public getProperty(): PropertySheet;
      public setFloat(name: string, f: number): void;
      public getFloat(name: string): number;
      public setVector4(name: string, c: Vector4f): void;
      public getVector4(name: string): Vector4f;
      public setMatrix4x4f(name: string, m: Matrix4x4f): void;
      public getMatrix4x4f(name: string): Matrix4x4f;
      public setTexture(name: string, tex: Texture): void;
      public getTexture(name: string): Texture;
      public setBuffer(name: string, tex: Buffer): void;
      public getBuffer(name: string): Buffer;
      public setInt(name: string, tex: number): void;
      public getInt(name: string): number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum MSAAMode {
      NONE,
      MSAA_4X,
      _4X,
      _16X,
      MSAA_16X,
    }
    namespace MSAAMode {
      let RTTI: RTTIDescriptor;
    }
    class AMGComputePipeline extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public compile(shader: Map): boolean;
      public newEntity(): AMGComputeEntity;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Texture2DPlatformSetting extends AssetPlatformSetting {
      constructor();
      public assetMgr: AssetManager;
      public textureFormat: Texture2DAssetFormat;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class LuaScript extends Script {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class TextureRotationAffector extends Affector {
      constructor();
      public assetMgr: AssetManager;
      public postion: Vector3f;
      public enabled: boolean;
      public updateMode: ParticleUpdateMode;
      public isUseOwnRotationSpeed: boolean;
      public rotationSpeed: Value;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class JSScriptMethodInfo extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ModelDownloadTask extends DownloadTask {
      constructor();
      public assetMgr: AssetManager;
      public status: JsDownloadStatus;
      public success: boolean;
      public errCode: number;
      public errString: string;
      public requirements: StringVector;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum AffectorIntersectionType {
      POINT,
      BOX,
    }
    namespace AffectorIntersectionType {
      let RTTI: RTTIDescriptor;
    }
    class JointInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public jointNum: number;
      public key_points_xy: Vec2Vector;
      public key_points_r: FloatVector;
      public key_points_type: UInt32Vector;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ImageArrayProvider extends ImageProvider {
      constructor();
      public assetMgr: AssetManager;
      public imagesUri: Vector;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class PetMattingInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public maskCount: number;
      public maskWidth: number;
      public maskHeight: number;
      public mask0: Image;
      public mask1: Image;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class TextureRenderTarget extends RenderTarget {
      constructor();
      public assetMgr: AssetManager;
      public attachment: AttachmentTarget;
      public texture: RenderTexture;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum LookAtDirection {
      X,
      Y,
      Z,
      MINUS_X,
      MINUS_Y,
      MINUS_Z,
    }
    namespace LookAtDirection {
      let RTTI: RTTIDescriptor;
    }
    class JSWrapByteNNConfig extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class AnimazTrack extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public keyCount: number;
      public keyTimes: FloatVector;
      public keyValues: FloatVector;
      public keyInValues: FloatVector;
      public keyOutValues: FloatVector;
      public interpolationType: InterpolationType;
      public trackDataType: TrackDataType;
      public targetName: string;
      public propertyName: string;
      public animation: Animaz;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class MemoryView extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class LookAtSystem extends System {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum CameraPosition {
      FRONT,
      BACK,
    }
    namespace CameraPosition {
      let RTTI: RTTIDescriptor;
    }
    class HairGerInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public width: number;
      public height: number;
      public channelId: number;
      public reflector: number;
      public image: Image;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class HumanParsingInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public width: number;
      public height: number;
      public image_width: number;
      public image_height: number;
      public handle: number;
      public Convert2Images(index: number): Image;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class FaceBackgroundFittingSystem extends System {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class FaceMouthMaskInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public face_mask_size: number;
      public face_mask: UInt8Vector;
      public warp_mat: FloatVector;
      public ID: number;
      public image: Image;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ScreenRenderTexture extends RenderTexture {
      constructor();
      public assetMgr: AssetManager;
      public width: number;
      public height: number;
      public depth: number;
      public internalFormat: InternalFormat;
      public dataType: DataType;
      public builtinType: BuiltInTextureType;
      public enableMipmap: boolean;
      public filterMin: FilterMode;
      public filterMag: FilterMode;
      public filterMipmap: FilterMipmapMode;
      public wrapModeS: WrapMode;
      public wrapModeT: WrapMode;
      public wrapModeR: WrapMode;
      public maxAnisotropy: number;
      public attachment: RenderTextureAttachment;
      public inputTexture: Texture;
      public massMode: MSAAMode;
      public shared: boolean;
      public colorFormat: PixelFormat;
      public realColorFormat: PixelFormat;
      public depthTexture: DrawTexture;
      public stencilTexture: DrawTexture;
      public colorTextures: Vector;
      public pecentX: number;
      public pecentY: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class SceneOutputRT extends RenderTexture {
      constructor();
      public assetMgr: AssetManager;
      public width: number;
      public height: number;
      public depth: number;
      public internalFormat: InternalFormat;
      public dataType: DataType;
      public builtinType: BuiltInTextureType;
      public enableMipmap: boolean;
      public filterMin: FilterMode;
      public filterMag: FilterMode;
      public filterMipmap: FilterMipmapMode;
      public wrapModeS: WrapMode;
      public wrapModeT: WrapMode;
      public wrapModeR: WrapMode;
      public maxAnisotropy: number;
      public attachment: RenderTextureAttachment;
      public inputTexture: Texture;
      public massMode: MSAAMode;
      public shared: boolean;
      public colorFormat: PixelFormat;
      public realColorFormat: PixelFormat;
      public depthTexture: DrawTexture;
      public stencilTexture: DrawTexture;
      public colorTextures: Vector;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class RenderTexture extends Texture {
      constructor();
      public assetMgr: AssetManager;
      public width: number;
      public height: number;
      public depth: number;
      public internalFormat: InternalFormat;
      public dataType: DataType;
      public builtinType: BuiltInTextureType;
      public enableMipmap: boolean;
      public filterMin: FilterMode;
      public filterMag: FilterMode;
      public filterMipmap: FilterMipmapMode;
      public wrapModeS: WrapMode;
      public wrapModeT: WrapMode;
      public wrapModeR: WrapMode;
      public maxAnisotropy: number;
      public attachment: RenderTextureAttachment;
      public inputTexture: Texture;
      public massMode: MSAAMode;
      public shared: boolean;
      public colorFormat: PixelFormat;
      public realColorFormat: PixelFormat;
      public depthTexture: DrawTexture;
      public stencilTexture: DrawTexture;
      public colorTextures: Vector;
      public handle: number;
      public getShared(): boolean;
      public setShared(value: boolean): void;
      public getPixel(x: number, y: number): Vector4f;
      public getPixels(positions: UInt16Vector): Vec4Vector;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ContactPoint3D extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public point: Vector3f;
      public normal: Vector3f;
      public impulse: number;
      public friction: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class IndoorSegInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public width: number;
      public height: number;
      public handle: number;
      public getMask(index: number): Image;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum TouchPhase {
      BEGIN,
      CANCEL,
      MOVE,
      END,
    }
    namespace TouchPhase {
      let RTTI: RTTIDescriptor;
    }
    class EffectLayer extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public mat: Material;
      public mat_instance: Material;
      public inline1Grad: GradientChange;
      public grad: GradientChange;
      public outline1Grad: GradientChange;
      public outline2Grad: GradientChange;
      public outline3Grad: GradientChange;
      public smoothing: number;
      public offset: Vector2f;
      public innerShadowEnabled: boolean;
      public textureLevel: number;
      public texture: Texture;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class AudioMidiNode extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public time: number;
      public duration: number;
      public pitch: number;
      public velocity: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class UniformVec4Array extends Uniform {
      constructor();
      public assetMgr: AssetManager;
      public value: Vec4Vector;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class AmazingVRBrushSystem extends System {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class PanGesture extends Gesture {
      constructor();
      public assetMgr: AssetManager;
      public type: GestureType;
      public time: number;
      public point: Vector2f;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class RotateGesture extends Gesture {
      constructor();
      public assetMgr: AssetManager;
      public type: GestureType;
      public time: number;
      public angle: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Gesture extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public type: GestureType;
      public time: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum Collision3DEventType {
      ENTER,
      STAY,
      EXIT,
    }
    namespace Collision3DEventType {
      let RTTI: RTTIDescriptor;
    }
    class MugResultInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public ID: number;
      public mug_region: Rect;
      public prob: number;
      public points: Vec2Vector;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class JSManager extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum GestureType {
      CLICK,
      PAN,
      ROTATE,
      SCALE,
    }
    namespace GestureType {
      let RTTI: RTTIDescriptor;
    }
    enum FilterMipmapMode {
      NONE,
      NEAREST,
      LINEAR,
    }
    namespace FilterMipmapMode {
      let RTTI: RTTIDescriptor;
    }
    enum GestureEvent {
      GESTURE_TAP,
      ANY_SUPPORTED,
      GESTURE_SWIPE,
      GESTURE_PINCH,
      GESTURE_LONG_TAP,
      GESTURE_DRAG,
      GESTURE_DROP,
      GESTURE_DOUBLE_CLICK,
    }
    namespace GestureEvent {
      let RTTI: RTTIDescriptor;
    }
    class VortexAffector extends Affector {
      constructor();
      public assetMgr: AssetManager;
      public postion: Vector3f;
      public rotation: Quaternionf;
      public enabled: boolean;
      public updateMode: ParticleUpdateMode;
      public rotationSpeed: Value;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class JsWrapAlgorithmTask extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public status: JsTaskStatus;
      public algorithmResult: AEAlgorithmResult;
      public inputTexture: Texture2D;
      public inputBuffer: UInt8Vector;
      public pipelineIndex: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class GroundSegResultInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public width: number;
      public height: number;
      public srcImageWidth: number;
      public srcImageHeight: number;
      public mask_data: UInt8Vector;
      public groundMask: Image;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ARSessionWrapper extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public getAllTrackedGeometries(): Vector;
      public getTrackingQuality(): void;
      public getSessionStatus(): void;
      public getTrackingQualityReson(): void;
      public isAvaliable(): boolean;
      public addAnchor(arg0: ARTrackedAnchor): void;
      public removeAnchor(arg0: ARTrackedAnchor): void;
      public removeAnchorWithGUID(arg0: string): void;
      public raycast(arg0: AMGRaycastQuery): Vector;
      public getDepthRegionConfidence(arg0: number, arg1: number, arg2: number, arg3: number): number;
      public getRawDepthTexture(arg0: boolean): Texture;
      public getRawDepthConfidenceTexture(): Texture;
      public getBackendType(): ARBackendType;
      public setAvatarAlgorithm(algorithmName: string): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum EffectFaceMakeupType {
      OUTPUT,
      MASK3D,
      JIEMAO_V2,
      NONE,
      MOUTH_PART,
      MASK,
      INPUT,
      SKIN_TONE,
      MASK240,
      LIPS_KEYPOINT,
      POINTS,
      SCLERA,
      LIPS_SEG,
      TEETH,
      EYE_PART,
      BROW,
      EYE_PART_DENSE,
      JIEMAO_V1,
      PUPIL,
      LIPS_V2,
      LIPS_V3,
      EYE_DETAIL,
      LIPS_V4,
      FACEU_MASK,
      FACEU_LIPS_KEYPOINT,
      FACEU_JIEMAO,
      FACEU_BROW,
      FACEU_EYEPART,
      FACEU_EYEDETAIL,
      FACEU_PUPIL,
    }
    namespace EffectFaceMakeupType {
      let RTTI: RTTIDescriptor;
    }
    class SlamResultInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public view: Matrix4x4f;
      public projection: Matrix4x4f;
      public colorCorrection: Vector4f;
      public enable: boolean;
      public trackStatus: number;
      public planeDetected: number;
      public trackingStateReason: number;
      public planeUpdate: boolean;
      public sizeOfFeaturePoints: number;
      public featurePoints: FloatVector;
      public withDepth: boolean;
      public depths: FloatVector;
      public planeTransform: Matrix4x4f;
      public hangboxDepths: Vec3Vector;
      public mapData: string;
      public fusionState: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum DeviceOrientation {
      PORTRAIT,
      LANDSCAPE_RIGHT,
      LANDSCAPE_LEFT,
      PORTRAIT_UPSIDE_DOWN,
    }
    namespace DeviceOrientation {
      let RTTI: RTTIDescriptor;
    }
    enum SensorType {
      Gravity,
      Rotation,
      Acceleration,
      Heading,
      Gyro,
      Geomagnetic,
    }
    namespace SensorType {
      let RTTI: RTTIDescriptor;
    }
    class ShadowMapSystem extends System {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public dirShadowLight: DirectionalLight;
      public dirShadowMap: RenderTexture;
      public spotShadowLight: SpotLight;
      public spotShadowMap: RenderTexture;
      public pointShadowLight: PointLight;
      public pointShadowMap: RenderTextureArray;
      public handle: number;
      public getShadowSystemEnable(): boolean;
      public getShadowLightEnable(light: Light): boolean;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class JSScriptSystem extends System {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class RenderSystem extends System {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class EventSystem extends System {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public postEvent(event: Event): void;
      public sendEvent(event: Event): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class BuiltinObjectSystem extends System {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class CameraSystem extends System {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class BrushSystem extends System {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ARRendererSystem extends System {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class EffectNodeSystem extends System {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class NodeExclusionSystem extends System {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class LightSystem extends System {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ReflectionProbeSystem extends System {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public getReflectionProbeNum(): number;
      public getReflectionProbe(index: number): ReflectionProbe;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class MeshRendererSystem extends RendererSystem {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class SkinMeshRendererSystem extends RendererSystem {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ParticleRendererSystem extends RendererSystem {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Sprite2DRendererSystem extends RendererSystem {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ReshapableGridRendererSystem extends RendererSystem {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class SeqMeshRendererSystem extends RendererSystem {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class IFLayer2dSystem extends RendererSystem {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ColorFilterRenderSystem extends RendererSystem {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class RendererSystem extends System {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class MeshTriangleSortSystem extends System {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class AudioSystem extends System {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class SDFTextSystem extends BaseTextSystem {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Text3DSystem extends BaseTextSystem {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class BaseTextSystem extends System {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class AnimSeqSystem extends System {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class GifAnimSeqSystem extends System {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class VideoAnimSeqSystem extends System {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class PBFSystem extends System {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Physics3DSystem extends System {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public autoStart: boolean;
      public handle: number;
      public runSimulation(): void;
      public stopSimulation(): void;
      public editSimulation(): void;
      public rayTest(from: Vector3f, to: Vector3f): Vector;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class InputSystem extends System {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class VFXRendererSystem extends System {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class FaceCaptureSystem extends System {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class AmazingEffectSystem extends System {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class TimerSystem extends System {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public addTimer(timerId: number, timerType: BEFTimerType, milliSeconds: number): void;
      public removeTimer(timerId: number, timerType: BEFTimerType, milliSeconds: number): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class UIInteractionSystem extends System {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public activeScriptComp: ScriptComponent;
      public handle: number;
      public showInputKeyboard(nArg1: number, nArg2: number, nArg3: string): void;
      public hideInputKeyboard(nArg1: number, nArg2: number, nArg3: string): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class FilterControlSystem extends System {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class FaceReshapeSystem extends System {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Face3DAccurateAttachingSystem extends System {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class FaceEditorSystem extends System {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class PinToMeshSystem extends System {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Face3DSystem extends System {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class FaceStretchSystem extends System {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class FaceMakeupV2System extends System {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class EventActionSystem extends System {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class EffectLightSystem extends System {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class CameraFollowerSystem extends System {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Sticker3DV3System extends System {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class FaceFollowSystem extends System {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ARSessionSystem extends System {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class MemojiSystem extends System {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class AMGPinSystem extends System {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Brush2DRendererSystem extends System {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class IFRootSystem extends System {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class IFAnimSpriteSystem extends System {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class IFAnchorAlignmentSystem extends System {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class IFTimerSystem extends System {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public start: boolean;
      public handle: number;
      public invokeOnce(obj: AObject, method: string, delay: number, userdata: Map, id: number): boolean;
      public invokeRepeating(obj: AObject, method: string, delay: number, interval: number, repeat: number, userdata: Map, id: number): boolean;
      public invokeInfinite(obj: AObject, method: string, delay: number, interval: number, userdata: Map, id: number): boolean;
      public cancelAll(): void;
      public cancel(obj: AObject, method: string, id: number): void;
      public isInvoking(obj: AObject, method: string, id: number): boolean;
      public pause(obj: AObject, method: string, id: number): void;
      public pauseAll(): void;
      public continue(obj: AObject, method: string, id: number): void;
      public continueAll(): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class IFUISystem extends System {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class IFUIConstraintsSystem extends System {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class GestureSystem extends System {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public subscribe(script: AObject, name: string, callback: string, priority: number): void;
      public unsubscribe(script: AObject, name: string, callback: string): void;
      public createRecognizer(name: string): GestureRecognizer;
      public removeRecognizer(name: string): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class FaceMakeUpSystem extends System {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class System extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public setEnable(b: boolean): void;
      public addEventType(type: number): void;
      public clearAllEventType(): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Meta extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public assetImporter: AssetImporter;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum InputListener {
      ON_TOUCH,
      ON_GESTURE_TAP,
      ON_GESTURE_PINCH,
      ON_GESTURE_DROP,
      ON_GESTURE_SWIPE,
      ON_GESTURE_LONG_TAP,
      ON_GESTURE_DRAG,
      ON_GESTURE_DOUBLE_CLICK,
    }
    namespace InputListener {
      let RTTI: RTTIDescriptor;
    }
    class TextureFrame extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public pixelRect: Rect;
      public rotated: boolean;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class MeshRectangle extends GeometryMesh {
      constructor();
      public assetMgr: AssetManager;
      public boundingBox: AABB;
      public vertices: FloatVector;
      public instanceData: FloatVector;
      public instanceDataStride: number;
      public materialIndex: number;
      public vertexAttribs: Vector;
      public skin: Skin;
      public seqMesh: SeqMesh;
      public morphers: Vector;
      public originalVertices: OriginalVertex;
      public submeshes: Vector;
      public clearAfterUpload: boolean;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class MeshQuad extends GeometryMesh {
      constructor();
      public assetMgr: AssetManager;
      public boundingBox: AABB;
      public vertices: FloatVector;
      public instanceData: FloatVector;
      public instanceDataStride: number;
      public materialIndex: number;
      public vertexAttribs: Vector;
      public skin: Skin;
      public seqMesh: SeqMesh;
      public morphers: Vector;
      public originalVertices: OriginalVertex;
      public submeshes: Vector;
      public clearAfterUpload: boolean;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class GeometryMesh extends Mesh {
      constructor();
      public assetMgr: AssetManager;
      public boundingBox: AABB;
      public vertices: FloatVector;
      public instanceData: FloatVector;
      public instanceDataStride: number;
      public materialIndex: number;
      public vertexAttribs: Vector;
      public skin: Skin;
      public seqMesh: SeqMesh;
      public morphers: Vector;
      public originalVertices: OriginalVertex;
      public submeshes: Vector;
      public clearAfterUpload: boolean;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Face3DMesh extends Mesh {
      constructor();
      public assetMgr: AssetManager;
      public boundingBox: AABB;
      public vertices: FloatVector;
      public instanceData: FloatVector;
      public instanceDataStride: number;
      public materialIndex: number;
      public vertexAttribs: Vector;
      public skin: Skin;
      public seqMesh: SeqMesh;
      public morphers: Vector;
      public originalVertices: OriginalVertex;
      public submeshes: Vector;
      public clearAfterUpload: boolean;
      public faceid: number;
      public type: Face3DMeshType;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Mesh extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public boundingBox: AABB;
      public vertices: FloatVector;
      public instanceData: FloatVector;
      public instanceDataStride: number;
      public materialIndex: number;
      public vertexAttribs: Vector;
      public skin: Skin;
      public seqMesh: SeqMesh;
      public morphers: Vector;
      public originalVertices: OriginalVertex;
      public submeshes: Vector;
      public clearAfterUpload: boolean;
      public handle: number;
      public addSubMesh(submesh: SubMesh): void;
      public addMorpher(morpher: Morpher): void;
      public setVertexArray(data: Vec3Vector, offset: number, count: number, calculateBounds: boolean): void;
      public setNormalArray(data: Vec3Vector, offset: number, count: number): void;
      public setTangentArray(data: Vec4Vector, offset: number, count: number): void;
      public setColorArray(data: Vec4Vector, offset: number, count: number): void;
      public setUvArray(uvIndex: number, data: Vec2Vector, offset: number, count: number): void;
      public setUv3DArray(uvIndex: number, data: Vec3Vector, offset: number, count: number): void;
      public setUserDefineArray(userIndex: number, data: Vec4Vector, offset: number, count: number): void;
      public setVertexCount(count: number): void;
      public setIndicesArray(data: Vec4Vector, offset: number, count: number): void;
      public setWeightArray(data: Vec4Vector, offset: number, count: number): void;
      public getVertexArray(offset: number, count: number): Vec3Vector;
      public getNormalArray(offset: number, count: number): Vec3Vector;
      public getTangentArray(offset: number, count: number): Vec4Vector;
      public getColorArray(offset: number, count: number): Vec4Vector;
      public getUvArray(uvIndex: number, offset: number, count: number): Vec2Vector;
      public getUv3DArray(uvIndex: number, offset: number, count: number): Vec3Vector;
      public getUserDefineArray(userIndex: number, offset: number, count: number): Vec4Vector;
      public getVertexCount(): number;
      public getVertex(index: number): Vector3f;
      public getNormal(index: number): Vector3f;
      public getColor(index: number): Vector4f;
      public getTangent(index: number): Vector4f;
      public getUv(uvIndex: number, index: number): Vector2f;
      public getUv3D(uvIndex: number, index: number): Vector3f;
      public getUserDefine(userIndex: number, index: number, count: number): Vec4Vector;
      public getSubMesh(index: number): SubMesh;
      public setAttributeData(attributeType: VertexAttribType, data: FloatVector, offset: number, count: number): void;
      public getAttributeData(attributeType: VertexAttribType, offset: number, count: number): FloatVector;
      public getIndicesByColor(color: Color, threshold: number): UInt32Vector;
      public reCalculateNormals(): void;
      public reCalculateTangents(): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class GestureInfo extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public type: GestureEvent;
      public x: number;
      public y: number;
      public xStart: number;
      public yStart: number;
      public firstTrigger: boolean;
      public duration: number;
      public scale: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class FlockCenteringAffector extends Affector {
      constructor();
      public assetMgr: AssetManager;
      public postion: Vector3f;
      public rotation: Quaternionf;
      public enabled: boolean;
      public updateMode: ParticleUpdateMode;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum CameraType {
      PERSPECTIVE,
      ORTHO,
    }
    namespace CameraType {
      let RTTI: RTTIDescriptor;
    }
    class HitInfo extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public point: Vector3f;
      public distance: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class SeqMesh extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public readMask: number;
      public currentIndex: number;
      public vertexDataList: Vector;
      public uvDataList: Vector;
      public colorDataList: Vector;
      public indexDataList: Vector;
      public normalDataList: Vector;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class PlaneColliderAffector extends BaseColliderAffector {
      constructor();
      public assetMgr: AssetManager;
      public postion: Vector3f;
      public rotation: Quaternionf;
      public enabled: boolean;
      public updateMode: ParticleUpdateMode;
      public intersectionType: AffectorIntersectionType;
      public collisionType: AffectorCollisionType;
      public plane: Vector4f;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class CurveOption extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public type: MeshCurve;
      public numSegments: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum Collider3DFlag {
      All,
      Physics,
      Input,
    }
    namespace Collider3DFlag {
      let RTTI: RTTIDescriptor;
    }
    class LocalRef {
      constructor();
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum Brush2DSmoothType {
      Average,
      Guass,
    }
    namespace Brush2DSmoothType {
      let RTTI: RTTIDescriptor;
    }
    class NetworkWSFeedbackLog extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public log: string;
      public wsid: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum RotateType {
      ROTATE_0,
      ROTATE_90,
    }
    namespace RotateType {
      let RTTI: RTTIDescriptor;
    }
    class ARTrackedEnvironmentProbeAnchor extends ARTrackedAnchor {
      constructor();
      public assetMgr: AssetManager;
      public anchorType: AnchorType;
      public handle: number;
      public getEnvironmentTex(): Texture;
      public setTexUpdateMinTimeInterval(arg0: number): void;
      public updateEnvTexToMaterial(arg0: Material, arg1: string): void;
      public setExtent(arg0: Vector3f): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class HairFlowInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public width: number;
      public height: number;
      public mask: UInt8Vector;
      public motion: UInt8Vector;
      public do_inpaint: boolean;
      public minX: number;
      public maxX: number;
      public minY: number;
      public maxY: number;
      public maskImage: Image;
      public motionImage: Image;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum IFUIGridSortingType {
      NONE,
      ALPHABETIC,
    }
    namespace IFUIGridSortingType {
      let RTTI: RTTIDescriptor;
    }
    class AlignAffector extends Affector {
      constructor();
      public assetMgr: AssetManager;
      public postion: Vector3f;
      public rotation: Quaternionf;
      public enabled: boolean;
      public updateMode: ParticleUpdateMode;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class HAvatarInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public ID: number;
      public rect: Rect;
      public action: HandAction;
      public leftProb: number;
      public handProb: number;
      public root: Vector3f;
      public kpt2d: Vec2Vector;
      public kpt3d: Vec3Vector;
      public quaternion: QuatVector;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class AssetPlatformSetting extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Quad extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ShaderSnippet extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public source: string;
      public location: string;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class SubMesh extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public useIndices32: boolean;
      public boundingBox: AABB;
      public indices16: UInt16Vector;
      public indices32: UInt32Vector;
      public indicesCount: number;
      public instanceCount: number;
      public primitive: Primitive;
      public mesh: Mesh;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum TextureType {
      TEXTURECUBEARRAY,
      TEXTURE2DARRAY,
      TEXTURE3D,
      TEXTURE2D,
      TEXTURECUBE,
      TEXTURERENDERING,
    }
    namespace TextureType {
      let RTTI: RTTIDescriptor;
    }
    class Morpher extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public channels: Vector;
      public handle: number;
      public getMorpherChannelsCount(): number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum IFUIGridHorizontalDirection {
      LEFT_TO_RIGHT,
      RIGHT_TO_LEFT,
    }
    namespace IFUIGridHorizontalDirection {
      let RTTI: RTTIDescriptor;
    }
    class ColorChange extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public change: boolean;
      public percent: number;
      public color: Color;
      public hsbOffset: Vector3f;
      public alphaOffset: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ColorAffector extends Affector {
      constructor();
      public assetMgr: AssetManager;
      public postion: Vector3f;
      public rotation: Quaternionf;
      public enabled: boolean;
      public updateMode: ParticleUpdateMode;
      public colorMap: Vector;
      public colorOperation: ColorOperation;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class FrameContext extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Image extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public width: number;
      public height: number;
      public format: PixelFormat;
      public dataType: DataType;
      public alphaPermul: boolean;
      public outerAlphaPermul: boolean;
      public origData: MemoryView;
      public handle: number;
      public loadPNG(pngData: string, pixelFormat: PixelFormat, dataType: DataType): void;
      public convertToPNG(): string;
      public loadPNGBin(pngData: UInt8Vector, pixelFormat: PixelFormat, dataType: DataType): void;
      public convertToPNGBin(): UInt8Vector;
      public convertToJPGBin(arg0: number): UInt8Vector;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum IFUILabelAlignment {
      Left,
      Right,
      Center,
    }
    namespace IFUILabelAlignment {
      let RTTI: RTTIDescriptor;
    }
    enum DataType {
      Invalid,
      U8norm,
      S8norm,
      U32,
      S8,
      U16norm,
      S16norm,
      U16,
      S32,
      S16,
      U8,
      F16,
      F32,
    }
    namespace DataType {
      let RTTI: RTTIDescriptor;
    }
    class Event extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public type: number;
      public args: Vector;
      public component: Component;
      public priority: EventPriority;
      public isHandled: boolean;
      public eventSource: EventSource;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class BufferRenderTarget extends RenderTarget {
      constructor();
      public assetMgr: AssetManager;
      public attachment: AttachmentTarget;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class RenderTarget extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public attachment: AttachmentTarget;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class HandInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public ID: number;
      public rect: Rect;
      public action: HandAction;
      public rot_angle: number;
      public score: number;
      public rot_angle_bothhand: number;
      public key_points_xy: Vec2Vector;
      public key_points_is_detect: UInt8Vector;
      public key_points_extension_xy: Vec2Vector;
      public key_points_extension_is_detect: UInt8Vector;
      public key_points_3d: Vec3Vector;
      public key_points_3d_is_detect: UInt8Vector;
      public scale: number;
      public seq_action: number;
      public segment_data: UInt8Vector;
      public segment_width: number;
      public segment_height: number;
      public left_prob: number;
      public ring_r_trans: Matrix4x4f;
      public ring_rt_trans: Matrix4x4f;
      public ring_render_mode: number;
      public mask_width: number;
      public mask_height: number;
      public image: Image;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum BuiltInTextureType {
      INPUT6,
      CLOTHES,
      INPUT2,
      NORAML,
      BG,
      INPUT0,
      HEAD,
      SALIENCYMASK_SMALL,
      MAKEUP,
      VE_OUT,
      INPUT3,
      INPUT5,
      INPUT7,
      CAR,
      INPUT8,
      GROUND,
      INPUT9,
      OUTPUT,
      HAIR,
      BUILDING,
      INPUT4,
      HANDMASK,
      DEPTH,
      FOOTMASK,
      INPUT1,
      FOOTMASK2,
      MOUTHMASK,
      TEETHMASK,
      FACEMASK,
      SKYSEGMASK,
      SALIENCYMASK_REGULAR,
      VE_IN,
      SALIENCYINPUT,
      APOLLOPROCMASK,
      NODEHUBIMAGEMASK,
      FILTER,
      SKINSEGMASK,
      BEAUTY,
      EXTERNAL,
      DISTORTION,
      CAM_OUT,
      DEFAULT_IN,
    }
    namespace BuiltInTextureType {
      let RTTI: RTTIDescriptor;
    }
    enum AttachmentTarget {}
    namespace AttachmentTarget {
      let RTTI: RTTIDescriptor;
    }
    enum FaceGanObjectType {}
    namespace FaceGanObjectType {
      let RTTI: RTTIDescriptor;
    }
    class TextureCube extends Texture {
      constructor();
      public assetMgr: AssetManager;
      public width: number;
      public height: number;
      public depth: number;
      public internalFormat: InternalFormat;
      public dataType: DataType;
      public builtinType: BuiltInTextureType;
      public enableMipmap: boolean;
      public filterMin: FilterMode;
      public filterMag: FilterMode;
      public filterMipmap: FilterMipmapMode;
      public wrapModeS: WrapMode;
      public wrapModeT: WrapMode;
      public wrapModeR: WrapMode;
      public maxAnisotropy: number;
      public POSITIVE_X: Image;
      public NEGATIVE_X: Image;
      public POSITIVE_Y: Image;
      public NEGATIVE_Y: Image;
      public POSITIVE_Z: Image;
      public NEGATIVE_Z: Image;
      public imageProvider: ImageProvider;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class FreidInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public faceid: number;
      public trackid: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum CollideDirection {
      X,
      Y,
      Z,
    }
    namespace CollideDirection {
      let RTTI: RTTIDescriptor;
    }
    class ImageCubeAtlas extends ImageAtlasBase {
      constructor();
      public assetMgr: AssetManager;
      public frames: Vector;
      public texture: Texture;
      public uris: Vector;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Prefab extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public entities: Vector;
      public standaloneResources: Map;
      public handle: number;
      public init(): boolean;
      public getRootEntity(): Entity;
      public instantiateToScene(scene: Scene, shouldUnpack: boolean): Entity;
      public instantiateToEntity(scene: Scene, ent: Entity, shouldUnpack: boolean): Entity;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Texture2DArrayDeprecated extends Texture {
      constructor();
      public assetMgr: AssetManager;
      public width: number;
      public height: number;
      public depth: number;
      public internalFormat: InternalFormat;
      public dataType: DataType;
      public builtinType: BuiltInTextureType;
      public enableMipmap: boolean;
      public filterMin: FilterMode;
      public filterMag: FilterMode;
      public filterMipmap: FilterMipmapMode;
      public wrapModeS: WrapMode;
      public wrapModeT: WrapMode;
      public wrapModeR: WrapMode;
      public maxAnisotropy: number;
      public index: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class JetAffector extends Affector {
      constructor();
      public assetMgr: AssetManager;
      public postion: Vector3f;
      public rotation: Quaternionf;
      public enabled: boolean;
      public updateMode: ParticleUpdateMode;
      public acceleration: Value;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ValueCurved extends Value {
      constructor();
      public assetMgr: AssetManager;
      public interpolationType: ValueCurvedInterpolationType;
      public controlPoints: Vector;
      public dirty: boolean;
      public handle: number;
      public getValue(x: number): number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class DeviceRotation extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public quat: Quaternionf;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class AudioExtractorResult extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public featureList: Vector;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Skin extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public skelRootName: string;
      public joints: Vector;
      public rootTransform: Transform;
      public meshCoarse: Mesh;
      public positionOnly: boolean;
      public useTangent: boolean;
      public meshCoarseTransform: Transform;
      public dynamicJoints: Vector;
      public dynamicJointColliders: Vector;
      public handle: number;
      public getSkinResult(bindMesh: Mesh, attribType: VertexAttribType, W2L: Matrix4x4f): Vec3Vector;
      public getSkinResultTangent(bindMesh: Mesh, W2L: Matrix4x4f): Vec4Vector;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class FootInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public footId: number;
      public box: Rect;
      public left_prob: number;
      public foot_prob: number;
      public is_left: boolean;
      public key_points_xy: Vec2Vector;
      public key_points_is_detect: UInt8Vector;
      public segment: UInt8Vector;
      public segment_box: Rect;
      public u_model: Matrix4x4f;
      public transMat: Matrix4x4f;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ImageAtlasBase extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public frames: Vector;
      public texture: Texture;
      public handle: number;
      public addFrame(frame: ImageFrame): void;
      public getFrameCount(): number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class StructData extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public addBool(name: string, b: boolean): StructData;
      public addInt32(name: string, i: number): StructData;
      public addFloat(name: string, f: number): StructData;
      public addVector2f(name: string, vec4: Vector2f): StructData;
      public addVector4f(name: string, vec4: Vector4f): StructData;
      public addMatrix4x4f(name: string, mat4: Matrix4x4f): StructData;
      public addInt32Vector(name: string, i: Int32Vector): StructData;
      public addFloatVector(name: string, f: FloatVector): StructData;
      public addVec2Vector(name: string, vec4: Vec2Vector): StructData;
      public addVec4Vector(name: string, vec4: Vec4Vector): StructData;
      public addMat4Vector(name: string, mat4: Mat4Vector): StructData;
      public addStructData(name: string, struct: StructData): StructData;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum TextureResizeLevel {
      32,
      64,
      128,
      256,
      512,
      1024,
      2048,
      4096,
      8192,
      16384,
      OFF,
    }
    namespace TextureResizeLevel {
      let RTTI: RTTIDescriptor;
    }
    class JSWrapAlgorithmModel extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ProxyVector2f extends ProxyBase {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ProxyVector3f extends ProxyBase {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ProxyVector4f extends ProxyBase {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ProxyQuaternionf extends ProxyBase {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ProxyColor extends ProxyBase {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ProxyMatrix3x3f extends ProxyBase {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ProxyMatrix4x4f extends ProxyBase {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ProxyBase extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class RelationRecogInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class SphereColliderAffector extends BaseColliderAffector {
      constructor();
      public assetMgr: AssetManager;
      public postion: Vector3f;
      public rotation: Quaternionf;
      public enabled: boolean;
      public updateMode: ParticleUpdateMode;
      public intersectionType: AffectorIntersectionType;
      public collisionType: AffectorCollisionType;
      public radius: number;
      public innerCollision: boolean;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class BaseColliderAffector extends Affector {
      constructor();
      public assetMgr: AssetManager;
      public postion: Vector3f;
      public rotation: Quaternionf;
      public enabled: boolean;
      public updateMode: ParticleUpdateMode;
      public intersectionType: AffectorIntersectionType;
      public collisionType: AffectorCollisionType;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class SineForceAffector extends BaseForceAffector {
      constructor();
      public assetMgr: AssetManager;
      public postion: Vector3f;
      public rotation: Quaternionf;
      public enabled: boolean;
      public updateMode: ParticleUpdateMode;
      public forceScalar: number;
      public forceApplication: AffectorForceApplication;
      public frequencyMin: number;
      public frequencyMax: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class BaseForceAffector extends Affector {
      constructor();
      public assetMgr: AssetManager;
      public postion: Vector3f;
      public rotation: Quaternionf;
      public enabled: boolean;
      public updateMode: ParticleUpdateMode;
      public forceScalar: number;
      public forceApplication: AffectorForceApplication;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class GravityAffector extends Affector {
      constructor();
      public assetMgr: AssetManager;
      public postion: Vector3f;
      public rotation: Quaternionf;
      public enabled: boolean;
      public updateMode: ParticleUpdateMode;
      public gravity: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class LineAffector extends Affector {
      constructor();
      public assetMgr: AssetManager;
      public postion: Vector3f;
      public rotation: Quaternionf;
      public enabled: boolean;
      public updateMode: ParticleUpdateMode;
      public maxDeviation: number;
      public end: Vector3f;
      public timeStep: number;
      public drift: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class NoiseAffector extends Affector {
      constructor();
      public assetMgr: AssetManager;
      public postion: Vector3f;
      public rotation: Quaternionf;
      public enabled: boolean;
      public updateMode: ParticleUpdateMode;
      public strength: number;
      public Xstrength: Value;
      public Ystrength: Value;
      public Zstrength: Value;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ScaleAffector extends Affector {
      constructor();
      public assetMgr: AssetManager;
      public postion: Vector3f;
      public rotation: Quaternionf;
      public enabled: boolean;
      public updateMode: ParticleUpdateMode;
      public type: AffectorScaleType;
      public scaleX: Value;
      public scaleY: Value;
      public scaleZ: Value;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ScaleVelocityAffector extends Affector {
      constructor();
      public assetMgr: AssetManager;
      public postion: Vector3f;
      public rotation: Quaternionf;
      public enabled: boolean;
      public updateMode: ParticleUpdateMode;
      public scale: Value;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class TextureAnimationAffector extends Affector {
      constructor();
      public assetMgr: AssetManager;
      public postion: Vector3f;
      public rotation: Quaternionf;
      public enabled: boolean;
      public updateMode: ParticleUpdateMode;
      public type: AffectorTextureAnimationType;
      public timeStep: number;
      public useTimeStep: boolean;
      public coordStart: number;
      public coordEnd: number;
      public isStartRandom: boolean;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class RotationAffector extends Affector {
      constructor();
      public assetMgr: AssetManager;
      public postion: Vector3f;
      public rotation: Quaternionf;
      public enabled: boolean;
      public updateMode: ParticleUpdateMode;
      public XRotationSpeed: Value;
      public YRotationSpeed: Value;
      public ZRotationSpeed: Value;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class CustomDataAffector extends Affector {
      constructor();
      public assetMgr: AssetManager;
      public postion: Vector3f;
      public rotation: Quaternionf;
      public enabled: boolean;
      public updateMode: ParticleUpdateMode;
      public customData1X: Value;
      public customData1Y: Value;
      public customData1Z: Value;
      public customData1W: Value;
      public customData2X: Value;
      public customData2Y: Value;
      public customData2Z: Value;
      public customData2W: Value;
      public useTimeToDeath: boolean;
      public useTimeToLive: boolean;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Affector extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public postion: Vector3f;
      public rotation: Quaternionf;
      public enabled: boolean;
      public updateMode: ParticleUpdateMode;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum IFListenerTypeOffset {
      UserListenerStart,
      ResponderStart,
      UIControlStart,
    }
    namespace IFListenerTypeOffset {
      let RTTI: RTTIDescriptor;
    }
    class FloatValueFixed extends FloatValue {
      constructor();
      public assetMgr: AssetManager;
      public floatValue: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum CameraClearType {
      COLOR_DEPTH,
      COLOR,
      DEPTH,
      DEPTH_STENCIL,
      COLOR_DEPTH_STENCIL,
      DONT,
    }
    namespace CameraClearType {
      let RTTI: RTTIDescriptor;
    }
    class EntityGroup extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class FloatValueCurved extends FloatValue {
      constructor();
      public assetMgr: AssetManager;
      public iType: ValueCurveInterpolationType;
      public cpList: Vector;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class BuiltinEffectConfig extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public getInternalBeautySmooth(): number;
      public getInternalBeautyBrighten(): number;
      public getInternalBeautySharp(): number;
      public getInternalReshapeEye(): number;
      public getInternalReshapeFace(): number;
      public getInternalMakeupBlusher(): number;
      public getInternalMakeupLips(): number;
      public getInternalLeftFilterIntensity(): number;
      public getInternalRightFilterIntensity(): number;
      public getInternalFilterPosition(): number;
      public getInternalFilterLeft(): Texture2D;
      public getInternalFilterRight(): Texture2D;
      public getInternalIntensity(name: string): number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class DeviceSensorAgentWrapper extends DeviceSensorHub {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class DeviceSensorHub extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public setSensorEnabled(arg0: SensorType, arg1: boolean): void;
      public getGravityData(arg0: SensorDataSpace): Vector3f;
      public getAccelerationData(arg0: SensorDataSpace): Vector3f;
      public getGyroData(arg0: SensorDataSpace): Vector3f;
      public getRotationData(arg0: SensorDataSpace): Quaternionf;
      public getGeomagneticData(arg0: SensorDataSpace): Vector3f;
      public getHeadingData(): number;
      public getFilteredCameraRotation(): Quaternionf;
      public setRefreshRate(arg0: SensorType, arg1: number): void;
      public setSensorFilterEnabled(arg0: boolean): void;
      public getGravityVector(arg0: number): Vector3f;
      public updateRigidBody3DGravity(arg0: Entity, arg1: boolean, arg2: number): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum ARBackendType {
      Unknown,
      ARKit,
      ARCore,
      Bach,
    }
    namespace ARBackendType {
      let RTTI: RTTIDescriptor;
    }
    class RenderObject extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum Mobility {
      Dynamic,
      Static,
      Stationary,
    }
    namespace Mobility {
      let RTTI: RTTIDescriptor;
    }
    enum RaycasterType {
      AR,
      UI,
      ThreeD,
      TwoD,
      Other,
    }
    namespace RaycasterType {
      let RTTI: RTTIDescriptor;
    }
    class Texture2DArray extends Texture {
      constructor();
      public assetMgr: AssetManager;
      public width: number;
      public height: number;
      public depth: number;
      public internalFormat: InternalFormat;
      public dataType: DataType;
      public builtinType: BuiltInTextureType;
      public enableMipmap: boolean;
      public filterMin: FilterMode;
      public filterMag: FilterMode;
      public filterMipmap: FilterMipmapMode;
      public wrapModeS: WrapMode;
      public wrapModeT: WrapMode;
      public wrapModeR: WrapMode;
      public maxAnisotropy: number;
      public imageProvider: ImageProvider;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum PassType {
      NORMAL,
      PIXELSELECT,
      SRPSPECIAL,
      PURECOLOR,
      SHADOW,
    }
    namespace PassType {
      let RTTI: RTTIDescriptor;
    }
    enum LightMode {
      NONE,
      FORWARD_ADD,
      FORWARD_BASE,
    }
    namespace LightMode {
      let RTTI: RTTIDescriptor;
    }
    class AMGAudioMicSourceNode extends AMGAudioNode {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public start(): void;
      public stop(): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum GestureRecognizerState {
      Began,
      Ended,
      Cancelled,
      Changed,
      Possible,
      Failed,
    }
    namespace GestureRecognizerState {
      let RTTI: RTTIDescriptor;
    }
    enum ShaderType {
      VERTEX,
      FRAGMENT,
      COMPUTE,
    }
    namespace ShaderType {
      let RTTI: RTTIDescriptor;
    }
    enum AMGListenerType {
      ALWAYS_INVOKE_TYPE,
    }
    namespace AMGListenerType {
      let RTTI: RTTIDescriptor;
    }
    enum BrushLocalFrameType {
      Natural,
      Vertical,
      CameraFacing,
    }
    namespace BrushLocalFrameType {
      let RTTI: RTTIDescriptor;
    }
    enum WrapMode {
      REPEAT,
      CLAMP,
      Mirror,
    }
    namespace WrapMode {
      let RTTI: RTTIDescriptor;
    }
    enum Brush2DStampStrategy {
      Restart,
      Continue,
      Shuffle,
    }
    namespace Brush2DStampStrategy {
      let RTTI: RTTIDescriptor;
    }
    enum BrushDrawingType {
      Discrete,
      Continuous,
    }
    namespace BrushDrawingType {
      let RTTI: RTTIDescriptor;
    }
    enum BrushSegment {
      Begin,
      Main,
      COUNT,
      End,
    }
    namespace BrushSegment {
      let RTTI: RTTIDescriptor;
    }
    class TextTexture extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public sdfTexture: RenderTexture;
      public nonsdfTexture: RenderTexture;
      public charRectMap: Map;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class NetworkResult extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public requestId: number;
      public status: number;
      public body: string;
      public binaryBody: UInt8Vector;
      public statusCode: number;
      public statusDesc: string;
      public headers: Map;
      public newBytesNum: number;
      public errorDesc: string;
      public contentLength: number;
      public succeed: boolean;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class DataPlaybackCenter extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public encodeBuffer(): string;
      public decodeBufferAndSet(buffer: string): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum TrackingType {
      Nail,
      ARKit,
    }
    namespace TrackingType {
      let RTTI: RTTIDescriptor;
    }
    class VertexAttribDesc extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public semantic: VertexAttribType;
      public bindingIndex: number;
      public offset: number;
      public componentCount: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum ARUnit {
      METER,
      CENTI_METER,
    }
    namespace ARUnit {
      let RTTI: RTTIDescriptor;
    }
    enum ParticleMeshRendererType {
      SIZE_BY_PARTICLE,
      SCALE_BY_PARTICLE,
    }
    namespace ParticleMeshRendererType {
      let RTTI: RTTIDescriptor;
    }
    enum BlendFactor {
      ONE,
      DST_ALPHA,
      ONE_MINUS_SRC_COLOR,
      SRC_COLOR,
      ONE_MINUS_DST_ALPHA,
      DST_COLOR,
      ZERO,
      ONE_MINUS_DST_COLOR,
      SRC_ALPHA,
      ONE_MINUS_SRC_ALPHA,
    }
    namespace BlendFactor {
      let RTTI: RTTIDescriptor;
    }
    class CullingResults extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public rt: RenderTexture;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ModelNode extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public mesh_index: UInt32Vector;
      public children: Vector;
      public parent: ModelNode;
      public transform: Transform;
      public materialIndices: UInt32Vector;
      public handle: number;
      public AddMeshIndex(index: number): void;
      public AddMaterialIndex(index: number): void;
      public AddChild(node: ModelNode): void;
      public FindNode(name: string): ModelNode;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class CubeCrossImageProvider extends ImageProvider {
      constructor();
      public assetMgr: AssetManager;
      public imagesUri: Vector;
      public handle: number;
      public setImageUri(uri: string): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum InternalFormat {
      ETC2,
      R5G6B5,
      RG8,
      PTC22,
      R16U,
      D24,
      R16I,
      PTC14,
      ETC1,
      ETC2A,
      R16,
      PTC24,
      R16S,
      RGBA8U,
      PTC14A,
      R1,
      ETC2A1,
      R8,
      RG8S,
      R8I,
      RG16I,
      R8U,
      RGBA32F,
      RG16U,
      RGBA8,
      R32U,
      R8S,
      RG8U,
      PTC12A,
      PTC12,
      RG16S,
      R16F,
      RGB8S,
      R32F,
      RG8I,
      D24S8,
      RG16,
      R32I,
      RG16F,
      RG32I,
      RG32F,
      RGB8,
      RGB8I,
      RGB8U,
      A8,
      RGB9E5F,
      RGBA16,
      BGRA8,
      RG32U,
      RGBA8I,
      RGBA8S,
      RGBA16I,
      RGBA16U,
      RGBA16F,
      RGBA16S,
      RGBA32I,
      RGBA4,
      RGBA32U,
      RGB5A1,
      RGB10A2,
      RG11B10F,
      D16,
      D32,
      D16F,
      D24F,
      D32F,
    }
    namespace InternalFormat {
      let RTTI: RTTIDescriptor;
    }
    enum RendererType {
      Direct3D10,
      Direct3D11,
      OpenGL,
      Null,
      Direct3D12,
      OpenGLES2,
      Gnm,
      OpenGLES32,
      Vulkan,
      Metal,
      OpenGLES30,
      OpenGLES31,
      Direct3D9,
      Count,
    }
    namespace RendererType {
      let RTTI: RTTIDescriptor;
    }
    class ObjectTrackInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public centerX: number;
      public centerY: number;
      public width: number;
      public height: number;
      public rotateAngle: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ViewportState extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public rect: Rect;
      public rectName: string;
      public minDepth: number;
      public minDepthName: string;
      public maxDepth: number;
      public maxDepthName: string;
      public portValueType: PortValueType;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class OriginalVertex extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public position: Vec3Vector;
      public indices: UInt32Vector;
      public convertMap: Map;
      public positionRuntime: Vec3Vector;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class RenderContext extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum ARSessionTrackingFeature {
      None,
      PoseDetection2D,
      SceneDepth,
      PersonSegmentation,
      PersonSegmentationWithDepth,
      SmoothedSceneDepth,
    }
    namespace ARSessionTrackingFeature {
      let RTTI: RTTIDescriptor;
    }
    class ARTrackedMeshAnchor extends ARTrackedAnchor {
      constructor();
      public assetMgr: AssetManager;
      public anchorType: AnchorType;
      public handle: number;
      public getClassificationHistogram(): FloatVector;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Model extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public ModelNode: ModelNode;
      public Meshes: Vector;
      public Animazes: Vector;
      public Materials: Vector;
      public handle: number;
      public AddMesh(mesh: Mesh): void;
      public AddMaterial(material: string): void;
      public createModelInstance(scene: Scene, name: string): Entity;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class DepthStencilState extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public depthTestEnable: boolean;
      public depthTestEnableName: string;
      public depthCompareOp: CompareOp;
      public depthCompareOpName: string;
      public depthWriteEnable: boolean;
      public stencilTestEnable: boolean;
      public stencilTestEnableName: string;
      public stencilFront: StencilOpState;
      public stencilBack: StencilOpState;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ColorBlendState extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public blendConstants: Vector4f;
      public blendEnableName: string;
      public blendFactorName: string;
      public blendOpName: string;
      public attachments: Vector;
      public handle: number;
      public pushAttachment(arg0: ColorBlendAttachmentState, arg1: boolean): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum ValueCurveInterpolationType {
      LINEAR,
      SPLINE,
      IMMEDIATE,
    }
    namespace ValueCurveInterpolationType {
      let RTTI: RTTIDescriptor;
    }
    class Vec4ValueFixed extends Vec4Value {
      constructor();
      public assetMgr: AssetManager;
      public Vec4Value: Vector4f;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class AMGAudioModule extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public createAudioProxy(config: Map): AMGAudioProxy;
      public destroyAudioProxy(audioProxy: AMGAudioProxy): void;
      public readMidi(s: string, i: number): Vector;
      public getPlaybackDeviceType(): number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum PolygonMode {
      FILL,
      LINE,
      POINT,
    }
    namespace PolygonMode {
      let RTTI: RTTIDescriptor;
    }
    enum VertexAttribType {
      NORMAL,
      TEXCOORD5,
      COLOR2,
      POSITION,
      TEXCOORD3D0,
      USER_DEFINE0,
      TEXCOORD0,
      INDICES,
      COLOR,
      TEXCOORD4,
      TEXCOORD1,
      TEXCOORD2,
      TANGENT,
      TEXCOORD3,
      TEXCOORD6,
      COLOR3,
      BINORMAL_OFFSET,
      TEXCOORD7,
      COLOR1,
      UNKOWN,
      TEXCOORD3D1,
      USER_DEFINE1,
      TEXCOORD3D2,
      WEIGHT,
      USER_DEFINE2,
      TEXCOORD3D3,
      USER_DEFINE3,
      BINORMAL,
      POSITION_OFFSET,
      NORMAL_OFFSET,
      TANGENT_OFFSET,
    }
    namespace VertexAttribType {
      let RTTI: RTTIDescriptor;
    }
    class WatchTryonInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public modelViewMatrix: Matrix4x4f;
      public isLeft: boolean;
      public vertices: Vec3Vector;
      public triangles: UInt16Vector;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class EntityGroupManager extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum ValueOscillationType {
      SINE,
      SQUARE,
    }
    namespace ValueOscillationType {
      let RTTI: RTTIDescriptor;
    }
    class TriMesh extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public vertices: Vec3Vector;
      public normals: Vec3Vector;
      public texCoords: Vec2Vector;
      public indices: Int32Vector;
      public handle: number;
      public getVertexCount(): number;
      public getTriangleCount(): number;
      public getBoundingBox(): AABB;
      public getVolume(): number;
      public clone(): TriMesh;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum CullFace {
      NONE,
      FRONT,
      BACK,
      FRONT_AND_BACK,
    }
    namespace CullFace {
      let RTTI: RTTIDescriptor;
    }
    enum FrontFace {
      COUNTER_CLOCKWISE,
      CLOCKWISE,
    }
    namespace FrontFace {
      let RTTI: RTTIDescriptor;
    }
    class MultisampleState extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum SubEmitterType {
      Birth,
      Death,
      Collision,
      Manual,
    }
    namespace SubEmitterType {
      let RTTI: RTTIDescriptor;
    }
    enum CompareOp {
      NEVER,
      LESS,
      ALWAYS,
      LESS_OR_EQUAL,
      EQUAL,
      GREATER,
      NOT_EQUAL,
      MAX_ENUM,
      GREATER_OR_EQUAL,
    }
    namespace CompareOp {
      let RTTI: RTTIDescriptor;
    }
    enum IFAnchorAlignmentTrackOption {
      TrackWithTargetNum,
      TrackWithIndex,
      TrackWithTrackId,
      TrackWithId,
    }
    namespace IFAnchorAlignmentTrackOption {
      let RTTI: RTTIDescriptor;
    }
    class AMGAudioSourceNode extends AMGAudioNode {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public setSource(s: string): void;
      public setLoop(b: boolean): void;
      public start(): void;
      public resume(): void;
      public pause(): void;
      public stop(): void;
      public getState(): number;
      public getLoopCount(): number;
      public getProgress(): number;
      public getDuration(): number;
      public setStartTime(f: number): boolean;
      public setEndTime(f: number): boolean;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class AMGAudioMusicSourceNode extends AMGAudioNode {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public start(): void;
      public stop(): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class AMGAudioRecorderNode extends AMGAudioNode {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public start(): void;
      public pause(): void;
      public stop(): void;
      public setPath(s: string): boolean;
      public getPath(): string;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class AMGAudioGainNode extends AMGAudioNode {
      constructor();
      public assetMgr: AssetManager;
      public gain: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class AMGAudioEffectNode extends AMGAudioNode {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public setParameter(s: string, f: number): void;
      public setParameters(m: Map): void;
      public getParameter(s: string): number;
      public getParameterRange(s: string): Vector2f;
      public getParameterDescriptors(): Map;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class AMGAudioExtractorNode extends AMGAudioNode {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public getResult(): AudioExtractorResult;
      public setParameter(s: string, f: number): void;
      public setStringParameter(s: string, s0: string): void;
      public getParameter(s: string): number;
      public getStringParameter(s: string): string;
      public getParameterDescriptors(): Map;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class AMGAudioNode extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public connect(node: AMGAudioNode): void;
      public pin(i: number): AMGAudioNodePin;
      public pout(i: number): AMGAudioNodePout;
      public setByPass(b: boolean): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum ARSessionType {
      None,
      Face,
      World,
      Image,
      Orientation,
      ObjectScanning,
      PoseTracking,
    }
    namespace ARSessionType {
      let RTTI: RTTIDescriptor;
    }
    class FaceGanInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public faceID: number;
      public doubleRate: number;
      public plumpRate: number;
      public objectType: FaceGanObjectType;
      public outWidth: number;
      public outHeight: number;
      public outChannel: number;
      public affine: Matrix4x4f;
      public rect: Rect;
      public image_width: number;
      public image_height: number;
      public data: Image;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class RasterizationState extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public depthClampEnable: boolean;
      public depthClampEnableName: string;
      public rasterizerDiscardEnable: boolean;
      public rasterizerDiscardEnableName: string;
      public polygonMode: PolygonMode;
      public polygonModeName: string;
      public cullMode: CullFace;
      public cullModeName: string;
      public frontFace: FrontFace;
      public frontFaceName: string;
      public depthBiasEnable: boolean;
      public depthBiasEnableName: string;
      public depthBiasConstantFactor: number;
      public depthBiasConstantFactorName: string;
      public depthBiasClamp: number;
      public depthBiasClampName: string;
      public depthBiasSlopeFactor: number;
      public depthBiasSlopeFactorName: string;
      public lineWidth: number;
      public lineWidthName: string;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class StencilOpState extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public failOp: StencilOp;
      public failOpName: string;
      public passOp: StencilOp;
      public passOpName: string;
      public depthFailOp: StencilOp;
      public depthFailOpName: string;
      public compareOp: CompareOp;
      public compareOpName: string;
      public compareMask: number;
      public compareMaskName: string;
      public writeMask: number;
      public writeMaskName: string;
      public reference: number;
      public referenceName: string;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum BlendOp {
      ADD,
      SUB,
      REVSUB,
      MIN,
      MAX,
    }
    namespace BlendOp {
      let RTTI: RTTIDescriptor;
    }
    class EnigmaInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public type: number;
      public text: string;
      public points: Vec2Vector;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum NetworkStatusWS {
      NETWORK_WS_STATE_CHANGED,
      NETWORK_WS_ERROR,
      NETWORK_WS_FEEDBACKLOG,
      NETWORK_WS_MESSAGE,
    }
    namespace NetworkStatusWS {
      let RTTI: RTTIDescriptor;
    }
    class UniformReal extends Uniform {
      constructor();
      public assetMgr: AssetManager;
      public value: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class LuaManager extends ScriptManager {
      constructor();
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ScriptManager {
      constructor();
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum AMGBeautyMeshType {
      FACE145,
    }
    namespace AMGBeautyMeshType {
      let RTTI: RTTIDescriptor;
    }
    class GeometryProcessor extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public contourEvalNormals(arg0: ContourSet): void;
      public contourSample(arg0: ContourSet, arg1: ContourSamplingOption): Vec2Vector;
      public contourDecimation(arg0: ContourSet, arg1: ContourDecimationOption): ContourSet;
      public marchingSquares(arg0: Image): ContourSet;
      public meshSubdivision(arg0: TriMesh): TriMesh;
      public meshDecimation(arg0: TriMesh, arg1: MeshDecimationOption): TriMesh;
      public meshSmoothing(arg0: TriMesh, arg1: MeshSmoothingOption): void;
      public meshBand(arg0: ContourSet, arg1: MeshBandOption): TriMesh;
      public meshExtrusion(arg0: ContourSet, arg1: MeshExtrudeOption, arg2: Int32Vector, arg3: TriMesh): void;
      public meshMerge(arg0: Vector): TriMesh;
      public meshTransform(arg0: TriMesh, arg1: Matrix4x4f): void;
      public meshFracture(arg0: TriMesh, arg1: MeshFractureOption): Vector;
      public meshTriangulation(arg0: ContourSet): TriMesh;
      public meshTriangulationEx(arg0: ContourSet, arg1: Int32Vector): TriMesh;
      public genTexCoords(arg0: TriMesh, arg1: TextureOption): Vec2Vector;
      public genSmoothNormals(arg0: TriMesh): Vec3Vector;
      public toTriMesh(arg0: Mesh): TriMesh;
      public toMesh(arg0: TriMesh, arg1: number): Mesh;
      public toModel(arg0: Mesh, arg1: MeshSkeleton): Model;
      public imageToMeshAsync(arg0: Image, arg1: ImagePreprocessOption, arg2: MeshExtrudeOption, arg3: ContourDecimationOption): void;
      public imageToSkinnedMeshAsync(arg0: Image, arg1: ImagePreprocessOption, arg2: MeshExtrudeOption, arg3: ContourDecimationOption, arg4: number): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum FilterMode {
      NEAREST,
      LINEAR,
    }
    namespace FilterMode {
      let RTTI: RTTIDescriptor;
    }
    class ContourSamplingOption extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public radius: number;
      public padding: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class CharRect extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public isSdf: boolean;
      public x0: number;
      public x1: number;
      public y0: number;
      public y1: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum IFUIMoveDirection {
      LEFT_TO_RIGHT,
      RIGHT_TO_LEFT,
      BOTTOM_TO_TOP,
      TOP_TO_BOTTOM,
    }
    namespace IFUIMoveDirection {
      let RTTI: RTTIDescriptor;
    }
    enum GridReshapeType {}
    namespace GridReshapeType {
      let RTTI: RTTIDescriptor;
    }
    class ContourDecimationOption extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public minContourSize: number;
      public maxDisThreshold: number;
      public decimationRatio: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class XShader extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public properties: PropertySheet;
      public renderQueue: number;
      public passes: Vector;
      public shadowMapStaticPass: Pass;
      public shadowMapDynamicPass: Pass;
      public fallbackShader: XShader;
      public handle: number;
      public addPass(pass: Pass): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class MeshSmoothingOption extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public numSteps: number;
      public lambda: number;
      public passband: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class MeshExtrudeOption extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public offset: number;
      public midSegment: number;
      public side: number;
      public segments: number;
      public normal: MeshNormal;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class FacePetInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public face_pet_type: FacePetType;
      public rect: Rect;
      public score: number;
      public points_array: Vec2Vector;
      public yaw: number;
      public pitch: number;
      public roll: number;
      public Id: number;
      public action: number;
      public ear_type: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class MeshSkeleton extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum IFLayer2dRenderOrderMode {
      ScreenOverlay,
      SceneCustom,
    }
    namespace IFLayer2dRenderOrderMode {
      let RTTI: RTTIDescriptor;
    }
    enum AffectorScaleType {
      LINEAR,
      RATIO,
    }
    namespace AffectorScaleType {
      let RTTI: RTTIDescriptor;
    }
    enum TrackingMode {
      Rotation,
      Surface,
      World,
    }
    namespace TrackingMode {
      let RTTI: RTTIDescriptor;
    }
    class MeshFractureOption extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public randomSeed: number;
      public piecesCount: number;
      public splitDisconnectedParts: boolean;
      public normal: Vector3f;
      public minimumVolume: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class UniformSampler extends Uniform {
      constructor();
      public assetMgr: AssetManager;
      public texture: Texture;
      public filter: FilterMode;
      public wrapMode: WrapMode;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class UniformVec2 extends Uniform {
      constructor();
      public assetMgr: AssetManager;
      public value: Vector2f;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class UniformVec4 extends Uniform {
      constructor();
      public assetMgr: AssetManager;
      public value: Vector4f;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class UniformMat3 extends Uniform {
      constructor();
      public assetMgr: AssetManager;
      public value: Matrix3x3f;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class UniformMat4 extends Uniform {
      constructor();
      public assetMgr: AssetManager;
      public value: Matrix4x4f;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class UniformVec3Array extends Uniform {
      constructor();
      public assetMgr: AssetManager;
      public value: Vec3Vector;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Uniform extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Particle extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public lifeRemaining: number;
      public linearVel: Vector3f;
      public color: Vector4f;
      public originalColor: Vector4f;
      public timeToLive: number;
      public timeFraction: number;
      public totalTimeToLive: number;
      public position: Vector3f;
      public originalPosition: Vector3f;
      public orientation: Quaternionf;
      public originalOrientation: Quaternionf;
      public direction: Vector3f;
      public originalDirection: Vector3f;
      public width: number;
      public originalWidth: number;
      public height: number;
      public originalHeight: number;
      public depth: number;
      public originalDepth: number;
      public originalVelocity: number;
      public disturbance: Vector3f;
      public textureAnimationTimeStep: number;
      public textureAnimationTimeStepCount: number;
      public textureCoordsCurrent: number;
      public textureAnimationDirectionUp: boolean;
      public rotation: Vector3f;
      public rotationSpeed: Vector3f;
      public customData1: Vector4f;
      public customData2: Vector4f;
      public mass: number;
      public affectorRatio: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class TextureAtlas extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public texUri: string;
      public frames: Vector;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ARTrackedFaceAnchor extends ARTrackedAnchor {
      constructor();
      public assetMgr: AssetManager;
      public anchorType: AnchorType;
      public handle: number;
      public getLeftEyeTransform(): Matrix4x4f;
      public getRightEyeTransform(): Matrix4x4f;
      public getLookAt(): Vector3f;
      public getBlendShapes(): Map;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Lut3DProvider extends ImageProvider {
      constructor();
      public assetMgr: AssetManager;
      public imagesUri: Vector;
      public handle: number;
      public setImageUri(uri: string): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class BrushStroke extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public renderDirty: boolean;
      public animationSpeed: number;
      public handle: number;
      public isEnded(): boolean;
      public isAnimationEnabled(): boolean;
      public refreshStroke(beginIndex: number): void;
      public finishStroke(): void;
      public size(): number;
      public getSegmentPosition(index: number): Vector3f;
      public setSegmentPosition(pos: Vector3f, index: number): void;
      public getSegmentUp(index: number): Vector3f;
      public setSegmentUp(up: Vector3f, index: number): void;
      public getSegmentTangent(index: number): Vector3f;
      public setSegmentTangent(index: Vector3f, arg1: number): void;
      public getSegmentTime(index: number): number;
      public setSegmentTime(time: number, index: number): void;
      public getSegmentRadius(index: number): number;
      public setSegmentRadius(radius: number, index: number): void;
      public getSegmentArcLength(index: number): number;
      public getSegmentArcLengthSum(index: number): number;
      public getSegmentTransform(index: number): Transform;
      public getSegmentRenderer(index: number): Renderer;
      public addPoint(pos: Vector3f, up: Vector3f, lookAt: Vector3f, touchPressure: number, isEnd: boolean): void;
      public addARPoint(pos: Vector2f, up: Vector3f, camPos: Vector3f, proj: Matrix4x4f, worldToClip: Matrix4x4f, touchPressure: number, isEnd: boolean): void;
      public addFacePoint(pos: Vector3f, mvp: Matrix4x4f, vertices: Vec3Vector, touchPressure: number, isEnd: boolean): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum LightUnit {
      Lux,
      Unitless,
      Lumens,
      Candelas,
    }
    namespace LightUnit {
      let RTTI: RTTIDescriptor;
    }
    enum ParticleRingBufferMode {
      DISABLED,
      PAUSE_UNTIL_REPLACED,
      LOOP_UNTIL_REPLACED,
    }
    namespace ParticleRingBufferMode {
      let RTTI: RTTIDescriptor;
    }
    class AudioParameterDescriptor extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public range: Vector2f;
      public description: string;
      public unit: string;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ValueFixed extends Value {
      constructor();
      public assetMgr: AssetManager;
      public value: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ValueRandom extends Value {
      constructor();
      public assetMgr: AssetManager;
      public min: number;
      public max: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ValueOscillate extends Value {
      constructor();
      public assetMgr: AssetManager;
      public oscillationType: ValueOscillationType;
      public frequency: number;
      public phase: number;
      public base: number;
      public amplitude: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Value extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class SystemList extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public systemList: StringVector;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum ParticleUpdateMode {
      PARTICLE,
      PS_SYSTEM,
      PARTICLE_FRACTION,
    }
    namespace ParticleUpdateMode {
      let RTTI: RTTIDescriptor;
    }
    class ARTrackedPointAnchor extends ARTrackedAnchor {
      constructor();
      public assetMgr: AssetManager;
      public anchorType: AnchorType;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class FacePartBeautyConfigInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public faceNum: number;
      public faceNum0: number;
      public faceNum1: number;
      public distance: number;
      public faceChange: number;
      public together: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ParticleQuatRenderer extends ParticleRenderer {
      constructor();
      public assetMgr: AssetManager;
      public sortingMode: ParticleRenderSortingMode;
      public orientationType: ParticleQuatRendererOrientationType;
      public alignType: ParticleQuatRendererAlignType;
      public fixedDirection: Vector3f;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ParticleMeshRenderer extends ParticleRenderer {
      constructor();
      public assetMgr: AssetManager;
      public sortingMode: ParticleRenderSortingMode;
      public templateMesh: Mesh;
      public displayMode: ParticleMeshRendererType;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ParticleSphereRenderer extends ParticleRenderer {
      constructor();
      public assetMgr: AssetManager;
      public sortingMode: ParticleRenderSortingMode;
      public numberOfRings: number;
      public numberOfSegments: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ParticleTrailRenderer extends ParticleRenderer {
      constructor();
      public assetMgr: AssetManager;
      public sortingMode: ParticleRenderSortingMode;
      public maxTrailElements: number;
      public trailLength: number;
      public trailChangeColor: Vector4f;
      public trailChangeWidth: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ParticleTrailRendererV2 extends ParticleRenderer {
      constructor();
      public assetMgr: AssetManager;
      public sortingMode: ParticleRenderSortingMode;
      public trailSegments: number;
      public ratio: number;
      public lifeTime: Value;
      public minimumVertexDistance: number;
      public dieWithParticle: boolean;
      public textureMode: TrailTextureMode;
      public sizeAffectWidth: boolean;
      public sizeAffectLifeTime: boolean;
      public inheritColor: boolean;
      public widthOverTrail: Value;
      public colorOverLifeTime: Vec4Value;
      public colorOverTrail: Vec4Value;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ParticleRenderer extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public sortingMode: ParticleRenderSortingMode;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum ColorOperation {
      MULTIPLY,
      SET,
      RANDOM,
    }
    namespace ColorOperation {
      let RTTI: RTTIDescriptor;
    }
    enum FaceMakeupMeshType {
      EYEPART,
      PUPIL,
      STEYEPART,
      FACE3DTITLE,
      STEYELASH,
      STPUPIL,
      FACE3D_LANDMARK,
      TT295,
      QUAD,
      ST295,
      FACE3D,
      FACE3DMOUSEEYES,
      DEFAULT,
    }
    namespace FaceMakeupMeshType {
      let RTTI: RTTIDescriptor;
    }
    enum AffectorForceApplication {
      AVERAGE,
      ADD,
    }
    namespace AffectorForceApplication {
      let RTTI: RTTIDescriptor;
    }
    class HandKeyPoint extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public x: number;
      public y: number;
      public is_detect: boolean;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class TeethInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public face_id: number;
      public teeth_pts: Vec2Vector;
      public face_count: number;
      public image_width: number;
      public image_height: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Script extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public scene: Scene;
      public handle: number;
      public addEventType(type: number): void;
      public removeEventType(type: number): void;
      public addAllEventType(): void;
      public clearAllEventType(): void;
      public addScriptListener(object: AObject, listenerType: number, funcName: string, scriptUserData: AObject): void;
      public removeScriptListener(object: AObject, listenerType: number, funcName: string, scriptUserData: AObject): void;
      public handleComponentName(compName: string): void;
      public handleNoComponent(): void;
      public handleAllComponent(): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class TextureOption extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public axis: Vector3f;
      public squareOrigin: Vector3f;
      public squareU: Vector3f;
      public squareV: Vector3f;
      public type: MeshUVType;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class FloatValueRandom extends FloatValue {
      constructor();
      public assetMgr: AssetManager;
      public minFloatValue: number;
      public maxFloatValue: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class FloatValue extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum PinOrientation {
      LOCAL,
      POSITION,
      POSITION_ORIENTATION,
    }
    namespace PinOrientation {
      let RTTI: RTTIDescriptor;
    }
    class MaterialPropertyBlock extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public setFloat(name: string, val: number): void;
      public setFloatVector(name: string, data: FloatVector): void;
      public setVec2Vector(name: string, data: Vec2Vector): void;
      public setVec3Vector(name: string, data: Vec3Vector): void;
      public setVec4Vector(name: string, data: Vec4Vector): void;
      public setVec4(name: string, vec4: Vector4f): void;
      public setMatrix(name: string, mat: Matrix4x4f): void;
      public setTexture(name: string, texture: Texture): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum AffectorTextureAnimationType {
      LOOP,
      UPDOWN,
      RANDOM,
      STOP,
    }
    namespace AffectorTextureAnimationType {
      let RTTI: RTTIDescriptor;
    }
    class CircleEmitter extends Emitter {
      constructor();
      public assetMgr: AssetManager;
      public position: Vector3f;
      public rotation: Quaternionf;
      public enable: boolean;
      public keepLocalParticles: boolean;
      public forceEmission: boolean;
      public useDurationTime: boolean;
      public angle: Value;
      public emissionRate: Value;
      public totalTimeToLive: Value;
      public duration: Value;
      public repeatDelay: Value;
      public particleMass: Value;
      public particleVelocity: Value;
      public particleColorList: Vec4Vector;
      public particleColor: Vector4f;
      public particleBurstsList: Vec2Vector;
      public orientationStart: Quaternionf;
      public orientationEnd: Quaternionf;
      public particleWidth: Value;
      public particleHeight: Value;
      public particleDepth: Value;
      public particleScale: Value;
      public particleSize: Value;
      public particleXRotation: Value;
      public particleYRotation: Value;
      public particleZRotation: Value;
      public particleXRotationSpeed: Value;
      public particleYRotationSpeed: Value;
      public particleZRotationSpeed: Value;
      public alignToDirection: boolean;
      public RandomDirection: Value;
      public SphereDirection: Value;
      public RandomPosition: Value;
      public distanceEmissionRate: Value;
      public radius: number;
      public inner_radius: number;
      public stepAngle: number;
      public useRandomAngle: boolean;
      public minAngle: number;
      public maxAngle: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class BoxEmitter extends Emitter {
      constructor();
      public assetMgr: AssetManager;
      public position: Vector3f;
      public rotation: Quaternionf;
      public enable: boolean;
      public keepLocalParticles: boolean;
      public forceEmission: boolean;
      public useDurationTime: boolean;
      public angle: Value;
      public emissionRate: Value;
      public totalTimeToLive: Value;
      public duration: Value;
      public repeatDelay: Value;
      public particleMass: Value;
      public particleVelocity: Value;
      public particleColorList: Vec4Vector;
      public particleColor: Vector4f;
      public particleBurstsList: Vec2Vector;
      public orientationStart: Quaternionf;
      public orientationEnd: Quaternionf;
      public particleWidth: Value;
      public particleHeight: Value;
      public particleDepth: Value;
      public particleScale: Value;
      public particleSize: Value;
      public particleXRotation: Value;
      public particleYRotation: Value;
      public particleZRotation: Value;
      public particleXRotationSpeed: Value;
      public particleYRotationSpeed: Value;
      public particleZRotationSpeed: Value;
      public alignToDirection: boolean;
      public RandomDirection: Value;
      public SphereDirection: Value;
      public RandomPosition: Value;
      public distanceEmissionRate: Value;
      public boxHeight: number;
      public boxWidth: number;
      public boxDepth: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class PointEmitter extends Emitter {
      constructor();
      public assetMgr: AssetManager;
      public position: Vector3f;
      public rotation: Quaternionf;
      public enable: boolean;
      public keepLocalParticles: boolean;
      public forceEmission: boolean;
      public useDurationTime: boolean;
      public angle: Value;
      public emissionRate: Value;
      public totalTimeToLive: Value;
      public duration: Value;
      public repeatDelay: Value;
      public particleMass: Value;
      public particleVelocity: Value;
      public particleColorList: Vec4Vector;
      public particleColor: Vector4f;
      public particleBurstsList: Vec2Vector;
      public orientationStart: Quaternionf;
      public orientationEnd: Quaternionf;
      public particleWidth: Value;
      public particleHeight: Value;
      public particleDepth: Value;
      public particleScale: Value;
      public particleSize: Value;
      public particleXRotation: Value;
      public particleYRotation: Value;
      public particleZRotation: Value;
      public particleXRotationSpeed: Value;
      public particleYRotationSpeed: Value;
      public particleZRotationSpeed: Value;
      public alignToDirection: boolean;
      public RandomDirection: Value;
      public SphereDirection: Value;
      public RandomPosition: Value;
      public distanceEmissionRate: Value;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class SphereEmitter extends Emitter {
      constructor();
      public assetMgr: AssetManager;
      public position: Vector3f;
      public rotation: Quaternionf;
      public enable: boolean;
      public keepLocalParticles: boolean;
      public forceEmission: boolean;
      public useDurationTime: boolean;
      public angle: Value;
      public emissionRate: Value;
      public totalTimeToLive: Value;
      public duration: Value;
      public repeatDelay: Value;
      public particleMass: Value;
      public particleVelocity: Value;
      public particleColorList: Vec4Vector;
      public particleColor: Vector4f;
      public particleBurstsList: Vec2Vector;
      public orientationStart: Quaternionf;
      public orientationEnd: Quaternionf;
      public particleWidth: Value;
      public particleHeight: Value;
      public particleDepth: Value;
      public particleScale: Value;
      public particleSize: Value;
      public particleXRotation: Value;
      public particleYRotation: Value;
      public particleZRotation: Value;
      public particleXRotationSpeed: Value;
      public particleYRotationSpeed: Value;
      public particleZRotationSpeed: Value;
      public alignToDirection: boolean;
      public RandomDirection: Value;
      public SphereDirection: Value;
      public RandomPosition: Value;
      public distanceEmissionRate: Value;
      public radius: number;
      public inner_radius: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ConeEmitter extends Emitter {
      constructor();
      public assetMgr: AssetManager;
      public position: Vector3f;
      public rotation: Quaternionf;
      public enable: boolean;
      public keepLocalParticles: boolean;
      public forceEmission: boolean;
      public useDurationTime: boolean;
      public angle: Value;
      public emissionRate: Value;
      public totalTimeToLive: Value;
      public duration: Value;
      public repeatDelay: Value;
      public particleMass: Value;
      public particleVelocity: Value;
      public particleColorList: Vec4Vector;
      public particleColor: Vector4f;
      public particleBurstsList: Vec2Vector;
      public orientationStart: Quaternionf;
      public orientationEnd: Quaternionf;
      public particleWidth: Value;
      public particleHeight: Value;
      public particleDepth: Value;
      public particleScale: Value;
      public particleSize: Value;
      public particleXRotation: Value;
      public particleYRotation: Value;
      public particleZRotation: Value;
      public particleXRotationSpeed: Value;
      public particleYRotationSpeed: Value;
      public particleZRotationSpeed: Value;
      public alignToDirection: boolean;
      public RandomDirection: Value;
      public SphereDirection: Value;
      public RandomPosition: Value;
      public distanceEmissionRate: Value;
      public radius: number;
      public coneAngle: number;
      public circleArc: number;
      public stepAngle: number;
      public emitFrom: ConeEmitterEmitFrom;
      public length: number;
      public useRandomAngle: boolean;
      public isAlignCone: boolean;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Emitter extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public position: Vector3f;
      public rotation: Quaternionf;
      public enable: boolean;
      public keepLocalParticles: boolean;
      public forceEmission: boolean;
      public useDurationTime: boolean;
      public angle: Value;
      public emissionRate: Value;
      public totalTimeToLive: Value;
      public duration: Value;
      public repeatDelay: Value;
      public particleMass: Value;
      public particleVelocity: Value;
      public particleColorList: Vec4Vector;
      public particleColor: Vector4f;
      public particleBurstsList: Vec2Vector;
      public orientationStart: Quaternionf;
      public orientationEnd: Quaternionf;
      public particleWidth: Value;
      public particleHeight: Value;
      public particleDepth: Value;
      public particleScale: Value;
      public particleSize: Value;
      public particleXRotation: Value;
      public particleYRotation: Value;
      public particleZRotation: Value;
      public particleXRotationSpeed: Value;
      public particleYRotationSpeed: Value;
      public particleZRotationSpeed: Value;
      public alignToDirection: boolean;
      public RandomDirection: Value;
      public SphereDirection: Value;
      public RandomPosition: Value;
      public distanceEmissionRate: Value;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class IbrDecoder extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public createIbrDecoder(dataDir: string): number;
      public updateIbrImage(lon: number, lat: number, ytex: Texture2D, utex: Texture2D, vtex: Texture2D): number;
      public updateIbrImageAlpha(lon: number, lat: number, ytex: Texture2D, utex: Texture2D, vtex: Texture2D, dtex: Texture2D): number;
      public destroy(): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum TrailTextureMode {
      Stretch,
      Distribute,
      DistributePerSegment,
      RepeatPerSegment,
    }
    namespace TrailTextureMode {
      let RTTI: RTTIDescriptor;
    }
    class BaseClip extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public blendWeight: number;
      public isRestoreOrigVal: boolean;
      public overrideOther: boolean;
      public initialBlendWeight: number;
      public handle: number;
      public getAttachedEntity(): Entity;
      public getTargetEntity(targetName: string): Entity;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ObjectDetection2InfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public rect: Rect;
      public prob: number;
      public IRLabel: number;
      public label: number;
      public objId: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum Primitive {
      POINTS,
      LINES,
      UNKOWN,
      LINE_LOOP,
      LINE_STRIP,
      TRIANGLES,
      TRIANGLE_STRIP,
      TRIANGLE_FAN,
    }
    namespace Primitive {
      let RTTI: RTTIDescriptor;
    }
    enum ParticleQuatRendererOrientationType {
      BILLBOARD,
      SHAPE,
      DIRECTION,
      FIXED,
    }
    namespace ParticleQuatRendererOrientationType {
      let RTTI: RTTIDescriptor;
    }
    enum VFXEventType {
      VFXOnPlay,
      VFXOnStop,
      VFXOnBurst,
    }
    namespace VFXEventType {
      let RTTI: RTTIDescriptor;
    }
    enum UniformType {
      REAL,
      VEC4,
      MAt4,
      VEC3_ARRAY,
      VEC4_ARRAY,
      VEC2,
      VEC3,
      MAT3,
      REAL_ARRAY,
      VEC2_ARRAY,
      SAMPLER,
    }
    namespace UniformType {
      let RTTI: RTTIDescriptor;
    }
    class AMGChar extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public utf8code: string;
      public initialPosition: Vector3f;
      public position: Vector3f;
      public rotate: Vector3f;
      public scale: Vector3f;
      public rowth: number;
      public idInRow: number;
      public width: number;
      public height: number;
      public anchor: Vector2f;
      public transparentRatio: number;
      public color: ProxyVector4f;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum LogicOp {
      CLEAR,
      EQUIVALENT,
      COPY_INVERTED,
      AND,
      COPY,
      AND_REVERSE,
      AND_INVERTED,
      NO_OP,
      XOR,
      OR_REVERSE,
      SET,
      OR,
      NOR,
      MAX_ENUM,
      INVERT,
      OR_INVERTED,
      NAND,
    }
    namespace LogicOp {
      let RTTI: RTTIDescriptor;
    }
    class NHImageInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public imageWidth: number;
      public imageHeight: number;
      public imageChannel: number;
      public step: number;
      public dataType: number;
      public image: Image;
      public floatData: FloatVector;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ClothGanInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public width: number;
      public height: number;
      public image_width: number;
      public image_height: number;
      public affineMatrix: Matrix4x4f;
      public image: Image;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class NHImageWithTfmInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public image: NHImageInfoInterface;
      public tfm: NHImageTransformInterface;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class AMGContactInfo extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public normal: Vector3f;
      public colliderId0: number;
      public colliderId1: number;
      public hitPoint0: Vector3f;
      public hitPoint1: Vector3f;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum ParticleSimulationSpace {
      LOCAL,
      WORLD,
      LOCAL_WITHOUT_PARENT_SCALE,
      WORLD_WITHOUT_PARENT_SCALE,
    }
    namespace ParticleSimulationSpace {
      let RTTI: RTTIDescriptor;
    }
    enum AffectorCollisionType {
      NONE,
      BOUNCE,
      FLOW,
      STOP,
    }
    namespace AffectorCollisionType {
      let RTTI: RTTIDescriptor;
    }
    class AMGAudioGraph extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public createAudioNode(type: string, config: Map): AMGAudioNode;
      public createAudioEffectNode(type: string, config: Map): AMGAudioNode;
      public createAudioExtractorNode(type: string, config: Map): AMGAudioNode;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class AMGAudioNodePout extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public connect(pin: AMGAudioNodePin): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum RenderTextureAttachment {
      DEPTH_STENCIL,
      STENCIL8,
      DEPTH16,
      NONE,
      DEPTH24,
      DEPTH,
      DEPTH24_STENCIL8,
    }
    namespace RenderTextureAttachment {
      let RTTI: RTTIDescriptor;
    }
    class Pass extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public shaders: Map;
      public semantics: Map;
      public renderTexture: RenderTexture;
      public clearColor: Color;
      public clearDepth: number;
      public clearType: CameraClearType;
      public renderState: RenderState;
      public useFBOTexture: boolean;
      public useCameraRT: boolean;
      public useFBOFetch: boolean;
      public isFullScreenShading: boolean;
      public macrosMap: Map;
      public preprocess: boolean;
      public passType: PassType;
      public keywordProgram: KeywordProgramProfile;
      public lightMode: LightMode;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum EntityOverrideType {
      Add,
      Modify,
    }
    namespace EntityOverrideType {
      let RTTI: RTTIDescriptor;
    }
    enum ObjectType {
      DET_RED,
      DET_DUMPLINGS,
      DET_FEAST,
    }
    namespace ObjectType {
      let RTTI: RTTIDescriptor;
    }
    enum TextAlign {
      LEFT,
      CENTER,
      RIGHT,
      DOWN,
      UP,
    }
    namespace TextAlign {
      let RTTI: RTTIDescriptor;
    }
    class FaceSmoothCPUInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public width: number;
      public height: number;
      public texture: Image;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ScriptableCullingParameters extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public useCulling: boolean;
      public shadowCasters: boolean;
      public shadowRendererDynamic: boolean;
      public handle: number;
      public getCullingPlane(planeIndex: number): Vector4f;
      public setCullingPlane(planeIndex: number, planeContent: Vector4f): void;
      public setLayersWithVector(vector: Vector): void;
      public getLayersWithVector(): Vector;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class AudioFeature extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public time: number;
      public duration: number;
      public values: Vector;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class PrefabManager extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public loadPrefab(path: string, name: string): Prefab;
      public loadPrefabAsync(path: string, name: string): AsyncLoadHandle;
      public getOrCreatePrefab(path: string, name: string): Prefab;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class JSWrapNodeContext extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public graphName: string;
      public handle: number;
      public getOutputMap(): Map;
      public getInputResult(): AEAlgorithmResult;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class AssetManager extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public rootDir: string;
      public handle: number;
      public SyncLoad(uri: string): AObject;
      public getAllScriptCustomAssets(): Map;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class EffectTextParam extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public version: number;
      public textColor: Color;
      public outlineMaxWidth: number;
      public randomGridSize: Vector2f;
      public effectLayers: Vector;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class SlamHitResultInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class InputSettings extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class GradientChange extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public scale: number;
      public angle: number;
      public gradient_type: GradientType;
      public color1: ColorChange;
      public percent1_2: number;
      public color2: ColorChange;
      public percent2_3: number;
      public color3: ColorChange;
      public linear: boolean;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class CatFaceInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public rect: Rect;
      public score: number;
      public points_array: Vec2Vector;
      public yaw: number;
      public pitch: number;
      public roll: number;
      public ID: number;
      public action: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum IFSprite2dSizeMode {
      Custom,
      Image,
    }
    namespace IFSprite2dSizeMode {
      let RTTI: RTTIDescriptor;
    }
    enum GradientType {
      OVERALL_GRADIENT,
      WORD_GRADIENT,
    }
    namespace GradientType {
      let RTTI: RTTIDescriptor;
    }
    enum MeshCenter {
      Baseline,
      Center,
    }
    namespace MeshCenter {
      let RTTI: RTTIDescriptor;
    }
    class AnimazClipInfo extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public clipName: string;
      public animation: Animaz;
      public startTime: number;
      public endTime: number;
      public initialBlendWeight: number;
      public wrapMode: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum MeshNormal {
      Side,
      Smooth,
      Face,
    }
    namespace MeshNormal {
      let RTTI: RTTIDescriptor;
    }
    enum ContextType {
      AMGNone,
      AMGSpawnerGPU,
      AMGOutput,
      AMGEvent,
      AMGTriangleOutput,
      AMGUpdate,
      AMGInitStrip,
      AMGPointOutput,
      AMGInit,
      AMGSpawner,
      AMGQuadOutput,
      AMGStrip,
      AMGQuad,
      AMGTriangle,
      AMGPoint,
      AMGMesh,
      AMGUpdateStrip,
      AMGStripQuadOutput,
      AMGMeshOutput,
      AMGQuadInstancingOutput,
    }
    namespace ContextType {
      let RTTI: RTTIDescriptor;
    }
    enum IFUIControlState {
      Normal,
      Pressed,
      Disabled,
    }
    namespace IFUIControlState {
      let RTTI: RTTIDescriptor;
    }
    enum AnimatorCullingMode {
      ALWAYS_ANIMATE,
      CULL_UPDATE_PROPERTY,
      CULL_COMPLETELY,
    }
    namespace AnimatorCullingMode {
      let RTTI: RTTIDescriptor;
    }
    class Animaz extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public duration: number;
      public startTime: number;
      public endTime: number;
      public tracks: Vector;
      public timeType: AnimTimeType;
      public handle: number;
      public getTrack(name: string): AnimazTrack;
      public getOrCreateClip(id: string, begin: number, end: number, animator: Animator): AnimazClip;
      public getClip(id: string, animator: Animator): AnimazClip;
      public playClipByName(clipId: string, animator: Animator, wrapMode: number, speed: number): void;
      public pauseClipByName(clipId: string, animator: Animator): void;
      public stopClipByName(clipId: string, animator: Animator): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ComponentOverride extends PrefabOverride {
      constructor();
      public assetMgr: AssetManager;
      public overrideObjectGuid: Guid;
      public componentOverrideType: ComponentOverrideType;
      public addComponent: Component;
      public modifyProperties: Map;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class EntityOverride extends PrefabOverride {
      constructor();
      public assetMgr: AssetManager;
      public overrideObjectGuid: Guid;
      public entityOverrideType: EntityOverrideType;
      public addEntity: Entity;
      public modifyProperties: Map;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class PrefabInstanceOverride extends PrefabOverride {
      constructor();
      public assetMgr: AssetManager;
      public overrideObjectGuid: Guid;
      public addPrefabInstance: PrefabInstance;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class PrefabOverride extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public overrideObjectGuid: Guid;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class SlamTouchInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public worldTransform: Matrix4x4f;
      public touchDirty: boolean;
      public touchX: number;
      public touchY: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Vec2ValueCurved extends Vec2Value {
      constructor();
      public assetMgr: AssetManager;
      public iType: ValueCurveInterpolationType;
      public cpList: Vector;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Vec2Value extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class AnimLayer extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public states: Vector;
      public layerType: LayerType;
      public blendWeight: number;
      public autoPlay: boolean;
      public layerMask: AnimLayerMask;
      public defaultStartState: AnimState;
      public currentState: AnimState;
      public handle: number;
      public createAnimationState(name: string, isTemporary: boolean): AnimState;
      public getAnimationState(name: string): AnimState;
      public play(state: AnimState, fadeTime: number, createTransition: boolean): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ActionRecognitionInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public isValid: boolean;
      public actionLabel: number;
      public actionScore: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum InterpolationType {
      BEZIER,
      LINEAR,
      LINEAR_BEZIER,
      FLOOR,
      BEZIER_BEZIER,
      BSPLINE,
      BEZIER_LINEAR,
      HERMITE_FLAT,
      ROUND,
      HERMITE,
      IMMEDIATE,
      CEIL,
    }
    namespace InterpolationType {
      let RTTI: RTTIDescriptor;
    }
    class ManipulateResult extends AlgorithmResultEvent {
      constructor();
      public assetMgr: AssetManager;
      public eventType: BEFEventType;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class StickerDownloadTask extends DownloadTask {
      constructor();
      public assetMgr: AssetManager;
      public status: JsDownloadStatus;
      public success: boolean;
      public errCode: number;
      public errString: string;
      public stickerId: string;
      public path: string;
      public progress: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class JSWrapNetworkListener extends NetworkListener {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public addScriptListener(listenerType: number, script: JSScript, funcName: string, scriptUserData: AObject): void;
      public removeScriptListener(listenerType: number, script: JSScript, funcName: string, scriptUserData: AObject): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class NetworkListener extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum IFPseudo3DType {
      None,
      Horizontal,
      Vertical,
      HorizontalAndVertical,
    }
    namespace IFPseudo3DType {
      let RTTI: RTTIDescriptor;
    }
    class AnimSeq extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public assettype: SeqAssetType;
      public assetfilename: string;
      public fps: number;
      public lazyload: boolean;
      public cache: boolean;
      public atlases: Vector;
      public memoryLimit: number;
      public preload: boolean;
      public indexAction: Map;
      public preloadCount: number;
      public handle: number;
      public getFrameCount(): number;
      public onLoadEnd(): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class SlamCircleInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public hasEllipse: boolean;
      public ID: number;
      public radius: number;
      public position: Vector3f;
      public normal: Vector3f;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Variant {
      constructor();
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum BEF_CAPTURE_EVENT_CODE {
      CAPTURE_NO_INIT,
      CAPTURE_ONCE,
    }
    namespace BEF_CAPTURE_EVENT_CODE {
      let RTTI: RTTIDescriptor;
    }
    enum PlayMode {
      once,
      loop,
      pingpong,
      random,
    }
    namespace PlayMode {
      let RTTI: RTTIDescriptor;
    }
    class SkeletonInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public ID: number;
      public rect: Rect;
      public key_points_xy: Vec2Vector;
      public key_points_detected: UInt8Vector;
      public key_points_score: FloatVector;
      public orientation: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class AnimSeqKeyInfo extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public type: AnimSeqEventType;
      public animSeqCom: AnimSeqComponent;
      public keyIndex: number;
      public keyName: string;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class FaceMaskInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public image: Image;
      public alpha: UInt8Vector;
      public bboxes: Rect;
      public kpts: Vec2Vector;
      public kpts3D: Vec3Vector;
      public mask_count: number;
      public width: number;
      public height: number;
      public rotation: Vec3Vector;
      public translate: Vec3Vector;
      public rotationStatus: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class TextureCache extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public setTexture(tex: Texture, arg1: number, arg2: number, arg3: number, arg4: number): boolean;
      public getTexture(arg0: boolean): Texture;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum AnimSeqEventType {
      ANIMSEQ_START,
      ANIMSEQ_ACTIONINDEX,
      ANIMSEQ_END,
      ANIMSEQ_WHOLE_START,
      ANIMSEQ_WHOLE_END,
    }
    namespace AnimSeqEventType {
      let RTTI: RTTIDescriptor;
    }
    enum ValueCurvedInterpolationType {
      LINEAR,
      SPLINE,
      CATMULL,
    }
    namespace ValueCurvedInterpolationType {
      let RTTI: RTTIDescriptor;
    }
    class SaliencySegInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public realW: number;
      public realH: number;
      public bboxcenterX: number;
      public bboxcenterY: number;
      public bboxwidth: number;
      public bboxheight: number;
      public bboxrotateAngle: number;
      public modelIndex: number;
      public mask: Image;
      public input: Image;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Rgbd2MeshInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public texture: UInt8Vector;
      public width: number;
      public height: number;
      public vertex: FloatVector;
      public v_len: number;
      public indices: UInt16Vector;
      public i_len: number;
      public mesh_score: number;
      public mask_image: Image;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class VideoAnimSeqKeyInfo extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public type: AnimSeqEventType;
      public animSeqCom: VideoAnimSeq;
      public keyIndex: number;
      public keyName: string;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class NetworkListenerWS extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum StretchMode {
      fit,
      fill_cut,
      fill,
      stretch,
      fit_height,
      fit_width,
      texture_size,
    }
    namespace StretchMode {
      let RTTI: RTTIDescriptor;
    }
    enum SeqAssetType {
      atlas,
      gif,
      mp4,
    }
    namespace SeqAssetType {
      let RTTI: RTTIDescriptor;
    }
    enum FluidStepType {
      Sphere,
      Cube,
    }
    namespace FluidStepType {
      let RTTI: RTTIDescriptor;
    }
    class MorpherChannel extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public targets: Vector;
      public handle: number;
      public getMorpherTargetsCount(): number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class FlipbookProvider extends ImageProvider {
      constructor();
      public assetMgr: AssetManager;
      public imagesUri: Vector;
      public rows: number;
      public cols: number;
      public handle: number;
      public setImageUri(uri: string): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum PrefabStatus {
      INIT,
      LOADING,
      LOADED,
      ERROR,
      NO_EXIST,
    }
    namespace PrefabStatus {
      let RTTI: RTTIDescriptor;
    }
    class AsyncLoadHandle extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public getObject(): AObject;
      public getState(): AsyncLoadState;
      public cancelHandle(): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum VFXProfileEvent {
      PROFILE_DIRTY,
    }
    namespace VFXProfileEvent {
      let RTTI: RTTIDescriptor;
    }
    enum PrefabOverrideType {
      None,
      ComponentOverride,
      EntityOverride,
      PrefabInstanceOverride,
    }
    namespace PrefabOverrideType {
      let RTTI: RTTIDescriptor;
    }
    class NetworkCenterWS extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public connect(listener: NetworkListenerWS, url: string): number;
      public disconnect(wsid: number): boolean;
      public isConnected(wsid: number): boolean;
      public sendMessage(wsid: number, msg: string): boolean;
      public sendBinaryMessage(wsid: number, msg: UInt8Vector): boolean;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum CubeMapTexType {
      POSITIVE_X,
      NEGATIVE_Z,
      NEGATIVE_X,
      POSITIVE_Y,
      NEGATIVE_Y,
      POSITIVE_Z,
    }
    namespace CubeMapTexType {
      let RTTI: RTTIDescriptor;
    }
    class CubeImageProvider extends ImageProvider {
      constructor();
      public assetMgr: AssetManager;
      public imagesUri: Vector;
      public handle: number;
      public setImageUri(texType: CubeMapTexType, uri: string): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class LatLongImageProvider extends ImageProvider {
      constructor();
      public assetMgr: AssetManager;
      public imagesUri: Vector;
      public handle: number;
      public setImageUri(uri: string): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class VFProvider extends ImageProvider {
      constructor();
      public assetMgr: AssetManager;
      public imagesUri: Vector;
      public handle: number;
      public setImageUri(uri: string): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ImageProvider extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public imagesUri: Vector;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class SceneRecogV3InfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public id: number;
      public confidence: number;
      public thres: number;
      public satisfied: boolean;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum CameraEvent {
      AFTER_FORWARD_OPAQUE,
      AFTER_RENDER,
      RENDER_IMAGE_EFFECTS,
      AFTER_EVERYTHING,
      BEFORE_FORWARD_ALPHA,
      BEFORE_FORWARD_OPAQUE,
      BEFORE_RENDER,
      AFTER_IMAGE_EFFECTS,
      AFTER_FORWARD_ALPHA,
    }
    namespace CameraEvent {
      let RTTI: RTTIDescriptor;
    }
    enum SampleCountFlagBits {
      BIT_1,
      BIT_16,
      BIT_2,
      BIT_4,
      BIT_8,
      BIT_32,
      BIT_64,
      BITS_MAX,
    }
    namespace SampleCountFlagBits {
      let RTTI: RTTIDescriptor;
    }
    enum ColorMask {
      R,
      G,
      B,
      A,
    }
    namespace ColorMask {
      let RTTI: RTTIDescriptor;
    }
    class ScissorState extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public rect: Rect;
      public rectName: string;
      public portValueType: PortValueType;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class JSWrapBachAlg extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum EventType {
      TOUCH,
      PAN,
      GEOMETRY,
      RCVALUE_CHANGE,
      VIEWER,
      SENSOR,
      ROTATION,
      CLICK,
      SCALE,
      AR_ANCHOR,
      COLLISION3D,
      MOUSE,
      TOUCH_DEPRECATED,
      KEYBOARD,
      TRACKER,
      TOUCH_MANIPULATE,
      COLLISION,
      TOUCH_UI,
    }
    namespace EventType {
      let RTTI: RTTIDescriptor;
    }
    enum MeshUVType {
      Planar,
      Square,
      Spherical,
    }
    namespace MeshUVType {
      let RTTI: RTTIDescriptor;
    }
    enum SensorEventType {
      GYRO,
    }
    namespace SensorEventType {
      let RTTI: RTTIDescriptor;
    }
    enum CollisionEventType {
      BEGIN_COLLISION,
      END_COLLISION,
      PRE_SOLVE,
      POST_SOLVE,
    }
    namespace CollisionEventType {
      let RTTI: RTTIDescriptor;
    }
    class PrefabLoader extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public getStatus(prefabPath: string): PrefabStatus;
      public get(prefabPath: string): Prefab;
      public remove(prefabPath: string): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum PortValueType {
      NONE,
      PERCENT,
      PIXEL,
    }
    namespace PortValueType {
      let RTTI: RTTIDescriptor;
    }
    class Shader extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public type: ShaderType;
      public sourcePath: string;
      public macros: StringVector;
      public source: string;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ExternalRef {
      constructor();
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum ViewerEventType {}
    namespace ViewerEventType {
      let RTTI: RTTIDescriptor;
    }
    enum TouchEventType {
      BEGAN,
      MOVED,
      CANCELED,
      ENDED,
    }
    namespace TouchEventType {
      let RTTI: RTTIDescriptor;
    }
    enum NetworkStatus {
      NETWORK_START,
      NETWORK_UPDATE,
      NETWORK_SUCCESS,
      NETWORK_FAIL,
      NETWORK_CANCEL,
    }
    namespace NetworkStatus {
      let RTTI: RTTIDescriptor;
    }
    class SceneRecogInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public prob: number;
      public satisfied: boolean;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum LightProbeBlendMode {
      OFF,
      BLEND_PROBES,
    }
    namespace LightProbeBlendMode {
      let RTTI: RTTIDescriptor;
    }
    class NetworkWSStateChanged extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public url: string;
      public state: number;
      public wsid: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Texture3D extends Texture {
      constructor();
      public assetMgr: AssetManager;
      public width: number;
      public height: number;
      public depth: number;
      public internalFormat: InternalFormat;
      public dataType: DataType;
      public builtinType: BuiltInTextureType;
      public enableMipmap: boolean;
      public filterMin: FilterMode;
      public filterMag: FilterMode;
      public filterMipmap: FilterMipmapMode;
      public wrapModeS: WrapMode;
      public wrapModeT: WrapMode;
      public wrapModeR: WrapMode;
      public maxAnisotropy: number;
      public image: Image;
      public tex3DProvider: ImageProvider;
      public handle: number;
      public storage(image: Image): void;
      public getImage(): Image;
      public setPixels(pixels: Vector): void;
      public getPixel(x: number, y: number, z: number): Vector4f;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class DrawTexture extends Texture {
      constructor();
      public assetMgr: AssetManager;
      public width: number;
      public height: number;
      public depth: number;
      public internalFormat: InternalFormat;
      public dataType: DataType;
      public builtinType: BuiltInTextureType;
      public enableMipmap: boolean;
      public filterMin: FilterMode;
      public filterMag: FilterMode;
      public filterMipmap: FilterMipmapMode;
      public wrapModeS: WrapMode;
      public wrapModeT: WrapMode;
      public wrapModeR: WrapMode;
      public maxAnisotropy: number;
      public colorFormat: PixelFormat;
      public realColorFormat: PixelFormat;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Texture extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public width: number;
      public height: number;
      public depth: number;
      public internalFormat: InternalFormat;
      public dataType: DataType;
      public builtinType: BuiltInTextureType;
      public enableMipmap: boolean;
      public filterMin: FilterMode;
      public filterMag: FilterMode;
      public filterMipmap: FilterMipmapMode;
      public wrapModeS: WrapMode;
      public wrapModeT: WrapMode;
      public wrapModeR: WrapMode;
      public maxAnisotropy: number;
      public handle: number;
      public getImage(): Image;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class NetworkWSError extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public url: string;
      public error: string;
      public state: number;
      public wsid: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class NetworkWSMessage extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public message: string;
      public size: number;
      public wsid: number;
      public binaryMessage: UInt8Vector;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum RenderPipelineType {
      BUILD,
      LUASRP,
      JSSRP,
    }
    namespace RenderPipelineType {
      let RTTI: RTTIDescriptor;
    }
    class DrawingSettings extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public overrideMaterial: Material;
      public overrideMaterialPassIndex: number;
      public sortingSettings: SortingSettings;
      public isSpecShaderPass: boolean;
      public shaderPassName: string;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class SortingType extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public renderQueue: boolean;
      public backToFront: boolean;
      public frontToBack: boolean;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class NailKeyPointInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public nailRect: Rect;
      public kpts: Vec2Vector;
      public cls: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class RenderQueueRange extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public lowerBound: number;
      public upperBound: number;
      public all: RenderQueueRange;
      public transparent: RenderQueueRange;
      public opaque: RenderQueueRange;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class FilteringSettings extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public renderQueueRange: RenderQueueRange;
      public enableRenderLayers: boolean;
      public editorOnlyFlag: boolean;
      public handle: number;
      public setLayersWithVector(vector: Vector): void;
      public getLayersWithVector(): Vector;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class MorpherTarget extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public fullweight: number;
      public indices: UInt16Vector;
      public offsetdata: FloatVector;
      public vertexAttribs: Vector;
      public handle: number;
      public getCtrlPointsCount(): number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ScriptRenderContext extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public attachScene: Scene;
      public isEditView: boolean;
      public handle: number;
      public setRenderTarget(targetRT: RenderTexture): void;
      public setRenderTargetWithSlice(targetRT: RenderTextureArray, slice: number): void;
      public clearRenderTarget(isClearColor: boolean, isClearDepth: boolean, clearColor: Color, clearDepth: number): void;
      public setViewport(viewport: Rect): void;
      public setGlobalFloat(value: string, arg1: number): void;
      public setGlobalVector4f(arg0: string, arg1: Vector4f): void;
      public setGlobalMatrix(arg0: string, arg1: Matrix4x4f): void;
      public setGlobalTexture2D(arg0: string, arg1: Texture2D): void;
      public setGlobalRenderTexture(arg0: string, arg1: RenderTexture): void;
      public setGlobalInt(arg0: string, arg1: number): void;
      public cull(cullParams: ScriptableCullingParameters): CullingResults;
      public drawRenderers(cullingResults: CullingResults, drawingSettings: DrawingSettings, filteringSettings: FilteringSettings): void;
      public drawRenderersWithState(cullingResults: CullingResults, drawingSettings: DrawingSettings, filteringSettings: FilteringSettings, srpRenderSateBlock: RenderState): void;
      public setupCameraProperties(camera: Camera): void;
      public execute(arg0: CommandBuffer): void;
      public submit(): void;
      public blit(src: Texture, dest: RenderTexture): void;
      public blitWithMaterial(src: Texture, dest: RenderTexture, material: Material, shaderPass: number): void;
      public blitWithMaterialAndProperties(src: Texture, dest: RenderTexture, material: Material, shaderPass: number, properties: MaterialPropertyBlock): void;
      public beginPassScope(passName: string): void;
      public endPassScope(): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Rectangle extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public left: number;
      public right: number;
      public top: number;
      public bottom: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum RenderCacheEventType {
      RC_TYPE_NONE,
      RC_TYPE_STRING,
      RC_TYPE_TEXTURE,
    }
    namespace RenderCacheEventType {
      let RTTI: RTTIDescriptor;
    }
    enum RenderCacheStatus {
      RC_STATUS_NONE,
      RC_STATUS_MODITY,
      RC_STATUS_REMOVE,
    }
    namespace RenderCacheStatus {
      let RTTI: RTTIDescriptor;
    }
    enum PhysicsDriverStatus {
      EDIT,
      RUN,
      STOP,
    }
    namespace PhysicsDriverStatus {
      let RTTI: RTTIDescriptor;
    }
    enum IFUILabelFontType {
      System,
      TrueType,
      SystemV2,
      Bitmap,
    }
    namespace IFUILabelFontType {
      let RTTI: RTTIDescriptor;
    }
    class PhysicsMaterial extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public staticFriction: number;
      public dynamicFriction: number;
      public bounciness: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class FaceReshapeLiquefyParams extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public params: string;
      public withMask: boolean;
      public use_yaw_corr: boolean;
      public low_corr_yaw_value: number;
      public high_corr_yaw_value: number;
      public narrow_face_scale: number;
      public widen_face_scale: number;
      public high_scale: number;
      public mesh_cache_enable: boolean;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum TimeInterpolateType {
      NO,
      INTERPOLATE,
      EXTRAPOLATE,
    }
    namespace TimeInterpolateType {
      let RTTI: RTTIDescriptor;
    }
    class AMGPbdSimulator extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public setNumSubsteps(numSubSteps: number): void;
      public setNumPositionSolveIterations(numIterations: number): void;
      public setNumVelocitySolveIterationsForContact(numIterations: number): void;
      public setGravityAcceleration(gravityAccel: Vector3f): void;
      public setRigidBodyInitialVelocity(bodyId: number, initialVelocity: Vector3f): void;
      public setRigidBodyRestitutionCoef(bodyId: number, restitutionCoef: number): void;
      public setRigidBodyDynamicFrictionCoef(bodyId: number, dynamicFrictionCoef: number): void;
      public step(deltaTime: number): void;
      public addRigidBody(mass: number, inertiaTensorDiagonalAtRest: Vector3f, restPos: Vector3f, restOrientation: Quaternionf, initialVelocity: Vector3f, initialAngularVelocity: Vector3f, linearDampingCoef: number, rotationalDampingCoef: number): number;
      public addRigidBodyWithEntity(mass: number, inertiaTensorDiagonalAtRest: Vector3f, entity: Entity, initialVelocity: Vector3f, initialAngularVelocity: Vector3f, linearDampingCoef: number, rotationalDampingCoef: number): number;
      public removeRigidBody(bodyId: number): void;
      public getRigidBodyPosition(bodyId: number): Vector3f;
      public getRigidBodyOrientation(bodyId: number): Quaternionf;
      public setRigidBodyRestTransformFromEntity(bodyId: number): void;
      public fetchRigidBodyRestTransformFromEntity(): void;
      public pushRigidBodyTransformToEntity(): void;
      public addBoxCollider(boxHalfExtent: Vector3f, attachedRigidBodyIndex: number, localScaling: Vector3f, groupBits: number, maskBits: number): number;
      public addSphereCollider(radius: number, attachedRigidBodyIndex: number, localScaling: Vector3f, groupBits: number, maskBits: number): number;
      public addCapsuleCollider(radius: number, height: number, attachedRigidBodyIndex: number, localScaling: Vector3f, groupBits: number, maskBits: number): number;
      public removeCollider(colliderId: number): void;
      public removeConstraint(constraintId: number): void;
      public enableBodyKinematic(bodyId: number): void;
      public disableBodyKinematic(bodyId: number): void;
      public addDistanceJoint(objectA: number, isParticleA: boolean, globalPosA: Vector3f, objectB: number, isParticleB: boolean, globalPosB: Vector3f, distanceJointCoef: Vector3f, restLength: number): number;
      public setDistanceJointRestLength(constraintId: number, restLength: number): void;
      public setDistanceJointConnectorLocalPos(constraintId: number, localPosA: Vector3f, localPosB: Vector3f): void;
      public addFixedJoint(objectA: number, objectB: number, compliance: number, dampingCoef: number): number;
      public addHingeJoint(objectA: number, objectB: number, hingeAxis: number, angleDegMin: number, angleDegMax: number, compliance: number, dampingCoef: number): number;
      public setHingeJointAngleLimits(constraintId: number, degreeMin: number, degreeMax: number, axis: number): void;
      public addAnisotropicSphericalJoint(objectA: number, objectB: number, degreeMin: Vector3f, degreeMax: Vector3f, compliance: number, dampingCoef: number, twistAxis: number): number;
      public addSphericalJoint(objectA: number, objectB: number, degree: Vector3f, compliance: number, dampingCoef: number, twistAxis: number, separateTwist: boolean): number;
      public setSphericalJointAngleLimit(constraintId: number, swingDegree: number, twistDegreeMin: number, twistDegreeMax: number, twistAxis: number): void;
      public setRigidBodyPosition(index: number, globalPos: Vector3f): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class AMGCollisionFinder extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public addBoxCollider(halfExtent: Vector3f, colliderOrigin: Vector3f, colliderOrientation: Quaternionf, localScaling: Vector3f, categoryBits: number, maskBits: number): number;
      public addBoxColliderWithEntity(entity: Entity, halfExtent: Vector3f, categoryBits: number, maskBits: number): number;
      public addSphereCollider(radius: number, colliderOrigin: Vector3f, colliderOrientation: Quaternionf, localScaling: Vector3f, categoryBits: number, maskBits: number): number;
      public addSphereColliderWithEntity(entity: Entity, radius: number, categoryBits: number, maskBits: number): number;
      public addCapsuleCollider(radius: number, height: number, colliderOrigin: Vector3f, colliderOrientation: Quaternionf, localScaling: Vector3f, categoryBits: number, maskBits: number): number;
      public addCapsuleColliderWithEntity(entity: Entity, radius: number, height: number, categoryBits: number, maskBits: number): number;
      public setColliderTransform(cid: number, origin: Vector3f, orientation: Quaternionf, localScaling: Vector3f): void;
      public setColliderTransformFromEntity(cid: number): void;
      public updateAllColliderTransformFromEntities(): void;
      public getAABB(cid: number): AABB;
      public removeCollider(cid: number): void;
      public doCollisionDetection(): void;
      public contactCount(): number;
      public getContactInfoList(contactInfoList: Vector): void;
      public rayTestClosestHit(origin: Vector3f, dir: Vector3f, maxDistance: number, collisionFilterMask: number, rayHitInfo: AMGRayHitInfo): boolean;
      public rayTestAllHits(origin: Vector3f, dir: Vector3f, maxDistance: number, collisionFilterMask: number): void;
      public rayHitCount(): number;
      public getRayHitInfoList(rayHitInfoList: Vector): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum PixelFormat {
      RGB8Snorm,
      RGB10A2Uscaled,
      BGR8Snorm,
      LA8Unorm,
      R5G6B5Unorm,
      BC4_RUnorm,
      RGB16Sint,
      PVRTC1_RGBA_4BPP,
      RG16Uscaled,
      RGB8Uint,
      A1RGB5Unorm,
      ASTC_4x4_LDR,
      ASTC_5x5_sRGB,
      BGRA8_sRGB,
      BGRA8Snorm,
      BGR8Uscaled,
      ASTC_5x4_LDR,
      RGB8_sRGB,
      R16Sscaled,
      R16Sint,
      BGR8Sint,
      EAC_RG11Unorm,
      A8Unorm,
      R8Sint,
      ETC2_RGB8A1Unorm,
      RGBA16Unorm,
      BC2_RGBAUnorm,
      ETC2_RGB8_sRGB,
      A1BGR5Unorm,
      RGBA16Uscaled,
      BGRA8Sscaled,
      R8Uscaleld,
      B5G6R5Unorm,
      L8Unorm,
      ASTC_8x8_LDR,
      PVRTC1_RGB_2BPP_sRGB,
      R8Sscaled,
      RGB8Uscaled,
      RGB10A2Sint,
      RG8Snorm,
      BGR10A2Uint,
      R8_sRGB,
      RG8Uscaled,
      BC1_RGBAUnorm,
      RGB10A2Unorm,
      RGBA8Uint,
      RGBA64Uint,
      BGRA4Unorm,
      BC6H_RGBSfloat,
      RG8Uint,
      BGR5A1Unorm,
      ARGB4Unorm,
      RG8Sint,
      RGB8Unorm,
      BGR8Unorm,
      R64Sint,
      D24X8Unorm,
      BGR8Sscaled,
      RGBA8Uscaled,
      RGBA8Sscaled,
      R16Unorm,
      RGBA8Unorm,
      RGBA8Sint,
      RGBA64Sint,
      D32Sfloat,
      RGBA8_sRGB,
      Invalid,
      ABGR8Uscaled,
      D32SfloatS8Uint,
      RGBA8Snorm,
      ASTC_6x6_sRGB,
      BGRA8Uscaled,
      RGB8Sscaled,
      ETC1_RGB8Unorm,
      BGRA8Uint,
      BGRA8Sint,
      ABGR8Snorm,
      ABGR8Sscaled,
      R16Snorm,
      ASTC_10x10_sRGB,
      R16Sfloat,
      PVRTC2_RGBA_2BPP,
      ABGR8Uint,
      RGB5A1Unorm,
      ABGR8Sint,
      BC7_RGBAUnorm,
      R8Unorm,
      ETC2_RGBA8Unorm,
      RG8Unorm,
      BGR10A2Unorm,
      ASTC_12x12_LDR,
      BGR10A2Snorm,
      ASTC_12x10_LDR,
      BGR10A2Uscaled,
      BGR8Uint,
      RGB32Sfloat,
      RGB10A2Uint,
      R32Sint,
      BC7_RGBAUnorm_sRGB,
      R8Uint,
      ASTC_8x5_sRGB,
      R16Uint,
      RG8Sscaled,
      RG16Snorm,
      RGB16Unorm,
      RGB8Sint,
      RG16Sscaled,
      RG16Uint,
      RGB16Uscaled,
      RG16Sfloat,
      RGB16Snorm,
      ASTC_8x6_LDR,
      RGB16Uint,
      RGBA16Snorm,
      ASTC_10x6_sRGB,
      RGBA16Uint,
      RGB10A2Sscaled,
      BGR10A2Sint,
      ASTC_4x4_sRGB,
      RGBA4Unorm,
      RGBA16Sint,
      BC6H_RGBUfloat,
      D24UnormS8Uint,
      RG32Sint,
      ASTC_6x6_LDR,
      R32Uint,
      RG32Sfloat,
      R32Sfloat,
      ASTC_10x6_LDR,
      ABGR8_sRGB,
      RG32Uint,
      BGR8_sRGB,
      RGB32Uint,
      RGB32Sint,
      RGBA32Uint,
      RGBA32Sint,
      PVRTC2_RGBA_4BPP,
      RGBA32Sfloat,
      R64Uint,
      D16UnormS8Uint,
      ASTC_5x4_sRGB,
      R64Sfloat,
      BGR10A2Sscaled,
      RG64Uint,
      S8Uint,
      ASTC_8x6_sRGB,
      RG16Sint,
      RGB64Sint,
      ABGR4Unorm,
      RGBA64Sfloat,
      RG11B10Ufloat,
      ETC2_RGB8Unorm,
      RGB9E5Ufloat,
      D16Unorm,
      RG64Sint,
      BC1_RGBUnorm,
      BC1_RGB_sRGB,
      BC1_RGBA_sRGB,
      RG64Sfloat,
      ASTC_10x5_LDR,
      BC2_RGBA_sRGB,
      BC3_RGBAUnorm,
      R16Uscaleld,
      ASTC_10x10_LDR,
      RGB64Sfloat,
      BC3_RGBA_sRGB,
      RGB16Sfloat,
      BC4_RSnorm,
      BC5_RGUnorm,
      BC5_RGSnorm,
      ETC2_RGB8A1_sRGB,
      ABGR8Unorm,
      ETC2_RGBA8_sRGB,
      RG16Unorm,
      RG8_sRGB,
      EAC_R11Unorm,
      GR4Unorm,
      EAC_R11Snorm,
      EAC_RG11Snorm,
      ASTC_5x5_LDR,
      RGBA16Sfloat,
      RGBA16Sscaled,
      ASTC_6x5_LDR,
      R8Snorm,
      ASTC_10x5_sRGB,
      ASTC_8x5_LDR,
      ASTC_8x8_sRGB,
      ASTC_10x8_LDR,
      RGB16Sscaled,
      ASTC_10x8_sRGB,
      ASTC_12x10_sRGB,
      RGB10A2Snorm,
      ASTC_12x12_sRGB,
      BGRA8Unorm,
      PVRTC2_RGBA_4BPP_sRGB,
      PVRTC1_RGB_2BPP,
      PVRTC1_RGB_4BPP,
      PVRTC1_RGBA_2BPP,
      ASTC_6x5_sRGB,
      PVRTC1_RGB_4BPP_sRGB,
      PVRTC1_RGBA_2BPP_sRGB,
      PVRTC1_RGBA_4BPP_sRGB,
      PVRTC2_RGBA_2BPP_sRGB,
    }
    namespace PixelFormat {
      let RTTI: RTTIDescriptor;
    }
    enum AssetPlatform {
      default,
      web,
      windows,
      mac,
      android,
      ios,
      linux,
    }
    namespace AssetPlatform {
      let RTTI: RTTIDescriptor;
    }
    class AMGRayHitInfo extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public colliderId: number;
      public hitPoint: Vector3f;
      public hitNormal: Vector3f;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum MeshCurve {
      Adaptive,
      Uniform,
    }
    namespace MeshCurve {
      let RTTI: RTTIDescriptor;
    }
    class MemojiMatchEmbeddingInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum ExclusiveType {
      ALL,
      ONLY_EXCLUDED,
    }
    namespace ExclusiveType {
      let RTTI: RTTIDescriptor;
    }
    class GazeEstimationInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public face_id: number;
      public valid: boolean;
      public head_r: FloatVector;
      public head_t: FloatVector;
      public leye_pos: FloatVector;
      public reye_pos: FloatVector;
      public leye_gaze: FloatVector;
      public reye_gaze: FloatVector;
      public mid_gaze: FloatVector;
      public leye_pos2d: FloatVector;
      public reye_pos2d: FloatVector;
      public leye_gaze2d: FloatVector;
      public reye_gaze2d: FloatVector;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class HandMaskInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public mask: UInt8Vector;
      public mask_width: number;
      public mask_height: number;
      public mask_image: Image;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class OilPaintInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public width: number;
      public height: number;
      public mask: UInt8Vector;
      public mask_image: Image;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Face106Interface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public rect: Rect;
      public score: number;
      public points_array: Vec2Vector;
      public visibility_array: FloatVector;
      public yaw: number;
      public pitch: number;
      public roll: number;
      public eye_dist: number;
      public ID: number;
      public tracking_cnt: number;
      public handle: number;
      public hasAction(action: number): boolean;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class FootMaskInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public mask: UInt8Vector;
      public mask2: UInt8Vector;
      public mask_width: number;
      public mask_height: number;
      public mask_image: Image;
      public mask_image2: Image;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum ColliderListener {
      ON_GESTURE_TAP,
      ON_GESTURE_LONG_TAP,
      ON_GESTURE_DOUBLE_CLICK,
      ON_GESTURE_DRAG,
      ON_HIT,
    }
    namespace ColliderListener {
      let RTTI: RTTIDescriptor;
    }
    class InputInternal extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class FaceNewLandmarkInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public faceID: number;
      public points: Vec2Vector;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum CubeMapResolution {
      16,
      32,
      64,
      128,
      256,
      512,
      1024,
      2048,
    }
    namespace CubeMapResolution {
      let RTTI: RTTIDescriptor;
    }
    class FaceReenactInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public rawData: UInt8Vector;
      public imageWidth: number;
      public imageHeight: number;
      public imageChannel: number;
      public dataType: number;
      public mvp: Matrix4x4f;
      public image: Image;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class VFXProfile extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public ctxBlocks: Vector;
      public pointCaches: Vector;
      public attributeMapVec: Vector;
      public handle: number;
      public getCtxBlock(i: number): VFXContextBlock;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class VFXContextBlock extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public type: ContextType;
      public index: number;
      public exposeProperties: PropertySheet;
      public inCtxID: number;
      public siblingCtxID: number;
      public shaders: Vector;
      public blendMode: VFXBlendMode;
      public materials: Vector;
      public depthTestMode: boolean;
      public depthWriteMode: boolean;
      public SemanticsVertexAttribMap: Map;
      public orderedUniform: Vector;
      public layoutBuffers: Vector;
      public attributeSize: number;
      public sortPassIndices: Vector;
      public mesh: Mesh;
      public keywordPrograms: Vector;
      public attributeMapIndices: Vector;
      public castShadow: boolean;
      public boundingBox: AABB;
      public handle: number;
      public sendEvent(m_event: VFXEventType): void;
      public setExternalBuffer(uniformName: string, size: number, value: FloatVector): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class MangaInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public data: UInt8Vector;
      public width: number;
      public height: number;
      public channels: number;
      public type: number;
      public matrix: FloatVector;
      public affine: Matrix4x4f;
      public image_width: number;
      public image_height: number;
      public image: Image;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class AttributeMap extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public index: number;
      public count: number;
      public uniformName: string;
      public attributeType: VertexAttribType;
      public isDynamic: boolean;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class FollowManager extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum VFXBlendMode {
      VFXAddtive,
      VFXAlpha,
      VFXOpaque,
      VFXAlphaPremultipy,
    }
    namespace VFXBlendMode {
      let RTTI: RTTIDescriptor;
    }
    enum VFContextEvent {
      AFTER_POINTCACHE_UPDATE,
    }
    namespace VFContextEvent {
      let RTTI: RTTIDescriptor;
    }
    class TouchPointer extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public pointerId: number;
      public type: TouchType;
      public x: number;
      public y: number;
      public force: number;
      public size: number;
      public time: number;
      public count: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class MattingResultInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public width: number;
      public height: number;
      public mask_data: UInt8Vector;
      public take_this: SnapShotRet;
      public bgMask: Image;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Vec4ValueCurved extends Vec4Value {
      constructor();
      public assetMgr: AssetManager;
      public vec2CurveX: Vec2ValueCurved;
      public vec2CurveY: Vec2ValueCurved;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Vec4Value extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class EffectColorCurved extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum Brush2DMeshType {
      Stamp,
    }
    namespace Brush2DMeshType {
      let RTTI: RTTIDescriptor;
    }
    class EffectLineBuildParams extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ColorBlendAttachmentState extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public blendEnable: boolean;
      public srcColorBlendFactor: BlendFactor;
      public dstColorBlendFactor: BlendFactor;
      public srcAlphaBlendFactor: BlendFactor;
      public dstAlphaBlendFactor: BlendFactor;
      public colorWriteMask: number;
      public ColorBlendOp: BlendOp;
      public AlphaBlendOp: BlendOp;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class EffectLineBuilder extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public SetLinePosition(positionList: Vec3Vector): void;
      public SetLineCornerVertices(countCornerVertice: number): void;
      public SetLineLoop(isLoop: boolean): void;
      public SetLineAlignType(alignType: number): void;
      public SetLineWidthCurvyType(curvyType: number): void;
      public SetLineColorCurvyType(curvyType: number): void;
      public SetLineWidth(length: number, value: number): void;
      public ClearLineWidth(value: number): void;
      public SetLineColor(length: number, value: Vector4f): void;
      public ClearLineColor(value: Vector4f): void;
      public SetLineConstuctParamsWidth(lineWidth: ValueCurved): void;
      public SetOpenUVExtendProperty(isOpenExtend: boolean): void;
      public SetLineConstuctParamsColor(lineColorR: ValueCurved, lineColorG: ValueCurved, lineColorB: ValueCurved, lineColorA: ValueCurved): void;
      public FillMesh(mesh: Mesh): void;
      public InitDefaultMesh(mesh: Mesh): void;
      public FillMeshWithAlignCamera(mesh: Mesh, camera: Camera): void;
      public ClearMesh(mesh: Mesh): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class AnimStateTransition extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public transitionType: StateTransitionType;
      public duration: number;
      public dstState: AnimState;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum StateTransitionType {
      linear,
    }
    namespace StateTransitionType {
      let RTTI: RTTIDescriptor;
    }
    class JointV2InfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public number: number;
      public key_points_xy: Vec2Vector;
      public key_points_detected: UInt8Vector;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum EventSource {}
    namespace EventSource {
      let RTTI: RTTIDescriptor;
    }
    class AnimLayerMask extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public entities: Map;
      public maskbits: DynamicBitset;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ExternalPropertyItem extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public value: Variant;
      public autoUpdate: boolean;
      public handle: number;
      public addSourcePropertyUpdater(sourceTargetName: string, sourcePropertyName: string, searchRoot: Entity): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ExternalTargetItem extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class AnalyticsManager extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public reportEvent(eventName: string, data: Map): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ScriptInfoInterface extends BachMapInterface {
      constructor();
      public assetMgr: AssetManager;
      public data: Map;
      public outputMap: Map;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Calibrate extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public faceCount: number;
      public handle: number;
      public getPnPMMatrix(index: number, camera: Camera, onlyGet: boolean, faceType: CaptureType): Matrix4x4f;
      public getPnPPMatrix(): Matrix4x4f;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum CaptureType {
      HUMAN,
      DOG,
      HUMAN_EXT,
      CAT,
      FACE_PLACEHOLDER,
      UNKNOW,
    }
    namespace CaptureType {
      let RTTI: RTTIDescriptor;
    }
    class CarSeriesInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public box: FloatVector;
      public car_id: number;
      public series_name: string;
      public series_id: number;
      public is_new: boolean;
      public car_series_prob: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ImageFrame extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public rotate: RotateType;
      public trimed: boolean;
      public tilingoffset: Vector4f;
      public srctilingoffset: Vector4f;
      public outerRect: Vector4f;
      public innerRect: Vector4f;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum CaptureVersion {
      SOLVEPNP,
      CVPOINTS,
    }
    namespace CaptureVersion {
      let RTTI: RTTIDescriptor;
    }
    class SortingSettings extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public sortingType: SortingType;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum CalibrationType {
      V1,
      V2,
      UNKNOW,
      V3,
      V4,
      V5,
      V6,
    }
    namespace CalibrationType {
      let RTTI: RTTIDescriptor;
    }
    enum BehaviorWhenTrackerDisappear {
      ALIGN_VISIBILITY_WITH_TRACKER,
      STAY_PREVIOUS_FRAME,
      RESET_TO_ORIGIN,
    }
    namespace BehaviorWhenTrackerDisappear {
      let RTTI: RTTIDescriptor;
    }
    enum EntityRotateType {
      ROTATE_DISABLE,
      ROTATE_AROUND_Z_AXIS,
      ROTATE_AROUND_XYZ_AXIS,
    }
    namespace EntityRotateType {
      let RTTI: RTTIDescriptor;
    }
    class AEAlgorithmManager extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public getAEAlgorithmResult(): AEAlgorithmResult;
      public setAlgorithmEnable(graphName: string, name: string, enable: boolean): boolean;
      public setAlgorithmParamInt(graphName: string, name: string, key: string, value: number): boolean;
      public setAlgorithmParamFloat(graphName: string, name: string, key: string, value: number): boolean;
      public setAlgorithmParamStr(graphName: string, name: string, key: string, value: string): boolean;
      public setInputTexture(inputSlot: number, texture: Texture, config: Map): boolean;
      public face106To295(points: Vec2Vector): Vec2Vector;
      public setBlitSize(graphName: string, width: number, height: number): boolean;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class AEAlgorithmResult extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public getAlgorithmParam(key: string): Variant;
      public getFaceCount(): number;
      public getFaceBaseInfo(index: number): Face106Interface;
      public getFaceExtraInfo(index: number): FaceExtraInterface;
      public getFaceMouthMask(index: number): FaceMouthMaskInterface;
      public getFaceTeethMask(index: number): FaceTeethMaskInterface;
      public getFaceFaceMask(index: number): FaceFaceMaskInterface;
      public getFaceOcclusion(index: number): FaceOcclusionInterface;
      public getFaceVerifyInfo(index: number): FaceVerifyInfoInterface;
      public getFaceVerifyCount(): number;
      public getCompleteFaceVerifyInfo(index: number): FaceVerifyInfoInterface;
      public getCompleteFaceVerifyCount(): number;
      public getFaceClustingInfo(): FaceClustingInfoInterface;
      public getFaceAttributeCount(): number;
      public getFaceAttributeInfo(index: number): FaceAttributeInterface;
      public getCatFaceCount(): number;
      public getCatFace(index: number): CatFaceInterface;
      public getFaceFittingCount(): number;
      public getFaceMeshInfo(index: number): FaceMeshInfoInterface;
      public getFaceMeshConfig(): FaceMeshConfigInterface;
      public getFaceFittingCount1256(): number;
      public getFaceMeshInfo1256(index: number): FaceMeshInfoInterface;
      public getFaceMeshConfig1256(): FaceMeshConfigInterface;
      public getSkeletonCount(): number;
      public getSkeletonInfo(index: number): SkeletonInfoInterface;
      public getSkeletonIsExecuted(): boolean;
      public getActionDetectCount(): number;
      public getActionDetectInfo(index: number): ActionDetectInfoInterface;
      public getActionRecognitionIsExecuted(): boolean;
      public getActionRecognitionCount(): number;
      public getActionRecognitionInfo(index: number): ActionRecognitionInfoInterface;
      public getJointInfo(): JointInfoInterface;
      public getJointV2Info(): JointV2InfoInterface;
      public getHandCount(): number;
      public getHandInfo(index: number): HandInfoInterface;
      public getHandMaskInfo(): HandMaskInfoInterface;
      public getHairInfo(): HairResultInterface;
      public getHairGerInfoCount(): number;
      public getHairGerInfo(index: number): HairGerInfoInterface;
      public getBgInfo(): MattingResultInterface;
      public getVideoMattingInfo(): MattingResultInterface;
      public getSkyInfo(): SkyResultInterface;
      public getBlingInfo(): BlingResultInterface;
      public getKiraInfo(): KiraResultInterface;
      public getMug(index: number): MugResultInterface;
      public getMugCount(): number;
      public getAvatarDriveInfo(index: number): AvatarDriveInfoInterface;
      public getAvatarDriveCount(): number;
      public getARScanInfoCount(): number;
      public getARScanInfo(index: number): ARScanInfoInterface;
      public getObjectDetectInfoCount(): number;
      public getObjectDetectInfo(index: number): ObjectDetectInfoInterface;
      public getObjectDetectType(): ObjectType;
      public getFacePetInfoCount(): number;
      public getFacePetInfo(index: number): FacePetInfoInterface;
      public getClothesSegInfo(): ClothesSegInfoInterface;
      public getBuildingSegInfo(): BuildingSegInfoInterface;
      public getBuildingNormalInfo(): BuildingNormalInfoInterface;
      public getNaviAvatarDriveInfo(): NaviAvatarDriveInfoInterface;
      public getSceneNormalInfo(): SceneNormalInfoInterface;
      public getCarSegInfoCount(): number;
      public getCarSegInfo(index: number): CarSegInfoInterface;
      public getCarSegConfig(): CarSegConfigInterface;
      public getHeadSegInfoCount(): number;
      public getHeadSegInfo(index: number): HeadSegInfoInterface;
      public getFacePartBeautyInfo(index: number): FacePartBeautyInfoInterface;
      public getFacePartBeautyInfoCount(): number;
      public getFacePartBeautyInfoConfig(): FacePartBeautyConfigInterface;
      public getEnigmaInfoCount(): number;
      public getEnigmaInfo(index: number): EnigmaInfoInterface;
      public getEnigmaInfoFactor(): number;
      public getSceneRecogInfoCount(): number;
      public getSceneRecogInfo(index: number): SceneRecogInfoInterface;
      public getSceneRecogInfoChoose(): number;
      public getFaceGanInfoCount(): number;
      public getFaceGanInfo(index: number): FaceGanInfoInterface;
      public getTrackingArInfo(): TrackingArInfoInterface;
      public getObjectTrackStatus(): number;
      public getObjectTrackTransform(): Matrix4x4f;
      public getObjectTrackProjection(): Matrix4x4f;
      public getObjectTrackObjectId(): number;
      public getObjectTrackAccuracy(): number;
      public isObjectTrackMirrored(): boolean;
      public getOldGanInfoCount(arg0: string): number;
      public getOldGanInfo(index: number, arg1: string): MegaClassicGanInfoInterface;
      public getBigGanInfoCount(arg0: string): number;
      public getBigGanInfo(index: number, arg1: string): MegaClassicGanInfoInterface;
      public getLaughGanInfoCount(arg0: string): number;
      public getLaughGanInfo(index: number, arg1: string): MegaClassicGanInfoInterface;
      public getSkeletonPose3DInfoCount(): number;
      public getSkeletonPose3DInfo(index: number): SkeletonPose3DInfoInterface;
      public getAvatar3DInfoCount(graphName: string, nodeName: string): number;
      public getAvatar3DInfo(index: number, graphName: string, nodeName: string): Avatar3DInfoInterface;
      public getAvatar3DInfoTracking(): boolean;
      public getAvatar3DIsExecuted(graphName: string, nodeName: string): boolean;
      public getGroundSegInfo(): GroundSegResultInterface;
      public getSaliencySegResult(): SaliencySegInfoInterface;
      public getFootCount(): number;
      public getFootInfo(index: number): FootInfoInterface;
      public getFootMaskInfo(): FootMaskInfoInterface;
      public getSlamInfo(): SlamResultInterface;
      public getSlamCircle(): SlamCircleInterface;
      public getSlamVideoInfo(): SlamVideoResultInterface;
      public getBeautyGanInfoCount(arg0: string): number;
      public getBeautyGanInfo(index: number, arg1: string): MegaClassicGanInfoInterface;
      public getFaceLightInfoCount(): number;
      public getFaceLightInfo(index: number): FaceLightInfoInterface;
      public getSceneLightInfo(): SceneLightInfoInterface;
      public getNHImageInfoCount(graphName: string, nodeName: string): number;
      public getNHImageTfmCount(graphName: string, nodeName: string): number;
      public getNHInputTensorCount(graphName: string, nodeName: string): number;
      public getNHOutputTensorCount(graphName: string, nodeName: string): number;
      public getNHClassificationInfoCount(graphName: string, nodeName: string): number;
      public getNHImageWithTfmCount(graphName: string, nodeName: string): number;
      public getNHImageInfo(graphName: string, nodeName: string, index: number): NHImageInfoInterface;
      public getNHImageTfmInfo(graphName: string, nodeName: string, index: number): NHImageTransformInterface;
      public getNHInputTensorInfo(graphName: string, nodeName: string, index: number): NHTensorInfoInterface;
      public getNHOutputTensorInfo(graphName: string, nodeName: string, index: number): NHTensorInfoInterface;
      public getNHClassificationInfo(graphName: string, nodeName: string, index: number): NHClassificationInfoInterface;
      public getNHImageWithTfmInfo(graphName: string, nodeName: string, index: number): NHImageWithTfmInterface;
      public getNHMulImageInfoCount(graphName: string, nodeName: string): number;
      public getNHMulImageInfo(graphName: string, nodeName: string, index: number): NHMulImageInfoInterface;
      public getIDreamInfo(index: number): IDreamInfoInterface;
      public getSkinSegInfo(): SkinSegInfoInterface;
      public getDepthEstimationInfo(graphName: string, nodeName: string, outputIndex: number): DepthEstimationInfoInterface;
      public getClothClassInfo(arg0: number): ClothClassInfoInterface;
      public getClothClassInfoCount(): number;
      public getDynGestInfo(index: number): DynGestInfoInterface;
      public getIndoorSegInfo(): IndoorSegInfoInterface;
      public getHumanParsingInfo(): HumanParsingInfoInterface;
      public getDeepInpaintInfo(): DeepInpaintInfoInterface;
      public getRgbd2MeshInfo(): Rgbd2MeshInfoInterface;
      public getPictureArInfo(): PictureArInfoInterface;
      public getEarSegInfoCount(): number;
      public getEarSegInfo(index: number): EarSegInfoInterface;
      public getFoodComicsInfo(): FoodComicsInfoInterface;
      public getOilPaintInfo(): OilPaintInfoInterface;
      public getPetMattingInfo(): PetMattingInfoInterface;
      public getGazeEstimationCount(): number;
      public getGazeEstimationInfo(index: number): GazeEstimationInfoInterface;
      public getTeethCount(): number;
      public getTeethInfo(index: number): TeethInfoInterface;
      public getBlockGanInfoCount(): number;
      public getBlockGanInfo(index: number): BlockGanInfoInterface;
      public getNailInfo(): NailInfoInterface;
      public getNailKeyPointInfo(index: number): NailKeyPointInfoInterface;
      public getNailKeyPointInfoCount(): number;
      public getMemojiMatchMessage(): MemojiMatchMessageInterface;
      public getHdrNetInfo(): HdrNetInfoInterface;
      public getFemaleGanInfo(): FemaleGanInfoInterface;
      public getGenderGanInfo(arg0: number, arg1: string): MegaClassicGanInfoInterface;
      public getFaceMaskInfoCount(): number;
      public getFaceMaskInfo(index: number): FaceMaskInfoInterface;
      public getFindContourCount(): number;
      public getFindContourInfo(index: number): FindContourInfoInterface;
      public getMangaInfoCount(): number;
      public getMangaInfo(index: number): MangaInfoInterface;
      public getBGMangaInfo(): MangaInfoInterface;
      public getAudioAvatarInfo(): AudioAvatarInfoInterface;
      public getObjectDetection2InfoCount(): number;
      public getObjectDetection2Info(index: number): ObjectDetection2InfoInterface;
      public getApolloFace3dInfoClassCount(): number;
      public getApolloFace3dInfoClass(index: number): ApolloFace3DInfoClassInterface;
      public getAvacapInfoCount(): number;
      public getAvacapInfo(index: number): AvacapInfoInterface;
      public getCarSeriesInfo(index: number): CarSeriesInfoInterface;
      public getCarSeriesCount(): number;
      public getFaceSmoothCPUInfo(): FaceSmoothCPUInfoInterface;
      public getHeadFittingInfo(index: number): HeadFittingInfoInterface;
      public getHeadFittingInfoCount(): number;
      public getObjectTrackInfoCount(): number;
      public getObjectTrackInfo(index: number): ObjectTrackInfoInterface;
      public getHandObjectSegInfo(): HandObjectSegInfoInterface;
      public getFaceNewLandmarkInfo(index: number): FaceNewLandmarkInfoInterface;
      public getFaceNewLandmarkInfoCount(): number;
      public getAfterEffectInfo(): AfterEffectInfoInterface;
      public getHairFlowInfo(): HairFlowInfoInterface;
      public getHAvatarInfoCount(): number;
      public getHAvatarInfo(index: number): HAvatarInfoInterface;
      public getWatchTryonCount(): number;
      public getWatchTryonInfo(index: number): WatchTryonInfoInterface;
      public getRelationRecogInfoCount(): number;
      public getRelationRecogInfo(index: number): RelationRecogInfoInterface;
      public getFreidInfoCount(): number;
      public getFreidInfo(index: number): FreidInfoInterface;
      public getFaceReenactInfo(index: number): FaceReenactInfoInterface;
      public getFaceReenactInfoCount(): number;
      public getSwapperMeBaseInfo(): SwapperMeBaseInfoInterface;
      public getSwapperMeFaceInfo(index: number): SwapperMeFaceInfoInterface;
      public getAvatar3DFusionInfoCount(): number;
      public getAvatar3DFusionInfo(index: number): Avatar3DFusionInfoInterface;
      public getAvatar3DFusionInfoTracking(): boolean;
      public getForeheadSegInfoCount(): number;
      public getForeheadSegInfo(index: number): ForeheadSegInfoInterface;
      public getContentRecommendInfoCount(): number;
      public getContentRecommendInfo(index: number): ContentRecommendInfoInterface;
      public getSwapLiveInfo(index: number): SwapLiveInfoInterface;
      public getOutputTexture(graphName: string, nodeName: string): BachTextureInterface;
      public getInteractiveMattingInfo(): InteractiveMattingInfoInterface;
      public getColorMappingInfo(): ColorMappingInfoInterface;
      public getScriptInfo(graphName: string, nodeName: string): ScriptInfoInterface;
      public getBlitImage(graphName: string, nodeName: string): BachImageInterface;
      public getChromaKeyingInfo(): ChromaKeyingInfoInterface;
      public getAlgorithmInfoCount(graphName: string, nodeName: string, algorithmType: string): number;
      public getAlgorithmInfo(graphName: string, nodeName: string, algorithmType: string, index: number): AObject;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ClothesSegInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public width: number;
      public height: number;
      public left: number;
      public top: number;
      public right: number;
      public bottom: number;
      public shiftX: number;
      public shiftY: number;
      public mask_data: UInt8Vector;
      public alphaMask: Image;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class FaceExtraInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public eye_count: number;
      public eyebrow_count: number;
      public lips_count: number;
      public iris_count: number;
      public eye_left: Vec2Vector;
      public eye_right: Vec2Vector;
      public eyebrow_left: Vec2Vector;
      public eyebrow_right: Vec2Vector;
      public lips: Vec2Vector;
      public left_iris: Vec2Vector;
      public right_iris: Vec2Vector;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class FaceTeethMaskInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public face_mask_size: number;
      public face_mask: UInt8Vector;
      public warp_mat: FloatVector;
      public ID: number;
      public image: Image;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class FaceFaceMaskInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public face_mask_size: number;
      public face_mask: UInt8Vector;
      public warp_mat: FloatVector;
      public ID: number;
      public image: Image;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum ParticleRenderSortingMode {
      NONE,
      BY_DISTANCE,
      YOUNGEST_IN_FRONT,
      OLDEST_IN_FRONT,
    }
    namespace ParticleRenderSortingMode {
      let RTTI: RTTIDescriptor;
    }
    class FaceOcclusionInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public prob: number;
      public id: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum IFMaskType {
      None,
      Rect,
      Ellipse,
      MaskSprites,
    }
    namespace IFMaskType {
      let RTTI: RTTIDescriptor;
    }
    class FaceClustingInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public is_valid: boolean;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class FaceMeshInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public ID: number;
      public param: FloatVector;
      public vertexes: Vec3Vector;
      public landmarks: Vec3Vector;
      public normals: Vec3Vector;
      public mvp: Matrix4x4f;
      public modelMatrix: Matrix4x4f;
      public rvec: Vector3f;
      public tvec: Vector3f;
      public scale: number;
      public tangents: Vec3Vector;
      public bitangents: Vec3Vector;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class FaceMeshConfigInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public uvs: Vec2Vector;
      public flist: UInt16Vector;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ActionDetectInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public ID: number;
      public index: number;
      public staticResult: number;
      public sequenceResult: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum AEPersonKeyPointType {
      kNose,
      kRightShoulder,
      kRightElbow,
      kRightWrist,
      kLeftShoulder,
      kRightAnkle,
      kNeck,
      kLeftElbow,
      kLeftWrist,
      kLeftEar,
      kRightHip,
      kRightKnee,
      kLeftHip,
      kLeftKnee,
      kRightEar,
      kLeftAnkle,
      kLeftEye,
      kRightEye,
      kRightHand,
      kLeftHand,
    }
    namespace AEPersonKeyPointType {
      let RTTI: RTTIDescriptor;
    }
    class SkyResultInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public width: number;
      public height: number;
      public channel: number;
      public mask_data: UInt8Vector;
      public skyMask: Image;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum TypeSettingKind {
      HORIZONTAL,
      VERTICAL,
    }
    namespace TypeSettingKind {
      let RTTI: RTTIDescriptor;
    }
    class SkeletonPose3DInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public pose3d: Vec3Vector;
      public fused3d: Vec3Vector;
      public skeleton2d_points: Vec2Vector;
      public skeleton2d_detecteds: Int8Vector;
      public detected: boolean;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class CommandBuffer extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public blit(src: Texture, dest: RenderTexture): void;
      public blitWithMaterial(src: Texture, dest: RenderTexture, material: Material, shaderPass: number): void;
      public blitWithMaterialAndProperties(src: Texture, dest: RenderTexture, material: Material, shaderPass: number, properties: MaterialPropertyBlock): void;
      public blitSliceWithMaterial(src: Texture, dest: RenderTexture, srcSlice: number, destSlice: number, material: Material, shaderPass: number): void;
      public blitSliceWithMaterialAndProperties(src: Texture, dest: RenderTexture, srcSlice: number, destSlice: number, material: Material, shaderPass: number, properties: MaterialPropertyBlock): void;
      public clearAll(): void;
      public clearRenderTexture(clearColor: boolean, clearDepth: boolean, backgroundColor: Color, depth: number): void;
      public clearRenderTextureWithStencil(clearColor: boolean, clearDepth: boolean, clearStencil: boolean, backgroundColor: Color, depth: number, stencil: number): void;
      public disableScissorRect(): void;
      public drawMesh(mesh: Mesh, matrix: Matrix4x4f, material: Material, submeshIndex: number, shaderPass: number, properties: MaterialPropertyBlock): void;
      public drawProcedural(material: Material, topology: Primitive, vertexCount: number, indices: UInt32Vector, instanceCount: number, layoutBufferDescs: Vector, properties: MaterialPropertyBlock): void;
      public drawProceduralWithPass(material: Material, shaderPass: number, topology: Primitive, vertexCount: number, indices: UInt32Vector, instanceCount: number, layoutBufferDescs: Vector, properties: MaterialPropertyBlock): void;
      public enableScissorRect(rect: Rect): void;
      public setGlobalColor(name: string, color: Color): void;
      public setGlobalFloat(name: string, value: number): void;
      public setGlobalVector4f(name: string, value: Vector4f): void;
      public setGlobalMatrix(name: string, value: Matrix4x4f): void;
      public setGlobalTexture(name: string, texture: RenderTexture): void;
      public setGlobalTextureCube(name: string, texture: TextureCube): void;
      public setInvertCulling(invCulling: boolean): void;
      public setProjectionMatrix(proj: Matrix4x4f): void;
      public setRenderTexture(target: RenderTexture): void;
      public setRenderTextureWithSlice(target: RenderTexture, slice: number): void;
      public setViewMatrix(view: Matrix4x4f): void;
      public setViewport(pixelRect: Rect): void;
      public endRender(): void;
      public setViewProjectionMatrices(view: Matrix4x4f, proj: Matrix4x4f): void;
      public dispatchCompute(entity: AMGComputeEntity, threadGroupsX: number, threadGroupsY: number, threadGroupsZ: number): void;
      public beginCompute(): void;
      public endCompute(): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class AABB2D extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public min: Vector2f;
      public max: Vector2f;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class BlingResultInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public points: Vec3Vector;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Input extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public frameTimestamp: number;
      public handle: number;
      public getTouchCount(): number;
      public getGestureCount(): number;
      public getTouch(index: number): Touch;
      public getGesture(index: number): Gesture;
      public getStickerRect(): Rect;
      public setStickerRect(rect: Rect): void;
      public getCameraPosition(): CameraPosition;
      public getDeviceOrientation(): DeviceOrientation;
      public getLocation(): string;
      public addScriptListener(script: Script, listenerType: number, funcName: string, scriptUserData: AObject): void;
      public removeScriptListener(script: Script, listenerType: number, funcName: string, scriptUserData: AObject): void;
      public createDeviceSensorHub(): DeviceSensorHub;
      public getFrameTimestamp(): number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class KiraResultInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public points: Vec3Vector;
      public width: number;
      public height: number;
      public channels: number;
      public pointNum: number;
      public mask: Image;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class AvatarDriveInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public alpha: FloatVector;
      public beta: FloatVector;
      public landmarks: Vec2Vector;
      public rot: Vector3f;
      public mvp: Matrix4x4f;
      public mv: Matrix4x4f;
      public affine_mat: Matrix3x3f;
      public succ: number;
      public ID: number;
      public action: number;
      public width: number;
      public height: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ARScanInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public status: number;
      public scannable_name: string;
      public target_area: FloatVector;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ObjectDetectInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public rect: Rect;
      public score: number;
      public Id: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum FaceStretchType {
      HUMAN,
      DOG,
      CAT,
    }
    namespace FaceStretchType {
      let RTTI: RTTIDescriptor;
    }
    class BuildingSegInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public width: number;
      public height: number;
      public shiftX: number;
      public shiftY: number;
      public mask_data: UInt8Vector;
      public mask: Image;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class SlamHandler extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public viewTracker: ViewTracker;
      public handle: number;
      public rayCastHit(index: number, touchPoint: Vector2f): boolean;
      public hitTest(index: number, touchPoint: Vector2f): boolean;
      public rayCastHitWithForce(index: number, touchPoint: Vector2f, force: boolean): boolean;
      public hitTestWithForce(index: number, touchPoint: Vector2f, force: boolean): boolean;
      public update(): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class BuildingNormalInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public numBoxes: number;
      public hangBoxesCenterX: number;
      public hangBoxesCenterY: number;
      public hangBoxesSizeWidth: number;
      public hangBoxesSizeHeight: number;
      public hangBoxesAngle: number;
      public hangBoxesNormal: FloatVector;
      public polygonCenterX: number;
      public polygonCenterY: number;
      public polygon: Vec2Vector;
      public objectCls: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class NaviAvatarDriveInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public blendshapeWeights: FloatVector;
      public modelView: Matrix4x4f;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum StencilOp {
      KEEP,
      MAX_ENUM,
      DECREMENT_AND_CLAMP,
      ZERO,
      REPLACE,
      INCREMENT_AND_CLAMP,
      INVERT,
      INCREMENT_AND_WRAP,
      DECREMENT_AND_WRAP,
    }
    namespace StencilOp {
      let RTTI: RTTIDescriptor;
    }
    class SceneNormalInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public width: number;
      public height: number;
      public mask_data: UInt8Vector;
      public mask: Image;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class BlockGanInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public faceCount: number;
      public width: number;
      public height: number;
      public matrix: FloatVector;
      public mask: UInt8Vector;
      public channel: number;
      public type: number;
      public count: number;
      public uid: number;
      public mask_image: Image;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class CarSegConfigInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public alphaTextureId: number;
      public rotateType: number;
      public realW: number;
      public realH: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum RigidBodyType {
      STATIC,
      KINEMATIC,
      DYNAMIC,
      KINEMATIC_FAST_MODE,
    }
    namespace RigidBodyType {
      let RTTI: RTTIDescriptor;
    }
    class HeadSegInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public face_id: number;
      public alpha: Image;
      public width: number;
      public height: number;
      public srcWidth: number;
      public srcHeight: number;
      public channel: number;
      public matrix: DoubleVector;
      public cameraMatrix: DoubleVector;
      public xScale: number;
      public yScale: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class FacePartBeautyInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public beauty_id: number;
      public beauty_score: Int32Vector;
      public features: FloatVector;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class TrackingArInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public pose: Matrix4x4f;
      public projection: Matrix4x4f;
      public status: number;
      public objectId: number;
      public accuracy: number;
      public isMirrored: boolean;
      public planeImgWidth: number;
      public planeImgHeight: number;
      public planeImg: Image;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class MegaClassicGanInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public id: number;
      public faceID: number;
      public faceId: number;
      public faceCount: number;
      public valid: number;
      public invalidDegree: number;
      public affine: Matrix4x4f;
      public affineMatrix: Matrix4x4f;
      public gpuMatrix: Matrix4x4f;
      public width: number;
      public height: number;
      public imageWidth: number;
      public imageHeight: number;
      public image_width: number;
      public image_height: number;
      public image_data: UInt8Vector;
      public image: Image;
      public alphaImage: Image;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class AfterEffectInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public time: number;
      public score: number;
      public face_score: number;
      public quality_score: number;
      public sharepness_score: number;
      public meaningless_score: number;
      public portrait_score: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Avatar3DInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public quaternion: QuatVector;
      public root: Vector3f;
      public valid: Int8Vector;
      public detected: boolean;
      public focal_length: number;
      public joints: Vec3Vector;
      public imageWidth: number;
      public imageHeight: number;
      public tracking_id: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Touch extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public point: Vector2f;
      public points: Vector;
      public fingerId: number;
      public fingerIds: Vector;
      public pressure: number;
      public pressures: Vector;
      public type: TouchPhase;
      public count: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class SlamVideoResultInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public frameSize: number;
      public frameViews: Vector;
      public frameValidPointSizes: Int32Vector;
      public frameTrackStatus: Int32Vector;
      public frameDepths: FloatVector;
      public projection: Matrix4x4f;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class FaceLightInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public face_id: number;
      public has_lighting: boolean;
      public SH_Light_RGB: FloatVector;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum LookAtWorldUp {
      SCENE_Y,
      TARGET_Y,
    }
    namespace LookAtWorldUp {
      let RTTI: RTTIDescriptor;
    }
    class SceneLightInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public SH_Light_RGB: FloatVector;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum SoftShadowType {
      PCF,
      EVSM,
      VSM,
      CSM,
    }
    namespace SoftShadowType {
      let RTTI: RTTIDescriptor;
    }
    class NHImageTransformInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public affine: Matrix3x3f;
      public mvp: Matrix4x4f;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class NHTensorInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public dataFormat: number;
      public dataType: number;
      public batch: number;
      public height: number;
      public width: number;
      public channel: number;
      public fraction: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum ParticleOritationMode {
      AFFECT_BY_ENTITY,
      NONE,
    }
    namespace ParticleOritationMode {
      let RTTI: RTTIDescriptor;
    }
    enum HandAction {
      PISTOL2,
      DOUBLE_FINGER_UP,
      UNKNOWN,
      VICTORY,
      OK,
      HAND_OPEN,
      BIG_V,
      ROCK2,
      PRAY,
      NAMASTE,
      NARUTO5,
      HEART_A,
      FIST,
      PLAM_UP,
      UNDETECT,
      ROCK,
      THREE,
      INDEX_FINGER_UP,
      PHONECALL,
      BEG,
      HEART_D,
      NARUTO9,
      THANKS,
      THUMB_UP,
      FOUR,
      PISTOL,
      SWEAR,
      THUMB_DOWN,
      NARUTO11,
      MAX_COUNT,
      SALUTE,
      AVENGERS,
      SPREAD,
      NARUTO8,
      CABBAGE,
      HEART_C,
      QIGONG,
      SLIDE,
      NARUTO1,
      NARUTO2,
      NARUTO3,
      HOLDFACE,
      NARUTO4,
      NARUTO7,
      HEART_B,
      NARUTO10,
      NARUTO12,
      PALM_DOWN,
      SPIDERMAN,
    }
    namespace HandAction {
      let RTTI: RTTIDescriptor;
    }
    class NHMulImageInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public getImageInfo(index: number): NHImageInfoInterface;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class IDreamInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public image: Image;
      public width: number;
      public height: number;
      public image_width: number;
      public image_height: number;
      public affine: Matrix4x4f;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class SkinSegInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public width: number;
      public height: number;
      public reflector: number;
      public mask_data: UInt8Vector;
      public data: Image;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class DepthEstimationInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public width: number;
      public height: number;
      public depthMask: UInt8Vector;
      public image: Image;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class DynGestInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public action: number;
      public action_score: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class DeepInpaintInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public width: number;
      public height: number;
      public image_width: number;
      public image_height: number;
      public mask_image: Image;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class PictureArInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public sourcePoints: Vec2Vector;
      public targetPoints: Vec2Vector;
      public mapMatch: Vec2Vector;
      public mapMatchIsValid: boolean;
      public anchorMatch: Vec2Vector;
      public anchorMatchIsValid: boolean;
      public frameScore: number;
      public frameScoreIsValid: boolean;
      public rotation: number;
      public rotationIsValid: boolean;
      public scale: number;
      public scaleIsValid: boolean;
      public isDetcting: boolean;
      public affineMat: boolean;
      public affineMatIsValid: boolean;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class EarSegInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public faceID: number;
      public maskWidth: number;
      public maskHeight: number;
      public maskChannel: number;
      public yaw: number;
      public alpha0: UInt8Vector;
      public alpha1: UInt8Vector;
      public matrix0: DoubleVector;
      public matrix1: DoubleVector;
      public cls: Int32Vector;
      public centerX: FloatVector;
      public centerY: FloatVector;
      public earWidth: Int8Vector;
      public earHeight: Int8Vector;
      public mask0: Image;
      public mask1: Image;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class NailInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public width: number;
      public height: number;
      public rtNum: number;
      public alpha_data: UInt8Vector;
      public alpha_image: Image;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class MemojiMatchMessageInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public status: number;
      public percent: number;
      public gender: string;
      public faceshape: string;
      public nose: string;
      public bang: string;
      public skinColor: string;
      public hair: string;
      public brow: string;
      public eye: string;
      public mouth: string;
      public glasses: string;
      public beard: string;
      public hairColor: Vector3f;
      public mouthColor: Vector3f;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum SnapShotRet {
      Disable,
      True,
      False,
    }
    namespace SnapShotRet {
      let RTTI: RTTIDescriptor;
    }
    class HdrNetInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public ccm: FloatVector;
      public ccm_bias: FloatVector;
      public shifts: FloatVector;
      public slopes: FloatVector;
      public channel_mix_weight: FloatVector;
      public channel_mix_bias: number;
      public grid: FloatVector;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class KeywordProgramProfile extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public keywordSets: Vector;
      public targetApis: Vector;
      public stagets: Vector;
      public shaderSnippets: Vector;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum IFUISliderMode {
      FOLLOW,
      OFFSET,
      DRAG_THUMB,
    }
    namespace IFUISliderMode {
      let RTTI: RTTIDescriptor;
    }
    class FemaleGanInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public cropImgData: number;
      public cropImgWidth: number;
      public cropImgHeight: number;
      public cropImgChannels: number;
      public cropImgStride: number;
      public cropImgAlignment: number;
      public outputImgData: number;
      public outputImgWidth: number;
      public outputImgHeight: number;
      public outputImgChannels: number;
      public outputImgStride: number;
      public outputImgAlignment: number;
      public affine: Matrix4x4f;
      public shouldDraw: boolean;
      public width: number;
      public height: number;
      public faceId: number;
      public cropImage: Image;
      public outputImage: Image;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class FindContourInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public contours: Vec2Vector;
      public hierarchy: Int32Vector;
      public width: number;
      public height: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum TouchType {
      TOUCH_BEGAN,
      TOUCH_MOVED,
      TOUCH_STATIONARY,
      TOUCH_CANCELED,
      TOUCH_ENDED,
    }
    namespace TouchType {
      let RTTI: RTTIDescriptor;
    }
    enum IFRotationType {
      None,
      Device,
      Algorithm,
    }
    namespace IFRotationType {
      let RTTI: RTTIDescriptor;
    }
    class AudioAvatarInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public blendShape: FloatVector;
      public rotation: Vector3f;
      public translation: Vector3f;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ApolloFace3DInfoClassInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public ID: number;
      public vertexes: Vec3Vector;
      public normals: Vec3Vector;
      public tangents: Vec4Vector;
      public uvs: Vec2Vector;
      public triangles: UInt16Vector;
      public landmarks3d: Vec3Vector;
      public params: FloatVector;
      public mvp: FloatVector;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum IFFilledType {
      Horizontal,
      Vertical,
      Radial,
    }
    namespace IFFilledType {
      let RTTI: RTTIDescriptor;
    }
    class HeadFittingInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public valid: boolean;
      public ID: number;
      public pupil_dist: number;
      public vertexes: Vec3Vector;
      public normals: Vec3Vector;
      public tangents: Vec3Vector;
      public bitangents: Vec3Vector;
      public uv: Vec2Vector;
      public triangle: UInt16Vector;
      public mvp: Matrix4x4f;
      public modelMatrix: Matrix4x4f;
      public viewMatrix: Matrix4x4f;
      public projectMatrix: Matrix4x4f;
      public landmarks2D: Vec2Vector;
      public project2D: Vec2Vector;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class HandObjectSegInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public width: number;
      public height: number;
      public mask_image: Image;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class SwapperMeFaceInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public points_array: Vec2Vector;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Avatar3DFusionInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public quaternion: QuatVector;
      public root: Vector3f;
      public valid: Int8Vector;
      public detected: boolean;
      public focal_length: number;
      public joints: Vec3Vector;
      public imageWidth: number;
      public imageHeight: number;
      public tracking_id: number;
      public left_hand_prob: number;
      public right_hand_prob: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ForeheadSegInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public face_id: number;
      public mask_width: number;
      public mask_height: number;
      public image_width: number;
      public image_height: number;
      public mvp_matrix: Matrix4x4f;
      public image: Image;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ContentRecommendInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class BachTextureInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public width: number;
      public height: number;
      public texId: number;
      public texture: Texture2D;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class AMGAudioNodePin extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class InteractiveMattingInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public width: number;
      public height: number;
      public left: number;
      public right: number;
      public bottom: number;
      public top: number;
      public alphaMask: Image;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ColorMappingInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public width: number;
      public height: number;
      public lutImage: Image;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class BachImageInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public width: number;
      public height: number;
      public image: Image;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ChromaKeyingInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public width: number;
      public height: number;
      public mask: UInt8Vector;
      public color_r: number;
      public color_g: number;
      public color_b: number;
      public maskImage: Image;
      public color_h: number;
      public keying_similar: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum FaceAction {
      EYE_BLINK,
      HEAD_YAW,
      HEAD_PITCH,
      MOUTH_AH,
      BROW_JUMP,
      MOUTH_POUT,
      EYE_BLINK_LEFT,
      EYE_BLINK_RIGHT,
      SIDE_NOD,
    }
    namespace FaceAction {
      let RTTI: RTTIDescriptor;
    }
    enum AsyncLoadState {
      PENDING,
      LOAD_SUCCESS,
      LOADING,
      CANCELED,
      LOAD_FAIL,
    }
    namespace AsyncLoadState {
      let RTTI: RTTIDescriptor;
    }
    class GraphicsInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public width: number;
      public height: number;
      public data: UInt8Vector;
      public matrix: Matrix4x4f;
      public id: number;
      public image: Image;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum FaceAttrExpression {
      DISGUST,
      HAPPY,
      ANGRY,
      UNKNOWN,
      FEAR,
      SAD,
      SURPRISE,
      NEUTRAL,
    }
    namespace FaceAttrExpression {
      let RTTI: RTTIDescriptor;
    }
    enum FacePetType {
      CAT,
      DOG,
      HUMAN,
      OTHERS,
    }
    namespace FacePetType {
      let RTTI: RTTIDescriptor;
    }
    class ObjectTrackingInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public centerX: number;
      public centerY: number;
      public width: number;
      public height: number;
      public rotateAngle: number;
      public timestamp: number;
      public trackingStatus: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum AlgorithmResultType {
      HAND,
      SCRIPT,
      CAT_FACE,
      SCENE_RECOGNITION,
      FACE_MASK,
      IMAGE_BUFFER,
      AUDIO_AVATAR,
      BYTENN,
      CHROMA_KEYING,
      SKELETON,
      SCENE_RECOG_V3,
      CAR_SEG,
      ENIGMA,
      FACE_NEW_LANDMARK,
      FACE_PET_DETECT,
      INVALID,
      SKIN_SEG,
      FLOWER_MA,
      GAN_IMAGE_ARRAY,
      DEEP_INPAINT,
      BLIT_IMAGE_BUFFER,
      FOREHEAD_SEG,
      FAKE_FACE,
      FACE_ATTR,
      NH_TENSOR_BUFFER,
      FACE_VERIFY,
      PORN_CLS,
      KEY_POINT,
      SWAPPERME,
      MATTING,
      HAIR,
      SKY_SEG,
      OBJECT_DETECT,
      FACE_BEAUTIFY,
      SLAM_NAIL,
      AFTER_EFFECT,
      ARSCAN,
      HAIR_FLOW,
      INPUT_SOURCE,
      NODE_HUB_IMAGE_BUFFER,
      CLOTHES_SEG,
      FACE_PART_BEAUTY,
      AUTO_REFRAME,
      AUDIO_PRODUCER,
      VIDEO_TEMP_REC,
      SKELETON_POSE_3D,
      FOOT,
      GAN_IMAGE_BUFFER,
      FACE_GAN,
      APOLLOFACE3D,
      SCENE_RECOG_V2,
      FACE_FITTING,
      BUILDING_NORMAL,
      TRACKING_AR,
      MV_TEMP_REC,
      SIMILARITY,
      LICENSE_PLATE_DETECT,
      MUG,
      VIDEO_SR,
      SCENE_LIGHT,
      NH_IMAGE_TFM_BUFFER,
      BEAUTY_GAN,
      FIND_CONTOUR,
      FACE_LIGHT,
      FACE,
      ARRAY_BUFFER,
      HAVATAR,
      PICTURE_AR,
      OLD_GAN,
      CAR_SERIES,
      NAVI_AVATAR_DRIVE,
      APOLLO_PROCESS,
      BLIT_TEXTURE,
      DEPTH_ESTIMATION,
      GENDER_GAN,
      VIDEO_MOMENT,
      DYNAMIC_GESTURE,
      BUILDING_SEG,
      UPPERBODY3D,
      NH_MUL_IMAGE_BUFFER,
      HUMAN_PARSING,
      SALIENCY_SEG,
      EAR_SEG,
      NH_IMAGE_WITH_TFM_BUFFER,
      JOINTS1,
      FACE_CLUSTING,
      NECK,
      CLOTH_CLASS,
      AVATAR_DRIVE,
      SCENE_NORMAL,
      FOOD_COMICS,
      GROUND_SEG,
      EYE_FITTING,
      PET_MATTING,
      ACTION_DETECT,
      IDREAM,
      BLING,
      NAIL,
      HEAD_FITTING,
      LAUGH_GAN,
      SWAP_LIVE,
      EFFECTGANRT,
      FEMALE_GAN,
      TEETH,
      VIDEO_CLS,
      AVATAR_3D,
      MANGA,
      KIRA,
      HAND_TV,
      GAZE_ESTIMATION,
      MEMOJI_MATCH,
      RGBD2MESH,
      HDR_NET,
      BLOCKGAN,
      TEXTURE,
      JOINTS2,
      OIL_PAINT,
      CPU_RENDER,
      BIG_GAN,
      HEAD_SEG,
      OBJECT_DETECTION2,
      SALIENT_HUMAN,
      AVACAP,
      ACTION_RECOGNITION,
      INTERACTIVE_MATTING,
      FACE_SMOOTH_CPU,
      INDOOR_SEG,
      SKIN_UNIFIED,
      HAND_OBJECT_SEG_TRACK,
      NH_MODEL_INFO,
      CLOTH_SERIES,
      NH_IMAGE_BUFFER,
      NH_CLASSIFICATION_BUFFER,
      OBJECT_TRACKING,
      MEME_FIT,
      WATCH_TRYON,
      RELATION_RECOG,
      FREID,
      FACE_REENACT,
      FACE_REENACT_KEYPOINT,
      AVATAR3D_FUSION,
      CONTENT_RECOMMEND,
      AUTOFOCUS,
      VIDEO_INPAINTING,
      COLOR_MAPPING,
      CLOTH_GAN,
      F_PARSING,
      AVATAR_SCORE,
      MULTI_OBJECT_TRACKING_AR,
      SENSOR,
      AVATAR_FIT,
      COLOR_TRANSFER,
      VIDEO_SELECT_FRAME,
      CLEANGAN,
      NAVI_FIT,
      STOP_MOTION,
      MEGA,
      LEGO_FIT,
      GENERAL_AR,
      AUTO_DETECTION,
      MOUTH_REENACT,
      MOUTH_REENACT_POST_PROCESS,
      MOBILE_VOS,
      LICENSECAKE_DETECTION,
    }
    namespace AlgorithmResultType {
      let RTTI: RTTIDescriptor;
    }
    class BachMapInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public data: Map;
      public handle: number;
      public get(key: string): Variant;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class JSWrapCVMat extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public rows: number;
      public cols: number;
      public channels: number;
      public step: number;
      public handle: number;
      public toImage(format: PixelFormat, copy: boolean): Image;
      public toTensor(): JSWrapByteNNTensor;
      public convertTo(m: JSWrapCVMat, rtype: number, alpha: number, beta: number): void;
      public mul(m: JSWrapCVMat): JSWrapCVMat;
      public matmul(m: JSWrapCVMat): void;
      public div(m: JSWrapCVMat): void;
      public sub(m: JSWrapCVMat): void;
      public add(m: JSWrapCVMat): void;
      public deepCopy(): JSWrapCVMat;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class AudioClip extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public source: string;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum IFUILabelFitType {
      AutoSize,
      FitWidth,
      FitSize,
    }
    namespace IFUILabelFitType {
      let RTTI: RTTIDescriptor;
    }
    class JSWrapCV extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum IFTweenStyle {
      Once,
      Loop,
      PingPong,
    }
    namespace IFTweenStyle {
      let RTTI: RTTIDescriptor;
    }
    class JSWrapByteNNEngine extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum BEF_RECODE_VEDIO_EVENT_CODE {
      RECODE_VEDIO_NO_INIT,
      RECODE_VEDIO_START,
      RECODE_VEDIO_END,
      RECODE_VEDIO_DELETE,
    }
    namespace BEF_RECODE_VEDIO_EVENT_CODE {
      let RTTI: RTTIDescriptor;
    }
    class JSWrapAlgorithmInfo extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class FaceReshapeParams extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public params: FloatVector;
      public degrees: FloatVector;
      public indices: UInt16Vector;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum FaceReshapeLiquefyType {
      HUMAN,
      DOG,
      CAT,
    }
    namespace FaceReshapeLiquefyType {
      let RTTI: RTTIDescriptor;
    }
    enum FaceReshapeLiquefyPetMeshType {
      MULTI_MESH,
      FIXED_MESH,
      NONE_MESH,
    }
    namespace FaceReshapeLiquefyPetMeshType {
      let RTTI: RTTIDescriptor;
    }
    class FaceReshapeLiquefyPetParams extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public leftEarInterpData: Int16Vector;
      public rightEarInterpData: Int16Vector;
      public faceInterpData: Int16Vector;
      public leftEarIndicesData: UInt16Vector;
      public reftEarIndicesData: UInt16Vector;
      public faceIndicesData: UInt16Vector;
      public intensities: FloatVector;
      public liquefyParams: FloatVector;
      public useFaceMask: boolean;
      public useLeftEarMask: boolean;
      public useRightEarMask: boolean;
      public onlyStandEarValid: boolean;
      public meshType: FaceReshapeLiquefyPetMeshType;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum LiquefyBrushType {
      MOVE,
      ERASE,
    }
    namespace LiquefyBrushType {
      let RTTI: RTTIDescriptor;
    }
    enum TouchSampleType {
      TOUCH_SAMPLE_ALL,
      TOUCH_SAMPLE_NEAREST,
      TOUCH_SAMPLE_UNIFORM,
    }
    namespace TouchSampleType {
      let RTTI: RTTIDescriptor;
    }
    class NHClassificationInfoInterface extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public numClasses: number;
      public handle: number;
      public getId(idx: number): number;
      public getConfidence(idx: number): number;
      public exceedThresh(idx: number): boolean;
      public getLabel(id: number): string;
      public getThresh(id: number): number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class AMGFaceMeshUtils extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public setMesh(_mesh: Mesh, _type: AMGBeautyMeshType, _posAttrStart: number, _posAttrSize: number): void;
      public updateMeshWithFaceData106(_type: AMGBeautyMeshType, _basePoints: Vec2Vector, _faceIndex: number): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ActionCallResult extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public eventType: BEFEventType;
      public actionType: string;
      public entityName: string;
      public animClipName: string;
      public action: string;
      public isLoop: boolean;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ActionController extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class RotateAction extends BaseAction {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class TranslateAction extends BaseAction {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class BaseAction extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ARTrackedPlaneAnchor extends ARTrackedAnchor {
      constructor();
      public assetMgr: AssetManager;
      public anchorType: AnchorType;
      public handle: number;
      public getCenter(): Vector3f;
      public getExtent(): Vector3f;
      public getAlignment(): void;
      public getNormal(): Vector3f;
      public getPlaneClassification(): void;
      public getPlaneClassificationStatus(): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class ARTrackedAnchor extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public anchorType: AnchorType;
      public handle: number;
      public getMesh(): Mesh;
      public getTransform(): Matrix4x4f;
      public getAnchorGuid(): string;
      public setTransform(arg0: Matrix4x4f): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class AMGARRaycastResult extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public getWorldTransform(): Matrix4x4f;
      public getRaycastTarget(): void;
      public getRaycastAlignment(): void;
      public getAnchor(): ARTrackedAnchor;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class AMGRaycastQuery extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public origin: Vector3f;
      public direction: Vector3f;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class AMGARHitTestResultTask extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public getLocalToWorldTransform(): Matrix4x4f;
      public getTrackedAnchor(): ARTrackedAnchor;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class HistoryStack extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public push(element: Variant): void;
      public undo(): Variant;
      public redo(): Variant;
      public getUndoCount(): number;
      public getRedoCount(): number;
      public clearRedo(): void;
      public clearAll(): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Brush2DParam extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public value: number;
      public min: number;
      public max: number;
      public jitter: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Brush2DSmoother extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Brush2DInterpolator extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class Sprite extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public textureAtlases: Vector;
      public frameIndex: number;
      public renderMode: CanvasRenderMode;
      public isAtlasCached: boolean;
      public preLoadedCount: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class EffectReadyResult extends AlgorithmResultEvent {
      constructor();
      public assetMgr: AssetManager;
      public eventType: BEFEventType;
      public type: string;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class HandGestureResult extends AlgorithmResultEvent {
      constructor();
      public assetMgr: AssetManager;
      public eventType: BEFEventType;
      public handIndex: number;
      public handAction: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class HandInfoResult extends AlgorithmResultEvent {
      constructor();
      public assetMgr: AssetManager;
      public eventType: BEFEventType;
      public handle: number;
      public getHandKeyPoint(hand_index: number, point_index: number): HandKeyPoint;
      public getHandExtensionPoints(hand_index: number, point_index: number): HandKeyPoint;
      public getHandRect(hand_index: number): BEFRect;
      public getHandCount(): number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class NewPlaneResult extends AlgorithmResultEvent {
      constructor();
      public assetMgr: AssetManager;
      public eventType: BEFEventType;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class HitEmptyPlaneResult extends AlgorithmResultEvent {
      constructor();
      public assetMgr: AssetManager;
      public eventType: BEFEventType;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class FaceActionResult extends AlgorithmResultEvent {
      constructor();
      public assetMgr: AssetManager;
      public eventType: BEFEventType;
      public faceIndex: number;
      public faceAction: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class RecodeVideoResult extends AlgorithmResultEvent {
      constructor();
      public assetMgr: AssetManager;
      public eventType: BEFEventType;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class AlgorithmResultEvent extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public eventType: BEFEventType;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class BEFRect extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public left: number;
      public top: number;
      public right: number;
      public bottom: number;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class DownloadTask extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public status: JsDownloadStatus;
      public success: boolean;
      public errCode: number;
      public errString: string;
      public handle: number;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class GestureRecognizer extends AObject {
      constructor();
      public assetMgr: AssetManager;
      public gestureName: string;
      public userData: Map;
      public state: GestureRecognizerState;
      public handle: number;
      public implement(script: AObject, callback: string): void;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    class AObject {
      constructor();
      public assetMgr: AssetManager;
      public handle: number;
      public isInstanceOf(name: string): boolean;
      public onLoadEnd(): void;
      public clone(): AObject;
      public eq(obj: AObject): boolean;
      public equals(obj: AObject): boolean;
    }
    enum DeformationType {
      ARAP,
      LaplacianAdvanced,
    }
    namespace DeformationType {
      let RTTI: RTTIDescriptor;
    }
    enum ControlMode {
      FACE,
      TONGUE,
      EYE,
    }
    namespace ControlMode {
      let RTTI: RTTIDescriptor;
    }
    enum Face3DMeshType {
      FACE,
      HEAD,
    }
    namespace Face3DMeshType {
      let RTTI: RTTIDescriptor;
    }
    enum BEFEventType {
      BET_BASE,
      BET_ANIMATION,
      BET_BASE_FACE_ATTRIBUTE,
      BET_BASE_FACE_DETECT,
      BET_EXCLUSIVE,
      BET_BASE_HAND_GESTURE,
      BET_EFFECT_COMPAT,
      BET_POINT2DTRANS,
      BET_FEATURE,
      BET_EFFECT,
      BET_USER,
      BET_BASE_HAND_INFO,
      BET_TIMER,
      BET_ACTION_DETECT,
      BET_COMPOSER,
      BET_TOUCH,
      BET_RECORD_VIDEO,
      BET_CAMERA_SWITCHED,
    }
    namespace BEFEventType {
      let RTTI: RTTIDescriptor;
    }
    enum IFBlendMode {
      Normal,
      Negation,
      Vividlight,
      Phoenix,
      Glow,
      Dodge,
      Difference,
      Burn,
      Reflect,
      Hardmix,
      Exclusion,
      Lineardodge,
      Darken,
      Multiply,
      Hardlight,
      Average,
      Add,
      Screen,
      Linearburn,
      Linearlight,
      Overlay,
      Pinlight,
      Lighten,
      Softlight,
      Substract,
      Snowcolor,
      Snowhue,
      EndFlag,
    }
    namespace IFBlendMode {
      let RTTI: RTTIDescriptor;
    }
    enum ARPlaneDetectionMode {
      None,
      HorizontalPlaneDetection,
      AnyPlaneDetection,
      VerticalPlaneDetection,
    }
    namespace ARPlaneDetectionMode {
      let RTTI: RTTIDescriptor;
    }
    enum AREnvironmentCaptureProbeType {
      None,
      Manual,
      Automatic,
    }
    namespace AREnvironmentCaptureProbeType {
      let RTTI: RTTIDescriptor;
    }
    enum ARSceneReconstructionMode {
      None,
      Mesh,
      MeshWithClassification,
    }
    namespace ARSceneReconstructionMode {
      let RTTI: RTTIDescriptor;
    }
    enum AnchorType {
      None,
      Face,
      Plane,
      Point,
      Camera,
      EnvionmentProbe,
      Mesh,
    }
    namespace AnchorType {
      let RTTI: RTTIDescriptor;
    }
    enum BEF_ANIMATION_EVENT_CODE {
      ANIMATION_START,
      ANIMATION_END,
      ANIMATION_INTERRUPT,
    }
    namespace BEF_ANIMATION_EVENT_CODE {
      let RTTI: RTTIDescriptor;
    }
    enum BEF_AR_ACTION_CODE {
      ACTION_TRANSLATE,
      ACTION_INTERRUPT,
      ACTION_ROTATE_RIGHT,
      ACTION_END,
      ACTION_ROTATE_LEFT,
      ACTION_CLICK,
    }
    namespace BEF_AR_ACTION_CODE {
      let RTTI: RTTIDescriptor;
    }
    enum BEFEventCode {
      BEC_TOUCH_BEGAN,
      BEC_TOUCH_MOVED,
      BEC_TOUCH_CANCELLED,
      BEC_TOUCH_ENDED,
    }
    namespace BEFEventCode {
      let RTTI: RTTIDescriptor;
    }
    enum FeatureType {
      FT_NONE,
      FT_3DV3,
      FT_2DV3,
    }
    namespace FeatureType {
      let RTTI: RTTIDescriptor;
    }
    enum MemojiOperateType {
      ADJUST,
    }
    namespace MemojiOperateType {
      let RTTI: RTTIDescriptor;
    }
    enum Brush2DPaintMode {
      Paint,
      Eraser,
      Animation,
    }
    namespace Brush2DPaintMode {
      let RTTI: RTTIDescriptor;
    }
    enum Brush2DCurveType {
      Polyline,
      Subdivision,
      Hermite,
      QuadBezier,
      CubicBezier,
    }
    namespace Brush2DCurveType {
      let RTTI: RTTIDescriptor;
    }
    enum Brush2DHistoryMode {
      NoHistory,
      UndoRedo,
      OnlyUndo,
    }
    namespace Brush2DHistoryMode {
      let RTTI: RTTIDescriptor;
    }
    enum Brush2DDirtyFlag {
      Unchanged,
      Increase,
      Undo,
      Redo,
      Cache,
    }
    namespace Brush2DDirtyFlag {
      let RTTI: RTTIDescriptor;
    }
    enum Brush2DListener {
      MATERIAL_DIRTY,
      PROPERTIES_DIRTY,
    }
    namespace Brush2DListener {
      let RTTI: RTTIDescriptor;
    }
    enum IFUIGridResizeMode {
      NONE,
      CHILDREN,
      CONTAINER,
    }
    namespace IFUIGridResizeMode {
      let RTTI: RTTIDescriptor;
    }
    enum IFResolutionType {
      Origin,
      FitHeight,
      FitWidth,
      Fit,
      Fill,
    }
    namespace IFResolutionType {
      let RTTI: RTTIDescriptor;
    }
    enum IFTweenCurveType {
      QuadIn,
      CubicOut,
      CircInOut,
      SineIn,
      CircIn,
      ElasticIn,
      BounceInOut,
      QuadOut,
      QuartOut,
      BackIn,
      BackOut,
      QuadInOut,
      CubicInOut,
      Linear,
      QuartIn,
      CubicIn,
      SineOut,
      SineInOut,
      ElasticInOut,
      QuartInOut,
      CircOut,
      BackInOut,
      ElasticOut,
      BounceIn,
      BounceOut,
    }
    namespace IFTweenCurveType {
      let RTTI: RTTIDescriptor;
    }
    enum IFTweenControlMode {
      PosXY,
      PosX,
      PosY,
    }
    namespace IFTweenControlMode {
      let RTTI: RTTIDescriptor;
    }
    enum IFSprite2dType {
      Normal,
      Tiled,
      Ellipse,
      Sliced,
      Filled,
      Grid,
      Free,
      Corner,
      Outline,
    }
    namespace IFSprite2dType {
      let RTTI: RTTIDescriptor;
    }
    enum IFAnchorAlignmentType {
      AlignOneAnchor,
      AlignTwoAnchor,
      AlignThreeAnchor,
      AlignFourAnchor,
    }
    namespace IFAnchorAlignmentType {
      let RTTI: RTTIDescriptor;
    }
    enum IFGenderType {
      None,
      Man,
      Woman,
    }
    namespace IFGenderType {
      let RTTI: RTTIDescriptor;
    }
    enum IFObjectType {
      Red,
      Dumplings,
      Feast,
    }
    namespace IFObjectType {
      let RTTI: RTTIDescriptor;
    }
    enum IFUIControlTouchType {
      TouchDown,
      TouchDownRepeat,
      DragOutside,
      TouchUpOutside,
      DragInside,
      DragEnter,
      DragExit,
      TouchUpInside,
      TouchCancel,
    }
    namespace IFUIControlTouchType {
      let RTTI: RTTIDescriptor;
    }
    enum IFUITabState {
      SELECTED,
      UNSELECTED,
    }
    namespace IFUITabState {
      let RTTI: RTTIDescriptor;
    }
    enum IFUIScrollDirection {
      Horizontal,
      Vertical,
      Both,
    }
    namespace IFUIScrollDirection {
      let RTTI: RTTIDescriptor;
    }
    enum IFUIGridStartAxis {
      HORIZONTAL,
      VERTICAL,
    }
    namespace IFUIGridStartAxis {
      let RTTI: RTTIDescriptor;
    }
    enum IFUIGridVerticalDirection {
      TOP_TO_BOTTOM,
      BOTTOM_TO_TOP,
    }
    namespace IFUIGridVerticalDirection {
      let RTTI: RTTIDescriptor;
    }
    enum IFUIConstraintsMode {
      Basic,
      Advanced,
    }
    namespace IFUIConstraintsMode {
      let RTTI: RTTIDescriptor;
    }
    enum IFUIConstraintsExecute {
      Once,
      Update,
    }
    namespace IFUIConstraintsExecute {
      let RTTI: RTTIDescriptor;
    }
    enum IFUISafeAreaType {
      Device,
      UI,
    }
    namespace IFUISafeAreaType {
      let RTTI: RTTIDescriptor;
    }
    enum SpriteType {
      QUAD,
      RECTANGLE,
      POLYGON,
      CIRCLE,
      SQUARE,
    }
    namespace SpriteType {
      let RTTI: RTTIDescriptor;
    }
    enum CanvasRenderMode {
      SCREEN_SPACE_OVERLAY,
      SCREEN_SPACE_CAMERA,
      WORLD_SPACE,
    }
    namespace CanvasRenderMode {
      let RTTI: RTTIDescriptor;
    }
    enum ModuleEventType {
      ADD_MODULE,
      ADD_MODULE_TRANSACTION_END,
      REMOVE_MODULE,
      ADD_PREFAB,
      REMOVE_PREFAB,
    }
    namespace ModuleEventType {
      let RTTI: RTTIDescriptor;
    }
    enum JsTaskStatus {
      INIT,
      WAITING,
      FINISHED,
      RUNNIG,
      CANCELED,
    }
    namespace JsTaskStatus {
      let RTTI: RTTIDescriptor;
    }
    enum GestureSystemListenerType {
      OnTouchGesture,
    }
    namespace GestureSystemListenerType {
      let RTTI: RTTIDescriptor;
    }
    enum FaceMakeUpType {
      EYE,
      FACE3D,
      FACE2D,
      FACE3D_LANDMARK,
      EYELASH,
      PUPIL,
    }
    namespace FaceMakeUpType {
      let RTTI: RTTIDescriptor;
    }
  }
}